(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3355357,     321110]*)
(*NotebookOutlinePosition[   3356955,     321160]*)
(*  CellTagsIndexPosition[   3356865,     321154]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Biomorphs", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Christian Jacob, jacob@cpsc.ucalgary.ca \[Dash] August 1997 (copyright)"], 
  "Subsubtitle"],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Two-dimensional sketch figures, known as ",
  StyleBox["biomorphs",
    FontSlant->"Italic"],
  ", have been introduced by Richard Dawkins in order to demonstrate the \
creative potential of simple selection-mutation mechanisms (",
  ButtonBox["Dawkins 1986",
    ButtonData:>{":::References.nb", "Dawkins 1986"},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["Dawkins 1996",
    ButtonData:>{":::References.nb", "Dawkins 1996"},
    ButtonStyle->"Hyperlink"],
  "). Tree-like, recursively constructed figures are described by a vector of \
21 parameters (Figure 1), where, e.g., the first one gives the recursion \
depth, and all following numbers describe the colour, thickness, and length \
of each arch, as well as its branching angle and the number of branches. \
There is a section of these five parameters for each recursion depth."
}], "Text"],

Cell[TextData[{
  " \n",
  Cell[GraphicsData["PICT", "\<\
10H0@@0j0<L1:P0A0_l<0?ooool0>P000440004Z0000a`000000000N01[>S<j<
cX`00@0:0440>@370BX0=01503d0F`4U0300A00l05`19P0J0000000000X00000
0000000d04P0e`1G0>H0<0180=L0F03W03@0B03V05L0m@0`04P0iP1H0?H0=018
0?D0E`440300B03e05P11@0d04P1101G0A<0<0180@@0F04D03@0B04C05L18P0`
04P14`1H0B<0=01806L0E`1f0300B01V05P0MP0d04P0MP1G08D0<01807D0F025
03@0B02505L0U00`04P0Q01H09@0=01809@0E`2S0300B02C05P0X`0d04P0F01G
06L0<01805L0F01W03@0B01105L0D00`04P0@@1H05402_oooooooooo07@07P1O
09P0I02N06@0V01O09/0I02N06@0V`1T09P0L00F06@0V`1^0:X0I02K06h0V`1^
0:X0M00N05l0R@1T08l0I02905l0S01T08l0I02<06@0R@1`01H0I02<07d0ZP1T
08`0O@2<07d0ZP1d01h0G`1j06@0P01T07X0G`1m06@0P01T07d0I01j07005P1T
07d0S02Z06@0O@2<07d0S02Z07@07P1O06/0I01a06@0J`1O06h0I01a06@0KP1T
06/0L00F06@0KP2K0:X0I01^09/0KP2K0:X0M00N05l0G01T0680I01L05l0G`1T
0680I01O06@0G01`01H0I01O0:X0ZP1T05l0ZP1O0:X0ZP1d01h0G`1606@0C01T
04H0G`1906@0C01T04T0I01607005P1T04T0`02Z06@0B@3004T0`02Z02`0300E
2DQUK7IUM6USH@0301D03@0:00KoojeP02h0100000405HB402^iK`e2LV5^HfPP
Hfm/KgEb00H0000002h010000@405HB402X?449bHFiSJ21dJ6USJfiULg<05HB4
02X?3D9bHFiSJ21/IFiWM6P000KoonRP02h0100000405HB402X?349bHFiSJ21Q
KVM/I@06oomH@00EQ8@0:Pl>@W9QKV=X86ieKF9ULW<01P000000;P0400010@0E
Q8@0:QH?DVESMG9cJFm^86AUL7AX000E?Ed0:01E04H1<@0E_DP0:AH1<P005Kdj
02T?0C<001Fm;00Y3`4d000E_Ah0:@l1=@005Kd@02T?0CH001Ee@@0Y@@8a=`0E
MC<0:@l2<CP05GDU02T?0S4i01Ee5`0Y3`8b<00EM@T0:@l2<S401P00LR00;P04
00000@0EFMl0:01A0;D5;R0^82h0o`\>"], "Graphics",
    ImageSize->{240, 134},
    ImageMargins->{{0, 0}, {0, 0}},
    ImageRegion->{{0, 1}, {0, 1}}],
  "\n"
}], "Text",
  TextAlignment->-0.5,
  TextJustification->0],

Cell[TextData[StyleBox["Encoding scheme for a biomorph figure",
  FontWeight->"Plain"]], "NumberedFigure",
  TextAlignment->Left,
  TextJustification->0],

Cell["\<\
Starting from an initial population of randomly generated biomorph \
vectors, we get structures similar to those shown in Figure 2 (Gen. 0). If we \
select one of those biomorphs which we like most for some reason or another \
as, for instance, the one shown left to the first population, and \
subsequently generate slightly mutated versions of this dedicated \
breeder\.b4s genotype, we arrive at yet another population of biomorphs, the \
next generation (not shown in Figure 2). Continuing this selection-mutation \
interaction, we are finally able to create quite complex looking structures, \
as compared to the samples we started with (Figure 2, Gen. 18).\
\>", "Text"],

Cell[" ", "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["PICT", "\<\
8Rh1``2D0Q/1^00A0_l<0?ooool0U0000L<0006h00026`000000000N00402P72
09<26`6i00X000000000000d0L<0j@8I0KL00@0:0L<0j@8I0KL0V8420000001/
0@800000000000180000B0000000200100P000000<AiJ000000001X;0000o`00
oooooooo007oooooc<`00_oloobZZ003ooooofIV00@g8cLS=b<01GHVMRIf9P06
]BZe:[DZ00Od;_@^m2h02000oobZZ009>a<k4c/C00Yj5gXGNQL02kTJ^AZi6P0<
n1kh7_PN00d00?oloo`03UEDoocoo00?ZZSoo?ol013ooiVI<c<04OooVIT0000B
oomVI_oo01?oofIVc<`053/C>a<k4`0ENQMj5gXG01Ji6[TJ^AX05oPNn1kh7P0H
003oo?ol01To0cl3?`<06Wh7OPMn1`0K_@^m2kd;01cl3_`>o0h07EED0000000N
ZZP0000001ooo00000008?oo002IV@0Qool006IV02;oo`00<c<08ooo0000000T
?`<o0cl302En1gh7OPL09[d;_@^m2`0Wo0kl3_`>02P3l0?`0o00:D;c@_=2l`0Z
PON1mh7g02_0nl3k`?/0;000001EE00]EE@005ED02jZZ000EE@0;ool001EE00`
c<bIVOoo037<c9VIc<`0</c<VIVIV@0c0o03l0?`03A2ld;c@_<0=H7gPON1m`0f
`?_0nl3k03L00000EE@0>0OP1n07h00iA^A6i4KT03Z5ihGWQNL0>lC[a>_4j`0l
00000:ZX03eEE000ZZP0?ZZX002ZZ00ooo`00:ZX043<c3<c<c<0@Lc<<c<00012
c<`00?oo04<7h0OP1n00A4KTA^A6i015QNN5ihGW04K4jlC[a>/0A`00002ZZ018
2m0;d0_@04U:e4[DB]@0BXWHRMR9f01;b=_8flSK04`00000oo`0CEED003oo01>
ZZP00?ol04ooo000oo`0D9VIc<bIV@1AVIW<c6IV05:IVLc<<c<0D`_@2m0;d01D
B]A:e4[D05F9f8WHRMP0E/SKb=_8f`1G00000?ol05P?`0o03l00FDk4C/A>a01J
SLR=b8g805_<c<c<c<`0G000EE@0001MEEAEE00005jZZ5ED0000GoolEE@0001P
VITc<ooo066IVC<cc<`0HYVI<c>IV@1S3l0?`0o006A>a4k4C/@0IHg8SLR=b01V
c<c<c<c<06L005ED0000J1>a4k4C/@1YD[AB]5:d06ZA^96hTKP0Jm2ld;c@_01/
001EE5ED06eEE5EDEE@0KZZXEEAEE01_ooaEE5ED071VI_oo<c<0LFIVool0001b
IVK<c?oo07<C/A>a4k40M5:dD[AB]01eTKRA^96h07K@_=2ld;`0M`00EEAEE01h
5j4GXANQ07UFYEJUEZD0NYFXUJREZ01ke:cD[=B/07`005EDZZP0OEEDEEBZZ01n
ZZQEE:ZX07ooo5EDZZP0P6IVIVJIV@21IVIVIVIV089VIVIV<c<0PaNQ5j4GX@24
EZEFYEJU08FEZ9FXUJP0Q]B/e:cD[027001EE:ZX08PKTA^A6i40REZEFYEJU@2:
VIVIVIVI08_HW=RLf9`0S000EECoo02=EEAEE?ol08jZZ5EDoo`0SoolEECoo02@
<c?ooooo094c<oooc<`0TS<coonIV@2C6i4KTA^A09AJUEZEFYD0UIVIVIVIV@2F
f9cHW=RL09L005EDoo`0V1n17h4OP@2IGXENQEj509ZMRIf9WHT0Vmb<g8cLS02L
002ZZ00009eEE:ZX0000WZZXZZP0002OoobZZ0000:0c<iVI<c<0XC<cVIT0002R
<c=VI_oo0:<OPAn17h40Y5j5GXENQ@2UWHVMRIf90:KLS=b<g8`0Y`00ZZP0002X
8g8SLR=b0:URMF9eHWD0ZZ5iXGVQN@2[h7gPON1m0:`00:ZXEE@0[EEDZZQEE02^
ZZRZZ5ED0:ooo:ZXEE@0/3<c002IV@2a<c<006IV0;8c<`00<c<0/b=b8g8SLP2d
HWERMF9e0;FQNJ5iXGT0]^1mh7gPO@2g002ZZ5ED0;PWHRMR9f80^FIVIVIVIP2j
YFVUJJEY0;_TKNA]i6d0_000ZZRZZ02mEEBZZ:ZX0;jZZ:ZXZZP0_oolZZRZZ030
002IVOoo0<4009VIc<`0`P00VIVIV@339f8WHRMR0<AVIVIVIVH0aJEYYFVUJ@36
i6gTKNA]0<L00:ZXZZP0b2]B:e8[DP39JUIZEVYF0<ZYFJUIZET0bnQMj5gXG@3<
002ZZ?ol0<eEE:ZXoo`0cZZXZZSoo03?oobZZ?ol0=0003<c<c<0d@00<c<0003B
00000?oo0=<[DR]B:e80e6YFJUIZEP3EZEVYFJUI0=KXGNQMj5d0e`00ZZSoo03H
;d8_@Rm20=U^AVi6KTH0fZe:[DZ]BP3Kk4g/CNa=0=`00?ol0000gEEDoo`0003N
ZZSoo0000=ooo?ol0000h14A0000003Q003^kP000>800=gM0000hbm2;d8_@P3T
KTI^AVi60>F]BZe:[DX0i^a=k4g/C@3W003oo0000>Pc<c<c<c<0jG8fLSIb=P3Z
/CZa>[4j0>_`?_0nl3h0k000ooaEE03]EECoo5ED0>jZZ?olEE@0koolooaEE03`
000007Mg0?400000EED0lP000014A03c<c<c<c<c0?Ab=W8fLSH0mK4j/CZa>P3f
l3k`?_0n0?L00?olEE@0n3LS=b<g8`3iMRIf9WHV0?Ze:[DZ]BX0no@^m2kd;P3l
003oo:ZX0?eEE?olZZP0oZZXoobZZ03o000000000000001/0@81``3Y0QT1]`0T
00J10840o`001X40P@3o0006P@210?l000J10840o`001X40P@3o000<P@2P002<
l000S?<000b10:0008c`002<l`003840W`00S?8008cb000<P@2O001=lP00CO80
00b109l004cb001<lP003840WP00CO@004ga000<P@2N001<m000C?4003;:002<
n`00S>d008c]002<l@00S?<008c^002<l`00S>h008cc002<k@00CO@004ga000n
l`00C?0004cZ002<o@00S>/00Ha<l@01C8c_006<C?L00Db<k000S?D008c/002<
m@00S>/004cf001<l000>o8004gb001=j003C@00CNP00De=m@01CDg[001=n@00
CNT004gg001=jP00COL004gZ001=mP00CO0003Wa001<m000C>H00Da<i@01C4ci
005<C>P004ck001<i`00C?T004cX001<n@00C>T004cf001<l000C?000Df<n001
S4g_002<n001CDgh002<m`00S?P00De=o@01CDgh002<k`05CDd004e=i@00CO/0
04gV001=n`00CNL004gh001=k`00B>h004cj001<k001S4cj005<C?X00Db<m@00
S?a<o03mC?`0o4`0S>`00Da<hP05C4`004a<i005C4`004a<iP00C?P004c_000k
k@00CO`004gY0?i=oP03C@00COh0oTg]0?a=0a5=CA7lCNH00De=h001CDgP005=
CN@004gh001=k`00E^`014a<04a<i@3nC?d0oTcU00<A000AkP01S8chC0DAC000
C17hC06<S?X00Hb<md`34Da<4OM<0Hb<nP01S8cgC0?OC4cOmd`1S8c`001<nP00
C>h004?h0?a=08cjC@8ACA7jC@2<o4g`00M=04dACDd0CN@00Q404N80017n000A
hP034@004N800mh00=kT001=nP00CNh003C[008A017S00<A000AoP004N@00Q40
4N400a40017R008A017Q00;O0=oS001<nP00C>h003;Z000Ai@3nC@L04@0A000A
0?i=iP014A7Q008A017P004A4N000MkNhP00CO`004g]000ajP004NP0oTcl00<A
4@0Ao03nC>T0017P008A017P004A4N000MoOhP004O`0017]000ajP004N`00hb<
CDgh004A4OP00de=S8c]000Ag`004Ml0017O003Nh@004O`0017]000Na`004Ml0
017O000Ag`004Ml00=oP000AoP004N`000b109T0017n000Ak0003840V@004Oh0
017/000:P@2H008A017[000:P@2H008A017[000:P@2H008A017[0008P@2G000A
jP002840U`004NX000J10840o`001X40P@3o0006P@210?l000J10840o`001X40
P@3o0006P@210?l000J10840o`001X40P@3o0006P@210?l000J10840o`001X40
P@3o0006P@210?l000J10840o`003840i000S?D008bZ000fc`00S?4008c_002<
l`00S>h008cc002<k@02S02<n@02S02<k@00S?<008c^002<lP00S?8003cc002<
l000S>l008cc002<k@00S?D008c/002<m@00S>`00Hb<m`01S8c/002<m@00S>`0
08cd002<l@00A?800Ha<m001C8c]001<m@00C>/004cg001<jP00@_L004;]00:<
S4cnS?/0oX`2C8b<k@00C?L004cZ001<mP00C?00043`005=COP00De=jP00COL0
04gY001=n@00CNP004;i0012j`02S01=m`02C@2<j`00COT004gX001=n000CNl0
04K^0?i<oP3nC>L00Da<n`01C4cW001<n`00C>H004;k0012jP04S000C4ck00A<
C000S>X004ck001<iP01C4cl005<C>h004;[0?i=hP05CDd004e=i005CDd004e=
i005@T800492kP00S?P004gm001=n000S>h01De=001=CN<014e=04e=k000<nd0
1d`AC01<4Da<h`01C4cP005<C>000D92k@01S8cg0?e<m`01S8c]005<C=l004cZ
001hlP3lC@404Oh00Q400?a=m@01S8cgC@<ACDdAmdd1S8cj006<S?M=0a5=CA7g
C@6<S?X00Hb<md834D924OM20Hb<n@03S000S?T00De=n@03S8`0S?T00Hb<mdd3
4De=4OM=0Hb<nP3nS?Q=115=04dAn4gnS?P004Oh006<S?e<nP024@0An@3nC06<
S>h00a40017R00<A000AhP034@004Nd0md`54D`004`Amdc]00<A000AhP004Oh0
017/000jj`024@0Ah@024@0Ah@024@0Ah@024@0Ak@04S8`0S8ck000AoP004OX0
o8c^008A017P008A017[000cj`024@0Ah0014A7P004A4N000A4Ak@01S8cg00<A
000Am`01S8c]004A4N000Q404N/002KZ000Ag`014A7P004A4N000A4Ah@024@0A
h0014A7P008A017[000PjP004Ml0017O000Ag`004N000Q404N00017N000AjP00
6/L0017O000Ag`004Ml0017O000AgP004NX000R10=h0016S0006P@210?l000J1
0840o`001X40P@3o0006P@210?l000J10840o`001X40P@3o0006P@210?l000J1
0840o`001X40P@3o0006P@210?l000J10840o`001X40P@3o0006P@210?l000J1
0840o`001X40P@3o0006P@210?l000J10840o`001X40P@3o0006P@210?l000J1
0840o`00>_8008cb002<kP00CO<004g^002<l`00S>h008cc002<kP00S?<008c^
002<l`00S>h008cb002<lP00?_400Ha<mP01C8c/001<m@00C>`008ce002<k000
S?D008c/002<m@00S>`008ce002<k001S4cf005<S?4003[_001=n000CNT004gg
001=jP00COL004gZ001=m`00CNX004gg001=jP00COL004gY001=n000CNl003[^
001<nP00C>L004ci001<j000C?T004cX001<n@00C>P004ci001<j000C?T004cW
001<nP00C>h003k]005=COh00De=i@00CO/004gV001=n`00CNH004gk001=iP00
CO/004gV001=n`00CND00De=oP01CDg]000kj`02C01<hP05C4`004a<i005C4`0
04a<i005C4`004a<i005C4`004a<i005C4`004a<hP02C01<j`008nX004gO005=
CN000De=h001CDgP005=CN000De=g`00CNX007Gh006<S?M<115<04`Amd`1S8cj
0?E<0a5<C17eC?X00Hb<md`34Da<4OM<0Hb<nP01S8cgC0<AC4`Amd`1S8cj006<
S?M<0a5<C17gC06<S?X00Hb<md`34Da<4OM<0Hb<nP01S8cgC0@AC01<4OM<0Hb<
n000=N`0017n000AhP034@004N800a40017R00<A000AhP034@004N800a40017R
000AoP004N`002c[008A017Q008A017Q008A017Q008A017Q008A017Q008A017P
008A017[000Wj`024@0Ah0014A7P004A4N000A4Ah0014A7P004A4N000Q404N/0
02O[008A017P004A4N000A4Ah0014A7P004A4N000A4Ah0024@0Aj`007^X0017O
000Ag`004Ml0017O000Ag`004Mh0017Z000NjP004Ml0017O000Ag`004Ml0017O
000AgP004NX000J10840o`001X40P@3o0006P@210?l000J10840o`001X40P@3o
0006P@210?l000J10840o`001X40P@3o0006P@210?l000J10840o`001X40P@3o
0007P@210040000100X1`P2C0Q/1^@0`0L<0j08J0KL0=07M09@2003M00402P7M
09@2003M09R0lP000000M@3a000000000000B00004P0000000P00@0800000034
NF@00000000J30000?l00?ooooooo`01ooooolc<00;oo?olZZP00ooooomVIP04
=b<g8cLS00Ef9WHVMRH01[DZ]BZe:P07m2kd;_@^00P00?olZZP02C/C>a<k4`0:
NQMj5gXG00^i6[TJ^AX03?PNn1kh7P0=003oo?ol00iEE?oloo`03jZXoocoo00@
oonIVC<c017ooiVI00004_ooIVKoo`0CoomVI/c<01@k4c/C>a<05GXGNQMj5`0F
^AZi6[TJ01Oh7_PNn1h06000oocoo00I?`<o0cl301Yn1gh7OPL06kd;_@^m2`0L
o0kl3_`>01eEE00000007ZZX0000000Ooo`00000023oo`00VIT08Ooo001VIP0R
ool003<c02?oo`00000093l3?`<o0`0UOPMn1gh702Jm2kd;_@/09o`>o0kl3P0X
0o03l0?`02U2ld;c@_<0:X7gPON1m`0[`?_0nl3k02`00000EE@0;EED001EE00^
ZZP005ED02ooo000EE@0<<c<VIWoo`0ac<bIVLc<03;<c9VIVIT0<`?`0o03l00d
@_=2ld;c03F1mh7gPOL0=/3k`?_0n`0g000005ED03P7h0OP1n00>DKTA^A6i00j
QNN5ihGW03_4jlC[a>/0?000002ZZ00mEE@00:ZX03jZZ000ZZP0?ool002ZZ010
c<`c<c<c047<c3<c0000@/c<003oo`131n07h0OP04A6i4KTA^@0AHGWQNN5i`16
a>_4jlC[04L00000ZZP0B0_@2m0;d019B]A:e4[D04Z9f8WHRMP0BlSKb=_8f`1<
00000?ol04eEE000oo`0CZZX003oo01?oo`00?ol052IVLc<VIT0DIVIc<aVIP1B
VIW<c3<c05<;d0_@2m00E4[DB]A:e01ERMR9f8WH05K8flSKb=/0E`00003oo01H
3l0?`0o005U>a4k4C/@0FXg8SLR=b01Kc<c<c<c<05`005ED0000GEEDEE@0001N
ZZQEE00005ooo5ED0000H9VI<c?oo`1QVITc<lc<06:IVC<cVIT0H`o03l0?`01T
C/A>a4k406F=b8g8SLP0I/c<c<c<c01W001EE00006PC/A>a4k40JE:dD[AB]01Z
TKRA^96h06_@_=2ld;`0K000EEAEE01]EEAEE5ED06jZZ5EDEE@0KoolEEAEE01`
IVKooc<c075VI_oo0000LVIVc<coo`1c4k4C/A>a07AB]5:dD[@0MI6hTKRA^01f
d;c@_=2l07L005EDEE@0N1NQ5j4GX@1iEZEFYEJU07ZEZ9FXUJP0NmB/e:cD[01l
001EE:ZX07eEE5EDZZP0OZZXEEBZZ01oooaEE:ZX081VIVIVVIT0PFIVIVIVIP22
IVIVIS<c08<GXANQ5j40Q5JUEZEFY@25UJREZ9FX08KD[=B/e:`0Q`00EEBZZ028
6i4KTA^A08UJUEZEFYD0RYVIVIVIV@2;f9cHW=RL08`005EDoo`0SEEDEECoo02>
ZZQEE?ol08ooo5EDoo`0T3<cooooo`2A<c?oolc<098c<oooVIT0Ta^A6i4KT@2D
FYEJUEZE09FIVIVIVIT0U]RLf9cHW02G001EE?ol09POPAn17h40VEj5GXENQ@2J
WHVMRIf909_LS=b<g8`0W000ZZP0002MEEBZZ00009jZZ:ZX0000WoolZZP0002P
<c>IVC<c0:4c<iVI0000XS<cIVKoo`2S7h4OPAn10:ANQEj5GXD0YIf9WHVMR@2V
g8cLS=b<0:L00:ZX0000Z2=b8g8SLP2YHWERMF9e0:ZQNJ5iXGT0Zn1mh7gPO@2/
002ZZ5ED0:eEE:ZXEE@0[ZZXZZQEE02_oobZZ5ED0;0c<`00VIT0/C<c001VIP2b
<c<003<c0;<SLR=b8g80]69eHWERM@2eXGVQNJ5i0;KPON1mh7d0]`00ZZQEE02h
9f8WHRMR0;UVIVIVIVH0^ZEYYFVUJ@2ki6gTKNA]0;`00:ZXZZP0_EEDZZRZZ02n
ZZRZZ:ZX0;ooo:ZXZZP0`000VIWoo`31002IVLc<0<8009VIVIT0`bMR9f8WHP34
IVIVIVIV0<FUJJEYYFT0a^A]i6gTK@37002ZZ:ZX0<P[DR]B:e80bFYFJUIZEP3:
ZEVYFJUI0<_XGNQMj5d0c000ZZSoo03=EEBZZ?ol0<jZZ:ZXoo`0coolZZSoo03@
000c<c<c0=4003<c0000dP00003oo`3C:e8[DR]B0=AZEVYFJUH0eJUIZEVYF@3F
j5gXGNQM0=L00:ZXoo`0f2m2;d8_@P3IKTI^AVi60=Z]BZe:[DX0fna=k4g/C@3L
003oo0000=eEE?ol0000gZZXoo`0003Ooocoo0000>0A4@000000h@00k^h0003R
003Mg@000><_@Rm2;d80i6i6KTI^AP3U[DZ]BZe:0>K/CNa=k4d0i`00oo`0003X
<c<c<c<c0>Ub=W8fLSH0j[4j/CZa>P3[l3k`?_0n0>`00?olEE@0kEEDooaEE03^
ZZSoo5ED0>ooo?olEE@0l000001gM`3a000005EE0?800000A4@0lc<c<c<c<`3d
LSIb=W8f0?Fa>[4j/CX0m_0nl3k`?P3g003oo5ED0?Pg8cLS=b<0nGHVMRIf9P3j
]BZe:[DZ0?_d;_@^m2h0o000oobZZ03mEECoo:ZX0?jZZ?olZZP0o`0000000000
0000M@3a0Md0U0800=d090B108l01840S`04P@2?00B108l01840S`04P@2?00B1
08l02/P0oHb;0?f<aP0:b03lS8d0o8c600[80?^<S`3kS<H02/P0nHbC0?V<aP0:
a`3iS9D0nHc500[60?V<U`3iS<@02/D0n8bK0?R<``0:``3iS9d0nHc100[20?R<
X@3hS<002/40n8bS0?R<_`0:_`3iS:D0nHbm00jn0?b<oDfY0?e=o8bl00jl0?j<
o4b[0?a<oXbj012k006<S?]=[@3kC@6<S;T03[X008ciC;40nD`0S;P02[P0nDfc
0?U=]P0:]`3hC;L0n4be00Zf0?Q=^@3hCK@02[@0nDbk0?U</P0:/`3hCKl0n4fa
00Za0?U<`@3iC:l02[00n4g50?Q=[P0:[`3hC<L0n4b]00Z]0?U=b@3iCJ/02Z`0
n4c=0?Q<ZP0:ZP3iCLl0nDfX00bY0?Q<d`3hC:P0020:Z03hCMD0n4fV00ZV0?U<
e`3iC:@02ZD0n4gK0?Q=X`0:X`3iC=d0nDbQ00ZR0?Q=h@3hCJ002Z40n4cS0?Q<
W`0:W`3iCND0nDfM00ZN0?Q<j@3hC9`02Y`0nDg[0?U=VP0:V`3hC>l0n4bI00ZJ
0?Q=l@3hCIP02YP0nDcc0?U<UP0:U`3hCOL0n4fE00ZE0?U<n@3iC9<02Y@0n4gm
0?Q=TP0;T`3hC0400?Q<T@06T@3aCHl01Y00ldb>00J>0?M=S006SP3gC8`01Xl0
mDf=00J@0?=<SP06TP3_CI002Y<0nDcm0?U<T@0:U@3hCO/0n4fC00ZF0?Q<n@3h
C9@02YL0nDge0?U=U@0FmP3_S;I<oA7lC?<0o4cm4KI<khcd01Kf0>n<]Tgm4Oi=
k`3nCOdA]Tg_S?@05_H0khbfC?`A04c]001<o16fC>n<m00BmP3_S;I=o17[0?`A
]Tg_S?@02YT0o17[0?`AU`0:V03l4Nd0o16F00ZH0?`Ak@3l4IH02YP0o17]0?`A
UP0:U`3l4Nl0o16E00ZG0?`Ak`3l4ID02YL0o17_0?`AU@0<UP3l4O40o16E001<
2YH0o17a0?`AU00:UP3l4O40o16D00ZE0?`Al`3l4I<02YD0o17c0?`AT`0:U@3l
4O<0o16C00ZD0?`Am@3l4I802Y@0o17e0?`ATP0:U03l4OD0o16B00ZC0?`Am`3l
4I402Y<0o17g0?`AT@0:T`3l4OL0o16A00bB0?dAm`3m4I40048:TP3l4OT0o16@
00ZB0?`An@3l4I002Y80o17i0?`AT00:T@3l4O/0o16?00ZA0?`An`3l4Hl02Y40
o17k0?`AS`0:T03l4Od0o16>00b@0?`Ao@3l4Hl004d:T03l4Od0o16>00^?0?`A
0@00o16=00^?0?`A0@00o16=00^?0?`A0@00o16=00J>0?LAS006SP3g4H`01Xh0
ma6<00J=0?TAR`06S@3i4H/01Xd0nA6;00J<0?/ARP06S03k4HX01X`0na6:00J;
0?dAR@06R`3m4HT01X/0oA6900B108l01840S`04P@2?00B108l01840S`04P@2?
00J1090002<4P@2?00000@0:0L80T`8K0KT0;00<01D9B6E/MVEdJF=Q00<05@0=
00X01P000b00;P0400000@0E1I<0:07A0:X6AfE^;R0`00060000000^00@00041
01F_R00[1d42<B/00?l\>"], "Graphics",
  CellMargins->{{72, Inherited}, {Inherited, Inherited}},
  TextAlignment->Center,
  TextJustification->0,
  ImageSize->{292, 88},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PICT", "\<\
=b027P2G0WH1]@0A0_l<0?ooool0U`000Qh0006e0002MP000000000N00402P8M
09H2M`6f00X000000000000d0Qh0U`9e0FH00@0:0Qh0U`9e0FH0V8420000001/
0@800000000000180000B0000000200100P000000<AiJ000000001WY0000o`00
oooooooo007oooooc<`00_oloobZZ003ooooofIV00Cooooo<c<01Oooool00006
ooo<c?oo00Ooolc<c<`02?ooc<bIV@09>a<k4c/C00Yj5gXGNQL02kTJ^AZi6P0<
n1kh7_PN00d00?oloo`03UEDoocoo00?ZZSoo?ol013ooiVI<c<04OooVIT0000B
oomVI_oo01?oofIVc<`05?ooIVJIV@0EoomVIVIV01KoofIV<c<05oooIVH0000H
oolc<ooo01To0cl3?`<06Wh7OPMn1`0K_@^m2kd;01cl3_`>o0h07EED0000000N
ZZP0000001ooo00000008?oo002IV@0Qool006IV02;oo`00<c<08ooo0000000T
c<cooooo02G<c?ooc<`09/c<oonIV@0Wc<coofIV02P3l0?`0o00:D;c@_=2l`0Z
PON1mh7g02_0nl3k`?/0;000001EE00]EE@005ED02jZZ000EE@0;ool001EE00`
c<bIVOoo037<c9VIc<`0</c<VIVIV@0cc<bIVFIV03C<c9VI<c<0=Lc<VIT0000f
c<aVI_oo03O<c6IVc<`0>0OP1n07h00iA^A6i4KT03Z5ihGWQNL0>lC[a>_4j`0l
00000:ZX03eEE000ZZP0?ZZX002ZZ00ooo`00:ZX043<c3<c<c<0@Lc<<c<00012
c<`00?oo04?<c000c<`0A<c<002IV@15c<`006IV04K<c000<c<0Alc<00000018
2m0;d0_@04U:e4[DB]@0BXWHRMR9f01;b=_8flSK04`00000oo`0CEED003oo01>
ZZP00?ol04ooo000oo`0D9VIc<bIV@1AVIW<c6IV05:IVLc<<c<0DiVIc<`0001D
VIVIVOoo05FIVIVIc<`0EYVIVIVIV@1GVIVIVFIV05P?`0o03l00FDk4C/A>a01J
SLR=b8g805_<c<c<c<`0G000EE@0001MEEAEE00005jZZ5ED0000GoolEE@0001P
VITc<ooo066IVC<cc<`0HYVI<c>IV@1SVITc<fIV06BIVC<c<c<0IIVI<c<0001V
VIT00?oo06NIV@00c<`0J1>a4k4C/@1YD[AB]5:d06ZA^96hTKP0Jm2ld;c@_01/
001EE5ED06eEE5EDEE@0KZZXEEAEE01_ooaEE5ED071VI_oo<c<0LFIVool0001b
IVK<c?oo07=VI/c<c<`0M6IVc<bIV@1eIVK<c6IV07IVI/c<<c<0MfIVc<`0001h
5j4GXANQ07UFYEJUEZD0NYFXUJREZ01ke:cD[=B/07`005EDZZP0OEEDEEBZZ01n
ZZQEE:ZX07ooo5EDZZP0P6IVIVJIV@21IVIVIVIV089VIVIV<c<0PfIVIVH00024
IVHc<ooo08EVIS<cc<`0QVIV<c>IV@27IVHc<fIV08PKTA^A6i40REZEFYEJU@2:
VIVIVIVI08_HW=RLf9`0S000EECoo02=EEAEE?ol08jZZ5EDoo`0SoolEECoo02@
<c?ooooo094c<oooc<`0TS<coonIV@2C<c?oofIV09@c<ooo<c<0UC<cool0002F
<c?<c?oo09Lc<lc<c<`0V1n17h4OP@2IGXENQEj509ZMRIf9WHT0Vmb<g8cLS02L
002ZZ00009eEE:ZX0000WZZXZZP0002OoobZZ0000:0c<iVI<c<0XC<cVIT0002R
<c=VI_oo0:<c<fIVc<`0Y3<cIVJIV@2U<c=VIVIV0:Hc<fIV<c<0Yc<cIVH0002X
8g8SLR=b0:URMF9eHWD0ZZ5iXGVQN@2[h7gPON1m0:`00:ZXEE@0[EEDZZQEE02^
ZZRZZ5ED0:ooo:ZXEE@0/3<c002IV@2a<c<006IV0;8c<`00<c<0/c<c0000002d
003ooooo0;D00?ooc<`0]P00oonIV@2g003oofIV0;PWHRMR9f80^FIVIVIVIP2j
YFVUJJEY0;_TKNA]i6d0_000ZZRZZ02mEEBZZ:ZX0;jZZ:ZXZZP0_oolZZRZZ030
002IVOoo0<4009VIc<`0`P00VIVIV@33002IVFIV0<@009VI<c<0a@00VIT00036
001VI_oo0<L006IVc<`0b2]B:e8[DP39JUIZEVYF0<ZYFJUIZET0bnQMj5gXG@3<
002ZZ?ol0<eEE:ZXoo`0cZZXZZSoo03?oobZZ?ol0=0003<c<c<0d@00<c<0003B
00000?oo0=<00000c<`0e000002IV@3E000006IV0=H00000<c<0enk^0000003H
;d8_@Rm20=U^AVi6KTH0fZe:[DZ]BP3Kk4g/CNa=0=`00?ol0000gEEDoo`0003N
ZZSoo0000=ooo?ol0000h14A0000003Q003^kP000>800=gM0000h`00^k/0003T
002ZZP000>D008R80000iP00MgL0003W001EE@000>Pc<c<c<c<0jG8fLSIb=P3Z
/CZa>[4j0>_`?_0nl3h0k000ooaEE03]EECoo5ED0>jZZ?olEE@0koolooaEE03`
000007Mg0?400000EED0lP000014A03c0000028R0?@000004A40mNk^k^k^kP3f
gMgMgMgM0?Nk^k^k^k/0n3LS=b<g8`3iMRIf9WHV0?Ze:[DZ]BX0no@^m2kd;P3l
003oo:ZX0?eEE?olZZP0oZZXoobZZ03o000000000000001/0@827P2G0WD1IP0T
00J10840o`001X40P@3o0006P@210?l000J10840o`001X40P@3o000Yl`004O00
017^001<m@00C>P004cm001<hP01C4cP005<C>000Da<a`00:O<0017`000Ak@00
COL004gX001=n`00CN<00De=h001CDgP005=CLL0037b000AlP004N/00Da<n`01
C4cW001<n`00C>@00d`004cR00=<001<hP03C000C<P003?b000AlP004NT01Dg6
0036CNH004gi001=iP00COd004gT001=o@00CN@004gm001=b@00Co80017b000A
i`01C<KU001<m`00C?00oTck0036o@00a_/0oTcf0?i<n`00a_d00<Kk0?i<mP3n
C?/00<Km0036n`3nC>l004ch001<k`00E_40017d000AiP00CN`0oTgl0036m`00
a_`0oTge0?i=0/H0a_/00/H0a_i=l03nC@;60<Kk00;60<KnCO00oTd2aP36n`02
aP36oTg/001=n000CNl004Ca000Am0004NH004cY0?i<0/H0a_L00/H0a_i<kP01
aTck005<a^P00LI<n`01C<KX0076C?/00Dc6j000C?P004c_000hl@004O@0017V
001=i@01aTgg005=a^T004gk001=iP00CO/004gV001=n`00CNL004gh001=k`00
=_00017f000Ai@00C><004ci001<iP00C?d004cT001<o@00C>@004cm001<iP00
C?P004c_000fl0004OH0017U001=h`00COT004gV001=o@00CN@004gm001=i000
COd004gV001=n000CNl003k`000AmP004ND004cS001<n@00C>H004cm001<i000
C?d004cT001<o@00C>l004ci0036n000a_T004ch000mk`004OP0017T001=hP00
CO/004gT00==001=h`00COd004gT001=o@00CNh004gj0036n000a_X004gg000k
k`004OP0017T001<hP00C?/004cT00=<001<hP03C000C>800d`004c]001<nP00
C?P004cj001<m`00@nl0017h000Ai0004N4004gm001=h`034@004N800dd004gR
00==001=k008C@00CDg6aP1=nP08C@36aTe=001=mP00ANh0017j000Ai002C15<
k000C?P0017m000An000C>d00d`AC17R00<A000AhP03g`00gnd0oDck001<o000
C?/0oDcg001;kP004OX0017T00==4@1=k001CDgj00E=4De=4Dgj005=CNd01Dd0
4A40CN<00a5=4DgR00?NCMi=j`00a_T014e=04e=n@00a_D006K^000AnP004ND0
14`04@1<jP01C4cl00E<C15<4Dcl005<C?D004ch00E<C00AC4ch001<n001C4ci
00E<C14AC4ch001<n001C4ci00E<C=oOC4ch001<m@00a_P004ch0036m000J>d0
017l000Ai@06C@004@00CNT00Tg6a_i=0`004@3nC@;6aTgb0?i=o007CDd00140
CDgl0?i=m@3nCO`01Dd04@00CO/0oTge0?i=o005C@3N001=n`3nCO@0nDd44Dd0
CA7iCO@006k]000Ao0004ND00d`0017n001<j002aP1<oP054@00C036k@06C<K6
C4`0C?d01T`0C4c6aTc_009<a/KnC0<04@00oT`3a/I<C>l00Tc6a_i<0`3O003n
C0?6aTa<lP00a_P00Q404OP00<Ke001<k@004O`0017V001=n@00CNT00/H0CO/0
0Td0a^X00/H0CO/00Td0a^T00LI=n`01CLKX0076CO/00Dg6k`00COL00Q404OL0
04gf001Bk0004Oh0017^0?Y<0/K6C?T00Tc6a_Y<lP02C01<n`02C01<jP02aP1<
n`02C036j@01aTck005<a^P00LI<n`01C<K_001<mP004OH004cf001:k0004Oh0
017U0036n@00a^T00Td0CO/00Td0CNX00Td0CO/00Td0CNT00De=n`01CDgX005=
CO/00De=l000COD0017e001=m`00GN`0017n000Ai@00a_T00<KZ00=<001<n`03
C000C>d0oT`2aP36o@05aP36aTa<kP05C4c6C036o@05aP36aTa<kP05C4c6C036
o@05aP36aTa<m000C>H004ch001Vj`024@0Ah`00CO/004gY00A=a/H0a_d01<H0
a/I=l@3mC@D004d00<Km00G6001=003mCOH0oDgn009=0<Km00;604gn0?e=mP3m
COh00Td0a_d00/H0COh0oDgh001=iP00COP004S[008A017S001<n`00C>/0oTcm
00=<001<o@3nC>d004cn00=<001<oP00C>T02D`004`004`004cX00U<001<001<
001<b`00C>/00Q404N<004gk001=k@04CDd004gl005=CO`014d004e=k`00COd0
0De=o@00CNT004gn005=COh004gX001=oP01CDgn001=b`00>^X0017Q001<o@00
C>800Da<i@00C?d00Da<o@00C>T004cn005<C?h004cX001<oP01C4cn001<b`00
9^X0017Q001=o@00CN@01De=001=CN800De=h001CDgP005=CLL000J10840o`00
1X40P@3o0006P@210?l000J10840o`001X40P@3o0006P@210?l000J10840o`00
:^/00Td0CN000De=h001CDgP005=CND004gg001=i@01CDgP009=04g[000XjP00
C=l00Da<h001C4cP005<C>D004cg001<iP03C000C>0004cZ000bj`02C@1=h@03
C@00CN800dd004gR00==001=iP00COL004gV00==001=h@02C@1=j`00B^`004cn
001<k001C4cj001<o@00C?T004c]001<o@00C>@004cm001<iP00C?T004c^001<
n@03C000C?T004c[001<oP00C>`006[f0?i=n`00a_`00<Kk0?i=m03nCOd00<Km
0036o03nCOD0oTgk0036o@00a_/0oTgf0?i=n`00a_d00<Kk0?i=k`00COT004g]
0?i=o@00COd004gm0?i=m03nCOX00<Kn0036nP3nCOH006_c0?i<0/H0a_X00/H0
a_i<kP03C<H0a_/01<H0aTa<k`3nC0;60<Kk00;60<KnC?00oT`2aP36n`02aP36
oTc/0036n@00a^X014c60036o@04aP00aTc^0?i<0lH00<Kl00?60036oTcc0014
k`01aTgj005=a^P004gi001=j001aTgk005=a^P00LK6n`01a/KW0036n`00a^L0
0LI=n`01CLKX0076COX00Dg6k`00>^h004cj001<iP00C?/004cV001<n`00C>H0
0<Kk0036iP3lC0;6aTcV001<n`00C>D004cl001<k@00?^d004gl001=i@00CO/0
04gU001=o@00CN@00<Km0036i`02a/I=n`02CLK6i`00COd004gT001=o000CNd0
04;]001<o000C>D004ck001<i@00C?d004cT0036o@00a^P004cn001<o@00C?h0
04cX001<o@00C>@004cl001<k@00@^d004gl001=i000COd004gT001=o@00CN@0
0<Km0036j@00COd004gm001=o@00CNT004gm001=h`00COh004g/0016k@00C?`0
04cT001<o@00C><00d`004cR00?60036jP03C4`0C?h004cm001<oP03C01<C>/0
04cm001<h`00C?h004c/000lk000COh004gS001=o@00CN<00dd004gR00?60036
i`00COd00dd004gm001=i`03C@00CN400Td0CN/003_/001<oP00C>800d`004cR
00<A000AhP034@004NL004cm00=<001<o@00C>L00d`004cQ008A017[000mk000
4Oh0017R00<A000AhP03CA5=4N800lHAaQ7V001=oP034@004Oh004gV00<A000A
hP04CA5=4Dg/001<k004C1404DcS00E<015<4DcT00E<015<4DcT00G601764LKW
001<oP034D`AC?h004cV00=<4D`Ak@01C4ch00A<4@0AC?L004cg001_k004CA5=
4Dg]001=n005CDdA4De=n000COP00De=n@05CDdA4De=n000COP00De=n@05a/HA
4LK6n000COD004gn00_6001=CA4ACDd00<Kn001=j`05CDdA4De=k03nCO/014d0
4@1=nP3nCOH007[/00A<C15<C>`0oTcl00M<C0004@1<C?`0oTce0?i<o005C000
4@1<n`3nC?D0oTcl00G6000A0<Kk0?i<l`00C?h02LH0C00A001<0<Kn001<m03n
C?X01D`00140C?X0oTcc005<a_h01T`0014004cn00;6C4cc001jk004C@0A04gY
009=a/KnCOh00Q400?i=0/K6CNl00Tg6a_i=0`004@3nC@?6aTe=k`00COc60`00
4@3laP5=CNl00Td00?i=0`0A003nC@8004g`0?i=0LK6oTd3000A0?i=0LK6oTg^
0036oTd4000A003nC@36l000D>d00Da<oP01C4cW00;604ck009<0<KY0076C?/0
0Dc6j001a/Kk0076a^X00lK60<Kk00=<0<I<jP01aTck005<a^P00/H0C?`00T`0
a^l005Oe0?]=0lK6CDgn00==CLK6ndg_0076COT00Dg6j@01aTgk005=a^P00LK6
n`01a/K[00==0036o4d6a/I=aP00CN/00LI=n`01CLKX0076COX00Dg6k`00D^d0
0LI<oP01C<KW005<C?T00Da<j@01C4ck005<C>P00Dc6n`01aTc/001<oP02aP00
oD`20036oP00C>`00Da<n`01C4cX0076C?X00Dc6k`00Lnd01/H0aP360<KW009=
0<Kk00?60<I=k@05CDg6C@36o@05aP36aTe=kP05CDg6C@36o@05aP36aTe=l@01
CDgm00;6003mC@800<Km005=CNl00lI=0<Km00?60<K6k005CDg6C@36o005aP36
aTe=lP00Lnd01/I<0<H0C<KZ0?e<0P00a_d01<H004`0oTcd0?e<oP02C036o@02
aP1<oP3mC?H0oDcn009<0<Km00;604cn0?e<k`00C?T004c/0?e<oP03C000C?h0
oDcc0?e<oP03C000a_h00lH004cn0?e<mP00Knh024d0CDd0CDd0CNh0oTgn001=
oP03C@00COh004gm005=CNl02Dd004d004d004gX00U=001=001=001=j000COT0
04g^005=COh004gn00==001=oP00COh00De=kP00COh00Td0COh004g_001Ll004
C4`0C4cn00A<C01<C>X004cm005<C?d004cY001<oP01C4cn001<j000C?h00Da<
oP00C>T004cg001<jP00C?h00d`004cn001<j@00C?d004cm001<k`00F?8044e=
04e=001=04d004e=04e=k000COd00De=o@00CNT004gn005=COh004gX001=oP01
CDgn001=j@00COL004gU005=CN@004gn009=04gn001=k`00:^/00T`0C>000Da<
h001C4cP005<C>D004cg001<i@01C4cP009<04c[0006P@210?l000J10840o`00
1X40P@3o0006P@210?l000J10840o`001X40P@3o0006P@210?l002O[009<04cP
005<C>000Da<h001C4cP005<C>000Da<h002@P12j`009NX004gO005=CN400dd0
04gQ005=CN000De=h001CDgO0012jP00<N/00T`0C>400d`004cR00=<001<hP03
C000C>800d`004cR00=<001<h@02@P12j`00A^`004gn001=h`00COd004g/001=
n@3mCOT004g/001=o@00CNd004gi001=o@00COT004g]001=o@00CN<004;n0012
k000LoH0oTck0036o000a_/0oTcf0?i<n`00C?d004ck0?i<m000C?/01D`0C4`0
C?/004cd0?i<n`00a_d00<Kk0?i<m@3nC?`00<Km0036o03nC?D0oTck0036o@00
a_/0oTcf0?i2n`00a_`00<Kk0?i2mP00Lo<0oTd2aP36nP02aP36oTg`0?e=0@1=
n`01C@3mCO000De=o@05aTd004g6o@01CDg`0?i=0/H0a_/00/H0a_i=k`04CLH0
0<Kk00C60036CNl0oTd2aP36n`02aP36oTg`0?i20/H0a_X00/H0a_i2l`00C^l0
0LI<nP01C<KX005<C?/00Da<k`3kC0;6aTck009<a/KkC>l00LI<n`01C<KY0076
C?T00Dc6j@01aTck005<a^P00LI<nP01C<K_000jkP00COX004gV001=n`00CNH0
04gk001=iP00CO/004gV001=n`00CNH004gk001=iP00COX004g^000jk@00C?`0
04cT001<o@00C>@004cm001<i000C?d004cU001<n`00C>D004cm001<i000C?`0
04c]000jk@00CO`004gT001=o@00CN@004gm001=i000COd004gU001=n`00CND0
04gm001=i000CO`004g]000jk@00C?`004cT001<o@00C>@004cm001<i000C?d0
04cT001<o@00C>@004cm001<i000C?`004c]000gk000COh004gR00==001=h`00
COd004gS00==001=h`00COd004gS00==001=hP00COh004g/000fk000C?h004cR
00=<001<hP03C000C>800d`004cS001<o@00C><00d`004cR001<oP00C>`003G/
000AoP004N800a40017R00==001=hP034@004N800dd004gR00<A000AhP004Oh0
017/000mk004C1404DcR00=<4D`Aj`00C?T00a40017i001<j`03C15<4N800a40
017R00<AC15<hP04C1404Dc/0019k@06C@0ACA40CN@01Dd04DdACN/004gj00==
4DdAnP00CN/01Dd04DdACN@01Dd04DdACN@01DdACA40CN@01Td04DdA04g]001n
mP00C?T01Ta<4@0AC4ci001<m`01C4ci00E<C14AC4ch001<m000C?`01Da<4A5<
C?`004cd005<C?T01Da<4A5<C?P004ch001<n005C4`A4Da<n000C?P00Da<n@05
C4`A4Da<n000C?L004;i00I<C1404Da<n@00@_H0087e0?i=o006C@004@00CO`0
oTgd0?i=o005C@004@1=n`3nCOH0o4d0a_h01Dd00140COh00<KlCOD0oTgl00E=
000A04gk0?i=mP3nCO`01de=000A04e=o03nCOD0oTgl00E=014004gk0?i=m@3n
@_`01Td0014004gl0?i2m@00P?800Tc6a_i<10004@00oT`2a/I<kP3kC0<00140
nTc]0036oT`3000A0?i<0<K/009<a/KnC0<00140oT`3a/I<C?000Tc6a_i<oP02
4@00oT`2a/I<k`02C<K6oT`301400?i<0lK6C4c_0092a/KnC0@001400?i<0/K6
@_8004[_0076COX00Dg6j001CDgk005=CNP00LI=n`01CLKX0076CO/00Dg6j@02
aP1=n`02C@36j@01aTgk005=a^P00LI=nP01CLK_0018k`01aTcj005<a^P00Da<
n`01C4cX0076C?/00Dc6j001aTck005<a^T00LI<n@01C<KY0076C?/00Dc6j001
aTcj005<a^l004g_005=COX00De=j001CDgk005=CNl0nTd1aTgk009=a/KkCNl0
0De=n`01CDgY0076COT00Dg6j@01CDgk005=CNP00D9=nP01CD;_001flP05C4c6
C036o005aP36aTa<kP3mC040C?d00D`0oDc]00A<C01<a_d01<I<04a<k@05C4c6
C036o@05aP36aTa<k@03aT`0a_/00lH0a/K]00E<C<I<0<Km00G60<K6C4c^00E2
@/I20<Kl00G60<K6@T;b002?mP3mCOh00Td0a_`00/H0COh0oDgf0?e=oP02C@1=
o@02C@1=oP3mCO<04De=04d0C@1=001=04d0C@1=CO<0oDgn009=0<Km00;604gn
0?e=m03nC@@0C@00a_d01<H004d0oTgd0?e=oP02C@36o@02aP1=oP3mCOH0oD;n
00920<Kl00;604;n0?e2mP00L^l00d`004cn00=<001<j009C000C000C000C>h0
14a<001<oP3kC?h014`004a<kP09C000C000C000C>l00Da<o@00C?h00d`004cn
001<o@01C4c_00U<001<001<001<j003@P00@_h00d8004;_001Nk`00COh00Td0
COh004gX001=oP01CDgn001=jP00COh0ndgn001=jP00COh00De=oP00CNT004gm
005=COd004gY001=oP01CDgn001=j000@_h00T80@_h004;_001Ck`00C?d004cm
001<j000C?h00Da<oP00C>@00Da<i000C?h00Da<oP00C>T004cm005<C?d004cY
001<oP01C4cn001<j000@_d004;m0012k`009n/00Td0CN000De=h001CDgP005=
CN000De=h001CDgP009204;[0006P@210?l000J10840o`001X40P@3o0006P@21
0?l000N108400@0000402P8M09H2M`6f03P0=08_0H@2I06d00402P8_0H@2I06d
09R0X0000000/@2O000000000000B00004P0000000P00@0800000034NF@00000
000IjP000?l00?ooooooo`01ooooolc<00;oo?olZZP00ooooomVIP04=b<g8cLS
00Ef9WHVMRH01[DZ]BZe:P07m2kd;_@^00P00?olZZP02C/C>a<k4`0:NQMj5gXG
00^i6[TJ^AX03?PNn1kh7P0=003oo?ol00iEE?oloo`03jZXoocoo00@oonIVC<c
017ooiVI00004_ooIVKoo`0CoomVI/c<01@k4c/C>a<05GXGNQMj5`0F^AZi6[TJ
01Oh7_PNn1h06000oocoo00I?`<o0cl301Yn1gh7OPL06kd;_@^m2`0Lo0kl3_`>
01eEE00000007ZZX0000000Ooo`00000023oo`00VIT08Ooo001VIP0Rool003<c
02?oo`00000093l3?`<o0`0UOPMn1gh702Jm2kd;_@/09o`>o0kl3P0X0o03l0?`
02U2ld;c@_<0:X7gPON1m`0[`?_0nl3k02`00000EE@0;EED001EE00^ZZP005ED
02ooo000EE@0<<c<VIWoo`0ac<bIVLc<03;<c9VIVIT0<`?`0o03l00d@_=2ld;c
03F1mh7gPOL0=/3k`?_0n`0g000005ED03P7h0OP1n00>DKTA^A6i00jQNN5ihGW
03_4jlC[a>/0?000002ZZ00mEE@00:ZX03jZZ000ZZP0?ool002ZZ010c<`c<c<c
047<c3<c0000@/c<003oo`131n07h0OP04A6i4KTA^@0AHGWQNN5i`16a>_4jlC[
04L00000ZZP0B0_@2m0;d019B]A:e4[D04Z9f8WHRMP0BlSKb=_8f`1<00000?ol
04eEE000oo`0CZZX003oo01?oo`00?ol052IVLc<VIT0DIVIc<aVIP1BVIW<c3<c
05<;d0_@2m00E4[DB]A:e01ERMR9f8WH05K8flSKb=/0E`00003oo01H3l0?`0o0
05U>a4k4C/@0FXg8SLR=b01Kc<c<c<c<05`005ED0000GEEDEE@0001NZZQEE000
05ooo5ED0000H9VI<c?oo`1QVITc<lc<06:IVC<cVIT0H`o03l0?`01TC/A>a4k4
06F=b8g8SLP0I/c<c<c<c01W001EE00006PC/A>a4k40JE:dD[AB]01ZTKRA^96h
06_@_=2ld;`0K000EEAEE01]EEAEE5ED06jZZ5EDEE@0KoolEEAEE01`IVKooc<c
075VI_oo0000LVIVc<coo`1c4k4C/A>a07AB]5:dD[@0MI6hTKRA^01fd;c@_=2l
07L005EDEE@0N1NQ5j4GX@1iEZEFYEJU07ZEZ9FXUJP0NmB/e:cD[01l001EE:ZX
07eEE5EDZZP0OZZXEEBZZ01oooaEE:ZX081VIVIVVIT0PFIVIVIVIP22IVIVIS<c
08<GXANQ5j40Q5JUEZEFY@25UJREZ9FX08KD[=B/e:`0Q`00EEBZZ0286i4KTA^A
08UJUEZEFYD0RYVIVIVIV@2;f9cHW=RL08`005EDoo`0SEEDEECoo02>ZZQEE?ol
08ooo5EDoo`0T3<cooooo`2A<c?oolc<098c<oooVIT0Ta^A6i4KT@2DFYEJUEZE
09FIVIVIVIT0U]RLf9cHW02G001EE?ol09POPAn17h40VEj5GXENQ@2JWHVMRIf9
09_LS=b<g8`0W000ZZP0002MEEBZZ00009jZZ:ZX0000WoolZZP0002P<c>IVC<c
0:4c<iVI0000XS<cIVKoo`2S7h4OPAn10:ANQEj5GXD0YIf9WHVMR@2Vg8cLS=b<
0:L00:ZX0000Z2=b8g8SLP2YHWERMF9e0:ZQNJ5iXGT0Zn1mh7gPO@2/002ZZ5ED
0:eEE:ZXEE@0[ZZXZZQEE02_oobZZ5ED0;0c<`00VIT0/C<c001VIP2b<c<003<c
0;<SLR=b8g80]69eHWERM@2eXGVQNJ5i0;KPON1mh7d0]`00ZZQEE02h9f8WHRMR
0;UVIVIVIVH0^ZEYYFVUJ@2ki6gTKNA]0;`00:ZXZZP0_EEDZZRZZ02nZZRZZ:ZX
0;ooo:ZXZZP0`000VIWoo`31002IVLc<0<8009VIVIT0`bMR9f8WHP34IVIVIVIV
0<FUJJEYYFT0a^A]i6gTK@37002ZZ:ZX0<P[DR]B:e80bFYFJUIZEP3:ZEVYFJUI
0<_XGNQMj5d0c000ZZSoo03=EEBZZ?ol0<jZZ:ZXoo`0coolZZSoo03@000c<c<c
0=4003<c0000dP00003oo`3C:e8[DR]B0=AZEVYFJUH0eJUIZEVYF@3Fj5gXGNQM
0=L00:ZXoo`0f2m2;d8_@P3IKTI^AVi60=Z]BZe:[DX0fna=k4g/C@3L003oo000
0=eEE?ol0000gZZXoo`0003Ooocoo0000>0A4@000000h@00k^h0003R003Mg@00
0><_@Rm2;d80i6i6KTI^AP3U[DZ]BZe:0>K/CNa=k4d0i`00oo`0003X<c<c<c<c
0>Ub=W8fLSH0j[4j/CZa>P3[l3k`?_0n0>`00?olEE@0kEEDooaEE03^ZZSoo5ED
0>ooo?olEE@0l000001gM`3a000005EE0?800000A4@0lc<c<c<c<`3dLSIb=W8f
0?Fa>[4j/CX0m_0nl3k`?P3g003oo5ED0?Pg8cLS=b<0nGHVMRIf9P3j]BZe:[DZ
0?_d;_@^m2h0o000oobZZ03mEECoo:ZX0?jZZ?olZZP0o`00000000000000/@2O
0Rl1Q09T0K@090J10>8006H6P@3R002X1X40hP00Q@J10>8005@4P@3Q00J10>80
05T6P@3R000f1X40hP00E0Zg0?i=o03nCKH02[L0oDcn0?e<]P0:]`3lC@00o4ff
00Jf0?Q<]@06]@3jCK@01[@0o4bc00Jd0?a=/`06]@3jC;@01[D0nTfd00Zf0?e<
003mC;D02[L0o4d00?a=]P0:^03lC?h0o4bg00Zh0?e=o03mCKL02[T0oDcj0?e<
^00:^P3lCOX0o4fi00Zj0?e<n03mC;T02[/0oDgf0?e=^P0:_03lC?H0o4bk00Zm
0?a=m03lCK`02[d0oDcb0?e<_00<_P3mCO00oDfn002<2[l0o4c`0?a<_P0Bm03n
CM00o4g^0?a=d03nCO<04_@0ndcC0?e<k03mC=<0ndcc01;d0?Q=e`3mCNX0oDgG
0?Q=l`0Bl`3fC=/0o4cZ0?a<f`3fC?804_00mTgO0?a=j03lCMl0mTg_01K]0?I<
hP3nS01<iP00C?j<hP3fC>`04^X0mTgV0?f<i03mS>H0mTgY01;W0?I<jP3lS>@0
o8cZ0?I<iP0Bi03fCNh0o8cR0?b<kP3fCN<04^40mTca0?f<h03mS?40mTcP01;N
0?I=m@3mS=h0oHce0?I=g@0Ff`3jC?f<n@3lS=h0o8ci0?f<nTcJ01KH0?e=nXcm
0?b<g03lS?d0nXcmCML03]D004cbS=X0lX`0C=@04]80nHcnC@2<f000S?i=nHcA
00k?0?b<oTcF0?i<o8c>013<006<S?e=f03mC@6<S</02/X0oDcH0?e<b@0<b@3n
CMP0oTg9001=2/T0oDcJ0?e<b00:b@3mCMX0oDg800c80?i<fP3nC<P008`:b03m
CM`0oDg700[80?e<g03mC<L02/L0oTgL0?i=aP0:a`3mC=h0oDc600[70?e=gP3m
CLH02/H0oTcN0?i<a@0:aP3mCN00oDg500[60?e<h03mC<D02/D0oTgP0?i=a00:
a@3mC>80oDc400[50?e=hP3mCL@02/@0oTcR0?i<``0:a03mCN@0oDg300[40?e<
i03mC<<02/<0oTgT0?i=`P0:``3mC>H0oDc200[30?e=iP3mCL802/80oTcV0?i<
`@0:`P3mCNP0oDg100[20?e<j03mC<402/40oTgX0?i=`00:`@3mC>X0oDc000[1
0?e=jP3mCL002/00oTcZ0?i<_`0:`03mCN`0oDfo00[00?e<k03mC;l02[l0oTg/
0?i=_P0:_`3mC>h0oDbn00Zo0?e=kP3mCKh02[h0oTc^0?i<_@0:_P3mCO00oDfm
00Zn0?e<l03mC;d02[d0oTg`0?i=_00:_@3mC?80oDbl00Zm0?e=lP3mCK`02[`0
oQ7b0?hA^`0>_03n4@1=m000COhA^`0D_@00C?dA0Da<n001C4cm4@1<_00B_@00
COdAoTgj0?i=oA40CK`05;d00Da<oQ7mC?`0oDcn4@5<C;`04[h0oTgm4Oa=003l
COdAoTfm00jn0?i<oA7fC?dAoTbm01Jn0?i=003n4@00n4d00?hA003nCKd05[l0
oD`00?dA003jC000oA400?e<_P0B_`3mC@00oA7hCOdA003mCKh06;l0oTcn0?hA
oD`00?e<oQ7n0?i<_`004AS00?e=oP3m4@5=COh00De=oA7n0?e=_`0H`03mC080
C4cm4OX0oA42C4`0oDc0001=7_X0oDg;0?i=003mCOhAnP3n4Oe=003nCL/0oDgi
01Kj0?Y<c`3hC?dAo03m4OQ<c`3jC?T06_X0mdgB0?U=003m4O`0oA400?U=dP3g
COT06_P0mDcF0?Y<oP3n4O`0oQ7n0?Y<eP3eC?L06_D0mDgJ0?]=o03m4Oh0oA7l
0?]=fP3eCO@06_80mDcN0?]<n`3m4Oh0oA7k0?]<gP3eC?406^h0mTgS0?Y=n@3n
4Oh0oQ7i0?Y=h`3fCNd07>/0mDcX0?Y<n03m4@00oA7h0?Y<j03eC>/004`Lj03e
CNd0n4gh0?dA003m4OP0n4g]0?E=j000CAcU0?E<l@3hC?H0oQ400?hAmP3hC?40
mDcU000A6^40nDgmS?H0mdgf0?XAmP3gCOH0oHciCN009=h0o4cjS?/0nd`1003m
C?H0nQ7f0?e<0@00ndck0?Z<o4cM02KK005=CON<0@00ndgn0?i=m03l4O@0oTgn
0?]=0@00mh`1CDgJ01[G0?V<nTcn0?e<m03l4O@0oDcn0?Y<nHcF01[D0?b<o4gl
0?e=m03l4O@0oDgl0?a=o8cC01cA006<S?e<n`3nC?80oQ7b0?i<n`3mC06<S=00
5/l0oXck0?e=lP3n4O80oDgk0?j<cP0Bc`3nS?/0oDcP0?e<n`3nS<h04/l0oXck
0?i=gP3nCO/0oXc>01;?0?j<o03mC=h0oDcl0?j<cP0Bc`3nS?`0oDgN0?e=o03n
S<h04/l0oXcl0?i<g03nC?`0oXc>01;?0?j<o@3mCM`0oDgm0?j<cP0Bc`3nS?d0
oDcL0?e<o@3nS<h05<l0oXcm0?i=fP3nCOd0oXc?000e4/l0oXcn0?e<fP3mC?h0
oXc>01;?0?j<oP3mCMX0oDgn0?j<cP0Bc`3nS?h0oTcH0?i<oP3nS<h05<l0oTd1
003mCMP0oDd1003nCLh05/l0oT`1003mC=P0oD`1003nC<l0014Dc`3nC@40S?i=
eP3nC@6<0?i=cP0Gc`3nC06<S?i<08cH002<oTcmS01<cP0Jd@01S8cnC@6<S?i=
0Hb<fP01S8cnCOZ<d00@e03lS?i<nHcL0?6<e000S1SG0?i=o8cnCOd0oHcL0?f<
o@3iS?i=eP0JfP3kC?b<oTcl0?f<gP3mS?`0oTclS?]<f@0Jg@3fCOh0oTgl0?b<
h03lS?`0oTgn0?I=g00Jh03fC?/0oTck0?b<hP3lS?/0oTck0?I<g`0Jh`3fCOP0
oTgj0?b<i03lS?X0oTgh0?I=hP0JiP3fC?D0oTci0?f<i03mS?T0oTce0?I<i@0N
j@3fCO80oTgh0?j<04gV001=oXch0?i=lP3fCNP08>`0mTc_0?i<n03nS05<C>P0
0Da<oXch0?i<k`3fC>/06^l0mTg/0?i=m`3lCNX0o4gg0?i=k03fCNh07?80mTcY
0?i<mP3mC>X0oDcf0?i<j@3fC?8008`Jm03gCNH0oTge0?e=k03mCOD0oTgV0?M=
l`0Jm03jC><0oTce0?a<kP3lC?D0oTcS0?Y<l`0Jm03mCN00oTgd0?a=l03lCO@0
oTgP0?e=l`0Bc`3nC?<0oDc`0?e<l`3nC<h04/l0oTgb0?e=lP3mCO80oTg>01;?
0?i<lP3lC?@0o4cb0?i<cP0Bc`3nCO40o4gf0?a=l@3nCLh04/l0oTc`0?e<mP3m
C?00oTc>01;?0?i=k`3mCOP0oDg_0?i=cP0Bc`3nC>l0o4cj0?a<k`3nC<h04/l0
oTg^0?e=nP3mCNh0oTg>01;?0?i<k@3mC?`0oDc]0?i<cP0Bc`3nCNd0o4gn0?a=
k@3nCLh04/l0oTc/0?a<003lC>`0oTc>01;?0?i=j`3mC@00oDg[0?i=cP0>c`3n
C>X0nTcZ0?i<cP0>c`3nCNX0nTgZ0?i=cP06]03lC;<01[@0o4fc00Re0?Y<]@00
S0Rf0?Q=]P00S0Zg0?a<003lC;H02[L0oDgn0?e=]P0:]`3nC?`0oTbf00Zg0?i=
o03nCKH01X40hP00S0B10>401840h@04P@3Q00B10>401840h@04P@3Q00B10>40
00402P8M09H2M`6f02`0300E2DQUK7IUM6USH@0301D03@0:00H000<P02h01000
00405LAA02P2;06=1TMUKRhP=@001P000000;P0400010@0EKTH0:`Q20S4[003o\>"], "Graphics",
  CellMargins->{{126, Inherited}, {Inherited, Inherited}},
  TextAlignment->Center,
  ImageSize->{286, 88},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PICT", "\<\
CkH2N@2L0]81^00A0_l<0?ooool0W0000WT0006h0002dP000000000N00402P9i
09/2dP6i00X000000000000d0Xd0W0:j0=D00@0:0Xd0W0:j0=D0V82l0000002E
0;`00000000000180000B0000000200100P000000<AiJ000000001Ve0000o`00
oooooooo007oooooc<`00_oloobZZ003ooooofIV00Cooooo<c<01Oooool00006
ooo<c?oo00Ooolc<c<`02?ooc<bIV@09>a<k4c/C00Yj5gXGNQL02kTJ^AZi6P0<
n1kh7_PN00d00?oloo`03UEDoocoo00?ZZSoo?ol013ooiVI<c<04OooVIT0000B
oomVI_oo01?oofIVc<`05?ooIVJIV@0EoomVIVIV01KoofIV<c<05oooIVH0000H
oolc<ooo01To0cl3?`<06Wh7OPMn1`0K_@^m2kd;01cl3_`>o0h07EED0000000N
ZZP0000001ooo00000008?oo002IV@0Qool006IV02;oo`00<c<08ooo0000000T
c<cooooo02G<c?ooc<`09/c<oonIV@0Wc<coofIV02P3l0?`0o00:D;c@_=2l`0Z
PON1mh7g02_0nl3k`?/0;000001EE00]EE@005ED02jZZ000EE@0;ool001EE00`
c<bIVOoo037<c9VIc<`0</c<VIVIV@0cc<bIVFIV03C<c9VI<c<0=Lc<VIT0000f
c<aVI_oo03O<c6IVc<`0>0OP1n07h00iA^A6i4KT03Z5ihGWQNL0>lC[a>_4j`0l
00000:ZX03eEE000ZZP0?ZZX002ZZ00ooo`00:ZX043<c3<c<c<0@Lc<<c<00012
c<`00?oo04?<c000c<`0A<c<002IV@15c<`006IV04K<c000<c<0Alc<00000018
2m0;d0_@04U:e4[DB]@0BXWHRMR9f01;b=_8flSK04`00000oo`0CEED003oo01>
ZZP00?ol04ooo000oo`0D9VIc<bIV@1AVIW<c6IV05:IVLc<<c<0DiVIc<`0001D
VIVIVOoo05FIVIVIc<`0EYVIVIVIV@1GVIVIVFIV05P?`0o03l00FDk4C/A>a01J
SLR=b8g805_<c<c<c<`0G000EE@0001MEEAEE00005jZZ5ED0000GoolEE@0001P
VITc<ooo066IVC<cc<`0HYVI<c>IV@1SVITc<fIV06BIVC<c<c<0IIVI<c<0001V
VIT00?oo06NIV@00c<`0J1>a4k4C/@1YD[AB]5:d06ZA^96hTKP0Jm2ld;c@_01/
001EE5ED06eEE5EDEE@0KZZXEEAEE01_ooaEE5ED071VI_oo<c<0LFIVool0001b
IVK<c?oo07=VI/c<c<`0M6IVc<bIV@1eIVK<c6IV07IVI/c<<c<0MfIVc<`0001h
5j4GXANQ07UFYEJUEZD0NYFXUJREZ01ke:cD[=B/07`005EDZZP0OEEDEEBZZ01n
ZZQEE:ZX07ooo5EDZZP0P6IVIVJIV@21IVIVIVIV089VIVIV<c<0PfIVIVH00024
IVHc<ooo08EVIS<cc<`0QVIV<c>IV@27IVHc<fIV08PKTA^A6i40REZEFYEJU@2:
VIVIVIVI08_HW=RLf9`0S000EECoo02=EEAEE?ol08jZZ5EDoo`0SoolEECoo02@
<c?ooooo094c<oooc<`0TS<coonIV@2C<c?oofIV09@c<ooo<c<0UC<cool0002F
<c?<c?oo09Lc<lc<c<`0V1n17h4OP@2IGXENQEj509ZMRIf9WHT0Vmb<g8cLS02L
002ZZ00009eEE:ZX0000WZZXZZP0002OoobZZ0000:0c<iVI<c<0XC<cVIT0002R
<c=VI_oo0:<c<fIVc<`0Y3<cIVJIV@2U<c=VIVIV0:Hc<fIV<c<0Yc<cIVH0002X
8g8SLR=b0:URMF9eHWD0ZZ5iXGVQN@2[h7gPON1m0:`00:ZXEE@0[EEDZZQEE02^
ZZRZZ5ED0:ooo:ZXEE@0/3<c002IV@2a<c<006IV0;8c<`00<c<0/c<c0000002d
003ooooo0;D00?ooc<`0]P00oonIV@2g003oofIV0;PWHRMR9f80^FIVIVIVIP2j
YFVUJJEY0;_TKNA]i6d0_000ZZRZZ02mEEBZZ:ZX0;jZZ:ZXZZP0_oolZZRZZ030
002IVOoo0<4009VIc<`0`P00VIVIV@33002IVFIV0<@009VI<c<0a@00VIT00036
001VI_oo0<L006IVc<`0b2]B:e8[DP39JUIZEVYF0<ZYFJUIZET0bnQMj5gXG@3<
002ZZ?ol0<eEE:ZXoo`0cZZXZZSoo03?oobZZ?ol0=0003<c<c<0d@00<c<0003B
00000?oo0=<00000c<`0e000002IV@3E000006IV0=H00000<c<0enk^0000003H
;d8_@Rm20=U^AVi6KTH0fZe:[DZ]BP3Kk4g/CNa=0=`00?ol0000gEEDoo`0003N
ZZSoo0000=ooo?ol0000h14A0000003Q003^kP000>800=gM0000h`00^k/0003T
002ZZP000>D008R80000iP00MgL0003W001EE@000>Pc<c<c<c<0jG8fLSIb=P3Z
/CZa>[4j0>_`?_0nl3h0k000ooaEE03]EECoo5ED0>jZZ?olEE@0koolooaEE03`
000007Mg0?400000EED0lP000014A03c0000028R0?@000004A40mNk^k^k^kP3f
gMgMgMgM0?Nk^k^k^k/0n3LS=b<g8`3iMRIf9WHV0?Ze:[DZ]BX0no@^m2kd;P3l
003oo:ZX0?eEE?olZZP0oZZXoobZZ03o000000000000002E0;`2S@2L0[X0e@0T
1840a@04P@3500B10<D01840a@04P@3500B10<D01840a@04P@3501:g001=m@00
COD004ge001=]`0R_`00C?X004cm001<nP00C?D004cj001<o@00C?X004bo02:o
001=nP00COd004gj001=m@00COX004gm001=nP00CKl08[h004ck001<o000C?/0
04ce001<n`00C?`004ck001<_P0R_P00CO/004gl001=n`00COD004gk001=o000
CO/004fn02k6001<nP00C?d00T`0C?`004ck001<m@00C?/004cl009<04cm001<
nP00C<H0;<D004gj001=o@01CDgk001=o000COD004gl001=n`01CDgm001=nP00
CLD0:/@004ck001<o000C?/004cl001<m@00C?`004ck001<o000C?/004c40333
009=04gn001=o001CDgl001=o000COD004gl001=o001CDgl001=oP02C@1=``0h
b@00C?`00T`0C?d004cm005<C?/004cm001<m@00C?d004ck005<C?d004cm009<
04cl001<b@0hb@00CO/00De=o@00COd00Td0CO`004gm001=m@00COd004gl009=
04gm001=o@01CDgk001=b@0hb000C?/004cm001<o@03C000C?d004cm001<m@00
C?d004cm00=<001<o@00C?d004ck001<b014d000COX004gk005=COd004gn001=
oP00COd004gn001=m@00COh004gm001=oP00COh004gm005=CO/004gj001=d014
c`00C?/004ck005<C?d004cn001<oP00C?d004cn001<m@00C?h004cm001<oP00
C?h004cm005<C?/004ck001<c`16cP00CO/004gl009=04gn001=oP00COd004gn
001=oP00COD004gn001=oP00COd004gn001=oP02C@1=o000CO/004g>04C>001<
n`00C?`00d`004cn00=<001<o000C?h00d`004ce00=<001<oP00C?`00d`004cn
00=<001<o000C?/004c>04;=001=o000CO`004gn00I=001=001=n`06C@00C@00
COD01Td004d004gk00I=001=001=oP00CO`004gl001=c@12c000C?`004cm001<
oP06C000C000C?/01T`004`004ce00I<001<001<n`06C000C000C?h004cm001<
o000C<`0?//004gm001=o@00COd01Dd004d0COX01Dd004d0COD01Dd0C@00COX0
1Dd0C@00COd004gm001=o@00CL/0>//004cm001<o@00C?`014`0C01<n@04C01<
04ce00A<04`0C?T014`0C01<o000C?d004cm001<b`14f`00CO4004gm001=oP00
CO/00de=04gk00I=001=C@1=m@06C@1=C@00CO/00dd0CDgk001=oP00COd004ga
001=f`16fP00C?4004cn001<oP00C?/00d`0C4cl001<oP03C01<C?D00da<04cn
001<o003C4`0C?/004cn001<oP00C?4004cJ03[I001=lP00COh004gn001=nP3n
COd004gl0?i=m@3nCO`004gm0?i=nP00COh004gn001=lP00CMT0?=P004cb001<
oP03C000C?T00Da<o@00C?/00Da<m@01C4ck001<o@01C4ci00=<001<oP00C?80
04cH03KH001=l@06C@00C@00COT0o/H2001=nP3na_L0o/Kj009=003na_T01Td0
04d004ga001=f00ce`00C?4014`0C000oTck0?g6oTck0?g6n@3ma_X00Da<oLKj
00I<C000C01<l@00C=L0BN0004gh001=lP07C@00C@1=003nCOh0o/H0COh0oTgn
0?g6n@03a/I=a_d0oTd1003ma_d0oTd604d0C@00CO8004gh001=h013g`00C?P0
04cb00A<04`0C?`0oT`30<K6C?/0oDcna_T0o/H1C03nC?`0o/H1003nC?d014`0
C01<lP00C?P004cO04KU001=n`01CDgj001=l@03CDd0CO/01Td0CLI=a/Kk0?i=
oLKk0?k6oDgk0?k6oDgk00==04e=l@00COX00De=n`00CND0D^@004cj001<nP00
C?800d`0C4cl001<oP00C?k604cm001<oP3maP1<o03nC036oP00C?`0oT`0a_h0
04cl00=<C01<lP00C?X004cj001<i019h`00COX004gj001=lP3nCOd004gm001=
o/H00?e=o03naP00o4gna_`00Dd0oTgnaP1=o@00COd0oTgb001=nP00COX004gS
057R001<nP01C4ck001<lP01C4cn001<o@01C03maP00o4cn0?g60Ta<0?i<0LK6
o@3mC000oLH104cm001<oP01C4cb001<n`01C4cj001<hP17hP00COP004gl001=
lP3naP8004gn00==0036oDgjaP5=a_i=nLKmCOc6oTd3aP00COh00Td00?k6lP00
CO`004gh001=hP0nj`00C?/00da<04ch005<C?d004cc0036mT`0a_E<0<KnC?W6
jdcna_<004cm005<C?P00d`0C4ck001<j`18jP00COX0oTgg001=o@00CO@0o/H0
COd014d00<K6oDgha_e=n/KnCOc6oDd4a/H004gm0?g6m000COd004gg0?i=nP00
CNX0D>T004ch0?e<nP01C4cn001<m@03a/I<a_h00d`0a/KkC?h00Da<oLKgC076
a_a<0@00o4cnaP40C?h0oLKe001<oP01C4cj0?e<n000C>T0E>P00De=nP00COh0
oTgk00==001=m009aTg6001=0<K6COk6ndd00?_6n4glaP00ndd9a/I=CLK604d0
0?k6m003C@00CO/0oTgn001=nP01CDgX05?V001<nP00C?`0oTcm00=<001<m@08
C<K6001<a/I<o/H00?e<003jaP00mDcmaP00o4cnaP1<o/H1003na_D00d`004cm
0?i<o000C?X004cV04oU005=CO/004gj0?e=101=C@1=m`00COg614g6CDg6nDd0
0?c6mTd00?]=0LH0nDd4aTe=aTgmaP1=m`04C@1=C@3mCOX004gk005=CND0@><0
04ck001<m`3mC?k6nP01C03la_a<o@3mC?g604cm0?]<o03iC?`0o4cmaP40C?X0
o/KmC?L004ck001<h`1:kP01CDgg001=o000COT004gm001=oLKk009=04gmaP5=
CO_6nTgj0?]=n@3kCOS6ndgk0?g604gm001=n@00CO`004gf001=kP10k03nC?T0
0Da<o@00C?X004cl0?c6o@3nC?O6g4cia_e<0LH0oTcn0?k60Dc6o000C?X004cm
005<C?P0oTc]04SY0?i=nP00COd004gk001=n`3kaP9=C@3kaP9=a/KfCOL0oDgg
0?a=nLKmCOk6003mCOk604gk001=n`00COd004gi0?i=jP1CiP3nC?`00Da<oP00
C?`004cl005<0?_6003ka_Y<oP01C03mC?P0oDch0?e<0@1<o@3jC?c60`1<a/Kn
C040C?`004cl001<oP01C4ck0?i<i`1>h`3nCOd00dd004gl001=o03nCOg6oTgn
a_]=o@02CDd0nTgj0?e=nP3jC@80CDgl0?e=nlH0COg6003nCOd004gl00==001=
o03nCN@0Fn00oT`5001<001<o@02C000oDcm0076a_I<o@05C000C000oT`1003n
C?d0oDcm0?i<0@00oT`5001<001<o@3lC?W6o@01C03nC040C?d00d`004cn0?i<
h@1Ig@3lC@40COh0oTd2001=o001CLKkC@400?i=oP00COh00Td00?e=o@3eCOd0
oDd2001=oP00COh0oTd3001=COc604gl001=oP01CDgn00A=04e=0?i=gP16fP3n
C?k60@1<o@00C?h0o<KkC000ndcn001<oP3mC?X0ndcj0?e<oP00C?h0nd`00?e<
oLKnC?h004cm005<0?k6oDcK03SG0?g604gm0?i=n/KgCOd004gl0?i=nP3kCOX0
oTgl001=o@3gCOk60Te=a_e=o@00COg604gH04CG0?g60T`00?i<003naP1<oLKg
C?h004cm005<0?i<o03gC?`0oT`104cm001<oP3gC?k61Dc6C<K60?i<0@00o<KG
04cF0?k614g6C@1=o/KnCOk60`1=003iC@8004gm005=0?e=o03iCO`0oDd104gm
009=003iC@<004d0o/H2CLI=o/H1C@3mC@76a]H0CmL03Da<a/I<a/H0C<K6C<I<
oLH0C?d0nT`104cl005<0?e<0@1<oP3iC?h00D`0oD`104cl005<0?Y<o@00C?g6
1Tc6C4c6aP3ma_i<e`1@fP3nCOh00/I=a_i=1<I=aTd0oLKl0?U=n`02C@00oTd1
04gn0?i=0@00oTgn005=0?i=0P00CO/0nDgl001=o/H304g6a_e=o/Kn0?i=fP1B
g@3nC?X00Dc6oD`3aP1<0?k6o@01C4cn0?]<o002C000oDcn0?e<0@00oDcn0?e<
0P00C?`0ndcn005<C?d01Tc6aP1<0<KmC076a_X0oTcM03cC005=a_]=0@00o/Kg
0?]=o@02C@00oDgn0?e=0@00oDgn0?e=0P00COd0ndgg00A=a/H00?]=0LI=d`0b
d`02C<K6n4ce0?Y<0P00C?h0oTcn0?i<o@3nC?h0oTcn009<003jC?D0n4`2aTa<
d`0ce004CDg6CLKiCOH0n4d104gn0?e=003mCOd0oDd00?e=oP01C@3hCOH0nDgn
aP5=CM@0>=D01T`0C<I<aP3jC?L00D`0mdcn0?e<003mC?d0oD`00?e<oP3gC040
C?L0nT`00?k60T`0C=D0BML02Te=001=aTg6C@00ndgh009=003nC@00ndgn0?i=
003nCO/0oTd00?i=oP3kC@00oTd2001=n03kC@8004gmaP<004e=e`0jf000C?d0
1Tc6C<I<003jC?H0oD`00?]<0@00nTck0?Y<0@00nd`00?e<mP3jC08004cma_d0
04cH03WJ005=CO`024e=aTd004d00?Y=n03mC@400?==n`3cC@400?e=n03jC@D0
04d004gna_`00De=fP0id`3nC08004cn005<0?]<o000C?h0oTcm0?I<n@3fC?d0
oTcn001<o03kC040C?h01D`004c6a]<0>M<0oTd7001=001=003iCOh004gn0?e=
oP3fCOT0mTgn0?e=oP00COh0nDd:001=001=0036CLKC04KD0?i<0P00C?h01D`0
04`00?]<oP02C000oDcn005<0?Q<n@3hC040C?h0oD`2001<oP3kC0D004`004cn
009<003nC=@0C]D004gnaP40COd00dd004gn0?]=0P00COh0oTgn009=003mCOhA
m`3n4Oe=0P00COh0oTgn009=003kCOh00dd004gm00E=04e=aTgE05Wf005<C>80
oLH104cn001<oP00C?h00D`0nTcn0?e<2000C000C01<C?hA04ci0?dA24a<04`0
04`00?e<oP3jC040C?h004cn001<oP01C03mC>4004cf05od0?i=iP00COg604gm
001=oP00COd00Dd0nTd1003mC@@004d0COh004gm4@1=n`00COdA04gn00A=04d0
0?e=0@00nTd104gm001=oP00COd01De=aTg6CND0oTge063a0?i<jP01C03naP1<
o000C?h004cl005<0?Y<0@00oT`4001<04cm0?dA0Da<o@01C4cn4@1<o@04C01<
003nC0400?Y<0@1<o000C?h004cl00E<aTc604cY0?i<lP1PkP3nCNh00Dd0oLH0
COd004gm001=o000COh0ndd00?e=0`1=04gm001=oQ41CDgm001=oA40COd00dd0
C@3mC@00ndgn001=o000COd004gm00I=aTg6aP1=k@3nCNl0EN/0oTca005<0?k6
0Da<o@00C?d004ck001<oP3eC040C?d004cm4@E<C000C4cm4@1<o@01C03eC?h0
04ck001<o@00C?d01Tc6aTc604c`0?i<k01=j03nCOD01dd00<K6C@1=o@00COd0
04gj001=o@3fCO`004gm4O]=oQ41CDgl0?I=o@00COX004gm001=o@07C@36CLH0
04gd0?i=j@1Bi@3nC?T00T`00?k60T`0C?d01D`004`0C?T004cm0?M<o001C4cn
4Oa<oA41C4cl0?M<o@00C?T01D`0C000C?d024`0aTc6aP00C?P0oTcV033R0?i=
nLKOCOhA0De=o001CDgm4Oe=oA41CDgl005=COhAgdgnaP1=oLH00?i=h`0[m`3Y
C?W6gdcm4Oi<oP01C4cm4Oe<oQ7nC?h0oTcm4Mm<o/H0C?g6jDcg02;R0?i=nLKO
CO`AnDgn4Oi=oA7jCO/AgdgmaP1=o/KnCN80F^H0oDcl001<o000C?k6101<001<
n`03C000C?X004cn005<C?h0na7kC?hAoTcm4O]<na7n005<C?h004cj00=<001<
n`04C000C03naP1<o000C?`0oDcV05gY0?i=n@00CO/004gmaP==001=n`00COh0
0De=n`00COh00De=oP3k4Oa=oA41CDgn4O]=na7n005=COh004gk005=COh004gk
00==001=oLH0CO/004gi0?i=j@1Mk03nC?H004ck001<oLH3C000C?/004cl001<
n`04C000C4cn0036na7mC?dA04cm4Oe<na41C4cn00A<C000C?/004cl001<n`03
C000C?g604ck001<mP3nC>`0GO00oDgd001=n`02C@00o/H0COP004gk0?i=oP07
C@00C@1=003na_/AoTgn4@1=oA7nCO/A2Te=aP00C@1=001=oP3nCO/004gh001=
o/H2001=n`00CO@0oDg`05Cc0?i<l@00C?X00T`00?g6k`01C4cn00I<04`004`0
o/H0C?/A0Da<nQ41C4cj4@Y<C<K604`004`0C?h00Da<k`00C?k60P00C?X004ca
0?i<l`1AmP3nCNl004gi009=003ma^h00De=oP05C@1=001=o/H1CDgk4@1=nQ40
CO/AoTgnaPE=001=04gn005=CNh004gnaP8004gi001=k`3nCOH0A>4004cj001<
o@3na_H004ch009<C03nC08004cna_e<ka7mC?k60T`00?i<0P1<C?P004cf009<
a/Km001<nP00C>40==T004gm0?k6m@00COP014e=04e=oP3iCO8An4gn00A=C@1=
COP004ge009=a/Km001=f@0af@00C?`0oTce001<n003C4`0C?k6n4cd4OM<1/K6
C4`0C4ch001<m@3nC?`004cI02oJ001=n`3nCO@00De=n@02aTe=o/KfCOLAmTgm
aP5=a_T00De=m03nCO/004gJ03WJ001<n`03C4`0C?<004cl0?c604cmaP9<a/Kk
C000nQ41003kC?C6o000C?<00d`0C4ck001<fP0Td`3YCO_61dg6C@36CLK6o4d1
003l4Oh0nTd2a/H0n<KYCM<0=m<01D`0C000C?<0oDcmaP80a/KnC0?6aTc6ndci
0?U<0/I<C?g6003ma_e<l`05C000C01<d`17d`05C@1=001=oP01CDgk0?e=0P1=
CO/0o/H6C@36aTe=a_a=n`3lC@36oDd00?g6n`02CDd0oDgj001=oP05C@00C@1=
d`16d`06C000C000C?d0ndcm005<0?e<oP3maPA<C<I<a_]<n`3lC036o4cma_d0
oT`104cm0?i<003nC?h01T`004`004cC04_C00==001=oP00COh0ndd3001=COh0
0Te=0?i=0P36a_e=0<KiCOd0ndd0a_]=0lK6003lCOh00De=oP3lCOh004gn00==
001=d`0nd`03C000C?h0oDck0?i<n`00C?h0nD`0a_U<0@00nD`1a/KmC036oT`2
001<nP3nC?`0oDcn00=<001<d`1:d`02C@00oDd104gj00==C@00oTgm001=o@00
a_i=0/K6COk6o4d1003iCOk6oTd0a_d004gl0?i=0P1=COX00Dd0oDd2001=d`10
d`3lC?d004cl001<nP3nC0H004a<0<K6ndcmaP00nD`00?i<oLKnC0C6aP1<C?h0
oTck001<o000C?d0o4cC03_C001=oP00COd004gn005=COH0oTd104gda_U=0<Kn
COS60Td00?i=m`01CDgn001=o@00COh004gC02oC001<oP00C?`00T`0C?800Da<
oLKnC?[6lDcma_e<lP02C01<o000C?h004cC02;C001=o@02C@00h4gla_e=o/Kn
COW6jDd2001=o@00CM<0<=<004cm001<oP03C000C?80mLH0C?g6oDcma_i<mLKb
00=<001<oP00C?d004cC03_C001=o@03C@1=COh004gb0?g60@00nlH3CDg6a_]=
o/KnCO_60@00oLKb001=oP03CDd0COd004gC03?C001<o000C?/004cc0?k6nP00
a_e<0<KiC036oT`1a/Kj0?k6l`00C?/004cl001<d`0hd`00COh0oTgj001=m03n
a_d0oDd40<I=a/KnCOc604gnaP00oDgm0?k6m000COX0oTgn001=d`0gd`00C?`0
04cj001<m@01C4cn0?i<o003aTc6a_i<n<Kl0?i<oP01C4ce001<nP00C?`004cC
01[C001=n`00COP0jTgba^U=n000CO/004gC037C001<n`00C?4014`0C01<m`00
C?_60`1<C03la_i<n004C01<04ca001<n`00C=<0=]<004gk001=lP04C@1=04gi
0?i=o<Kn005=COh0o/H1CLKmCOX014d0C@1=lP00CO/004gC03cC001<k@06C4`0
C000C?`0oT`2001<oLH9C000C000C000C?k60Da<oP3nC?d01T`004`0C4c]001<
d`0md`00CNh004gn00E=001=003nCOd00Dd0oLH2C@1=o@02C@1=oLH104gl0?i=
101=001=oP00CNh004gC03C0001<oP00C?h0oTcl00=<C000oLH2C01<o@02C01<
oLH3001<C?/0oT`2001<oP00C<00<l800De=oP01C@3nCOX01De=001=COk60De=
n`01CDgnaPE=C@00CDgj0?a=oP01CDg202c3001<o@3nC08004cl00=<C000n4ck
0?Q<0`00C4cl001<oP3nC?h004c303C4009=003mCOd004gl00I=001=04d0ndgk
0?]=1P1=04d004gl001=o@06C@1=C@00CL@0@<H00Da<o000C?d004cm00U<C000
C01<04`0oT`104ck005<0?i<2@1<04`0C000C4cm001<o@00C?`00Da<aP12a`00
COX004gm001=oP0@C@00CDd0C@00CDd0C@1=04gm011=04d0C@1=C@00C@1=C@00
COh004gm001=nP00CLL0@/P004cj001<o006C000C000C?h02T`004a<04`0C01<
o@0:C01<04`0C4`004cn00I<001<001<o000C?X004c804K:005=COX004gl00I=
04e=001=oP0;C@00C@1=04d0C@1=o@0;C@1=04d0C@1=001=oP06C@00CDd0CO`0
04gj005=CLX0>/8004ck00E<C000C4cn001<oP07C4`004`004ck00M<001<001<
C?h004cn00E<C000C4ck001<`P0f`P00CO/00dd004gl001=oP07CDd004d004gk
00M=001=001=COh004gl00==001=n`00CL80><<004cl0?i<0@1<o000C?h024`0
C000C000C?/024`004`004`0C?h004cl005<0?i<o000C<<0=<@004gj0?i=o000
COd00De=oP00COh004gm001=oP00COh00De=o@00CO`0oTgj001=a00da000C?X0
04ck001<o001C4cn001<oP00C?d004cn001<oP01C4cl001<n`00C?X004c4032m
005=CO/004gm009=04gn001=oP00COd004gn001=oP02C@1=o@00CO/00De=_@0[
_`3nC?/004cl005<C?d004cm00=<001<o@00C?d00Da<o000C?/0oTbo02^m001=
o000CO/00De=o@00COd00dd004gm001=o@01CDgk001=o000CKd0;Kd004cl001<
o002C01<o@00C?d00d`004cm001<o@02C01<o000C?`004bm026h001=n`01CDgl
001=o001CDgl001=o001CDgk001=^00Q^@00C?X00Da<o000C?`00Da<o000C?`0
0Da<nP00C;T08kX004gj009=04gl001=o001CDgl001=o002C@1=nP00CKX08KX0
04cj005<C?/004cl005<C?`004ck005<C?X004bj01Vb005=CO/004gl005=CO`0
04gk005=CK806k<00T`0C?/004cl005<C?`004ck009<04bc01^c005=COX004gm
00==001=o@00COX00De=/`0I/P00C?X004cm00=<001<o@00C?X004bb00ZZ001=
m@00CJX01840a@04P@3500B10<D01840a@04P@3500B10<D01840a@04P@350001
00X2N@2K0]81^@0/00`05@U8IFafIGAYHf400`0E00d02P06oonB@00^00@00001
01D<W@0X0XH0ZPM7IFh^834h00H0000002h010000@405E@V02/9B@8a:`00=09j
0>T2d06g00402P9j0>T2d06g09R10P000000K042000000000000B00004P00000
00P00@0800000034NF@00000000I]P000?l00?ooooooo`01ooooolc<00;oo?ol
ZZP00ooooomVIP04oooooc<c00Gooooo00001_ooc<coo`07ooo<c<c<00Soolc<
VIT02C/C>a<k4`0:NQMj5gXG00^i6[TJ^AX03?PNn1kh7P0=003oo?ol00iEE?ol
oo`03jZXoocoo00@oonIVC<c017ooiVI00004_ooIVKoo`0CoomVI/c<01CoofIV
VIT05OooIVIVIP0FoomVIS<c01OoofIV00006?oo<c?oo`0I?`<o0cl301Yn1gh7
OPL06kd;_@^m2`0Lo0kl3_`>01eEE00000007ZZX0000000Ooo`00000023oo`00
VIT08Ooo001VIP0Rool003<c02?oo`0000009<c<ooooo`0Uc<coolc<02K<c?oo
VIT09lc<oomVIP0X0o03l0?`02U2ld;c@_<0:X7gPON1m`0[`?_0nl3k02`00000
EE@0;EED001EE00^ZZP005ED02ooo000EE@0<<c<VIWoo`0ac<bIVLc<03;<c9VI
VIT0<lc<VIUVIP0dc<bIVC<c03G<c9VI0000=/c<IVKoo`0gc<aVI/c<03P7h0OP
1n00>DKTA^A6i00jQNN5ihGW03_4jlC[a>/0?000002ZZ00mEE@00:ZX03jZZ000
ZZP0?ool002ZZ010c<`c<c<c047<c3<c0000@/c<003oo`13c<`00<c<04C<c000
VIT0ALc<001VIP16c<`003<c04O<c0000000B0_@2m0;d019B]A:e4[D04Z9f8WH
RMP0BlSKb=_8f`1<00000?ol04eEE000oo`0CZZX003oo01?oo`00?ol052IVLc<
VIT0DIVIc<aVIP1BVIW<c3<c05>IVLc<0000E9VIVIWoo`1EVIVIVLc<05JIVIVI
VIT0EiVIVIUVIP1H3l0?`0o005U>a4k4C/@0FXg8SLR=b01Kc<c<c<c<05`005ED
0000GEEDEE@0001NZZQEE00005ooo5ED0000H9VI<c?oo`1QVITc<lc<06:IVC<c
VIT0HiVI<c=VIP1TVITc<c<c06FIVC<c0000IYVI003oo`1WVIT00<c<06PC/A>a
4k40JE:dD[AB]01ZTKRA^96h06_@_=2ld;`0K000EEAEE01]EEAEE5ED06jZZ5ED
EE@0KoolEEAEE01`IVKooc<c075VI_oo0000LVIVc<coo`1cIVK<c<c<07AVI/c<
VIT0MFIVc<aVIP1fIVK<c3<c07MVI/c<0000N1NQ5j4GX@1iEZEFYEJU07ZEZ9FX
UJP0NmB/e:cD[01l001EE:ZX07eEE5EDZZP0OZZXEEBZZ01oooaEE:ZX081VIVIV
VIT0PFIVIVIVIP22IVIVIS<c08=VIVIV0000Q6IV<c?oo`25IVHc<lc<08IVIS<c
VIT0QfIV<c=VIP286i4KTA^A08UJUEZEFYD0RYVIVIVIV@2;f9cHW=RL08`005ED
oo`0SEEDEECoo02>ZZQEE?ol08ooo5EDoo`0T3<cooooo`2A<c?oolc<098c<ooo
VIT0Tc<coomVIP2D<c?ooc<c09Dc<ooo0000US<cc<coo`2G<c?<c<c<09POPAn1
7h40VEj5GXENQ@2JWHVMRIf909_LS=b<g8`0W000ZZP0002MEEBZZ00009jZZ:ZX
0000WoolZZP0002P<c>IVC<c0:4c<iVI0000XS<cIVKoo`2S<c=VI/c<0:@c<fIV
VIT0YC<cIVIVIP2V<c=VIS<c0:Lc<fIV0000Z2=b8g8SLP2YHWERMF9e0:ZQNJ5i
XGT0Zn1mh7gPO@2/002ZZ5ED0:eEE:ZXEE@0[ZZXZZQEE02_oobZZ5ED0;0c<`00
VIT0/C<c001VIP2b<c<003<c0;<c<`000000]000ooooo`2e003oolc<0;H00?oo
VIT0]`00oomVIP2h9f8WHRMR0;UVIVIVIVH0^ZEYYFVUJ@2ki6gTKNA]0;`00:ZX
ZZP0_EEDZZRZZ02nZZRZZ:ZX0;ooo:ZXZZP0`000VIWoo`31002IVLc<0<8009VI
VIT0``00VIUVIP34002IVC<c0<D009VI0000aP00IVKoo`37001VI/c<0<P[DR]B
:e80bFYFJUIZEP3:ZEVYFJUI0<_XGNQMj5d0c000ZZSoo03=EEBZZ?ol0<jZZ:ZX
oo`0coolZZSoo03@000c<c<c0=4003<c0000dP00003oo`3C00000<c<0=@00000
VIT0e@00001VIP3F000003<c0=O^kP000000f2m2;d8_@P3IKTI^AVi60=Z]BZe:
[DX0fna=k4g/C@3L003oo0000=eEE?ol0000gZZXoo`0003Ooocoo0000>0A4@00
0000h@00k^h0003R003Mg@000><00;^k0000i000ZZX0003U0028R0000>H007Mg
0000i`00EED0003X<c<c<c<c0>Ub=W8fLSH0j[4j/CZa>P3[l3k`?_0n0>`00?ol
EE@0kEEDooaEE03^ZZSoo5ED0>ooo?olEE@0l000001gM`3a000005EE0?800000
A4@0l`00000R8P3d0000014A0?G^k^k^k^h0m]gMgMgMg@3g^k^k^k^k0?Pg8cLS
=b<0nGHVMRIf9P3j]BZe:[DZ0?_d;_@^m2h0o000oobZZ03mEECoo:ZX0?jZZ?ol
ZZP0o`00000000000000K0420WX0j@;@0KL09006P@210?l000J10840o`001X40
P@3o0006P@210?l000J10840o`001X40P@3o000>P@2J00I=04d0C@1=k@005lP0
0da<04b10=P024`0C4`0C4`0C>h003_:0?a=0P1=CNP004gn0?e=oP00CNT0oTd3
04e=0?i=j@3lC@400?a=jP3lC@400?a=i`3nC@00oTg]001BcP3nC000nD`00?i<
k@01C4cn0?e<oP01C4c[0?i<003mC000oTc[005<0?e<0@00oD`104c/005<0?e<
0@00oD`104c_001<nP3lC?X004cd001Vk`004OP0017/00E=C@1=003nC@P0CDd0
04d0CDg_00==04e=oP01CDgn00==C@1=kP3aCNh00Dd0o4d1003lC@40CNh00Dd0
o4d1003lC@40CNl00dd004gn0?a=oP03C@00CO<006[_000An0004Nd0nd`704a<
aP1<C03kC>l03D`0C4`004a<001<C01<k`05C000C4`0nD`504a<001<lP02C000
nd`1003kC08004cb009<003kC0400?]<0P00C?<00T`00?1<0P00C?D007[^000A
nP004N`00Te=0?i=1`1=CLI=CLH0oTd204e=kP0;CDd0C@1=aP1=0<I=kP03CDd0
0?a=0LK6o4d3001=CO<014d0C@00oDd2aP00o4d4001=04gd00A=04d00?e=0/H0
0?a=1000C@1=m03gC@?6CLK6n4ge001ekP004OX0017]00U<04a<aTc6C4c6nT`4
aTa<04cd00=<C000oD`0a_i<0LK6oD`3001<C?D0o4`10<KlC036oD`1aP3lC?H0
o4`1003hC0;6003lC?H0o4`1003hC0;6003lC?80o4`704a<04a<0<KlC?<0087^
000AnP004Nh00dd0C@3iC@?6aTg6oDd304d0COH0oTd1003kC@36nTd1003nCOD0
2Dd0CDg6CLI=CLKlC@K6CLI=C@1=mP3nC@D0CDg6CLKjC@36o4d00?i=n03nC@D0
CDg6CLKjC@36o4d00?i=m03lC@?604g6oTd00?]=l`00Knd0017l000Ak001C03m
C036mT`3aT`0C?D0oD`4aTc6C03kC000nDcg009<C03dC0;6C<KmC080C4cf009<
C<KdC0G6C4c6C4cd009<C<KdC0G6C4c6C4cb00=<C000oT`0a_h0oT`4aP00C4cc
001Qk@004O`0017_0?i=101=04g6mTd5aTe=04d0oTgf0>m=0LI=l`3lC@?6CDd0
oDd00?a=0/I=CO<0oTd0a_5=lP3nC@36lDgb00==04d0oTd6aTe=04e=a_i=0`36
04gd001Vn0004OL0017l000Am`004OX0o4`0a_9<0<KkC?D00Ta<a_I<0lK6C4ca
0>e<l002C4`0oD`1003mC080C4c^009<C03mC0400?e<0P1<C?@0nT`804c6C<I<
4D`Ao4`10<KkC?P008gg000An0004O`0017h000An005CDd0CDg6ndd14@3hC@80
CDgi00A=001=0?5=1/I=04d004gf0?a=2@1=CA40015=C@3lCOH004gn0?U=0a40
017lC@;6CDgn001=nP00COh0nDd34@004Oa=0/I=COh004gh0?a=2/K6CDdACA40
4DdAo4d0a_i=mP00Z_H0017h000AoP004OP0017h0?e<0lI<C03nC0DAC140aQ7n
C000nTcj0?i<003iC0<A000AnD`00?i<nP03C4`00?i<003nC0D04D`AC03nC000
oT`3001<C?T00da<003nC0/0C01<4D`AC4`0C03nC0<004a<n003C4`00?i<2`1<
04`AC15<C01<0?i<0`00C4ci0?Q<3<I<C1404@0AC4c6C<KjC?P007ce004A4OX0
017n000AnP014A7d0?Q=0a4ACA7hCOD0nDd4aTdACA7lC@00o4gh0?e=0<KlC@LA
CDdA4De=4OM=nP3mC@36ndd54DdA4DdAmTgj0?e=0<KkC@DACA4ACA7fCOX00Te=
0?i=003kCOhAndd00?i=0P1=COP007kc000An`004Oh0017k000Al@3kC0LA4D`A
4D`A4O]<mP3gC0LA4D`AC4`A4OM<nP3lC136001<04`AC15<4A5<04`00?]<nP3l
C040a_a<0a4AC17kC000o4cj0?a<0@36o4`34A5<4O]<003lC?D00<KjC0804@3j
C036l`00KO800A4Ao0024@0Ao0014A7`0?U=oA7iCO800Dg6ndgm4OU=lP3kC@76
COhA0Dg6nTgb005=0?Y=114ACDg6oDd104gb005=0?Y=114ACDg6oDd104gb00E=
0<K6CLKnCOh0oTd5aTe=aP1=m000HO00017m008A017m000AlP3mC0S6C4`0C4c6
C<KnC036oT`00?Y<mP3fC0;6C<KkC?40nD`3aTa<a_]<k`3kC036oT`0a_a<kP3k
C036oT`0a_a<l@3mC000m4`00?e<m@00JNl0017n008A017n000Al@3bC@36mDgg
00==aP36oDd5aTg6CLK6o4d204e=lP06C@1=C@1=a_]=101=C@1=k`3nC@80aP3m
C@80aP3nCNh0oTd20<H0oDd20<H0oTg`0?1=0lI=aTgd001`kP084A400140014A
l001C4cn0?e<101<aTc6oD`00?e<oP01C4cj0?a<003aC000o4ce005<0?]<0/I<
a_a<0@1<k`3kC0;6C<KjC>h0nd`2aTc6nTcb0?i<1P1<04c6C03lC000oT`204`0
oTcf0018k0044@0A017W0?==lP01CDgm0?==o@01CDga0?E=j`3cCN`0ldgc00E=
C@1=04gn00760?i=003nC@40COh01Dd0C@1=COP0043[0?hAiP3cC?8004ck009<
C03kC080C4ck001<l@3eC>X0mDcZ0?E<l005C000C000oDcl0?e<1@00C000C?H0
03K;0?M=j@00COh0oDgn001=j03mC@00oTgW0?M=j03gCO000De=o001CDgh005=
CO`00De=m`008/X0nDcT0?e<h`3nC080C4cU0?U<iP3iC>P0oTcj0?i<l0005/P0
oDf10=/00dd0CDgj00==C@1=l@004X40WP03C01<C?X00da<04ca0006P@210?l0
00J10840o`001X40P@3o0006P@210?l000J10840o`001X40P@3o0006P@210?l0
00J10840o`001X40P@3o000>k`01C4cj005<C840W0008O400dd0CDgj00==C@1=
P@01003kCL401Td0C@1=04g]0014l03nC?X0oTcZ0?e<0`1<C03mC>X0o4`1003l
C>X0o4`1003lC>/00T`00?U<0P00C>/0o4`1003lC>X0nd`00?]<l000Cnl00De=
nP01CDgZ0?==k001C@3mC@400?e=0@1=k001C@3mC@400?e=0@1=kP3_CNh00Dd0
oDd1003mC@40CN`00Dd0o4d00?a=0@1=l@00ENh004cj001<jP3lC000oD`00?a<
kP01C03lC0400?a<0@1<kP01C03lC0400?a<0@1<l@3[C?400D`0o4`1003lC040
C>h00D`0nd`00?]<0@1<lP00NoL004gi0036oTd1003nCOT004ge00M=001=C@1=
0?e=1`1=04e=001=lP02C@00ndd1003kC@8004gb009=003kC@400?]=0P00CO80
nTd3aTg6a_Q=lP02C@00oDd504d004d0oDd2001=l@01C@3jC@00nTd104gc002J
n002C01<n`01C03lC0?6C01<n`02C01<m`0:C01<001<C<I<C<KkC0@004`0C?@0
14`0C000oD`2aP00o4`4001<04cd00A<04`00?e<0/H00?a<1000C01<m03iC0O6
aTa<a/I<a_]<m00EC01<001<C<H0aTa<aP36C4`004`0C?@014a<04`0oT`2aTc6
nT`404`0C4ce0029m`02C@1=o@04CLK6C@3nC@@0CDg6COd00Td0COL0o4d00?]=
0LK6oTd1aP3lCOH0o4d1003hC@;6003lCOH0o4d1003hC@;6003lCOD0oDd=aP36
C@00CDd004g60<KmCOD0o4d1003lC@36oTd2aP00o4gf0?e=003nC@36nDd3aTe=
0?e=mP00Y?P0oT`304`00?]<oP3kC0<004`0oTci005<0?e<1LH0aTa<a_a<0LH0
o4`104ch0?i<1@1<C<I<a_Y<0<KlC000oTch0?i<1@1<C<I<a_Y<0LK6oD`00?i<
n001C4cn00o6C<I<04`0C4`0C01<aTc6oP01C4ch0?i<201<C<H0C<I<a_]<003n
C000oTch005<0?e<0<KgC0;6C<KlC040C?L007Sf009=CLKlC@8004gn00Y=001=
CLI=CLI=COH0lTd0a_U=m@02CDg6m4d5aTe=aTe=m002CDg6nTd1a/KnC@K6aTe=
aTe=m`3kC@o604e=04d0CDd0C@1=C@36ndgg00I=CLH0CDg6nTd7aTg6C@36CDge
0>Q=mP00JO<0oTcm001<oP00C?d00Tc6C?40nT`00?e<1`1<C<I<C<I<lP3nC036
lDcb0?i<0<KjC0S6C<K6C4c6C4cf0?Y<4000C01<04a<04`0C000C<K6oDcd009<
C<KdC?00n4`204`0n4cd001`l`02aTe=o@04CDd0CDgm009=CLKa0?9=0<KmCO00
0Te=0?e=0@00oDd204e=kP02CDd0oDd80036CLI=0<I=lP3nCA4004d004d0C@00
C@1=001=003nCO80lDg_0?e=2P1=C@1=04d0CDd0oDgc002[l`01aP3mC0H0C140
4D`0oD`10<Ke001<oP02C4c6o4`34@004OU<oP00C?X004cn0?U<0a40017lC0;6
C4cn001<nP00C?h0nd`=aT`A000Aa/I<aTc6C4cn001<nP3mC1@004`0C01<C140
015<C01<04`00<KnC?X004cm005<a_a<0a5<C17jC?d004cj001<o@3mC000oT`2
4@0AoT`00?e<o@00C?P00:kd005=COh0oDd24@0AoDgn005=COD014e=0036ndd2
4DdAnDd3001=COP00de=003nC@/0C@1=4DdACDd0C@3nC@<004e=n003CDd00?i=
2`1=04dAaQ76aP360?i=0`00CDgi00==C@00ndd74DdACA5=017kC@<004e=n@04
CDd00<KkC@8ACA7jC@C6001=COP00Te=0?i=003lC@8ACA7lC@00oTd204e=m`00
RoD0oTcn00Y<C15<0140C15<C?h0oTcg0?e<0<KkC0DAC14AC17fC?X0oD`0a_]<
1A5<4A5<4OI<nP3mC036nd`54LHA4LHAnlKlC?L00<Km00U<C<HAC14AC176oTcn
0036m`3mC036nd`54D`A4D`And`0a_e<nP3mC036nd`64Da<4Da<4OI<n000Y?H0
64e=04d004d0C@0A01404@1=04d004d0CDgh0?e=4`1=C@1=04e=4A5=4LI=04d0
CDd0oDgj0?a=0@36o4d34A5=4O]=003lCOX0o4d10<KmC@G64A764LKlC@00o4gg
0036nP05CA4A015=nP00a_L0oTd?001=aTe=04e=4A5=4De=0?e=0@00oTgj0?Y=
003mC@@ACA5=4Oe=003jCOP008Kf00Y<C01<04`0C01<a_hA2/I<04`0C01<04a<
m@01C03lC0K6C<HA4Dc6nd`104cc005<0?Y<114AC4c6oD`104cb005<0?a<0lI<
4A7na_e<0@1<m002C4`0oT`90036C4`A4Da<a_h014a<04a<l`3lC0C6C<HA4OU<
l03iC?hAnDcc001Gl`02C@00oTd10<KmC@00oTd2001=k`3iC@;6CLKlCNh0ndd0
a_i=0<KlCNh0ndd4a/I=a/KlCO@0oTd1003lC@36ndd0a_a=0@00oTgd0?5=k`3^
CO<006g^0?e<101<aTa<jP3lC0C6C4c6a_]<kP3nC080aP3mC080aP3nC>h0oT`9
0<H0a/I<aP360?i<l`03C4`00?]<0LK6oT`0a_]<0`00C4cc0?e<0<KnC036nTc_
005<0?]<0lI<C<KlC040C?<005o`0?i=0/I=a_Y=k03jC@36nDg^0?]=0/I=a_Y=
kP3kC@;6CLKjCO8004gl0?i=1LI=a/I=a_i=o000CO400Dd0oTd2aP00oDd104g^
00==04d0oDd0a_]=0`1=04gc000`lP3jC0;6C<KjC>d0ldc/0?=<k03cC>`0nd`0
a_Y<k03nC000nd`00?i<jP3fC>l003S_00Y=001=C@1=C@00CNT00Te=0?]=0P1=
CNX0mDgZ0?E=j@3gCNT0mDg[009=C@3hC@80CDga000dl@03C4`00?i<003nC0<0
04a<jP3gC>P0mdcX0?M<jP02C4`0nD`204a<jP3gC>T0m4c`000bl00<C@1=04e=
04e=04d0CNP0nDgV0?U=iP3iCNP00Td00?]=0P00CNP0nDgV0?Q=kP007>h024a<
04`0C01<C840n`3mC;l014a<04a<k0003^d01Td0C@1=04f109X000J10840o`00
1X40P@3o0006P@210?l000J10840o`001X40P@3o0006P@210?l000J10840o`00
1X40P@3o0006P@210?l000J10840o`008>l00D`0oT`00?i<0@1<P@2i00520?i2
003n@P40@^l004S`0?]=003kCNX0o4d1003lCNX00Dd0oTd1003nC@40CNT00Td0
COd00Td0CNT0o4d1003lCNX0o4d1003lCNX0nd800?]2l000I_800D`0oD`404`0
C03mC040C>d00D`0oD`1003mC040C>`0nd`1003kC>`014`0C01<o@04C01<04c/
0?]<0@00ndc/005<0?e<0@00oD`104c]00520?e210120480oD8104;b001Ll@3j
C@00nTg]005=0?a=0@00o4d104g/0?i=1@1=001=0?i=jP03C@1=0?e=0`1=04g/
0?i=2@1=04d004d0C@3nCNh00Dd0o4d1003lC@40CNd0nT800?Y2l@00Q_<04T`0
04a<0<I<aP36C<H0C4`004ca009<003kC0400?]<0P00C?8004cn0?i<1@1<001<
0?i<oP00C>h00D`0nD`104c^01=<001<C036C<H00<I<aP1<C000C?800T`00?]<
0@00nd`2001<l@0B@P00@T80aT;60<I2aP12@P00@_<009ke00E=C@1=003mC@c6
04e=aTe=001=04e=m004C@1=003mC@:d003lC@@004d0CO@00Td0COh00dg6CLKk
COh00Td0CO@004gn0?a=0<KiCOh004ge00E=C@1=003lC@?6aTg6oTd5001=04e=
m@04C@1=003mC@;6003lC@@004d0CO@01D9204800?e23<H0@T;6@T800480@T;e
002<mP3mC080C03kC036oT`3aP1<0?e<mP3lC0400?Q<0[@00?a<mP01C03nC080
0<KmC036oT`2aP00oT`104cf005<0?e<003lC036oT`1aP3mC040C?H0oT`204`0
mT`3aP1<0?i<mP3lC0400?Q<0/H00?a<mP3m@P80@P3k@P36oT83aP120?e2mP00
XoL0oTd804e=aTg6CDg6oDd1a/KlC@00oTgh0?i=1@1=CKA=]?Y=0;ClC@00oTgh
0?i=2000CLH0aTe=a_e=1/I=0<I=003nCOH01Td004g6CLKjC@36oDd2001=mP3l
C@K6C@36CDg6oDd0a_i=0<KlCOP0oTd504e=aTg6nTd0a_a=003nCOP0oT880492
aT;6@T;6oD82a/I=oD800?i2m`00K_D00Ta<a_=<1LI<C<I<C?@00Ta<]?A<1KA<
C;A<C?@00Ta<a_A<1LK6C<I<C?<0lT`4aTa<aTcc0?e<0<KfC0G6C4c6C4cd009<
C<KdC0G6C4c6C4cd0092@/Kk@P1<oT89C492C<I2@/I2@_D005Gd0?e=0<KaCO80
oTd0]?5=l@02CDg6oTd00?e=003kCO000Te=a_9=l@3nC@760?M=003mCO80oTd0
a_5=lP3m@P36oT8<CD9=@Te2CDe2@Te2@_@007[b0?i<003mC000oD`00?i<kP02
C4`0oD`1003mC080C4c`00m<C<I<04a<04`004`0C4`0oDcc0?M<0@00nd`0a_i<
lP3nC000oD`1003mC000oTc_009<C03mC0400?e<0P1<C>h0oT800?i22D`0C49<
C012C4;b002Cn000COd0oDd00?i=0Q404Oi=003mCOd004gj001=oP3iC@<A000A
o4d2]4e=oP00COD00<KkC@<A000Ao4d1aTga0?]=1`1=4@004Dd0oTd2aTe=l@3j
C@<A000AnTge001=oP3iC@<A000Ao4d2aTe=oP00COX004;m0?e2003n@PLA015=
@Td0COi2o@00@_P00;Gg00=<C000nT`4015<4@3jC0<004a<n003C4`00?i<2`1<
04`AC15<C01<0?i<0`00C4ci005<C?h00lI<C03nC08AC17mC000oTcn005<C?X0
oD`0a_]<1A4AC15<4O]<0<KmC?X00da<003kC0L0C15<4Da<0?]<oP00C?T00da<
003nC0/0C01<4D`AC4`0C03nC0<004a<n003@T800?Y21`0AC140C49<oD830012
@_L008Gh0?e=0<KkC@HACDdACDdAmTgj0?e=0;CkC@DACA4ACA7fCOX0oDd0a_]=
1A5=4A5=4OI=mP3nC@@0CDd0COdA1lH0CDd0aTe=mP3nC@76a_]=1A5=4A5=4OI=
nP3mC@36ndd54DdA4DdAmTgj0?e23LI2@Te2CD8A@TdACDdAndgl@_P00:?h0?e<
0`1<aP3mC0@AC15<4Oe<0`1<C03mC?X0o4`10;ClC0<A4D`And`00?a<mP04C<H0
C03nC0<A4D`AoT`404`0C4cc00=<C036nd`14A7kC0?604a<m`3lC0;6003mC0<A
4D`AoD`1003nC080C4cj0?a<0@36o4`34A5<4O]<003lC?X0oD8304;60?i21D`A
C15<4Oe20`12@P3m@_P007;c0?U=oQ41CLKkCO400Dd0nTd44A5=CKCmC@40CO40
o4d7aTe=4A5=CLKlCO800Te=0?e=0lI=CA7nC@36oDd204e=lP3mC@36oTd44A5=
CLKlCO400Dd0nTd44A5=CLKmC@40CO40nD;n4@5=a_]2l`00B?80nT`0a_Q<kP3k
C02doT`0]?a<kP3kC036oT`0a_a<kP3kC036n4c_0?Y<0<KgC>l0nd`0a_i<0<Kl
C>h0nT82aTa<nT;b001MlP3gC@36ndg^0?i=0P2d0?e=0P2d0?i=kP04CDd00<Kj
C@<004e=k@02C@00oDd0a_i=0P00CNh0n4d2aTg6ndg_0?i=0P360?e=0P360?i=
kP3i@P9=CLKk@_8006Sb009<C03mC0;6C<KmC080C4c^0?]<0[A<]?Y<kP3kC0;6
C<KjC>d01D`0C01<a_e<0`1<04c^00=<C000oT`2aTc6oD`3001<C>l0nd`2aTc6
nTc^0092@P3m@P;6@/Km@P80@T;b000Zk`3mC@36ndgZ0?==j`3eCNX0mDg[0?a=
0<KiCN`0ldgZ0?e20<Kk@^l0043a009<C03hC080C4c[0?E<j`01C03gC040C>/0
0T`00?]<0P00C>X0o4`00?]<jP3eC>/00T920?Q20P12@_40047`0?i=003lC@00
oTgY0?M=j002CDd0oDd204e=i`07C@1=001=04gW0?a=003mCNP0mdgY0?i2003l
@P00oT;`000_kP3hC>H0nDcV005<0?e<0@1<iP07C01<001<04cV0?e<003nC>H0
nDcV0?Q2kP003>d0nTf10;D0nT;]0006P@210?l000J10840o`001X40P@3o0006
P@210?l000J10840o`001X40P@3o0006P@210?l000402P9i09/2dP6i0302N@3X
0]41]`3o\>"], "Graphics",
  CellMargins->{{126, Inherited}, {Inherited, Inherited}},
  TextAlignment->Center,
  ImageSize->{284, 89},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}]
}, Open  ]],

Cell["Interactive breeding of biomorphs", "NumberedFigure"],

Cell[TextData[{
  "In the sequel of this section we will explore the creative potential of \
evolutionary breeding of biomorph figures. We will explain how to encode the \
biomorphs and how to generate the line drawings from the biomorph vectors. A \
few examples will illustrate the huge variety of biomorph structures. \
Finally, a ",
  ButtonBox["breeding experiment",
    ButtonData:>"breeding experiment",
    ButtonStyle->"Hyperlink"],
  " will demonstrate how to actually evolve biomorphs interactively."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Biomorph Zoo", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Simple Biomorphs", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Function for random biomorph creation", "Subsubsection"],

Cell[BoxData[
    \(randBio := randomBiomorphParams[]\)], "Input",
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["A basic biomorph and some of its mutants", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      biomorph[{3, 2, 3, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 
          7}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .71276 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.119809 0.952381 [
[ 0 0 0 0 ]
[ 1 .71276 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .71276 L
0 .71276 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.24991 .3919 m
.058 .48969 L
s
P
p
.2 0 1 r
.008 w
.24991 .3919 m
.15212 .58382 L
s
P
p
.2 0 1 r
.008 w
.36852 .45234 m
.27073 .64425 L
s
P
p
.2 0 1 r
.008 w
.36852 .45234 m
.40221 .66508 L
s
P
p
.2 0 1 r
.008 w
.40221 .2396 m
.24991 .3919 L
s
P
p
.2 0 1 r
.008 w
.40221 .2396 m
.36852 .45234 L
s
P
p
.2 0 1 r
.008 w
.63148 .45234 m
.59779 .66508 L
s
P
p
.2 0 1 r
.008 w
.63148 .45234 m
.72927 .64425 L
s
P
p
.2 0 1 r
.008 w
.75009 .3919 m
.84788 .58382 L
s
P
p
.2 0 1 r
.008 w
.75009 .3919 m
.942 .48969 L
s
P
p
.2 0 1 r
.008 w
.59779 .2396 m
.63148 .45234 L
s
P
p
.2 0 1 r
.008 w
.59779 .2396 m
.75009 .3919 L
s
P
p
.2 0 1 r
.008 w
.5 .04769 m
.40221 .2396 L
s
P
p
.2 0 1 r
.008 w
.5 .04769 m
.59779 .2396 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{212, 150},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003D0000UPP10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000=@0003D0000e0000=@0003D0000e0000=@0
003D0000e0000=@0001Y0003C00006P0001Y0003C@0006P0001X0003C01<06T0001X0003C@1=06T0
001W0005C00004`0J00006L000E=0000C@1X0000IP000d`000030003C00006D0001V0003C@0000<0
00==0000I@0006D000=<00001@000d`0001T0000I@000dd000050003C@0006@0001T0003C00000L0
00=<0000H`0006@000==00001`000dd0001S0000H`000d`000090003C0000680001S0003C@0000T0
00==0000HP00068000=<00002`000d`0001Q0000HP000dd0000;0003C@000640001Q0003C00000d0
00=<0000H000064000==00003@000dd0001P0000H0000d`0000?0003C00005l0001P0003C@0000l0
00==0000G`0005l000=<00004@000d`0001N0000G`000dd0000A0003C@0005h0001O0003C0000140
00=<0000GP0005h000==00004`000dd0001M0000GP000d`0000C0003C00005d0001M0003C@0001D0
00==0000G00005d000=<00005@000d`0001L0000G0000dd0000G0003C@0005/0001L0003C00001L0
00=<0000F`0005/000==00006@000dd0001J0000F`000d`0000I0003C00005X0001J0003C@0001/0
00==0000F@0005X000=<00006`000d`0001I0000F@000dd0000M0003C@0005P0001I0003C00001d0
00=<0000F00005P000==00007`000dd0001G0000F0000d`0000O0003C00005L0001G0003C@000240
00==0000EP0005L000=<00008@000d`0001F0000EP000dd0000S0003C@0005D0001F0003C00002<0
00=<0000E@0005@00TdW009=E@0005<000=<04`09`000d`0C01D0000DP0014d004dW0004C@00CE<0
001A0005C00004`09`001D`0001<0580001@0005C@0004d0:@001Dd0001=0540001?0003C0000080
00=<00009`000d`000020003C00004h0001>0003C@0000<000==00009`000dd000030003C@0004d0
001=0003C00000@000=<00009`000d`000040003C00004`0001<0003C@0000D000==00009`000dd0
00050003C@0004/0001;0003C00000H000=<00009`000d`000060003C00004X0001:0003C@0000H0
00==0000:@000dd000060003C@0004T000190003C00000L000=<0000:@000d`000070003C00004P0
00180003C@0000P000==0000:@000dd000080003C@0004L000170003C00000T000=<0000:@000d`0
00090003C00004H000160003C@0000X000==0000:@000dd0000:0003C@0004D000150003C00000/0
00=<0000:@000d`0000;0003C00004@000140003C@0000`000==0000:@000dd0000<0003C@0004<0
00130003C00000`000=<0000:`000d`0000<0003C000048000120003C@0000d000==0000:`000dd0
000=0003C@00044000110003C00000h000=<0000:`000d`0000>0003C000040000100003C@0000l0
00==0000:`000dd0000?0003C@0003l0000o0003C000010000=<0000:`000d`0000@0003C00003h0
000n0003C@00014000==0000:`000dd0000A0003C@0003d0000m0003C000014000=<0000;@000d`0
000A0003C00003`0000l0003C@00018000==0000;@000dd0000B0003C@0003/0000k0003C00001<0
00=<0000;@000d`0000C0003C00003X0000j0003C@0001@000==0000;@000dd0000D0003C@0003T0
000i0003C00001D000=<0000;@000d`0000E0003C00003P0000h0003C@0001H000==0000;@000dd0
000F0003C@0003L0000g0003C00001H000=<0000;`000d`0000F0003C00003H0000f0003C@0001L0
00==0000;`000dd0000G0003C@0003D0000d009<6P000d`0000_0003C00001P00T`e0000<P02C@03
04d001T000==0000;`000dd0000H0004C@1=CC<0000`009<0P000d`0000I0003C00002l000=<0000
6@000d`00002C340000^009=10000dd0000I0003C@0002l000==00006@000dd00002009=;`0002`0
0T`50003C00001X000=<0000;`000d`0000J0003C00000<00T`]0000:`000dd000050003C@0001T0
00==0000<@000dd0000I0003C@0000D000==0000:P0002T00T`70003C00001X000=<0000<@000d`0
000J0003C00000D00T`Z00009`02C@T000==00006P000dd0000a0003C@0001X000==00001`02CBP0
000U009<2P000d`0000K0003C000034000=<00006`000d`00008009<9P0002<00Td<0003C@0001/0
00==0000<@000dd0000K0003C@0000X00TdT00008@02C0d000=<000070000d`0000a0003C00001`0
00=<00002`02C280000O009=3`000dd0000K0003C@0003<000==00006`000dd0000=009=800001d0
0T`@0003C00001`000=<0000<`000d`0000L0003C00000h00T`N00006`02CA8000==000070000dd0
000c0003C@0001`000==00004002CA`0000I009<4`000d`0000M0003C00003<000=<00007@000d`0
000A009<6P0001L00TdE0003C@0001`00Tde009=7P000dd0000C009=600001H000=<000050000d`0
000M009<=@02C1l000=<000050000d`0000E00005002CAL000==0000700014d004dc0004C@00CAh0
00==00005@02CAD0000B009<60000d`0000M0004C000C3<000A<001<7`000d`0000F009<4`000100
0TdJ0003C@0001`000E=0000C@0c0005C@0004d07P000dd0000H009=4@0000h00T`K0003C00001d0
00E<0000C00c0005C00004`07`000d`0000I009<3`0000d000==00006P000dd0000M0003C@000080
00==0000<@000dd000020003C@0001d000==00006P000dd0000<0000:P000d`0000M0003C0000080
00=<0000<@000d`000020003C00001d000=<0000:@0002T000==00007@000dd000030003C@000340
00==00000`000dd0000M0003C@0002P0000Y0003C00001`000=<00001@000d`0000_0003C00000D0
00=<000070000d`0000X0000:0000dd0000M0003C@0000D000==0000;`000dd000050003C@0001d0
00==00009`0002P000=<000070000d`000060003C00002l000=<00001P000d`0000L0003C00002L0
000W0003C@0001d000==00001P000dd0000_0003C@0000H000==00007@000dd0000V00009`000d`0
000L0003C00000L000=<0000;`000d`000070003C00001`000=<00009P0002H000==00007@000dd0
00070003C@0002l000==00001`000dd0000M0003C@0002D0000V0003C00001`000=<00002@000d`0
000]0003C00000T000=<000070000d`0000U00009@000dd0000M0003C@0000T000==0000;@000dd0
00090003C@0001d000==0000900002D000=<000070000d`0000:0003C00002d000=<00002P000d`0
000L0003C00002@0000T0003C@0001d000==00002P000dd0000]0003C@0000X000==00007@000dd0
000S000090000d`0000L0003C00000/000=<0000;@000d`0000;0003C00001`000=<00008`0002<0
00==00007@000dd0000;0003C@0002d000==00002`000dd0000M0003C@000280000S0003C00001`0
00=<00003@000d`0000[0003C00000d000=<000070000d`0000R00008P000dd0000M0003C@0000d0
00==0000:`000dd0000=0003C@0001d000==00008@00028000=<000070000d`0000>0003C00002/0
00=<00003P000d`0000L0003C0000240000Q0003C@0001d000==00003P000dd0000[0003C@0000h0
00==00007@000dd0000P00008@000d`0000L0003C00000l000=<0000:`000d`0000?0003C00001`0
00=<00008000020000==00007@000dd0000?0003C@0002/000==00003`000dd0000M0003C@0001l0
000o0003C000010000=<0000:`000d`0000@0003C00003h0000o0003C@00014000==0000:@000dd0
000A0003C@0003h0000n0003C000018000=<0000:@000d`0000B0003C00003d0000m0003C@0001<0
00==0000:@000dd0000C0003C@0003`0000m0003C00001<000=<0000:@000d`0000C0003C00003`0
000l0003C@0001@000==0000:@000dd0000D0003C@0003/0000l0003C00001@000=<0000:@000d`0
000D0003C00003/0000k0003C@0001H000==00009`000dd0000F0003C@0003X0000k0003C00001H0
00=<00009`000d`0000F0003C00003X0000j0003C@0001L000==00009`000dd0000G0003C@0003T0
000j0003C00001L000=<00009`000d`0000G0003C00003T0000i0003C@0001P000==00009`000dd0
000H0003C@0003P0001D0003C00002L000=<0000D`0005@000==00009`000dd0001C0000E@000d`0
000U0003C00005@0001E0003C@0002D000==0000E00005D000=<00009@000d`0001D0000e0000=@0
003D0000e0000=@0003D0000e0000=@0003D0000\
\>"],
  ImageRangeCache->{{{0, 211}, {149, 0}} -> {-0.0299112, 0.125796, 0.00502286,
   0.00502286}}]
}, Open  ]],

Cell[TextData["Gen 1+"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      biomorph[{4, 2, 3, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 
          7}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65137 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.150506 0.952381 [
[ 0 0 0 0 ]
[ 1 .65137 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .65137 L
0 .65137 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.19909 .34402 m
.05426 .36696 L
s
P
p
.2 0 1 r
.008 w
.19909 .34402 m
.0954 .44771 L
s
P
p
.2 0 1 r
.008 w
.26317 .40811 m
.15948 .51179 L
s
P
p
.2 0 1 r
.008 w
.26317 .40811 m
.24023 .55294 L
s
P
p
.2 0 1 r
.008 w
.32974 .27745 m
.19909 .34402 L
s
P
p
.2 0 1 r
.008 w
.32974 .27745 m
.26317 .40811 L
s
P
p
.2 0 1 r
.008 w
.34392 .44925 m
.24023 .55294 L
s
P
p
.2 0 1 r
.008 w
.34392 .44925 m
.32098 .59408 L
s
P
p
.2 0 1 r
.008 w
.43343 .46343 m
.41049 .60826 L
s
P
p
.2 0 1 r
.008 w
.43343 .46343 m
.5 .59408 L
s
P
p
.2 0 1 r
.008 w
.41049 .3186 m
.34392 .44925 L
s
P
p
.2 0 1 r
.008 w
.41049 .3186 m
.43343 .46343 L
s
P
p
.2 0 1 r
.008 w
.43343 .17376 m
.32974 .27745 L
s
P
p
.2 0 1 r
.008 w
.43343 .17376 m
.41049 .3186 L
s
P
p
.2 0 1 r
.008 w
.56657 .46343 m
.5 .59408 L
s
P
p
.2 0 1 r
.008 w
.56657 .46343 m
.58951 .60826 L
s
P
p
.2 0 1 r
.008 w
.65608 .44925 m
.67902 .59408 L
s
P
p
.2 0 1 r
.008 w
.65608 .44925 m
.75977 .55294 L
s
P
p
.2 0 1 r
.008 w
.58951 .3186 m
.56657 .46343 L
s
P
p
.2 0 1 r
.008 w
.58951 .3186 m
.65608 .44925 L
s
P
p
.2 0 1 r
.008 w
.73683 .40811 m
.75977 .55294 L
s
P
p
.2 0 1 r
.008 w
.73683 .40811 m
.84052 .51179 L
s
P
p
.2 0 1 r
.008 w
.80091 .34402 m
.9046 .44771 L
s
P
p
.2 0 1 r
.008 w
.80091 .34402 m
.94574 .36696 L
s
P
p
.2 0 1 r
.008 w
.67026 .27745 m
.73683 .40811 L
s
P
p
.2 0 1 r
.008 w
.67026 .27745 m
.80091 .34402 L
s
P
p
.2 0 1 r
.008 w
.56657 .17376 m
.58951 .3186 L
s
P
p
.2 0 1 r
.008 w
.56657 .17376 m
.67026 .27745 L
s
P
p
.2 0 1 r
.008 w
.5 .04311 m
.43343 .17376 L
s
P
p
.2 0 1 r
.008 w
.5 .04311 m
.56657 .17376 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{221, 143},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M0000S`P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000=d0003M0000g@000=d0003M0000g@000=d0
003M0000g@000=d0001^0003C@0006`0001^0003C00006`0001]0003C@1=06d0001]0003C01<06d0
001/0005C@0004d0K00006`000E<0000C01/0000J`000dd000030003C@0006T0001[0003C00000<0
00=<0000J@0006X000==00001@000dd0001X0000J@000d`000060003C00006P0001Y0003C@0000L0
00==0000I`0006P000=<000020000d`0001W0000J0000dd000090003C@0006H0001W0003C00000X0
00=<0000IP0006L000==00002`000dd0001U0000IP000d`0000<0003C00006D0001V0003C@0000d0
00==0000I00006D000=<00003P000d`0001T0000I@000dd0000?0003C@0006<0001T0003C0000100
00=<0000H`0006@000==00004@000dd0001R0000H`000d`0000B0003C0000680001R0003C@0001@0
00==0000H@00068000=<000050000d`0001Q0000H@000dd0000F0003C@000600001Q0003C00001H0
00=<0000H000060000==000060000dd0001O0000H0000d`0000H0003C00005l0001O0003C@0001X0
00==0000GP0005h00T`L009<G`0005d000==04d070000dd0C@1N0000G00014`004`L0004C000C5d0
001K0004C@00CAh000A=001=G00005X000E<0000C00N0005C00004`0F`0005T000==00000P000dd0
000L0003C@00008000==0000F00005P000=<00000`000d`0000L0003C00000<000=<0000E`0005L0
00==000010000dd0000L0003C@0000@000==0000EP0005H000=<00001@000d`0000L0003C00000D0
00=<0000E@0005D000==00001P000dd0000L0003C@0000H000==0000E00005@000=<00001P000d`0
000N0003C00000H000=<0000D`0005<000==00001`000dd0000N0003C@0000L000==0000DP000580
00=<000020000d`0000N0003C00000P000=<0000D@00054000==00002@000dd0000N0003C@0000T0
00==0000D000050000=<00002P000d`0000N0003C00000X000=<0000C`0004l000==00002`000dd0
000N0003C@0000/000==0000CP0004h000=<00002`000d`0000P0003C00000/000=<0000C@0004d0
00==000030000dd0000P0003C@0000`000==0000C00004`000=<00003@000d`0000P0003C00000d0
00=<0000B`0004/000==00003P000dd0000P0003C@0000h000==0000BP0004X000=<00003`000d`0
000P0003C00000l000=<0000B@0004T000==000040000dd0000P0003C@00010000==0000B00004L0
0T`B0003C000028000=<00004002C4P00015009=00<0C@004@000dd0000R0003C@00010000A=04e=
AP0004<00T`20003C000014000=<00008P000d`0000A0003C000009<A00004400Td40003C@000140
00==00008P000dd0000A0003C@0000800Te20000?`02C0D000=<00004P000d`0000R0003C0000180
00=<00000`02C400000m009=1`000dd0000B0003C@00028000==00004P000dd00005009=?P0003/0
0T`80003C00001<000=<00008P000d`0000C0003C00000H00T`l0000>@02C@X000==00004P000dd0
000T0003C@00018000==00002002CCX0000g009<2`000d`0000C0003C00002@000=<00004`000d`0
0009009<>00003D00Td=0003C@0001<000==000090000dd0000C0003C@0000/00Tdf0000<`02C0h0
00=<000050000d`0000T0003C00001@000=<00003002C3@0000a009=40000dd0000C009=9P02CAD0
00==00003P02CC80000_009<4@000d`0000D009<9P02C1H000=<00003`02C300000]009=4`000dd0
000C0004C@00CB@000A=001=5@000dd0000A009=;P0002T014`D0003C00001@000A<001<900014`0
04`F0003C000018014`Z00008P07C@8000==00004`000dd0000C0005C@0004d090001Dd0001=01D0
00==00004`000dd00007CB<0000L00I<20000d`0000C0003C00001@000E<0000C00T0005C00004`0
5P000d`0000C0003C00000H01T`M00005P06C@d000==000050000dd0000C0003C@00008000==0000
8P000dd000020003C@0001<000==000050000dd0000;00I=5`0000l01d`B0003C00001@000=<0000
4`000d`000030003C000028000=<00000`000d`0000C0003C00001@000=<00004007C100000<00==
60000dd0000E0003C@0001<000==00000`000dd0000R0003C@0000<000==00004`000dd0000E0003
C@0001H00dd=00009P000d`0000E0003C00001<000=<00001@000d`0000P0003C00000D000=<0000
4`000d`0000E0003C00002D0000U0003C@0001H000==00004`000dd000050003C@00020000==0000
1@000dd0000C0003C@0001H000==0000900002@000=<00005P000d`0000C0003C00000H000=<0000
80000d`000060003C00001<000=<00005P000d`0000S00008`000dd0000G0003C@0001<000==0000
1P000dd0000P0003C@0000H000==00004`000dd0000G0003C@000280000R0003C00001L000=<0000
4`000d`000070003C000020000=<00001`000d`0000C0003C00001L000=<00008@00024000==0000
60000dd0000C0003C@0000L000==000080000dd000070003C@0001<000==000060000dd0000P0000
80000d`0000H0003C00001<000=<00002@000d`0000N0003C00000T000=<00004`000d`0000H0003
C00001l0000O0003C@0001T000==00004`000dd000090003C@0001h000==00002@000dd0000C0003
C@0001T000==00007P0001h000=<00006@000d`0000C0003C00000X000=<00007P000d`0000:0003
C00001<000=<00006@000d`0000M00007@000dd0000I009=5@000dd0000:0003C@0001h000==0000
2P000dd0000C009=6`000dd0000L000070000d`0000I0003C01<01@000=<00002`000d`0000N0003
C00000/000=<00004P000d`0C00K0003C00001/0000K0003C@0001T000A=001=4`000dd0000<0003
C@0001h000==000030000dd0000A0004C@00CA/000==00006P0001X000=<00006@0014`004`D0003
C00000d000=<000070000d`0000=0003C000018000A<001<6`000d`0000I00006@000dd0000I0005
C@0004d04`000dd0000>0003C@0001`000==00003P000dd0000A0005C@0004d06`000dd0000H0000
60000d`0000I0003C000008000=<00004@000d`0000>0003C00001`000=<00003P000d`0000A0003
C000008000=<00006@000d`0000G00005`000dd0000I0003C@0000<000==000040000dd0000?0003
C@0001`000==00003`000dd0000@0003C@0000<000==00006@000dd0000F00005P000d`0000I0003
C00000@000=<000040000d`0000?0003C00001`000=<00003`000d`0000@0003C00000@000=<0000
6@000d`0000E00005@000dd0000I0003C@0000D000==00003`000dd0000@0003C@0001`000==0000
40000dd0000?0003C@0000D000==00006@000dd0000D0000<0000d`000060003C00000l000=<0000
40000d`0000L0003C000010000=<00003`000d`000060003C00002l0000_0003C@0000H000==0000
3`02CA<000==00006P000dd0000A009=4@000dd000060003C@0002h0000^0003C00000L000=<0000
3P000d`0C00C0003C00001X000=<00004@000d`0C00@0003C00000L000=<0000;@0002d000==0000
20000dd0000=0003C@1=01@000==00006P000dd0000B0003C@1=00l000==000020000dd0000/0000
;0000d`000090003C00000`000A<001<50000d`0000J0003C000018000A<001<3P000d`000090003
C00002/0000[0003C@0000X000==00002`001Dd0001=01@00TdJ009=50001Dd0001=00d000==0000
2P000dd0000Z0000:P000d`0000;0003C00000X000=<00000P000d`0000B009<6P02C1@000=<0000
0P000d`0000:0003C00000/000=<0000:@0002T000==00002`000dd0000:0003C@0000<000==0000
4@0014d004dH0004C@00CA<000==00000`000dd0000:0003C@0000/000==0000:00002P000=<0000
30000d`000090003C00000@000=<00004@0014`004`H0004C000C1<000=<000010000d`000090003
C00000`000=<00009`0002L000==00003@000dd000080003C@0000D000==00004@001Dd0001=01H0
00E=0000C@0C0003C@0000D000==000020000dd0000=0003C@0002H0000V0003C00000h000=<0000
1`000d`000050003C000018000E<0000C00F0005C00004`050000d`000050003C00000L000=<0000
3P000d`0000U00009@000dd0000?0003C@0000H000==00001P000dd0000B0003C@00008000==0000
4P000dd000020003C@00018000==00001P000dd000060003C@0000l000==0000900002@000=<0000
40000d`000050003C00000L000=<00004P000d`000030003C000014000=<00000P000d`0000B0003
C00000L000=<00001@000d`0000@0003C00002<0000S0003C@00010000==00001@000dd000080003
C@00014000==000010000dd0000@0003C@0000@000==00004@000dd000080003C@0000D000==0000
40000dd0000R0000=P000d`000040003C00000T000=<00004@000d`000050003C00000l000=<0000
10000d`0000A0003C00000T000=<000010000d`0000e0000=P000dd000030003C@0000X000==0000
4@000dd000050003C@0000h000==00001@000dd0000A0003C@0000X000==00000`000dd0000e0000
=P000d`000020003C00000X000=<00004P000d`000060003C00000d000=<00001@000d`0000B0003
C00000X000=<00000P000d`0000e0000=P001Dd0001=00d000==00004P000dd000060003C@0000`0
00==00001P000dd0000B0003C@0000/000E=0000C@0g0000=P0014`004`>0003C000018000=<0000
1`000d`0000;0003C00000H000=<00004P000d`0000<0004C000C3L0000f0003C@1=00l000==0000
4@000dd000080003C@0000X000==000020000dd0000A0003C@0000d000==04d0=`0003D000=<04`0
40000d`0000A0003C00000T000=<00002@000d`000080003C000014000=<00003P000d`0C00f0000
=@02CA4000==00004@000dd000090003C@0000P000==00002@000dd0000A0003C@0000l00Tdf0000
=@000d`0000?0003C000018000=<00002P000d`000070003C00000T000=<00004P000d`0000?0003
C00003@000170003C@00018000==00002P000dd000060003C@0000X000==00004P000dd000160000
A`000d`0000B0003C00000/000=<00001@000d`0000:0003C000018000=<0000AP0004L000==0000
4P000dd0000<0003C@0000<000==00002`000dd0000B0003C@0004H000170003C000014000=<0000
3@000d`000030003C00000`000=<00004@000d`000160000A`000dd0000A0003C@0000h000E=0000
C@0?0003C@00014000==0000AP0004L000=<00004@000d`0000>0005C00004`03`000d`0000A0003
C00004H000160003C@00018000==00003`000dd0C@0@0003C@00018000==0000A@0004H000=<0000
4P000d`0000?0003C01<010000=<00004P000d`000150000AP000dd0000B0003C@00010000==0000
3`000dd0000B0003C@0004D0001J0003C00002@000=<0000F@0005X000==000090000dd0001I0000
FP000d`0000T0003C00005T0003M0000g@000=d0003M0000g@000=d0003M0000g@000=d00000\
\>"],
  ImageRangeCache->{{{0, 220}, {142, 0}} -> {-0.0298168, 0.158028, 0.00481652,
   0.00481652}}]
}, Open  ]],

Cell[TextData["Gen 2+"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      biomorph[{3, 3, 3, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 
          7}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55676 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.197811 0.952381 [
[ 0 0 0 0 ]
[ 1 .55676 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .55676 L
0 .55676 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.21626 .18508 m
.05504 .18508 L
s
P
p
.2 0 1 r
.008 w
.21626 .18508 m
.08583 .27984 L
s
P
p
.2 0 1 r
.008 w
.27482 .26569 m
.1444 .36045 L
s
P
p
.2 0 1 r
.008 w
.27482 .26569 m
.225 .41901 L
s
P
p
.2 0 1 r
.008 w
.36958 .13526 m
.21626 .18508 L
s
P
p
.2 0 1 r
.008 w
.36958 .13526 m
.27482 .26569 L
s
P
p
.2 0 1 r
.008 w
.45018 .35504 m
.35542 .48546 L
s
P
p
.2 0 1 r
.008 w
.45018 .35504 m
.45018 .51625 L
s
P
p
.2 0 1 r
.008 w
.54982 .35504 m
.54982 .51625 L
s
P
p
.2 0 1 r
.008 w
.54982 .35504 m
.64458 .48546 L
s
P
p
.2 0 1 r
.008 w
.5 .20172 m
.45018 .35504 L
s
P
p
.2 0 1 r
.008 w
.5 .20172 m
.54982 .35504 L
s
P
p
.2 0 1 r
.008 w
.72518 .26569 m
.775 .41901 L
s
P
p
.2 0 1 r
.008 w
.72518 .26569 m
.8556 .36045 L
s
P
p
.2 0 1 r
.008 w
.78374 .18508 m
.91417 .27984 L
s
P
p
.2 0 1 r
.008 w
.78374 .18508 m
.94496 .18508 L
s
P
p
.2 0 1 r
.008 w
.63042 .13526 m
.72518 .26569 L
s
P
p
.2 0 1 r
.008 w
.63042 .13526 m
.78374 .18508 L
s
P
p
.2 0 1 r
.008 w
.5 .04051 m
.36958 .13526 L
s
P
p
.2 0 1 r
.008 w
.5 .04051 m
.5 .20172 L
s
P
p
.2 0 1 r
.008 w
.5 .04051 m
.63042 .13526 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{238, 132},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003^0000Q0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000>h0003^0000kP000>h0003^0000kP000>h0
003^0000kP000>h0001e00=<MP0007@000E=04d0C@1e0000LP02C08000=<00000Tac0000L@000dd0
00020003C@00008000==0000L000070000=<00000`000d`000030003C00006l0001^009=1P000dd0
0004009=K`0006d000=<00001P000d`000060003C00006`0001[009=2@000dd00007009=K00006X0
00=<00002@000d`000090003C00006T0001Y0003C@0000X000==00002P000dd0001X0000I`02C0d0
00=<00002`02C6P0001V0003C@0000d000==00003@000dd0001U0000I002C10000=<00003P02C6D0
001S0003C@00010000==000040000dd0001R0000HP000d`0000A0003C000014000=<0000H@000600
0TdD0003C@0001800TeQ0000G`000d`0000D0003C00001@000=<0000GP0005d00TdG0003C@0001D0
0TeN0000G0000d`0000G0003C00001L000=<0000F`0005/000==000060000dd0000H0003C@0005X0
001I009<6`000d`0000I009<FP0005P000==00006`000dd0000K0003C@0005L0001F009<7P000d`0
000L00=<EP0005<00dd00`1=000M0003C@0001`000==00000deC0000D003C0<000=<00007@000d`0
000M0003C00000800da@0000C@03C@D000==00007P000dd0000N0003C@0000@00de=0000BP03C0P0
00=<00007P000d`0000N0003C00000L00da:0000A`03C@X000==00007`000dd0000O0003C@0000T0
0de70000A003C0`000=<000080000d`0000P0003C00000/00da40000@@03C@h000==00008@000dd0
000Q0003C@0000d00de10000?P03C14000=<00008@000d`0000Q0003C00001000d`n0000>`03CA<0
00==00008P000dd0000R0003C@0001800ddk0000>003C1D000=<00008`000d`0000S0003C00001@0
0d`h0000=@03CAP000==00008`000dd0000S0003C@0001L00dde00003@0XC1X000=<000090000d`0
000T0003C00001T09d`>0000<@000dd0000J0003C@0002D000==00009@000dd0000J0003C@000300
000`0003C00001X000=<00009P000d`0000V0003C00001X000=<0000;`0002h00TdM0003C@0002H0
00==00009P000dd0000K009=;`0002d000=<000070000d`0000W0003C00002L000=<000070000d`0
000/0000:`02CAh000==0000:0000dd0000X0003C@0001`00Td/0000:P000d`0000N0003C00002L0
00=<04`0:@000d`0000N0003C00002T0000Y0003C@0001h000==0000:0000dd0C@0Z0003C@0001h0
00==0000:00002L00T`P0003C00002T000=<04`0:`000d`0000N009<:00002H000==00007`000dd0
000Y0005C@0004d0:`000dd0000O0003C@0002D0000U0003C000020000=<0000:@001D`0001<02/0
00=<000080000d`0000T00008`02CB8000==0000:P001Dd0001=02`000==00008002CB@0000R0003
C000024000=<0000:P000d`000030003C00002X000=<00008@000d`0000Q00008@000dd0000R0003
C@0002X000==00000`000dd0000Z0003C@00028000==0000800001l00T`T0003C00002/000=<0000
0`000d`0000[0003C00002800T`P00007P000dd0000S0003C@0002/000==00001@000dd0000[0003
C@0002<000==00007@0001`00T`U0003C00002`000=<00001@000d`0000/0003C00002<00T`M0000
6`000dd0000U0003C@0002`000==00001@000dd0000/0003C@0002D000==00006P0001X000=<0000
9@000d`0000/0003C00000L000=<0000;0000d`0000U0003C00001T0000H009=9P02CBl000==0000
1`000dd0000]009=9P02CAT0000G0003C00002D000=<04`0;`000d`000070003C00002d000=<04`0
9`000d`0000F00005P000dd0000T009=00<0C@00;P000dd000090003C@0002d000A=04e=9P000dd0
000E00005@000d`0000T0005C00004`0;`000d`000090003C00002d000E<0000C00V0003C00001@0
000k0003C@00008000==0000;@000dd000090003C@0002d000==00000P000dd0000j0000>@02C0@0
00=<0000;@000d`0000;0003C00002d000=<00000P02C3X0000h0003C@0000@000==0000;@000dd0
000;0003C@0002d000==000010000dd0000g0000=P02C0L000=<0000;@000d`0000;0003C00002d0
00=<00001@02C3L0000e0003C@0000H000==0000;@000dd0000=0003C@0002d000==00001P000dd0
000d0000=0000d`000070003C00002d000=<00003@000d`0000]0003C00000L000=<0000<`000380
0Td:0003C@0002d000==00003@000dd0000]0003C@0000P00Tdc0000<@000d`000090003C00002d0
00=<00003`000d`0000]0003C00000T000=<0000<00002l00Td<0003C@0002d000==00003`000dd0
000]0003C@0000X00Td`0000;P000d`0000<0003C00002d000=<00003`000d`0000]0003C00000`0
00=<0000;@0002d000==000030000dd0000]0003C@00014000==0000;@000dd0000<0003C@0002`0
000[009<3`000d`0000]0003C000014000=<0000;@000d`0000=009<;00002X000==00003`000dd0
000]0003C@00014000==0000;@000dd0000?0003C@0002T0000X009<4@000d`0000]0003C00001<0
00=<0000;@000d`0000?009<:@0002L000==00004@000dd0000]0003C@0001<000==0000;@000dd0
000A0003C@0002H0000V0003C000018000=<0000;@000d`0000C0003C00002d000=<00004P000d`0
000U00009002CA@000==0000;@000dd0000E0003C@0002d000==00004P02CBD0000S0003C00001@0
00=<0000;@000d`0000E0003C00002d000=<000050000d`0000R00008P000dd0000E0003C@0002d0
00==00005@000dd0000]0003C@0001D000==00008@0003T000=<0000;@02C1L00T`_0003C00003P0
000i0003C@0002`000==04d05`000dd0C@0^0003C@0003P0000i0003C00002`000=<04`05`000d`0
C00^0003C00003P0000h0003C@0002`000A=001=5`0014d004d^0003C@0003L0000h0003C00002/0
00E<0000C00G0005C00004`0;@000d`0000g0000>0000dd0000Z0003C@00008000==00005@000dd0
00020003C@0002X000==0000=`0003L000=<0000:`000d`000020003C00001D000=<00000P000d`0
000[0003C00003H0000g0003C@0002X000==00000`000dd0000E0003C@0000<000==0000:P000dd0
000f0000=`000d`0000Y0003C00000@000=<00005@000d`000040003C00002T000=<0000=P0003H0
00==0000:P000dd000040003C@0001D000==000010000dd0000Z0003C@0003D0000f0003C00002T0
00=<00001@000d`0000E0003C00000D000=<0000:@000d`0000e0000=P000dd0000X0003C@0000H0
00==00005@000dd000060003C@0002P000==0000=@0003D000=<0000:0000d`000070003C00001D0
00=<00001`000d`0000X0003C00003@0000e0003C@0002P000==00001`000dd0000E0003C@0000L0
00==0000:0000dd0000d0000G`000d`000080003C00001D000=<000020000d`0001N0000GP000dd0
00090003C@0001D000==00002@000dd0001M0000GP000d`000090003C00001D000=<00002@000d`0
001M0000G@000dd0000:0003C@0001D000==00002P000dd0001L0000G0000d`0000;0003C00001D0
00=<00002`000d`0001K0000F`000dd0000<0003C@0001D000==000030000dd0001J0000F`000d`0
000<0003C00001D000=<000030000d`0001J0000FP000dd0000=0003C@0001D000==00003@000dd0
001I0000F@000d`0000>0003C00001D000=<00003P000d`0001H0000F@000dd0000>0003C@0001D0
00==00003P000dd0001H0000F0000d`0000?0003C00001D000=<00003`000d`0001G0000E`000dd0
000@0003C@0001D000==000040000dd0001F0000EP000d`0000A0003C00001D000=<00004@000d`0
001E0000EP000dd0000A0003C@0001D000==00004@000dd0001E0000E@000d`0000B0003C00001D0
00=<00004P000d`0001D0000E0000dd0000C0003C@0001D000==00004`000dd0001C0000JP000d`0
000E0003C00006T0001Z0003C@0001D000==0000J@0006X000=<00005@000d`0001Y0000JP000dd0
000E0003C@0006T0001Z0003C00001D000=<0000J@0006X000==00005@000dd0001Y0000JP000d`0
000E0003C00006T0003^0000kP000>h0003^0000kP000>h0003^0000kP000>h00000\
\>"],
  ImageRangeCache->{{{0, 237}, {131, 0}} -> {-0.028821, 0.207699, 0.00446262, 
  0.00446262}}]
}, Open  ]],

Cell[TextData["Gen 3+"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      biomorph[{3, 2, 4, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 
          7}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .60741 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.172483 0.952381 [
[ 0 0 0 0 ]
[ 1 .60741 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .60741 L
0 .60741 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.23618 .30687 m
.05655 .36524 L
s
P
p
.2 0 1 r
.008 w
.23618 .30687 m
.12516 .45968 L
s
P
p
.2 0 1 r
.008 w
.33062 .37549 m
.2196 .52829 L
s
P
p
.2 0 1 r
.008 w
.33062 .37549 m
.33062 .56436 L
s
P
p
.2 0 1 r
.008 w
.38898 .19586 m
.23618 .30687 L
s
P
p
.2 0 1 r
.008 w
.38898 .19586 m
.33062 .37549 L
s
P
p
.2 0 1 r
.008 w
.66938 .37549 m
.66938 .56436 L
s
P
p
.2 0 1 r
.008 w
.66938 .37549 m
.7804 .52829 L
s
P
p
.2 0 1 r
.008 w
.76382 .30687 m
.87484 .45968 L
s
P
p
.2 0 1 r
.008 w
.76382 .30687 m
.94345 .36524 L
s
P
p
.2 0 1 r
.008 w
.61102 .19586 m
.66938 .37549 L
s
P
p
.2 0 1 r
.008 w
.61102 .19586 m
.76382 .30687 L
s
P
p
.2 0 1 r
.008 w
.5 .04305 m
.38898 .19586 L
s
P
p
.2 0 1 r
.008 w
.5 .04305 m
.61102 .19586 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{227, 137},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003S0000R@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000><0003S0000h`000><0003S0000h`000><0
003S0000h`000><0001a0003C@0006l0001a0003C00006l0001`0003C@1=0700001_0005C00004`0
K`0006h000==00000P000dd0001]0000KP000d`000030003C00006`0001]0003C@0000D000==0000
J`0006`000=<00001`000d`0001Z0000J`000dd000080003C@0006X0001[0003C00000T000=<0000
J@0006X000==00002`000dd0001X0000J@000d`0000<0003C00006P0001Y0003C@0000d000==0000
I`0006P000=<00003`000d`0001V0000I`000dd0000A0003C@0006D0001V0003C000018000=<0000
I@0006H000==00004`000dd0001T0000I@000d`0000E0003C00006<0001T0003C@0001H000==0000
H`0006<000=<000060000d`0001R0000H`000dd0000I0003C@000640001R0003C00001X000=<0000
H@00064000==000070000dd0001P0000H0000d`0000N0003C00005l0001P0003C@0001l000==0000
GP0005l000=<000080000d`0001N0000GP000dd0000R0003C@0005d0001N0003C00002<000=<0000
G00005d000==000090000dd0001L0000G0000d`0000V0003C00005/0001K0003C@0002P000==0000
FP0005/000=<0000:@000d`0001I0000FP000dd0000Z0003C@0005T0001I0003C00002`000=<0000
F00005L00Td`009=F00005H000=<04`0<0000d`0C01G0000E002C@8000==0000;P000dd00002CED0
001C0005C00004`0<P001D`0001<05@0001B0003C@00008000==0000<0000dd000020003C@000540
001@009<1@000d`0000`0003C00000<00TaA0000C`000dd000040003C@00038000==000010000dd0
001>0000C@02C0L000=<0000<P000d`00005009<CP0004`000==00001`000dd0000b0003C@0000L0
00==0000B`0004/000=<00001`000d`0000d0003C00000L000=<0000BP0004T00Td:0003C@0003@0
00==00002002CDX000180003C00000X000=<0000=0000d`0000:0003C00004L00016009=30000dd0
000f0003C@0000X00Te70000A@000d`0000<0003C00003H000=<000030000d`000140000A0000dd0
000=0003C@0003H000==00003@000dd000130000@P02C0l000=<0000>0000d`0000=009<@`000440
00==00003`000dd0000h0003C@0000l000==0000@00003l00T`B0003C00003P000=<00004002C400
000n0003C@00014000==0000>P000dd0000A0003C@0003d0000m0003C000018000=<0000>P000d`0
000B0003C00003`0000k009=5@000dd0000j0003C@0001<00Tdl0000>P000d`0000D0003C00003`0
00=<000050000d`0000i0000>002CAL000==0000?0000dd0000E009=>@0003L000=<00005`000d`0
000l0003C00001L000=<0000=P0003H000==000060000dd0000l0003C@0001P000==0000=@0003<0
0d`J0003C00003h000=<00006003C3@0000`00==0P000dd0000H0003C@0003h000==000060000dd0
0003CC40000]00=<10000d`0000I0003C00003h000=<00006@000d`0000200=<;P0002X00dd60003
C@0001T000==0000@0000dd0000I0003C@0000@00dd[00009`03C0T000=<00006@000d`000100003
C00001T000=<00001`03C2P0000T00==2`000dd0000J0003C@00040000==00006P000dd0000900==
9@0002400d`=0003C00001X000=<0000@P000d`0000J0003C00000/00d`R00007P03C@l000==0000
6`000dd000120003C@0001/000==00003@03CAl0000K00=<4P000d`0000K0003C000048000=<0000
6`000d`0000@00=<700001P00ddD0003C@0001/000==0000A0000dd0000K0003C@0001800ddI0000
5@03C1H000=<000070000d`000140003C00001`000=<00005003C1H0000B00==6@000dd0000L0003
C@0004@000==000070000dd0000G00==4`0000l00d`K0003C00001`000=<0000AP000d`0000L0003
C00001T00d`@00003@02CAd000==00007@000dd000160003C@0001d000==00006`02C@h0000[0003
C00001h000=<0000AP000d`0000N0003C00002X0000[0003C@0001d000==0000B0000dd0000M0003
C@0002X0000Z0003C00001h000=<0000B0000d`0000N0003C00002T0000Y0003C@0001l000==0000
B0000dd0000O0003C@0002P0000Y0003C00001h00Ta:009<80000d`0000X0000:0000dd0000N0003
C@1=04X000==04d080000dd0000W00009`000d`0000N0004C000C4X000A<001<80000d`0000V0000
9`000dd0000N0004C@00CDX000A=001=80000dd0000V00009P000d`0000N0005C00004`0BP001D`0
001<020000=<00009@0002D000==00007P000dd000020003C@0004P000==00000P000dd0000N0003
C@0002@0000T0003C00001h000=<00000`000d`000180003C00000<000=<00007P000d`0000S0000
90000dd0000N0003C@0000<000==0000B0000dd000030003C@0001h000==00008`0002<000=<0000
7P000d`000040003C00004P000=<000010000d`0000N0003C0000280000R0003C@0001h000==0000
1@000dd000180003C@0000D000==00007P000dd0000Q00008P000d`0000N0003C00000D000=<0000
B0000d`000050003C00001h000=<00008@00024000==00007P000dd000060003C@0004P000==0000
1P000dd0000N0003C@000200000P0003C00001h000=<00001`000d`000180003C00000L000=<0000
7P000d`0000O00007`000dd0000N0003C@0000P000==0000B0000dd000080003C@0001h000==0000
7P0001l000=<00007P000d`000080003C00004P000=<000020000d`0000N0003C00001h0000N0003
C@0001h000==00002@000dd000180003C@0000T000==00007P000dd0000M00007@000d`0000N0003
C00000X000=<0000B0000d`0000:0003C00001h000=<0000700003d000==00002`000dd000180003
C@0000/000==0000?00003d000=<00002`000d`000180003C00000/000=<0000?00003`000==0000
30000dd000180003C@0000`000==0000>`0003/000=<00003@000d`000180003C00000d000=<0000
>P0003X000==00003P000dd000180003C@0000h000==0000>@0003X000=<00003P000d`000180003
C00000h000=<0000>@0003T000==00003`000dd000180003C@0000l000==0000>00003P000=<0000
40000d`000180003C000010000=<0000=`0003P000==000040000dd000180003C@00010000==0000
=`0003L000=<00004@000d`000180003C000014000=<0000=P0003H000==00004P000dd000180003
C@00018000==0000=@0003D000=<00004`000d`000180003C00001<000=<0000=00003D000==0000
4`000dd000180003C@0001<000==0000=00003@000=<000050000d`000180003C00001@000=<0000
<`0003<000==00005@000dd000180003C@0001D000==0000<P00038000=<00005P000d`000180003
C00001H000=<0000<@0004/000==0000B0000dd0001:0000B`000d`000180003C00004X0001;0003
C@0004P000==0000BP0004/000=<0000B0000d`0001:0000B`000dd000180003C@0004X0001;0003
C00004P000=<0000BP0004/000==0000B0000dd0001:0000B`000d`000180003C00004X0003S0000
h`000><0003S0000h`000><0003S0000h`000><00000\
\>"],
  ImageRangeCache->{{{0, 226}, {136, 0}} -> {-0.0299258, 0.181104, 0.00468961,
   0.00468961}}]
}, Open  ]],

Cell[TextData["Gen 7+"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      biomorph[{3, 2, 3, 2, 4, 7, 3, 2, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 
          7}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .63276 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.159812 0.952381 [
[ 0 0 0 0 ]
[ 1 .63276 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .63276 L
0 .63276 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.24435 .29962 m
.05661 .32935 L
s
P
p
.2 0 1 r
.008 w
.24435 .29962 m
.10994 .43402 L
s
P
p
.2 0 1 r
.008 w
.32741 .38268 m
.19301 .51709 L
s
P
p
.2 0 1 r
.008 w
.32741 .38268 m
.29768 .57042 L
s
P
p
.2 0 1 r
.008 w
.44344 .40106 m
.41371 .58879 L
s
P
p
.2 0 1 r
.008 w
.44344 .40106 m
.52973 .57042 L
s
P
p
.2 0 1 r
.008 w
.41371 .21332 m
.24435 .29962 L
s
P
p
.2 0 1 r
.008 w
.41371 .21332 m
.32741 .38268 L
s
P
p
.2 0 1 r
.008 w
.41371 .21332 m
.44344 .40106 L
s
P
p
.2 0 1 r
.008 w
.55656 .40106 m
.47027 .57042 L
s
P
p
.2 0 1 r
.008 w
.55656 .40106 m
.58629 .58879 L
s
P
p
.2 0 1 r
.008 w
.67259 .38268 m
.70232 .57042 L
s
P
p
.2 0 1 r
.008 w
.67259 .38268 m
.80699 .51709 L
s
P
p
.2 0 1 r
.008 w
.75565 .29962 m
.89006 .43402 L
s
P
p
.2 0 1 r
.008 w
.75565 .29962 m
.94339 .32935 L
s
P
p
.2 0 1 r
.008 w
.58629 .21332 m
.55656 .40106 L
s
P
p
.2 0 1 r
.008 w
.58629 .21332 m
.67259 .38268 L
s
P
p
.2 0 1 r
.008 w
.58629 .21332 m
.75565 .29962 L
s
P
p
.2 0 1 r
.008 w
.5 .04396 m
.41371 .21332 L
s
P
p
.2 0 1 r
.008 w
.5 .04396 m
.58629 .21332 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{221, 139},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M0000R`P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000=d0003M0000g@000=d0003M0000g@000=d0
003M0000g@000=d0001^0003C@0006`0001^0003C00006`0001]0003C@1=06d0001]0003C01<06d0
001/0005C@0004d0K00006`000E<0000C01/0000J`000dd000030003C@0006T0001[0003C00000<0
00=<0000J@0006X000==00001@000dd0001X0000JP000d`000050003C00006P0001Y0003C@0000L0
00==0000I`0006T000=<00001`000d`0001W0000J0000dd000090003C@0006H0001X0003C00000T0
00=<0000IP0006L000==00002`000dd0001U0000I`000d`0000;0003C00006D0001V0003C@0000d0
00==0000I00006H000=<00003@000d`0001T0000I@000dd0000?0003C@0006<0001T0003C0000100
00=<0000H`0006@000==000040000dd0001S0000H`000d`0000B0003C0000680001S0003C@000180
00==0000HP00068000=<000050000d`0001Q0000HP000dd0000D0003C@000640001Q0003C00001H0
00=<0000H000064000==00005P000dd0001P0000H0000d`0000H0003C00005l0001P0003C@0001P0
00==0000G`0005l000=<00006P000d`0001N0000G`000dd0000J0003C@0005h0001N0003C00001`0
00=<0000G@0005h000==000070000dd0001M0000G@000d`0000N0003C00005`0001M0003C@0001h0
00==0000G00005`000=<000080000d`0001K0000G0000dd0000P0003C@0005/0001J009<9002C5/0
001H009=00<0C@008`0014d0CDeI0000EP02C0800T`T009<0P02C5L0001D009=1002CB@00Td4009=
E@0005800T`50004C000C28000A<001<1@02C5<0001@009=1`0014d004dR0004C@00C@L00TeA0000
CP02C0P000E<0000C00R0005C00004`02002C4l0001<009=2P001Dd0001=028000E=0000C@0:009=
C@0004X00T`;0003C000008000=<000080000d`000020003C00000T00Ta;0000B002C@d000==0000
0P000dd0000P0003C@00008000==00002`02CDT000170003C00000`000=<00000`000d`0000P0003
C00000<000=<000030000d`000160000A@02C@l000==000010000dd0000N0003C@0000@000==0000
3@02CDH00013009<40000d`000050003C00001h000=<00001@000d`0000>009<A00004400TdB0003
C@0000D000==00007P000dd000050003C@0001000Te20000?`02C1<000=<00001P000d`0000N0003
C00000H000=<00004@02C400000m009=5@000dd000060003C@0001h000==00001P000dd0000C009=
?P0003/00T`F0003C00000L000=<00007P000d`000070003C00001@00T`l0000>@02CAP000==0000
1`000dd0000N0003C@0000L000==00005P02CCX0000g009<6@000d`000090003C00001`000=<0000
2@000d`0000G009<>00003<014dJ0003C@0000X000==000070000dd0000:0003C@0001P014dd0000
;007C00304`001/000=<00002P000d`0000L0003C00000X000=<00006P000d`0C006C2d0000U00M=
1`000dd0000J0003C@0000/000==000070000dd0000;0003C@0001X000==00001@07CBH0000N00M<
3@000d`0000K0003C00000/000=<000070000d`0000;0003C00001/000=<00002`07C1l0000G00M=
4`000dd0000K0003C@0000`000==000070000dd0000<0003C@0001/000==00004@07CAP0000@00M<
6@000d`0000L0003C00000`000=<000070000d`0000<0003C00001`000=<00005`07C140000=00==
7`000dd0000L0003C@0000h000==00006P000dd0000>0003C@0001`000==00007@03C@h0000^0003
C00001d000=<00003P000d`0000J0003C00000h000=<00007@000d`0000]0000;@000dd0000M0003
C@0000l000==00006P000dd0000?0003C@0001d000==0000;00002`000=<00007P000d`0000?0003
C00001X000=<00003`000d`0000N0003C00002/0000[0003C@0001h000==000040000dd0000J0003
C@00010000==00007P000dd0000Z0000:P000d`0000O0003C000010000=<00006P000d`0000@0003
C00001l000=<0000:@0002T000==00007`000dd0000A0003C@0001X000==00004@000dd0000O0003
C@0002P0000X0003C000020000=<00004P000d`0000H0003C000018000=<000080000d`0000W0000
9`000dd0000P0003C@0001<000==000060000dd0000C0003C@00020000==00009P0002H000=<0000
8@000d`0000C0003C00001P000=<00004`000d`0000Q0003C00002D0000U0003C@00024000==0000
50000dd0000H0003C@0001@000==00008@000dd0000T000090000d`0000R0003C00001@000=<0000
60000d`0000D0003C000028000=<00008`0002<000==00008P000dd0000E0003C@0001P000==0000
5@000dd0000R0003C@000280000R0003C00002800T`G0003C00001P000=<00005@02C2@000=<0000
8@00024000==00008P000dd0C@0H0003C@0001H000==00005P000dd0C@0T0003C@000200000P0003
C000028000A<001<60000d`0000F0003C00001H000A<001<90000d`0000O00007`000dd0000R0004
C@00CAT000==00005P000dd0000G0004C@00CB@000==00007P0001h000=<00008P001D`0001<01T0
00=<00005P000d`0000G0005C00004`090000d`0000M00007@000dd0000R0003C@00008000==0000
5`02CAH00TdI0003C@00008000==00008P000dd0000L000070000d`0000R0003C00000<000=<0000
5`02C1H00T`I0003C00000<000=<00008P000d`0000K00006`000dd0000R0003C@0000@000==0000
5P0014d004dD0004C@00CAP000==000010000dd0000R0003C@0001X0000J0003C000028000=<0000
1@000d`0000F0004C000C1@000A<001<60000d`000050003C000028000=<00006@0001T000==0000
8P000dd000050003C@0001L000E=0000C@0B0005C@0004d06@000dd000050003C@00028000==0000
600001P000=<00008P000d`000060003C00001L000E<0000C00B0005C00004`06@000d`000060003
C000028000=<00005`0003`000==00001`000dd0000G0003C@00008000==00003P000dd000020003
C@0001L000==00001`000dd0000k0000>`000d`000080003C00001L000=<00000P000d`0000>0003
C000008000=<00005`000d`000080003C00003X0000j0003C@0000T000==00005`000dd000030003
C@0000`000==00000`000dd0000G0003C@0000T000==0000>@0003T000=<00002P000d`0000F0003
C00000@000=<000030000d`000040003C00001H000=<00002P000d`0000h0000>0000dd0000:0003
C@0001L000==00001@000dd0000:0003C@0000D000==00005`000dd0000:0003C@0003L0000g0003
C00000/000=<00005`000d`000050003C00000X000=<00001@000d`0000G0003C00000/000=<0000
=P0003H000==000030000dd0000G0003C@0000H000==000020000dd000060003C@0001L000==0000
30000dd0000e0000=@000d`0000=0003C00001L000=<00001P000d`000080003C00000H000=<0000
5`000d`0000=0003C00003@0000d0003C@0000h000==00005`000dd000070003C@0000H000==0000
1`000dd0000G0003C@0000h000==0000<`0003<000=<00003P000d`0000H0003C00000L000=<0000
1P000d`000070003C00001P000=<00003P000d`0000b0000<P000dd0000?0003C@0001L000==0000
2@000dd000040003C@0000T000==00005`000dd0000?0003C@000340000a0003C000010000=<0000
5`000d`0000:0003C000008000=<00002P000d`0000G0003C000010000=<0000<000030000==0000
4@000dd0000G0003C@0000X000==00000P000dd0000:0003C@0001L000==00004@000dd0000_0000
;`000d`0000B0003C00001L000=<00002`0014`004`=0003C00001L000=<00004P000d`0000^0000
;P000dd0000C0003C@0001L000==00002`0014d004d=0003C@0001L000==00004`000dd0000]0000
;@000d`0000C0003C00001P000=<00003002C0h000=<000060000d`0000C0003C00002`0000/0003
C@0001@000==000060000dd0000<009=3P000dd0000H0003C@0001@000==0000:`0002/000=<0000
5@000d`0000G0003C00000d00T`?0003C00001L000=<00005@000d`0000Z0000@`000dd0000G0003
C@0000d00Td?0003C@0001L000==0000@P0004<000=<00005`000d`0000<0004C000C0h000=<0000
5`000d`000120000@`000dd0000G0003C@0000`000A=001=3P000dd0000G0003C@00048000120003
C00001P000=<00002`000d`000020003C00000/000=<000060000d`000110000@P000dd0000H0003
C@0000/000==00000P000dd0000;0003C@0001P000==0000@@00048000=<000060000d`0000:0003
C00000@000=<00002P000d`0000H0003C000044000120003C@0001L000==00002`000dd000040003
C@0000/000==00005`000dd000110000@P000d`0000G0003C00000X000=<00001P000d`0000:0003
C00001L000=<0000@@00048000==00005`000dd0000:0003C@0000H000==00002P000dd0000G0003
C@00044000110003C00001P000=<00002@000d`000080003C00000T000=<000060000d`000100000
@@000dd0000H0003C@0000T000==000020000dd000090003C@0001P000==0000@000044000=<0000
60000d`000080003C00000X000=<000020000d`0000H0003C0000400001L0003C@00020000==0000
F`0005/000=<00008P000d`0001J0000F`000dd0000R0003C@0005X0001K0003C000028000=<0000
FP000=d0003M0000g@000=d0003M0000g@000=d0003M0000g@000001\
\>"],
  ImageRangeCache->{{{0, 220}, {138, 0}} -> {-0.0295979, 0.167799, 0.00481453,
   0.00481453}}]
}, Open  ]],

Cell[TextData["Gen 12+"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      biomorph[{3, 2, 3, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 
          7}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .68284 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.134773 0.952381 [
[ 0 0 0 0 ]
[ 1 .68284 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .68284 L
0 .68284 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.26088 .37538 m
.05748 .4076 L
s
P
p
.2 0 1 r
.008 w
.26088 .37538 m
.11526 .521 L
s
P
p
.2 0 1 r
.008 w
.26088 .37538 m
.22867 .57879 L
s
P
p
.2 0 1 r
.008 w
.37429 .43317 m
.22867 .57879 L
s
P
p
.2 0 1 r
.008 w
.37429 .43317 m
.34207 .63657 L
s
P
p
.2 0 1 r
.008 w
.37429 .43317 m
.46778 .61666 L
s
P
p
.2 0 1 r
.008 w
.4065 .22976 m
.26088 .37538 L
s
P
p
.2 0 1 r
.008 w
.4065 .22976 m
.37429 .43317 L
s
P
p
.2 0 1 r
.008 w
.62571 .43317 m
.53222 .61666 L
s
P
p
.2 0 1 r
.008 w
.62571 .43317 m
.65793 .63657 L
s
P
p
.2 0 1 r
.008 w
.62571 .43317 m
.77133 .57879 L
s
P
p
.2 0 1 r
.008 w
.73912 .37538 m
.77133 .57879 L
s
P
p
.2 0 1 r
.008 w
.73912 .37538 m
.88474 .521 L
s
P
p
.2 0 1 r
.008 w
.73912 .37538 m
.94252 .4076 L
s
P
p
.2 0 1 r
.008 w
.5935 .22976 m
.62571 .43317 L
s
P
p
.2 0 1 r
.008 w
.5935 .22976 m
.73912 .37538 L
s
P
p
.2 0 1 r
.008 w
.5 .04627 m
.4065 .22976 L
s
P
p
.2 0 1 r
.008 w
.5 .04627 m
.5935 .22976 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{212, 144},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003D0000T0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000=@0003D0000e0000=@0003D0000e0000=@0
003D0000e0000=@0001Y0003C00006P0001Y0003C@0006P0001X0003C01<06T0001X0003C@1=06T0
001W0005C00004`0J00006L000E=0000C@1X0000IP000d`000030003C00006D0001V0003C@0000<0
00==0000I@0006D000=<00001@000d`0001T0000I@000dd000050003C@0006@0001T0003C00000L0
00=<0000H`0006@000==00001`000dd0001S0000H`000d`000090003C0000680001S0003C@0000T0
00==0000HP00068000=<00002`000d`0001Q0000HP000dd0000;0003C@000640001Q0003C00000d0
00=<0000H000064000==00003@000dd0001P0000H0000d`0000?0003C00005l0001P0003C@0000l0
00==0000G`0005l000=<00004@000d`0001N0000GP000dd0000C0003C@0005d0001N0003C00001<0
00=<0000G@0005d000==00005@000dd0001L0000G@000d`0000E0003C00005`0001L0003C@0001L0
00==0000F`0005`000=<00005`000d`0001K0000F`000dd0000I0003C@0005X0001K0003C00001T0
00=<0000FP0005X000==00006`000dd0001I0000FP000d`0000K0003C00005T0001I0003C@0001d0
00==0000F00005T000=<00007@000d`0001H0000F0000dd0000O0003C@0005L0001H0003C00001l0
00=<0000E`0005L000==00008@000dd0001F0000E`000d`0000Q0003C00005H0001F0003C@0002<0
00==0000E@0005H000=<00008`000d`0001E0000E@000dd0000U0003C@0005@0001D009<9`02C5D0
001C0003C@1=02L000==04d0E000058000A<001<9`0014`004aC0000D@0014d004dY0004C@00CE80
001@0005C00004`0:@001D`0001<0540001?0003C@00008000==00009`000dd000020003C@0004h0
001>0003C00000<000=<00009`000d`000030003C00004d0001=0003C@0000@000==00009`000dd0
00040003C@0004`0001<0003C00000D000=<00009`000d`000050003C00004/0001;0003C@0000H0
00==00009`000dd000060003C@0004X0001:0003C00000H000=<0000:@000d`000060003C00004T0
00190003C@0000L000==0000:@000dd000070003C@0004P000180003C00000P000=<0000:@000d`0
00080003C00004L000170003C@0000T000==0000:@000dd000090003C@0004H000160003C00000X0
00=<0000:@000d`0000:0003C00004D000150003C@0000/000==0000:@000dd0000;0003C@0004@0
00140003C00000`000=<0000:@000d`0000<0003C00004<000130003C@0000`000==0000:`000dd0
000<0003C@00048000120003C00000d000=<0000:`000d`0000=0003C000044000110003C@0000h0
00==0000:`000dd0000>0003C@00040000100003C00000l000=<0000:`000d`0000?0003C00003l0
000o0003C@00010000==0000:`000dd0000@0003C@0003h0000n0003C000014000=<0000:`000d`0
000A0003C00003d0000m0003C@00018000==0000:`000dd0000B0003C@0003`0000l0003C0000180
00=<0000;@000d`0000B0003C00003/0000k0003C@0001<000==0000;@000dd0000C0003C@0003X0
000j0003C00001@000=<0000;@000d`0000D0003C00003T0000i0003C@0001D000==0000;@000dd0
000E0003C@0003P0000h0003C00001H000=<0000;@000d`0000F0003C00003L0000d00A=6@000dd0
000]0003C@0001L014de0000;P06C0800T`I0003C00002d000=<00005`02C0801T`_0000:006C@L0
00==04d060000dd0000_0003C@0001H000==04d01`06CBT0000Q00M<300014`004`H0003C00002l0
00=<00005P0014`004`<00M<8P0001/01TdB0004C@00CAT000==0000;`000dd0000G0004C@00CA80
1TdL00005@06C1L000E<0000C00I0003C00002l000=<00005`001D`0001<01L01T`F00003`06CA`0
00==00000P000dd0000G0003C@0002l000==00005`000dd000020003C@0001X01Td@00003003C240
00=<00000`000d`0000G0003C00002l000=<00005`000d`000030003C00001l00d`=0000;`000dd0
00040003C@0001L000==0000;`000dd0000G0003C@0000@000==0000;P0002h000=<00001@000d`0
000F0003C000034000=<00005P000d`000050003C00002d0000]0003C@0000D000==00005`000dd0
000a0003C@0001L000==00001@000dd0000/0000;0000d`000060003C00001L000=<0000<@000d`0
000G0003C00000H000=<0000:`0002/000==00001`000dd0000G0003C@00034000==00005`000dd0
00070003C@0002X0000Z0003C00000P000=<00005P02C3<00T`H0003C00000P000=<0000:@0002T0
00==00002@000dd0000E0004C@1=CC400Td00`1=000F0003C@0000T000==0000:00002P000=<0000
2P000d`0000D0003C000009<<@02C08000=<000050000d`0000:0003C00002L0000W0003C@0000X0
00==0000500014d004d20003C@0002d000A=001=0P000dd0000D0003C@0000X000==00009P0002H0
00=<00002`000d`0000C0005C00004`00P000d`0000]0004C000C0<000=<00004`000d`0000;0003
C00002D0000U0003C@0000`000==00004P000dd000020005C@0004d0;@001Dd0001=00@000==0000
4P000dd0000<0003C@0002@0000T0003C00000d000=<00004@000d`000030005C00004`0;@001D`0
001<00D000=<00004@000d`0000=0003C00002<0000S0003C@0000h000==000040000dd000040003
C@00008000==0000:@000dd000020003C@0000@000==000040000dd0000>0003C@000280000R0003
C00000l000=<00003`000d`000050003C000008000=<0000:@000d`000020003C00000D000=<0000
3`000d`0000?0003C0000240000Q0003C@0000l000==00003`000dd000050003C@0000@000==0000
9`000dd000040003C@0000D000==00003`000dd0000?0003C@000200000P0003C000010000=<0000
3P000d`000060003C00000@000=<00009`000d`000040003C00000H000=<00003P000d`0000@0003
C00001l0000O0003C@00014000==00003@000dd000070003C@0000D000==00009@000dd000050003
C@0000L000==00003@000dd0000A0003C@0001h0000N0003C000018000=<000030000d`000080003
C00000D000=<00009@000d`000050003C00000P000=<000030000d`0000B0003C00001d0000M0003
C@0001<000==00002`000dd000090003C@0000H000==00008`000dd000060003C@0000T000==0000
2`000dd0000C0003C@0001`0000L0003C00001@000=<00002P000d`0000:0003C00000H000=<0000
8`000d`000060003C00000X000=<00002P000d`0000D0003C00001/0000K0003C@0001D000==0000
2@000dd0000:0003C@0000P000==00008@000dd000080003C@0000X000==00002@000dd0000E0003
C@0001X0000J0003C00001D000=<00002@000d`0000;0003C00000P000=<00008@000d`000080003
C00000/000=<00002@000d`0000E0003C00001T0000I0003C@0001H000==000020000dd0000<0003
C@0000T000==00007`000dd000090003C@0000`000==000020000dd0000F0003C@0001P0000H0003
C00001L000=<00001`000d`0000=0003C00000T000=<00007`000d`000090003C00000d000=<0000
1`000d`0000G0003C00001L0000b0003C@0000H000==00003P000dd0000:0003C@0001d000==0000
2P000dd0000>0003C@0000H000==0000<@00038000=<00001@000d`0000?0003C00000X000=<0000
7@000d`0000:0003C00000l000=<00001@000d`0000a0000<P000dd000040003C@0000l000==0000
2`000dd0000M0003C@0000/000==00003`000dd000040003C@000340000a0003C00000@000=<0000
40000d`0000<0003C00001/000=<000030000d`0000@0003C00000@000=<0000<000034000==0000
0`000dd0000A0003C@0000`000==00006`000dd0000<0003C@00014000==00000`000dd0000`0000
<@000d`000020003C000018000=<00003@000d`0000I0003C00000d000=<00004P000d`000020003
C0000300000a0005C@0004d05@000dd0000=0003C@0001T000==00003@000dd0000C0005C@0004d0
<P00034000A<001<5P000d`0000>0003C00001L000=<00003P000d`0000D0004C000C380000a0003
C@1=01L000==00003P000dd0000G0003C@0000h000==00005@000dd0C@0b0000<0000d`0C00G0003
C000010000=<00005@000d`0000@0003C00001D000=<04`0<@0003000TdH0003C@00010000==0000
5@000dd0000@0003C@0001H00Tda0000<0000d`0000G0003C000014000=<00004`000d`0000A0003
C00001L000=<0000;`0004X000==00004@000dd0000C0003C@00014000==0000B@0004X000=<0000
4P000d`0000A0003C000018000=<0000B@0004X000==00004P000dd0000A0003C@00018000==0000
B@0004T000=<000050000d`0000?0003C00001@000=<0000B00004T000==000050000dd0000?0003
C@0001@000==0000B00004T000=<00005@000d`0000=0003C00001D000=<0000B00004T000==0000
5@000dd0000=0003C@0001D000==0000B00004T000=<00005P000d`0000;0003C00001H000=<0000
B00004T000==0000?@000dd000180000B0000d`0000o0003C00004L000180003C@0003l000==0000
A`0004P000=<0000?`000d`000170000e0000=@0003D0000e0000=@0003D0000e0000=@0003D0000
\
\>"],
  ImageRangeCache->{{{0, 211}, {143, 0}} -> {-0.0289675, 0.141508, 0.00501391,
   0.00501391}}]
}, Open  ]],

Cell[TextData["Gen 13+"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      biomorph[{3, 2, 3, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 
          7}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .68559 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.133394 0.952381 [
[ 0 0 0 0 ]
[ 1 .68559 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .68559 L
0 .68559 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.25684 .38117 m
.05767 .44589 L
s
P
p
.2 0 1 r
.008 w
.25684 .38117 m
.19213 .58034 L
s
P
p
.2 0 1 r
.008 w
.37216 .43993 m
.24907 .60936 L
s
P
p
.2 0 1 r
.008 w
.37216 .43993 m
.43688 .6391 L
s
P
p
.2 0 1 r
.008 w
.40492 .23309 m
.25684 .38117 L
s
P
p
.2 0 1 r
.008 w
.40492 .23309 m
.37216 .43993 L
s
P
p
.2 0 1 r
.008 w
.62784 .43993 m
.56312 .6391 L
s
P
p
.2 0 1 r
.008 w
.62784 .43993 m
.75093 .60936 L
s
P
p
.2 0 1 r
.008 w
.74316 .38117 m
.80787 .58034 L
s
P
p
.2 0 1 r
.008 w
.74316 .38117 m
.94233 .44589 L
s
P
p
.2 0 1 r
.008 w
.59508 .23309 m
.62784 .43993 L
s
P
p
.2 0 1 r
.008 w
.59508 .23309 m
.74316 .38117 L
s
P
p
.2 0 1 r
.008 w
.5 .04649 m
.40492 .23309 L
s
P
p
.2 0 1 r
.008 w
.5 .04649 m
.59508 .23309 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{212, 144},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003D0000T0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000=@0003D0000e0000=@0003D0000e0000=@0
003D0000e0000=@0001Y0003C00006P0001Y0003C@0006P0001X0003C01<06T0001X0003C@1=06T0
001W0005C00004`0J00006L000E=0000C@1X0000IP000d`000030003C00006D0001V0003C@0000<0
00==0000I@0006D000=<00001@000d`0001T0000I@000dd000050003C@0006@0001T0003C00000L0
00=<0000H`0006@000==00001`000dd0001S0000H`000d`000090003C0000680001S0003C@0000T0
00==0000HP00068000=<00002`000d`0001Q0000HP000dd0000;0003C@000640001Q0003C00000d0
00=<0000H000064000==00003@000dd0001P0000H0000d`0000?0003C00005l0001P0003C@0000l0
00==0000G`0005l000=<00004@000d`0001N0000GP000dd0000C0003C@0005d0001N0003C00001<0
00=<0000G@0005d000==00005@000dd0001L0000G@000d`0000E0003C00005`0001L0003C@0001L0
00==0000F`0005`000=<00005`000d`0001K0000F`000dd0000I0003C@0005X0001K0003C00001T0
00=<0000FP0005X000==00006`000dd0001I0000FP000d`0000K0003C00005T0001I0003C@0001d0
00==0000F00005T000=<00007@000d`0001H0000F0000dd0000O0003C@0005L0001H0003C00001l0
00=<0000E`0005L000==00008@000dd0001F0000E`000d`0000Q0003C00005H0001F0003C@0002<0
00==0000E@0005H000=<00008`000d`0001E0000E@000dd0000U0003C@0005@0001D009<9`02C5D0
001C0003C@1=02L000==04d0E000058000A<001<9`0014`004aC0000D@0014d004dY0004C@00CE80
001@0005C00004`0:@001D`0001<0540001?0003C@00008000==00009`000dd000020003C@0004h0
001>0003C00000<000=<00009`000d`000030003C00004d0001=0003C@0000@000==00009`000dd0
00040003C@0004`0001<0003C00000D000=<00009`000d`000050003C00004/0001;0003C@0000D0
00==0000:@000dd000050003C@0004X0001:0003C00000H000=<0000:@000d`000060003C00004T0
00190003C@0000L000==0000:@000dd000070003C@0004P000180003C00000P000=<0000:@000d`0
00080003C00004L000170003C@0000T000==0000:@000dd000090003C@0004H000160003C00000X0
00=<0000:@000d`0000:0003C00004D000150003C@0000X000==0000:`000dd0000:0003C@0004@0
00140003C00000/000=<0000:`000d`0000;0003C00004<000130003C@0000`000==0000:`000dd0
000<0003C@00048000120003C00000d000=<0000:`000d`0000=0003C000044000110003C@0000h0
00==0000:`000dd0000>0003C@00040000100003C00000l000=<0000:`000d`0000?0003C00003l0
000o0003C@0000l000==0000;@000dd0000?0003C@0003h0000n0003C000010000=<0000;@000d`0
000@0003C00003d0000m0003C@00014000==0000;@000dd0000A0003C@0003`0000l0003C0000180
00=<0000;@000d`0000B0003C00003/0000k0003C@0001<000==0000;@000dd0000C0003C@0003X0
000j0003C00001@000=<0000;@000d`0000D0003C00003T0000i0003C@0001D000==0000;@000dd0
000E0003C@0003P0000h0003C00001D000=<0000;`000d`0000E0003C00003L0000g0003C@0001H0
00==0000;`000dd0000F0003C@0003H0000e009<6@000d`0000_0003C00001L00T`f0000<P03C@03
04d001P000==0000;`000dd0000G0003C@1=009=<`0002l00d`40003C00001L000=<0000;`000d`0
000G0003C00000800d``0000;003C@H000==000060000dd0000_0003C@0001P000==00001003CBd0
000Y00=<2@000d`0000G0003C000034000=<00005`000d`0000700=<:P0002H00dd<0003C@0001L0
00==0000<@000dd0000G0003C@0000X00ddW00008`03C0h000=<000060000d`0000a0003C00001P0
00=<00003003C2@0000P00==4@000dd0000H0003C@00034000==000060000dd0000?00==8@0001d0
0d`D0003C00001P000=<0000<@000d`0000H0003C00001800d`N00006P03CAH000==00006@000dd0
000a0003C@0001T000==00005003CA/0000G00=<6@000d`0000H0003C00003<000=<000060000d`0
000G00=<600001@00ddL0003C@0001P000==0000<`000dd0000H0003C@0001X00ddE00004@03C1h0
00=<00006@000d`0000c0003C00001T000=<00007003C180000>00==8@000dd0000I0003C@0003<0
00==00006@000dd0000O00==3`0000d000=<00008P000d`0000H0003C01<03<000=<04`06P000d`0
000R0003C00000`0000b0003C@0001L000A=001=<`0014d004dI0003C@000340000a0003C00001P0
00A<001<<`0014`004`J0003C0000300000a0003C@0001L000==00000P000dd0000_0003C@000080
00==00005`000dd0000`0000<@000d`0000F0003C00000<000=<0000;`000d`000030003C00001H0
00=<0000<000030000==00005P000dd000040003C@0002l000==000010000dd0000F0003C@0002l0
000`0003C00001H000=<00001@000d`0000]0003C00000D000=<00005P000d`0000_0000<0000dd0
000E0003C@0000H000==0000;@000dd000060003C@0001D000==0000;`0002l000=<00005@000d`0
00070003C00002d000=<00001`000d`0000E0003C00002h0000_0003C@0001D000==000020000dd0
000[0003C@0000P000==00005@000dd0000^0000;`000d`0000D0003C00000T000=<0000:`000d`0
00090003C00001@000=<0000;P0002h000==000050000dd0000:0003C@0002/000==00002P000dd0
000D0003C@0002d0000^0003C00001@000=<00002`000d`0000Y0003C00000/000=<000050000d`0
000]0000;P000dd0000C0003C@0000`000==0000:@000dd0000<0003C@0001<000==0000;@0002d0
00=<00004`000d`0000=0003C00002T000=<00003@000d`0000C0003C00002`0000]0003C@0001<0
00==00003P000dd0000W0003C@0000h000==00004`000dd0000/0000;@000d`0000B0003C00000l0
00=<00009`000d`0000?0003C000018000=<0000;00002d000==00004@000dd0000@0003C@0002L0
00==000040000dd0000A0003C@0002`0000/0003C000014000=<00004P000d`0000U0003C0000180
00=<00004@000d`0000[0000;0000dd0000A0003C@00018000==00009@000dd0000B0003C@000140
00==0000:`0002`000=<000040000d`0000C0003C00002D000=<00004`000d`0000@0003C00002/0
000[0003C@00010000==00005@000dd0000S0003C@0001D000==000040000dd0000Z0000:`000d`0
000@0003C00001D000=<00008`000d`0000E0003C000010000=<0000:P0002/000==00003`000dd0
000F0003C@0002<000==00005P000dd0000?0003C@0002X0000Z0003C00000l000=<000060000d`0
000Q0003C00001P000=<00003`000d`0000Y0000:P000dd0000?0003C@0001P000==00008@000dd0
000H0003C@0000l000==0000:@0002X000=<00003P000d`0000I0003C000024000=<00006@000d`0
000>0003C00002T0000Y0003C@0000h000==00006`000dd0000O0003C@0001/000==00003P000dd0
000X0000:@000d`0000>0003C00001/000=<00007`000d`0000K0003C00000h000=<0000:00003T0
00==000070000dd0000O0003C@0001`000==0000>00003P000=<00007P000d`0000M0003C00001h0
00=<0000=`0003L000==00007`000dd0000M0003C@0001l000==0000=P0003L000=<00007`000d`0
000M0003C00001l000=<0000=P0003H000==00008@000dd0000K0003C@00024000==0000=@0003D0
00=<00008P000d`0000K0003C000028000=<0000=00005X000==00006`000dd0001I0000F`000d`0
000I0003C00005X0001K0003C@0001T000==0000FP0005/000=<00006@000d`0001J0000G0000dd0
000G0003C@0005/0001L0003C00001L000=<0000F`000=@0003D0000e0000=@0003D0000e0000=@0
003D0000e0000001\
\>"],
  ImageRangeCache->{{{0, 211}, {143, 0}} -> {-0.0310978, 0.14006, 0.0050341, 
  0.0050341}}]
}, Open  ]],

Cell[TextData["Gen 17+ (neutral)"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      biomorph[{3, 2, 3, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 7, 3, 2, 2, 4, 
          7}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .71276 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.119809 0.952381 [
[ 0 0 0 0 ]
[ 1 .71276 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .71276 L
0 .71276 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.24991 .3919 m
.058 .48969 L
s
P
p
.2 0 1 r
.008 w
.24991 .3919 m
.15212 .58382 L
s
P
p
.2 0 1 r
.008 w
.36852 .45234 m
.27073 .64425 L
s
P
p
.2 0 1 r
.008 w
.36852 .45234 m
.40221 .66508 L
s
P
p
.2 0 1 r
.008 w
.40221 .2396 m
.24991 .3919 L
s
P
p
.2 0 1 r
.008 w
.40221 .2396 m
.36852 .45234 L
s
P
p
.2 0 1 r
.008 w
.63148 .45234 m
.59779 .66508 L
s
P
p
.2 0 1 r
.008 w
.63148 .45234 m
.72927 .64425 L
s
P
p
.2 0 1 r
.008 w
.75009 .3919 m
.84788 .58382 L
s
P
p
.2 0 1 r
.008 w
.75009 .3919 m
.942 .48969 L
s
P
p
.2 0 1 r
.008 w
.59779 .2396 m
.63148 .45234 L
s
P
p
.2 0 1 r
.008 w
.59779 .2396 m
.75009 .3919 L
s
P
p
.2 0 1 r
.008 w
.5 .04769 m
.40221 .2396 L
s
P
p
.2 0 1 r
.008 w
.5 .04769 m
.59779 .2396 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{207, 147},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003?0000T`P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000<l0003?0000c`000<l0003?0000c`000<l0
003?0000c`000<l0001W0003C@0006D0001W0003C00006D0001V0003C@1=06H0001V0003C01<06H0
001U0005C@0004d0I@0006D000E<0000C01U0000I0000dd000030003C@000680001T0003C00000<0
00=<0000HP0006<000==00001@000dd0001Q0000H`000d`000050003C0000640001R0003C@0000L0
00==0000H000064000=<000020000d`0001P0000H@000dd000090003C@0005l0001P0003C00000X0
00=<0000G`00060000==00002`000dd0001N0000G`000d`0000<0003C00005h0001O0003C@0000d0
00==0000G@0005h000=<00003P000d`0001M0000GP000dd0000?0003C@0005`0001M0003C0000100
00=<0000G00005d000==00004@000dd0001K0000G0000d`0000B0003C00005/0001L0003C@0001<0
00==0000FP0005/000=<000050000d`0001J0000F`000dd0000E0003C@0005T0001J0003C00001H0
00=<0000F@0005X000==00005`000dd0001H0000F@000d`0000H0003C00005P0001I0003C@0001T0
00==0000E`0005P000=<00006P000d`0001G0000F0000dd0000K0003C@0005H0001G0003C00001`0
00=<0000EP0005H000==00007P000dd0001E0000EP000d`0000N0003C00005D0001E0003C@000200
00==0000E00005D000=<000080000d`0001D0000E0000dd0000R0003C@0005<0001D0003C0000280
00=<0000D`0005<000==000090000dd0001B0000D`000d`0000T0003C0000580001B0003C@0002H0
00==0000D@0005400T`X009<DP00050000==04d0:0000dd0C@1A0000C`0014`004`X0004C000C500
001>0005C@0004d0:0001Dd0001=04l0001=0005C00004`0:P001D`0001<04h0001<0003C@000080
00==0000:0000dd000020003C@0004/0001;0003C00000<000=<0000:0000d`000030003C00004X0
001:0003C@0000@000==0000:0000dd000040003C@0004T000190003C00000D000=<0000:0000d`0
00050003C00004P000180003C@0000H000==0000:0000dd000060003C@0004L000170003C00000L0
00=<0000:0000d`000070003C00004H000160003C@0000L000==0000:P000dd000070003C@0004D0
00150003C00000P000=<0000:P000d`000080003C00004@000140003C@0000T000==0000:P000dd0
00090003C@0004<000130003C00000X000=<0000:P000d`0000:0003C000048000120003C@0000/0
00==0000:P000dd0000;0003C@00044000110003C00000`000=<0000:P000d`0000<0003C0000400
00100003C@0000d000==0000:P000dd0000=0003C@0003l0000o0003C00000d000=<0000;0000d`0
000=0003C00003h0000n0003C@0000h000==0000;0000dd0000>0003C@0003d0000m0003C00000l0
00=<0000;0000d`0000?0003C00003`0000l0003C@00010000==0000;0000dd0000@0003C@0003/0
000k0003C000014000=<0000;0000d`0000A0003C00003X0000j0003C@00018000==0000;0000dd0
000B0003C@0003T0000i0003C00001<000=<0000;0000d`0000C0003C00003P0000h0003C@0001<0
00==0000;P000dd0000C0003C@0003L0000g0003C00001@000=<0000;P000d`0000D0003C00003H0
000f0003C@0001D000==0000;P000dd0000E0003C@0003D0000e0003C00001H000=<0000;P000d`0
000F0003C00003@0000d0003C@0001L000==0000;P000dd0000G0003C@0003<0000b009<6P000d`0
000^0003C00001P00T`c0000<002C@0304d001T000==0000;P000dd0000H0004C@1=CC40000^009<
0P000d`0000H0003C000030000=<000060000d`00002C2l0000/009=10000dd0000H0003C@000300
00==000060000dd00002009=;@0002X00T`50003C00001T000=<0000<0000d`0000I0003C00000<0
0T`[0000:002C@L000==00006@000dd0000`0003C@0001T000==00001@02CBT0000V009<20000d`0
000J0003C000030000=<00006P000d`00006009<9`0002@00Td:0003C@0001X000==0000<0000dd0
000J0003C@0000P00TdU00008P02C0/000=<00006`000d`0000`0003C00001/000=<00002@02C2<0
000P009=3@000dd0000J0003C@00038000==00006P000dd0000;009=8@0001l000=<000030000d`0
000K0003C000038000=<00006`000d`0000<0003C00001h0000M009=3`000dd0000K0003C@000380
00==00006`000dd0000=009=7P0001/00T`@0003C00001`000=<0000<P000d`0000L0003C00000h0
0T`L00006@02CA8000==000070000dd0000b0003C@0001`000==00004002CAX0000G009<4`000d`0
000L009<=002C1h000=<00004@02C1P0000E009=5@000dd0000L009==002CAh000==00004`02CAH0
000C009<5P000d`0000L0003C01<03@000=<04`07P000d`0000D009<500001400TdH0003C@0001`0
00A=001=<P0014d004dN0003C@0001H00TdB00003`02C1T000=<000070001D`0001<038000E<0000
C00N0003C00001L00T`@00003@02CA/000==000070001Dd0001=038000E=0000C@0N0003C@0001T0
0Td>000030000d`0000J0003C00001`000=<00000P000d`0000`0003C000008000=<000070000d`0
000J0003C00000/0000X0003C@0001d000==00000P000dd0000`0003C@00008000==00007@000dd0
000W0000:0000d`0000L0003C00000<000=<0000<0000d`000030003C00001`000=<00009`0002L0
00==00007@000dd000030003C@00030000==00000`000dd0000M0003C@0002H0000W0003C00001`0
00=<00001@000d`0000^0003C00000D000=<000070000d`0000V00009P000dd0000M0003C@0000D0
00==0000;P000dd000050003C@0001d000==00009@0002H000=<000070000d`000060003C00002h0
00=<00001P000d`0000L0003C00002D0000U0003C@0001d000==00001P000dd0000^0003C@0000H0
00==00007@000dd0000T00009@000d`0000L0003C00000L000=<0000;P000d`000070003C00001`0
00=<0000900002@000==00007@000dd000070003C@0002h000==00001`000dd0000M0003C@0002<0
000T0003C00001`000=<000020000d`0000^0003C00000P000=<000070000d`0000S00008`000dd0
000M0003C@0000T000==0000;0000dd000090003C@0001d000==00008P0002<000=<000070000d`0
000:0003C00002`000=<00002P000d`0000L0003C0000280000R0003C@0001`000==00002`000dd0
000/0003C@0000/000==000070000dd0000Q00008P000d`0000L0003C00000/000=<0000;0000d`0
000;0003C00001`000=<00008@00024000==000070000dd0000<0003C@0002`000==000030000dd0
000L0003C@000200000Q0003C00001`000=<000030000d`0000/0003C00000`000=<000070000d`0
000P000080000dd0000L0003C@0000d000==0000;0000dd0000=0003C@0001`000==00007`000200
00=<000070000d`0000=0003C00002`000=<00003@000d`0000L0003C00001l0000O0003C@0001`0
00==00003`000dd0000Z0003C@0000l000==000070000dd0000N0000?P000d`0000?0003C00002X0
00=<00003`000d`0000m0000?@000dd0000@0003C@0002X000==000040000dd0000l0000?@000d`0
000@0003C00002X000=<000040000d`0000l0000?0000dd0000A0003C@0002X000==00004@000dd0
000k0000?0000d`0000A0003C00002X000=<00004@000d`0000k0000>`000dd0000B0003C@0002X0
00==00004P000dd0000j0000>`000d`0000C0003C00002P000=<00004`000d`0000j0000>P000dd0
000D0003C@0002P000==000050000dd0000i0000>P000d`0000D0003C00002P000=<000050000d`0
000i0000>@000dd0000E0003C@0002P000==00005@000dd0000h0000>@000d`0000E0003C00002P0
00=<00005@000d`0000h0000>0000dd0000F0003C@0002P000==00005P000dd0000g0000D@000d`0
000X0003C0000500001B0003C@0002H000==0000D@00058000=<00009P000d`0001A0000DP000dd0
000V0003C@000540001B0003C00002H000=<0000D@000<l0003?0000c`000<l0003?0000c`000<l0
003?0000c`000001\
\>"],
  ImageRangeCache->{{{0, 206}, {146, 0}} -> {-0.0279847, 0.125796, 0.00512606,
   0.00512606}}]
}, Open  ]],

Cell[TextData["Gen 1-"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      biomorph[{2, 2, 3, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 
          7}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81811 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0671348 0.952381 [
[ 0 0 0 0 ]
[ 1 .81811 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .81811 L
0 .81811 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.33063 .39102 m
.06683 .65482 L
s
P
p
.2 0 1 r
.008 w
.33063 .39102 m
.27227 .7595 L
s
P
p
.2 0 1 r
.008 w
.66937 .39102 m
.72773 .7595 L
s
P
p
.2 0 1 r
.008 w
.66937 .39102 m
.93317 .65482 L
s
P
p
.2 0 1 r
.008 w
.5 .05861 m
.33063 .39102 L
s
P
p
.2 0 1 r
.008 w
.5 .05861 m
.66937 .39102 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{197, 161},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000350000X@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000<D000350000a@000<D000350000a@000<D0
00350000a@000<D000350000a@00068000==0000H000068000=<0000H000064000==04d0H@000640
00=<04`0H@00060000E=0000C@1P0000H0001D`0001<0600001O0003C@0000<000==0000G@0005l0
00=<00000`000d`0001M0000GP000dd000050003C@0005`0001N0003C00000D000=<0000G00005d0
00==00001`000dd0001K0000G@000d`000070003C00005/0001L0003C@0000T000==0000FP0005/0
00=<00002P000d`0001J0000F`000dd0000;0003C@0005T0001J0003C00000`000=<0000F@0005X0
00==00003@000dd0001H0000F@000d`0000>0003C00005P0001I0003C@0000l000==0000E`0005P0
00=<000040000d`0001G0000F0000dd0000A0003C@0005H0001G0003C000018000=<0000EP0005L0
00==00004`000dd0001E0000EP000d`0000D0003C00005D0001F0003C@0001D000==0000E00005D0
00=<00005P000d`0001D0000E@000dd0000G0003C@0005<0001D0003C00001P000=<0000D`0005@0
00==00006@000dd0001B0000D`000d`0000J0003C0000580001C0003C@0001/000==0000D@000580
00=<000070000d`0001A0000DP000dd0000M0003C@000500001A0003C00001l000=<0000C`000500
00==000080000dd0001?0000D0000d`0000Q0003C00004h0001?0003C@00028000==0000CP0004l0
00=<00008`000d`0001=0000CP000dd0000T0003C@0004d0001>0003C00002D000=<0000C00004d0
00==00009P000dd0001<0000C@000d`0000W0003C00004/0001<0003C@0002P000==0000B`0004`0
00=<0000:@000d`0001:0000B`000dd0000Z0003C@0004X0001;0003C00002/000=<0000B@0004X0
00==0000;0000dd000190000BP000d`0000]0003C00004P000190003C@0002h000==0000B00004T0
00=<0000;`000d`000170000B0000dd0000`0003C@0004L000180003C000034000=<0000AP0004L0
00==0000<P000dd000160000A`000d`0000c0003C00004D000160003C@0003@000==0000A@0004D0
00=<0000=P000d`000140000A@000dd0000f0003C@0004@000140003C00003P000=<0000@`0004@0
00==0000>0000dd000130000@`000d`0000j0003C000048000130003C@0003X000==0000@P000480
00=<0000?0000d`000110000@P000dd0000l0003C@00044000110003C00003h000=<0000@0000440
00==0000?P000dd000100000@0000d`000100003C00003l000100003C@00040000==0000?`0003l0
0Ta2009<@00003h000==04d0@P000dd0C@0o0000?@000d`0C0140003C01<03h0000l0004C@00CD@0
00A=001=?@0003/000E<0000C0140005C00004`0?00003X000==00000P000dd000120003C@000080
00==0000>@0003T000=<00000`000d`000120003C00000<000=<0000>00003P000==000010000dd0
00120003C@0000@000==0000=`0003L000=<00001@000d`000120003C00000D000=<0000=P0003H0
00==00001@000dd000140003C@0000D000==0000=@0003D000=<00001P000d`000140003C00000H0
00=<0000=00003@000==00001`000dd000140003C@0000L000==0000<`0003<000=<000020000d`0
00140003C00000P000=<0000<P00038000==00002@000dd000140003C@0000T000==0000<@000340
00=<00002P000d`000140003C00000X000=<0000<000030000==00002P000dd000160003C@0000X0
00==0000;`0002l000=<00002`000d`000160003C00000/000=<0000;P0002h000==000030000dd0
00160003C@0000`000==0000;@0002d000=<00003@000d`000160003C00000d000=<0000;00002`0
00==00003P000dd000160003C@0000h000==0000:`0002/000=<00003`000d`000160003C00000l0
00=<0000:P0002X000==000040000dd000160003C@00010000==0000:@0002T000=<000040000d`0
00180003C000010000=<0000:00002P000==00004@000dd000180003C@00014000==00009`0002L0
00=<00004P000d`000180003C000018000=<00009P0002H000==00004`000dd000180003C@0001<0
00==00009@0002D000=<000050000d`000180003C00001@000=<0000900002@000==00005@000dd0
00180003C@0001D000==00008`0002<000=<00005@000d`0001:0003C00001D000=<00008P000280
00==00005P000dd0001:0003C@0001H000==00008@00024000=<00005`000d`0001:0003C00001L0
00=<00008000020000==000060000dd0001:0003C@0001P000==00007`0001l000=<00006@000d`0
001:0003C00001T000=<00007P0001h000==00006P000dd0001:0003C@0001X000==00007@0001d0
00=<00006`000d`0001:0003C00001/000=<0000700001`000==00006`000dd0001<0003C@0001/0
00==00006`0001/000=<000070000d`0001<0003C00001`000=<00006P0001X000==00007@000dd0
001<0003C@0001d000==00006@0001T000=<00007P000d`0001<0003C00001h000=<0000600001P0
00==00007`000dd0001<0003C@0001l000==00005`0001L000=<000080000d`0001<0003C0000200
00=<00005P0001H000==00008@000dd0001<0003C@00024000==00005@0001D000=<00008@000d`0
001>0003C000024000=<0000500001@000==00008P000dd0001>0003C@00028000==00004`0001<0
00=<00008`000d`0001>0003C00002<000=<00004P00018000==000090000dd0001>0003C@0002@0
00==00004@00014000=<00009@000d`0001>0003C00002D000=<00004000010000==00009P000dd0
001>0003C@0002H000==00003`0000l000=<00009P000d`0001@0003C00002H000=<00003P0000h0
00==00009`000dd0001@0003C@0002L000==00003@0000d000=<0000:0000d`0001@0003C00002P0
00=<0000300003P000==0000D0000dd0000g0000>0000d`0001@0003C00003L0000h0003C@000500
00==0000=`0003P000=<0000D0000d`0000g0000=`000dd0001B0003C@0003H0000g0003C0000580
00=<0000=P0003L000==0000DP000dd0000f0000=`000d`0001B0003C00003H0000g0003C@000580
00==0000=P0003L000=<0000DP000d`0000f0000=P000dd0001D0003C@0003D0000f0003C00005@0
00=<0000=@0003H000==0000E0000dd0000e0000=P000d`0001D0003C00003D0000f0003C@0005@0
00==0000=@0003H000=<0000E0000d`0000e0000=P000dd0001D0003C@0003D0000e0003C00005H0
00=<0000=00003D000==0000EP000dd0000d0000=@000d`0001F0003C00003@000350000a@000<D0
00350000a@000<D000350000a@000<D000350000a@000001\
\>"],
  ImageRangeCache->{{{0, 196}, {160, 0}} -> {-0.0261522, 0.0704872, 0.0053689,
   0.0053689}}]
}, Open  ]],

Cell[TextData["Gen 2-"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      biomorph[{3, 1, 3, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 
          7}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.59627 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.260128 1.52026 0.0380064 1.52026 [
[ 0 0 0 0 ]
[ 1 1.59627 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 1.59627 L
0 1.59627 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.35374 1.02321 m
.07554 1.40612 L
s
P
p
.2 0 1 r
.008 w
.35374 1.02321 m
.35374 1.49651 L
s
P
p
.2 0 1 r
.008 w
.64626 1.02321 m
.64626 1.49651 L
s
P
p
.2 0 1 r
.008 w
.64626 1.02321 m
.92446 1.40612 L
s
P
p
.2 0 1 r
.008 w
.5 .57306 m
.35374 1.02321 L
s
P
p
.2 0 1 r
.008 w
.5 .57306 m
.64626 1.02321 L
s
P
p
.2 0 1 r
.008 w
.5 .09976 m
.5 .57306 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{141, 225},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002=0000h@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP0008d0002=0000S@0008d0002=0000S@0008d0
002=0000S@0008d0002=0000S@0008d0002=0000S@0004H000=<0000A00004H000==0000A00004H0
00=<0000A00004H000==0000A00004H000=<0000A00004H000==0000A00004H000=<0000A00004H0
00==0000A00004H000=<0000A00004H000==0000A00004H000=<0000A00004H000==0000A00004H0
00=<0000A00004H000==0000A00004H000=<0000A00004H000==0000A00004H000=<0000A00004H0
00==0000A00004H000=<0000A00004H000==0000A00004H000=<0000A00004H000==0000A00004H0
00=<0000A00004H000==0000A00004H000=<0000A00004H000==0000A00004H000=<0000A00004H0
00==0000A00004H000=<0000A00004H000==0000A00004H000=<0000A00004H000==0000A00004H0
00=<0000A00004H000==0000A00004H000=<0000A00004H000==0000A00004H000=<0000A00004H0
00==0000A00004H000=<0000A00004H000==0000A00004H000=<0000A00004H000==0000A00004H0
00=<0000A00004H000==0000A00004H000=<0000A00004H000==0000A00004H000=<0000A00004H0
00==0000A00004H000=<0000A00004H000==0000A00004H000=<0000A00004H000==0000A00004H0
00=<0000A00004H000==0000A00004H000=<0000A00004H000==0000A00004H000=<0000A00004H0
00==0000A00004H000=<0000A00004H000==0000A00004H000=<0000A00004H000==0000A00004H0
00=<0000A00004H000==0000A00004H000=<0000A00004H000==0000A00004H000=<0000A00004H0
00==0000A00004D00Ta60000A@000dd0C@150000A@000d`0C0150000A00014d004e50000A0001D`0
001<04@000140005C@0004d0A00004<000=<00000P000d`000120000@`000dd000030003C@000440
00130003C00000<000=<0000@@00048000==000010000dd000110000@P000d`000050003C0000400
00120003C@0000D000==0000@000044000=<00001P000d`000100000@@000dd000070003C@0003l0
00110003C00000L000=<0000?`00040000==000020000dd0000o0000@0000d`000090003C00003h0
00100003C@0000T000==0000?P0003l000=<00002P000d`0000n0000?`000dd0000;0003C@0003d0
000o0003C00000/000=<0000?@0003h000==000030000dd0000m0000?P000d`0000<0003C00003d0
000n0003C@0000d000==0000?00003d000=<00003P000d`0000l0000?@000dd0000>0003C@0003`0
000m0003C00000l000=<0000>`0003`000==000040000dd0000k0000?0000d`0000@0003C00003/0
000l0003C@00014000==0000>P0003/000=<00004P000d`0000j0000>`000dd0000B0003C@0003X0
000k0003C00001<000=<0000>@0003X000==000050000dd0000i0000>P000d`0000D0003C00003T0
000j0003C@0001D000==0000>00003T000=<00005P000d`0000h0000>@000dd0000F0003C@0003P0
000i0003C00001L000=<0000=`0003P000==000060000dd0000g0000>0000d`0000H0003C00003L0
000h0003C@0001P000==0000=`0003L000=<00006P000d`0000f0000=`000dd0000J0003C@0003H0
000g0003C00001X000=<0000=P0003H000==000070000dd0000e0000=P000d`0000L0003C00003D0
000f0003C@0001`000==0000=@0003D000=<00007P000d`0000d0000=@000dd0000N0003C@0003@0
000e0003C00001h000=<0000=00003@000==000080000dd0000c0000=0000d`0000P0003C00003<0
000d0003C@00020000==0000<`0003<000=<00008P000d`0000b0000<`000dd0000R0003C@000380
000c0003C000028000=<0000<P00038000==000090000dd0000a0000<P000d`0000T0003C0000340
000b0003C@0002@000==0000<@00034000=<00009P000d`0000`0000<@000dd0000V0003C@000300
000a0003C00002H000=<0000<00003000TdX009=<@0002l000=<04`0:0000d`0C00`0000;P0014d0
04dX0004C@00CBl0000^0004C000C2P000A<001<;`0002d000E=0000C@0X0005C@0004d0;P0002`0
00=<00000P000d`0000V0003C000008000=<0000:`0002`000==00000P000dd0000V0003C@000080
00==0000:`0002/000=<00000`000d`0000V0003C00000<000=<0000:P0002X000==000010000dd0
000V0003C@0000@000==0000:@0002T000=<00001@000d`0000V0003C00000D000=<0000:00002T0
00==00001@000dd0000V0003C@0000D000==0000:00002P000=<00001P000d`0000V0003C00000H0
00=<00009`0002L000==00001`000dd0000V0003C@0000L000==00009P0002L000=<00001`000d`0
000V0003C00000L000=<00009P0002H000==000020000dd0000V0003C@0000P000==00009@0002D0
00=<00002@000d`0000V0003C00000T000=<0000900002@000==00002P000dd0000V0003C@0000X0
00==00008`0002@000=<00002P000d`0000V0003C00000X000=<00008`0002<000==00002`000dd0
000V0003C@0000/000==00008P00028000=<000030000d`0000V0003C00000`000=<00008@000240
00==00003@000dd0000V0003C@0000d000==00008000024000=<00003@000d`0000V0003C00000d0
00=<00008000020000==00003P000dd0000V0003C@0000h000==00007`0001l000=<00003`000d`0
000V0003C00000l000=<00007P0001l000==00003`000dd0000V0003C@0000l000==00007P0001h0
00=<000040000d`0000V0003C000010000=<00007@0001d000==00004@000dd0000V0003C@000140
00==0000700001`000=<00004P000d`0000V0003C000018000=<00006`0001`000==00004P000dd0
000V0003C@00018000==00006`0001/000=<00004`000d`0000V0003C00001<000=<00006P0001X0
00==000050000dd0000V0003C@0001@000==00006@0001X000=<000050000d`0000V0003C00001@0
00=<00006@0001T000==00005@000dd0000V0003C@0001D000==0000600001P000=<00005P000d`0
000V0003C00001H000=<00005`0001L000==00005`000dd0000V0003C@0001L000==00005P0001L0
00=<00005`000d`0000V0003C00001L000=<00005P0001H000==000060000dd0000V0003C@0001P0
00==00005@0001D000=<00006@000d`0000V0003C00001T000=<0000500001@000==00006P000dd0
000V0003C@0001X000==00004`0001@000=<00006P000d`0000V0003C00001X000=<00004`0001<0
00==00006`000dd0000V0003C@0001/000==00004P00018000=<000070000d`0000V0003C00001`0
00=<00004@00018000==000070000dd0000V0003C@0001`000==00004@00014000=<00007@000d`0
000V0003C00001d000=<00004000010000==00007P000dd0000V0003C@0001h000==00003`0000l0
00=<00007`000d`0000V0003C00001l000=<00003P0000l000==00007`000dd0000V0003C@0001l0
00==00003P0000h000=<000080000d`0000V0003C000020000=<00003@0000d000==00008@000dd0
000V0003C@00024000==0000300000d000=<00008@000d`0000V0003C000024000=<0000300000`0
00==00008P000dd0000V0003C@00028000==00002`0000/000=<00008`000d`0000V0003C00002<0
00=<00002P0000X000==000090000dd0000V0003C@0002@000==00002@00034000=<00009P000d`0
000`0000<@000dd0000V0003C@000300000a0003C00002H000=<0000<000034000==00009P000dd0
000`0000<@000d`0000V0003C0000300000a0003C@0002H000==0000<000034000=<00009P000d`0
000`0000<@000dd0000V0003C@000300000a0003C00002H000=<0000<000034000==00009P000dd0
000`0000<@000d`0000V0003C0000300000a0003C@0002H000==0000<00008d0002=0000S@0008d0
002=0000S@0008d0002=0000S@0008d0002=0000S@0008d0002=0000\
\>"],
  ImageRangeCache->{{{0, 140}, {224, 0}} -> {0.171104, -0.026232, 0.00469849, 
  0.00469849}}]
}, Open  ]],

Cell[TextData["Gen 7-"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      biomorph[{3, 2, 3, 2, 4, 7, 1, 2, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 
          7}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .86423 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0440733 0.952381 [
[ 0 0 0 0 ]
[ 1 .86423 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .86423 L
0 .86423 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.25326 .54004 m
.06111 .7322 L
s
P
p
.2 0 1 r
.008 w
.25326 .54004 m
.21075 .80844 L
s
P
p
.2 0 1 r
.008 w
.37663 .29792 m
.25326 .54004 L
s
P
p
.2 0 1 r
.008 w
.74674 .54004 m
.78925 .80844 L
s
P
p
.2 0 1 r
.008 w
.74674 .54004 m
.93889 .7322 L
s
P
p
.2 0 1 r
.008 w
.62337 .29792 m
.74674 .54004 L
s
P
p
.2 0 1 r
.008 w
.5 .05579 m
.37663 .29792 L
s
P
p
.2 0 1 r
.008 w
.5 .05579 m
.62337 .29792 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{192, 165},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000300000Y@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000<0000300000`0000<0000300000`0000<00
00300000`0000<0000300000G`000d`0001N0000G`000dd0001N0000GP000d`0C01O0000GP000dd0
C@1O0000G@001D`0001<05h0001M0005C@0004d0GP0005`000=<00000`000d`0001K0000G0000dd0
00030003C@0005/0001K0003C00000D000=<0000FP0005/000==00001@000dd0001J0000FP000d`0
00070003C00005T0001J0003C@0000L000==0000F@0005T000=<00002@000d`0001H0000F@000dd0
00090003C@0005P0001H0003C00000/000=<0000E`0005P000==00002`000dd0001G0000E`000d`0
000=0003C00005H0001G0003C@0000d000==0000EP0005H000=<00003`000d`0001E0000EP000dd0
000?0003C@0005D0001E0003C000014000=<0000E00005D000==00004@000dd0001D0000E0000d`0
000C0003C00005<0001D0003C@0001<000==0000D`0005<000=<00005@000d`0001B0000D`000dd0
000E0003C@000580001B0003C00001L000=<0000D@00058000==00005`000dd0001A0000D@000d`0
000I0003C0000500001A0003C@0001T000==0000D000050000=<00006`000d`0001?0000D0000dd0
000K0003C@0004l0001?0003C00001d000=<0000CP0004l000==00007@000dd0001>0000CP000d`0
000O0003C00004d0001>0003C@0001l000==0000C@0004d000=<00008@000d`0001<0000C@000dd0
000Q0003C@0004`0001<0003C00002<000=<0000B`0004`000==00008`000dd0001;0000B`000d`0
000U0003C00004X0001;0003C@0002D000==0000BP0004X000=<00009`000d`000190000BP000dd0
000W0003C@0004T000190003C00002T000=<0000B00004T000==0000:@000dd000180000B0000d`0
000[0003C00004L000180003C@0002/000==0000A`0004L000=<0000;@000d`000160000A`000dd0
000]0003C@0004H000160003C00002l000=<0000A@0004H000==0000;`000dd000150000A@000d`0
000a0003C00004@000150003C@00034000==0000A00004@000=<0000<`000d`000130000A0000dd0
000c0003C@0004<000130003C00003D000=<0000@P0004<000==0000=@000dd000120000@P000d`0
000g0003C000044000110003C@0003T000==0000@000044000=<0000>@000d`000100000@0000dd0
000k0003C@0003l000100003C00003/000=<0000?`0003l000==0000?@000dd0000n0000?`000d`0
000m0003C00003h0000n0003C@0003l000==0000?@0003h000=<0000?`000d`0000m0000?@000dd0
00110003C@0003`0000m0003C000044000=<0000?00003`000==0000@`000dd0000k0000?0000d`0
00130003C00003/0000k0003C@0004D000==0000>P0003/000=<0000A@000d`0000j0000>P000dd0
00170003C@0003T0000j0003C00004L000=<0000>@0003T000==0000B@000dd0000h0000>@000d`0
00190003C00003P0000h0003C@0004/000==0000=`0003P000=<0000B`000d`0000g0000=`000dd0
001=0003C@0003H0000g0003C00004d000=<0000=P0003H000==0000C`000dd0000e0000=@000d`0
001A0003C00003@0000e0003C@00054000==0000=00003@000=<0000D`000d`0000c0000=0000dd0
001C0003C@0003<0000c0003C00005D000=<0000<P0003<000==0000E@000dd0000b0000<P000d`0
001G0003C0000340000b0003C@0005L000==0000<@00034000=<0000F@000d`0000`0000<@000dd0
001I0003C@000300000`0003C00005/000=<0000;`0002l00TeM009=<00002h000=<04`0G@000d`0
C00_0000;@0014d004eM0004C@00CBh0000/0004C000C5l000A<001<;@0002/000E=0000C@1O0005
C@0004d0;00002X000=<00000P000d`0001M0003C000008000=<0000:@0002T000==00000`000dd0
001M0003C@0000<000==0000:00002P000=<000010000d`0001M0003C00000@000=<00009`0002L0
00==00001@000dd0001M0003C@0000D000==00009P0002H000=<00001P000d`0001M0003C00000H0
00=<00009@0002D000==00001P000dd0001O0003C@0000H000==0000900002@000=<00001`000d`0
001O0003C00000L000=<00008`0002<000==000020000dd0001O0003C@0000P000==00008P000280
00=<00002@000d`0001O0003C00000T000=<00008@00024000==00002P000dd0001O0003C@0000X0
00==00008000020000=<00002`000d`0001O0003C00000/000=<00007`0001l000==00002`000dd0
001Q0003C@0000/000==00007P0001h000=<000030000d`0001Q0003C00000`000=<00007@0001d0
00==00003@000dd0001Q0003C@0000d000==0000700001`000=<00003P000d`0001Q0003C00000h0
00=<00006`0001/000==00003`000dd0001Q0003C@0000l000==00006P0001X000=<000040000d`0
001Q0003C000010000=<00006@0001T000==000040000dd0001S0003C@00010000==0000600001P0
00=<00004@000d`0001S0003C000014000=<00005`0001L000==00004P000dd0001S0003C@000180
00==00005P0001H000=<00004`000d`0001S0003C00001<000=<00005@0001D000==000050000dd0
001S0003C@0001@000==0000500001@000=<00005@000d`0001S0003C00001D000=<00004`0001<0
00==00005P000dd0001S0003C@0001H000==00004P00018000=<00005P000d`0001U0003C00001H0
00=<00004@00014000==00005`000dd0001U0003C@0001L000==00004000010000=<000060000d`0
001U0003C00001P000=<00003`0000l000==00006@000dd0001U0003C@0001T000==00003P0000h0
00=<00006P000d`0001U0003C00001X000=<00003@0000d000==00006`000dd0001U0003C@0001/0
00==0000300000`000=<00006`000d`0001W0003C00001/000=<00002`0002X000==0000I`000dd0
000Y0000:P000d`0001W0003C00002T0000Z0003C@0006L000==0000:@0002X000=<0000I`000d`0
000Y0000:P000dd0001W0003C@0002T0000Y0003C00006T000=<0000:00002T000==0000J@000dd0
000X0000:@000d`0001Y0003C00002P0000Y0003C@0006T000==0000:00002T000=<0000J@000d`0
000X0000:@000dd0001Y0003C@0002P0000Y0003C00006T000=<0000:00002P000==0000J`000dd0
000W0000:0000d`0001[0003C00002L0000X0003C@0006/000==00009`000<0000300000`0000<00
00300000`0000<0000300000`0000<000000\
\>"],
  ImageRangeCache->{{{0, 191}, {164, 0}} -> {-0.0284239, 0.0462724, 
  0.00553323, 0.00553323}}]
}, Open  ]],

Cell[TextData["Gen 8-"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      biomorph[{3, 2, 3, 2, 4, 7, 2, 1, 2, 4, 7, 2, 2, 2, 4, 7, 2, 2, 2, 4, 
          7}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .77885 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0867637 0.952381 [
[ 0 0 0 0 ]
[ 1 .77885 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .77885 L
0 .77885 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.25191 .45587 m
.05925 .59584 L
s
P
p
.2 0 1 r
.008 w
.25191 .45587 m
.17832 .68235 L
s
P
p
.2 0 1 r
.008 w
.3183 .48969 m
.17832 .68235 L
s
P
p
.2 0 1 r
.008 w
.3183 .48969 m
.3183 .72783 L
s
P
p
.2 0 1 r
.008 w
.39189 .26321 m
.25191 .45587 L
s
P
p
.2 0 1 r
.008 w
.39189 .26321 m
.3183 .48969 L
s
P
p
.2 0 1 r
.008 w
.6817 .48969 m
.6817 .72783 L
s
P
p
.2 0 1 r
.008 w
.6817 .48969 m
.82168 .68235 L
s
P
p
.2 0 1 r
.008 w
.74809 .45587 m
.82168 .68235 L
s
P
p
.2 0 1 r
.008 w
.74809 .45587 m
.94075 .59584 L
s
P
p
.2 0 1 r
.008 w
.60811 .26321 m
.6817 .48969 L
s
P
p
.2 0 1 r
.008 w
.60811 .26321 m
.74809 .45587 L
s
P
p
.2 0 1 r
.008 w
.5 .05102 m
.39189 .26321 L
s
P
p
.2 0 1 r
.008 w
.5 .05102 m
.60811 .26321 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{200, 155},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000380000V`P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000<P000380000b0000<P000380000b0000<P0
00380000b0000<P000380000H`000d`0001R0000H`000dd0001R0000HP000d`0C01S0000HP000dd0
C@1S0000H@001D`0001<0680001Q0005C@0004d0HP00060000=<00000`000d`0001O0000H0000dd0
00030003C@0005l0001O0003C00000D000=<0000GP0005l000==00001@000dd0001N0000GP000d`0
00070003C00005d0001N0003C@0000L000==0000G@0005d000=<00002@000d`0001L0000G@000dd0
00090003C@0005`0001L0003C00000/000=<0000F`0005`000==00002`000dd0001K0000F`000d`0
000=0003C00005X0001K0003C@0000d000==0000FP0005X000=<00003`000d`0001I0000FP000dd0
000?0003C@0005T0001I0003C000014000=<0000F00005T000==00004@000dd0001H0000F0000d`0
000C0003C00005L0001H0003C@0001<000==0000E`0005L000=<00005@000d`0001F0000E`000dd0
000E0003C@0005H0001F0003C00001L000=<0000E@0005H000==00005`000dd0001E0000E@000d`0
000I0003C00005@0001E0003C@0001T000==0000E00005@000=<00006`000d`0001C0000E0000dd0
000K0003C@0005<0001C0003C00001d000=<0000DP0005<000==00007@000dd0001B0000DP000d`0
000O0003C0000540001B0003C@0001l000==0000D@00054000=<00008@000d`0001@0000D@000dd0
000Q0003C@000500001@0003C00002<000=<0000C`00050000==00008`000dd0001?0000C`000d`0
000U0003C00004h0001?0003C@0002D000==0000CP0004h000=<00009`000d`0001=0000CP000dd0
000W0003C@0004d0001=0003C00002T000=<0000C00004`00Td[009=C@0004/000=<04`0:`000d`0
C01<0000B`02CBd00Te<0000BP000d`0C00]0003C01<04/000190004C@00CBd000A=001=BP0004P0
00A<001<;`0014`004a90000B00014d004d_0004C@00CDT000170005C00004`0;`001D`0001<04P0
00160005C@0004d0<@001Dd0001=04L000160005C00004`0<@001D`0001<04L000150003C@000080
00==0000;`000dd000020003C@0004@000140003C000008000=<0000<@000d`000020003C00004<0
00130003C@0000<000==0000<@000dd000030003C@00048000130003C00000<000=<0000<@000d`0
00030003C000048000120003C@0000<000==0000<`000dd000030003C@00044000110003C00000@0
00=<0000<`000d`000040003C000040000100003C@0000D000==0000<`000dd000050003C@0003l0
00100003C00000@000=<0000=@000d`000040003C00003l0000o0003C@0000D000==0000=@000dd0
00050003C@0003h0000n0003C00000H000=<0000=@000d`000060003C00003d0000m0003C@0000H0
00==0000=`000dd000060003C@0003`0000m0003C00000H000=<0000=`000d`000060003C00003`0
000l0003C@0000L000==0000=`000dd000070003C@0003/0000k0003C00000L000=<0000>@000d`0
00070003C00003X0000j0003C@0000P000==0000>@000dd000080003C@0003T0000j0003C00000P0
00=<0000>@000d`000080003C00003T0000i0003C@0000P000==0000>`000dd000080003C@0003P0
000h0003C00000T000=<0000>`000d`000090003C00003L0000h0003C@0000T000==0000>`000dd0
00090003C@0003L0000g0003C00000T000=<0000?@000d`000090003C00003H0000f0003C@0000X0
00==0000?@000dd0000:0003C@0003D0000e0003C00000/000=<0000?@000d`0000;0003C00003@0
000e0003C@0000X000==0000?`000dd0000:0003C@0003@0000d0003C00000/000=<0000?`000d`0
000;0003C00003<0000c0003C@0000`000==0000?`000dd0000<0003C@000380000a009<3P000d`0
00110003C00000`00T`b0000<0000dd0C@0>0003C@00044000==000030000dd0C@0a0000;P02C003
04`000h000=<0000@@000d`0000=0004C01<C2l0000]0005C@0004d03P000dd000130003C@0000`0
00E=0000C@0^0000;0000d`000020003C00000`000=<0000@`000d`0000<0003C000008000=<0000
:`0002X00Td40003C@0000d000==0000@`000dd0000=0003C@0000800Td[0000:@000d`000040003
C00000`000=<0000A@000d`0000<0003C00000@000=<0000:00002L00Td70003C@0000`000==0000
A@000dd0000<0003C@0000D00TdX00009P000d`000060003C00000`00Ta7009<3P000d`000060003
C00002D0000U0003C@0000L000==00002`000dd0C@170003C@1=00d000==00001`000dd0000T0000
8`02C0X000=<00002P0014`004a70004C000C0`000=<00002002C2@0000R0003C@0000T000==0000
2`0014d004e70004C@00C@d000==00002@000dd0000Q00008002C0`000=<00002P001D`0001<04L0
00E<0000C00<0003C00000X00T`Q00007`000dd0000<0003C@0000T000==00000P000dd000150003
C@00008000==00002@000dd0000<0003C@0001h0000N0003C00000`000=<00002@000d`000030003
C00004D000=<00000`000d`000090003C00000`000=<00007@0001`00Td?0003C@0000T000==0000
0`000dd000150003C@0000<000==00002@000dd0000=009=7@0001/000=<00003`000d`000080003
C00000@000=<0000A@000d`000040003C00000P000=<00003`000d`0000J00006@02CA4000==0000
20000dd000050003C@0004D000==00001@000dd000080003C@0000l00TdJ000060000d`0000A0003
C00000P000=<00001@000d`000150003C00000D000=<000020000d`0000A0003C00001L0000G0003
C@00018000==00001`000dd000060003C@0004D000==00001P000dd000070003C@00018000==0000
5P0001D00T`D0003C00000L000=<00001`000d`000150003C00000L000=<00001`000d`0000B009<
5P0001@000==000050000dd000060003C@0000P000==0000A@000dd000080003C@0000H000==0000
50000dd0000C00004P02C1L000=<00001P000d`000080003C00004D000=<000020000d`000060003
C00001D00T`C00004@000dd0000F0003C@0000H000==00002@000dd000150003C@0000T000==0000
1P000dd0000F0003C@000100000@0003C00001L000=<00001@000d`0000:0003C00004D000=<0000
2P000d`000050003C00001L000=<00003`0000h00TdJ0003C@0000@000==00002`000dd000150003
C@0000/000==000010000dd0000H009=3`0000d000=<00006@000d`000050003C00000/000=<0000
A@000d`0000;0003C00000D000=<00006@000d`0000<000030000dd0000J0003C@0000@000==0000
30000dd000150003C@0000`000==000010000dd0000J0003C@0000/0000Y0003C00000<000=<0000
3@000d`000150003C00000d000=<00000`000d`0000X0000:0000dd000030003C@0000h000==0000
A@000dd0000>0003C@0000<000==00009`0002P000=<00000`000d`0000>0003C00004D000=<0000
3P000d`000030003C00002L0000X0003C@00008000==00003`000dd000150003C@0000l000==0000
0P000dd0000W00009`000d`000020003C000010000=<0000A@000d`0000@0003C000008000=<0000
9P0002L000E=0000C@0C0003C@0004D000==00004@001Dd0001=02P0000W0005C00004`04`000d`0
00150003C000014000E<0000C00X00009P001Dd0001=01@000==0000A@000dd0000B0005C@0004d0
9`0002H000A<001<5@000d`000150003C00001<000A<001<9`0002H000A=001=5@000dd000150003
C@0001<000A=001=9`0002D000A<001<5P000d`000150003C00001@000A<001<9P0002D000==04d0
5`000dd000150003C@0001D000==04d09P0002D00T`H0003C00004D000=<00005P02C2H0000T0003
C@1=01P000==0000A@000dd0000F0003C@1=02D0000T009<6@000d`000150003C00001L00T`U0000
90000dd0000H0003C@0004D000==000060000dd0000S00008`000d`0000I0003C00004D000=<0000
6@000d`0000R0000?`000dd000150003C@0003h0000o0003C00004D000=<0000?P0003l000==0000
A@000dd0000n0000?`000d`000150003C00003h0000o0003C@0004D000==0000?P0003l000=<0000
A@000d`0000n0000?`000dd000150003C@0003h0000o0003C00004D000=<0000?P0003l000==0000
A@000dd0000n0000b0000<P000380000b0000<P000380000b0000<P000380000b0000001\
\>"],
  ImageRangeCache->{{{0, 199}, {154, 0}} -> {-0.0283842, 0.0910978, 
  0.00531039, 0.00531039}}]
}, Open  ]],

Cell[TextData["Gen 13-"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[
      biomorph[{3, 2, 3, 2, 4, 7, 2, 2, 2, 4, 7, 2, 1, 2, 4, 7, 2, 2, 2, 4, 
          7}]]; \)\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .74342 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.104481 0.952381 [
[ 0 0 0 0 ]
[ 1 .74342 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .74342 L
0 .74342 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.23978 .40729 m
.05847 .53902 L
s
P
p
.2 0 1 r
.008 w
.23978 .40729 m
.10806 .5886 L
s
P
p
.2 0 1 r
.008 w
.3632 .47017 m
.29394 .68332 L
s
P
p
.2 0 1 r
.008 w
.3632 .47017 m
.3632 .69428 L
s
P
p
.2 0 1 r
.008 w
.39826 .24882 m
.23978 .40729 L
s
P
p
.2 0 1 r
.008 w
.39826 .24882 m
.3632 .47017 L
s
P
p
.2 0 1 r
.008 w
.6368 .47017 m
.6368 .69428 L
s
P
p
.2 0 1 r
.008 w
.6368 .47017 m
.70606 .68332 L
s
P
p
.2 0 1 r
.008 w
.76022 .40729 m
.89194 .5886 L
s
P
p
.2 0 1 r
.008 w
.76022 .40729 m
.94153 .53902 L
s
P
p
.2 0 1 r
.008 w
.60174 .24882 m
.6368 .47017 L
s
P
p
.2 0 1 r
.008 w
.60174 .24882 m
.76022 .40729 L
s
P
p
.2 0 1 r
.008 w
.5 .04914 m
.39826 .24882 L
s
P
p
.2 0 1 r
.008 w
.5 .04914 m
.60174 .24882 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{207, 153},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003?0000V@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000<l0003?0000c`000<l0003?0000c`000<l0
003?0000c`000<l0003?0000I`000d`0001U0000I`000dd0001U0000IP000d`0C01V0000IP000dd0
C@1V0000I@001D`0001<06D0001U0005C@0004d0I@0006@000=<00000`000d`0001R0000I0000dd0
00030003C@000680001S0003C00000D000=<0000H@0006<000==00001@000dd0001Q0000HP000d`0
00070003C0000600001Q0003C@0000P000==0000H000064000=<00002@000d`0001O0000H0000dd0
000:0003C@0005l0001P0003C00000/000=<0000GP0005l000==000030000dd0001N0000G`000d`0
000=0003C00005d0001N0003C@0000h000==0000G@0005h000=<00003`000d`0001L0000G@000dd0
000@0003C@0005`0001M0003C000014000=<0000F`0005`000==00004P000dd0001K0000G0000d`0
000C0003C00005X0001K0003C@0001@000==0000FP0005/000=<00005@000d`0001I0000FP000dd0
000F0003C@0005T0001J0003C00001L000=<0000F00005T000==000060000dd0001H0000F@000d`0
000I0003C00005L0001H0003C@0001X000==0000E`0005P000=<00006`000d`0001F0000E`000dd0
000L0003C@0005H0001F0003C00001h000=<0000E@0005H000==00007P000dd0001E0000E@000d`0
000P0003C00005@0001E0003C@00020000==0000E00005@000=<00008P000d`0001C0000E0000dd0
000R0003C@0005<0001C0003C00002@000=<0000DP0005<000==000090000dd0001B0000DP000d`0
000V0003C0000540001A009=:002CE80001@0003C01<02P000=<04`0D@0004l000A=001=:00014d0
04e@0000CP0014`004`Z0004C000C4l0001=0005C@0004d0:P001Dd0001=04h0001<0003C0000080
00=<0000:0000d`000020003C00004/0001;0003C@0000<000==0000:0000dd000030003C@0004X0
001:0003C00000@000=<0000:0000d`000040003C00004T000190003C@0000D000==0000:0000dd0
00050003C@0004P000180003C00000H000=<0000:0000d`000060003C00004L000170003C@0000H0
00==0000:P000dd000060003C@0004H000160003C00000L000=<0000:P000d`000070003C00004D0
00150003C@0000P000==0000:P000dd000080003C@0004@000140003C00000T000=<0000:P000d`0
00090003C00004<000130003C@0000X000==0000:P000dd0000:0003C@00048000120003C00000/0
00=<0000:P000d`0000;0003C000044000110003C@0000/000==0000;0000dd0000;0003C@000400
00100003C00000`000=<0000;0000d`0000<0003C00003l0000o0003C@0000d000==0000;0000dd0
000=0003C@0003h0000n0003C00000h000=<0000;0000d`0000>0003C00003d0000m0003C@0000l0
00==0000;0000dd0000?0003C@0003`0000l0003C000010000=<0000;0000d`0000@0003C00003/0
000k0003C@00014000==0000;0000dd0000A0003C@0003X0000j0003C000014000=<0000;P000d`0
000A0003C00003T0000i0003C@00018000==0000;P000dd0000B0003C@0003P0000h0003C00001<0
00=<0000;P000d`0000C0003C00003L0000g0003C@0001@000==0000;P000dd0000D0003C@0003H0
000f0003C00001D000=<0000;P000d`0000E0003C00003D0000e0003C@0001H000==0000;P000dd0
000F0003C@0003@0000d0003C00001L000=<0000;P000d`0000G0003C00003<0000c0003C@0001L0
00==0000<0000dd0000G0003C@000380000b0003C00001P000=<0000<0000d`0000H0003C0000340
000`009=6`000dd0000`0003C@0001T00Tda0000;`000d`0C00K0003C000030000=<00006@000d`0
C00`0000;P000dd0C@0L0003C@00030000==00006P000dd0C@0_0000;002C00304`001`000=<0000
<0000d`0000K0004C01<C2d0000[0004C@00CAd000==0000<P000dd0000K0004C@00CB`0000Y009<
0`000d`0000K0003C000038000=<00006`0014`00002C2X0000X0003C@00008000==000070000dd0
000b0003C@0001`000==00000P000dd0000W00009`000d`000020003C00001d000=<0000<P000d`0
000M0003C000008000=<00009P0002D00Td50003C@0001d000==0000<P000dd0000M0003C@0000<0
0TdV000090000d`000040003C00001h000=<0000<P000d`0000N0003C00000@000=<00008`0002<0
00==000010000dd0000O0003C@00038000==00007`000dd000040003C@000280000Q009<1P000d`0
000O0003C00003@000=<00007`000d`00004009<8P00020000==00001P000dd0000O0003C@0003@0
00==00007`000dd000060003C@0001l0000N009<20000d`0000P0003C00003@000=<000080000d`0
0006009<7`0001d000==00001`000dd0000Q0003C@0003@000==00008@000dd000070003C@0001`0
000L0003C00000L000=<00008@02C3H00T`S0003C00000L000=<00006`0001X00Td:0003C@000240
0Tdf009=8`000dd00008009=6`0001T000=<00002@000d`0000R009<=P02C2@000=<00002@000d`0
000H000060000dd000090003C@00028000==04d0=P000dd0C@0T0003C@0000T000==00005`0001H0
0T`;0003C00002<000=<04`0=P000d`0C00U0003C00000T00T`G00005@000dd0000;0003C@0002<0
00==04d0=P000dd0C@0U0003C@0000/000==0000500001@000=<00002`000d`0000S0004C000C3H0
00A<001<9@000d`0000;0003C00001<0000B009=3@000dd0000T0004C@00CCH000A=001=9P000dd0
000;009=4`00014000=<00003@000d`0000T0004C000C3H000A<001<9P000d`0000=0003C0000100
000?009=3`000dd0000T0005C@0004d0=P001Dd0001=02H000==00003@02CA00000>0003C00000h0
00=<00009@001D`0001<03H000E<0000C00W0003C00000h000=<00003@0000d000==00003P000dd0
000V0005C@0004d0=P001Dd0001=02P000==00003P000dd0000<000030000d`0000?0003C00002D0
00=<00000P000d`0000d0003C000008000=<00009@000d`0000?0003C00000/0000M0003C@0002H0
00==00000P000dd0000d0003C@00008000==00009P000dd0000L000070000d`0000W0003C0000080
00=<0000=0000d`000020003C00002L000=<00006`0001/000==00009`000dd000030003C@0003@0
00==00000`000dd0000W0003C@0001X0000K0003C00002L000=<00000`000d`0000d0003C00000<0
00=<00009`000d`0000J00006P000dd0000X0003C@0000<000==0000=0000dd000030003C@0002P0
00==00006@0001T000=<0000:0000d`000040003C00003@000=<000010000d`0000X0003C00001P0
000I0003C@0002P000==000010000dd0000d0003C@0000@000==0000:0000dd0000H000060000d`0
000X0003C00000D000=<0000=0000d`000050003C00002P000=<00005`0001L000==0000:@000dd0
00050003C@0003@000==00001@000dd0000Y0003C@0001H0000F0003C00002X000=<00001@000d`0
000d0003C00000D000=<0000:P000d`0000E0000@P000dd000060003C@0003@000==00001P000dd0
00110000@P000d`000060003C00003@000=<00001P000d`000110000@P000dd000060003C@0003@0
00==00001P000dd000110000@@000d`000070003C00003@000=<00001`000d`000100000@@000dd0
00070003C@0003@000==00001`000dd000100000@@000d`000070003C00003@000=<00001`000d`0
00100000@0000dd000080003C@0003@000==000020000dd0000o0000@0000d`000080003C00003@0
00=<000020000d`0000o0000@0000dd000080003C@0003@000==000020000dd0000o0000?`000d`0
00090003C00003@000=<00002@000d`0000n0000?`000dd000090003C@0003@000==00002@000dd0
000n0000?`000d`000090003C00003@000=<00002@000d`0000n0000?P000dd0000:0003C@0003@0
00==00002P000dd0000m0000?P000d`0000:0003C00003@000=<00002P000d`0000m0000?P000dd0
000:0003C@0003@000==00002P000dd0000m0000?@000d`0000;0003C00003@000=<00002`000d`0
000l0000?@000dd0000;0003C@0003@000==00002`000dd0000l0000?@000d`0000;0003C00003@0
00=<00002`000d`0000l0000?0000dd0000<0003C@0003@000==000030000dd0000k0000B`000d`0
000d0003C00004X0001;0003C@0003@000==0000BP000<l0003?0000c`000<l0003?0000c`000<l0
003?0000c`000<l00000\
\>"],
  ImageRangeCache->{{{0, 206}, {152, 0}} -> {-0.0289584, 0.109701, 0.00513552,
   0.00513552}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples (1)", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(bioTable = Table[randBio, {3}, {5}]\), 
    \(\(biomorph[bioTable]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{{2, 5, 1, 8, 6, 2, 3, 9, 9, 4, 2, 5, 8, 4, 8, 8, 5, 6, 5, 7, 3}, {3, 
          5, 1, 5, 8, 7, 1, 9, 8, 9, 2, 1, 10, 6, 6, 10, 3, 8, 8, 5, 2}, {3, 
          4, 8, 1, 4, 2, 3, 6, 10, 9, 7, 1, 8, 2, 8, 10, 2, 4, 8, 3, 9}, {4, 
          4, 2, 1, 9, 10, 1, 2, 5, 10, 4, 4, 7, 10, 7, 8, 3, 5, 1, 2, 7}, {4, 
          5, 3, 10, 4, 8, 4, 8, 8, 4, 8, 4, 9, 4, 4, 7, 5, 3, 4, 5, 3}}, {{3, 
          5, 4, 6, 1, 2, 2, 1, 5, 5, 9, 4, 7, 3, 6, 1, 3, 4, 4, 6, 2}, {4, 3, 
          1, 9, 6, 3, 3, 8, 8, 6, 8, 1, 8, 1, 10, 10, 5, 5, 7, 6, 4}, {4, 2, 
          9, 3, 10, 5, 2, 1, 10, 7, 6, 2, 7, 10, 8, 7, 4, 2, 5, 4, 7}, {2, 1, 
          2, 10, 10, 3, 3, 1, 6, 3, 3, 1, 7, 8, 6, 6, 1, 6, 3, 9, 6}, {2, 2, 
          7, 6, 7, 7, 5, 5, 6, 4, 2, 4, 5, 8, 7, 1, 1, 6, 3, 4, 6}}, {{4, 1, 
          10, 8, 6, 4, 3, 7, 5, 2, 7, 4, 7, 9, 4, 7, 1, 9, 9, 3, 2}, {3, 5, 
          9, 5, 1, 7, 2, 10, 3, 1, 5, 3, 8, 4, 5, 9, 4, 5, 3, 5, 2}, {4, 4, 
          4, 1, 1, 1, 4, 3, 3, 5, 5, 1, 6, 7, 3, 10, 1, 5, 2, 6, 7}, {4, 3, 
          5, 8, 2, 1, 3, 10, 7, 1, 4, 4, 4, 9, 6, 8, 4, 9, 2, 3, 5}, {4, 4, 
          6, 9, 9, 8, 2, 6, 5, 9, 8, 2, 6, 1, 5, 4, 1, 2, 1, 1, 4}}}\)], 
  "Output",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .59259 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0141093 0.190476 [
[ 0 0 0 0 ]
[ 1 .59259 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .59259 L
0 .59259 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0141093 0.200176 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0506102 0.952381 [
[ 0 0 0 0 ]
[ 1 .85116 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85116 L
0 .85116 L
closepath
clip
newpath
p
P
p
.8 1 0 r
.006 w
.55209 .58728 m
.69506 .73024 L
s
P
p
.8 1 0 r
.006 w
.44076 .24462 m
.47238 .04493 L
s
P
p
.8 1 0 r
.006 w
.22898 .5361 m
.04884 .62789 L
s
P
p
.8 1 0 r
.006 w
.58927 .5361 m
.76942 .62789 L
s
P
p
.2 0 1 r
.008 w
.40913 .44431 m
.55209 .58728 L
s
P
p
.2 0 1 r
.008 w
.40913 .44431 m
.44076 .24462 L
s
P
p
.2 0 1 r
.008 w
.40913 .44431 m
.22898 .5361 L
s
P
p
.2 0 1 r
.008 w
.40913 .44431 m
.58927 .5361 L
s
P
p
.8 1 0 r
.006 w
.53163 .42296 m
.56326 .22327 L
s
P
p
.8 1 0 r
.006 w
.31985 .71445 m
.13971 .80623 L
s
P
p
.8 1 0 r
.006 w
.68015 .71445 m
.86029 .80623 L
s
P
p
.8 1 0 r
.006 w
.46837 .42296 m
.43674 .22327 L
s
P
p
.2 0 1 r
.008 w
.5 .62266 m
.53163 .42296 L
s
P
p
.2 0 1 r
.008 w
.5 .62266 m
.31985 .71445 L
s
P
p
.2 0 1 r
.008 w
.5 .62266 m
.68015 .71445 L
s
P
p
.2 0 1 r
.008 w
.5 .62266 m
.46837 .42296 L
s
P
p
.8 1 0 r
.006 w
.41073 .5361 m
.23058 .62789 L
s
P
p
.8 1 0 r
.006 w
.77102 .5361 m
.95116 .62789 L
s
P
p
.8 1 0 r
.006 w
.55924 .24462 m
.52762 .04493 L
s
P
p
.8 1 0 r
.006 w
.44791 .58728 m
.30494 .73024 L
s
P
p
.2 0 1 r
.008 w
.59087 .44431 m
.41073 .5361 L
s
P
p
.2 0 1 r
.008 w
.59087 .44431 m
.77102 .5361 L
s
P
p
.2 0 1 r
.008 w
.59087 .44431 m
.55924 .24462 L
s
P
p
.2 0 1 r
.008 w
.59087 .44431 m
.44791 .58728 L
s
P
p
.2 0 1 r
.004 w
.5 .51033 m
.40913 .44431 L
s
P
p
.2 0 1 r
.004 w
.5 .51033 m
.5 .62266 L
s
P
p
.2 0 1 r
.004 w
.5 .51033 m
.59087 .44431 L
s
P
p
0 1 .4 r
.012 w
.5 .33062 m
.5 .51033 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.0141093 0.39418 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0310005 0.952381 [
[ 0 0 0 0 ]
[ 1 .89038 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .89038 L
0 .89038 L
closepath
clip
newpath
p
P
p
1 0 .6 r
.01 w
.52666 .71919 m
.59104 .52105 L
s
P
p
1 0 .6 r
.01 w
.52666 .71919 m
.35812 .84164 L
s
P
p
1 0 .6 r
.01 w
.52666 .71919 m
.73499 .71919 L
s
P
p
1 0 .6 r
.01 w
.77948 .53551 m
.7151 .73364 L
s
P
p
1 0 .6 r
.01 w
.77948 .53551 m
.94802 .41305 L
s
P
p
1 0 .6 r
.01 w
.77948 .53551 m
.57114 .53551 L
s
P
p
0 1 1 r
.002 w
.65307 .62735 m
.52666 .71919 L
s
P
p
0 1 1 r
.002 w
.65307 .62735 m
.77948 .53551 L
s
P
p
1 0 .6 r
.01 w
.56813 .12071 m
.44567 .28926 L
s
P
p
1 0 .6 r
.01 w
.56813 .12071 m
.76627 .05633 L
s
P
p
1 0 .6 r
.01 w
.56813 .12071 m
.36999 .05633 L
s
P
p
1 0 .6 r
.01 w
.27092 .21728 m
.39338 .04873 L
s
P
p
1 0 .6 r
.01 w
.27092 .21728 m
.07279 .28166 L
s
P
p
1 0 .6 r
.01 w
.27092 .21728 m
.46906 .28166 L
s
P
p
0 1 1 r
.002 w
.41953 .169 m
.56813 .12071 L
s
P
p
0 1 1 r
.002 w
.41953 .169 m
.27092 .21728 L
s
P
p
1 0 .6 r
.01 w
.34375 .67708 m
.5123 .55463 L
s
P
p
1 0 .6 r
.01 w
.34375 .67708 m
.13542 .67708 L
s
P
p
1 0 .6 r
.01 w
.34375 .67708 m
.5123 .79954 L
s
P
p
1 0 .6 r
.01 w
.65625 .67708 m
.4877 .79954 L
s
P
p
1 0 .6 r
.01 w
.65625 .67708 m
.86458 .67708 L
s
P
p
1 0 .6 r
.01 w
.65625 .67708 m
.4877 .55463 L
s
P
p
0 1 1 r
.002 w
.5 .67708 m
.34375 .67708 L
s
P
p
0 1 1 r
.002 w
.5 .67708 m
.65625 .67708 L
s
P
p
1 0 .6 r
.01 w
.72908 .21728 m
.53094 .28166 L
s
P
p
1 0 .6 r
.01 w
.72908 .21728 m
.92721 .28166 L
s
P
p
1 0 .6 r
.01 w
.72908 .21728 m
.60662 .04873 L
s
P
p
1 0 .6 r
.01 w
.43187 .12071 m
.63001 .05633 L
s
P
p
1 0 .6 r
.01 w
.43187 .12071 m
.23373 .05633 L
s
P
p
1 0 .6 r
.01 w
.43187 .12071 m
.55433 .28926 L
s
P
p
0 1 1 r
.002 w
.58047 .169 m
.72908 .21728 L
s
P
p
0 1 1 r
.002 w
.58047 .169 m
.43187 .12071 L
s
P
p
1 0 .6 r
.01 w
.22052 .53551 m
.42886 .53551 L
s
P
p
1 0 .6 r
.01 w
.22052 .53551 m
.05198 .41305 L
s
P
p
1 0 .6 r
.01 w
.22052 .53551 m
.2849 .73364 L
s
P
p
1 0 .6 r
.01 w
.47334 .71919 m
.26501 .71919 L
s
P
p
1 0 .6 r
.01 w
.47334 .71919 m
.64188 .84164 L
s
P
p
1 0 .6 r
.01 w
.47334 .71919 m
.40896 .52105 L
s
P
p
0 1 1 r
.002 w
.34693 .62735 m
.22052 .53551 L
s
P
p
0 1 1 r
.002 w
.34693 .62735 m
.47334 .71919 L
s
P
p
.2 0 1 r
.002 w
.5 .41667 m
.65307 .62735 L
s
P
p
.2 0 1 r
.002 w
.5 .41667 m
.41953 .169 L
s
P
p
.2 0 1 r
.002 w
.5 .41667 m
.5 .67708 L
s
P
p
.2 0 1 r
.002 w
.5 .41667 m
.58047 .169 L
s
P
p
.2 0 1 r
.002 w
.5 .41667 m
.34693 .62735 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.0141093 0.588183 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0092285 0.952381 [
[ 0 0 0 0 ]
[ 1 .97084 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .97084 L
0 .97084 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.012 w
.52155 .11877 m
.53254 .04937 L
s
P
p
1 0 0 r
.006 w
.48307 .36168 m
.52155 .11877 L
s
P
p
.2 0 1 r
.012 w
.21815 .21735 m
.16847 .16766 L
s
P
p
1 0 0 r
.006 w
.39206 .39125 m
.21815 .21735 L
s
P
p
.2 0 1 r
.012 w
.11958 .52074 m
.05018 .53173 L
s
P
p
1 0 0 r
.006 w
.36248 .48227 m
.11958 .52074 L
s
P
p
.2 0 1 r
.012 w
.30708 .77882 m
.27518 .84143 L
s
P
p
1 0 0 r
.006 w
.41874 .55969 m
.30708 .77882 L
s
P
p
0 1 1 r
.01 w
.46659 .46578 m
.48307 .36168 L
s
P
p
0 1 1 r
.01 w
.46659 .46578 m
.39206 .39125 L
s
P
p
0 1 1 r
.01 w
.46659 .46578 m
.36248 .48227 L
s
P
p
0 1 1 r
.01 w
.46659 .46578 m
.41874 .55969 L
s
P
p
.2 0 1 r
.012 w
.16631 .34556 m
.1037 .31366 L
s
P
p
1 0 0 r
.006 w
.38544 .45721 m
.16631 .34556 L
s
P
p
.2 0 1 r
.012 w
.16631 .66456 m
.1037 .69646 L
s
P
p
1 0 0 r
.006 w
.38544 .55291 m
.16631 .66456 L
s
P
p
.2 0 1 r
.012 w
.42439 .85207 m
.4134 .92147 L
s
P
p
1 0 0 r
.006 w
.46286 .60916 m
.42439 .85207 L
s
P
p
.2 0 1 r
.012 w
.72778 .75349 m
.77747 .80318 L
s
P
p
1 0 0 r
.006 w
.55388 .57959 m
.72778 .75349 L
s
P
p
0 1 1 r
.01 w
.47935 .50506 m
.38544 .45721 L
s
P
p
0 1 1 r
.01 w
.47935 .50506 m
.38544 .55291 L
s
P
p
0 1 1 r
.01 w
.47935 .50506 m
.46286 .60916 L
s
P
p
0 1 1 r
.01 w
.47935 .50506 m
.55388 .57959 L
s
P
p
.2 0 1 r
.012 w
.27222 .75349 m
.22253 .80318 L
s
P
p
1 0 0 r
.006 w
.44612 .57959 m
.27222 .75349 L
s
P
p
.2 0 1 r
.012 w
.57561 .85207 m
.5866 .92147 L
s
P
p
1 0 0 r
.006 w
.53714 .60916 m
.57561 .85207 L
s
P
p
.2 0 1 r
.012 w
.83369 .66456 m
.8963 .69646 L
s
P
p
1 0 0 r
.006 w
.61456 .55291 m
.83369 .66456 L
s
P
p
.2 0 1 r
.012 w
.83369 .34556 m
.8963 .31366 L
s
P
p
1 0 0 r
.006 w
.61456 .45721 m
.83369 .34556 L
s
P
p
0 1 1 r
.01 w
.52065 .50506 m
.44612 .57959 L
s
P
p
0 1 1 r
.01 w
.52065 .50506 m
.53714 .60916 L
s
P
p
0 1 1 r
.01 w
.52065 .50506 m
.61456 .55291 L
s
P
p
0 1 1 r
.01 w
.52065 .50506 m
.61456 .45721 L
s
P
p
.2 0 1 r
.012 w
.69292 .77882 m
.72482 .84143 L
s
P
p
1 0 0 r
.006 w
.58126 .55969 m
.69292 .77882 L
s
P
p
.2 0 1 r
.012 w
.88042 .52074 m
.94982 .53173 L
s
P
p
1 0 0 r
.006 w
.63752 .48227 m
.88042 .52074 L
s
P
p
.2 0 1 r
.012 w
.78185 .21735 m
.83153 .16766 L
s
P
p
1 0 0 r
.006 w
.60794 .39125 m
.78185 .21735 L
s
P
p
.2 0 1 r
.012 w
.47845 .11877 m
.46746 .04937 L
s
P
p
1 0 0 r
.006 w
.51693 .36168 m
.47845 .11877 L
s
P
p
0 1 1 r
.01 w
.53341 .46578 m
.58126 .55969 L
s
P
p
0 1 1 r
.01 w
.53341 .46578 m
.63752 .48227 L
s
P
p
0 1 1 r
.01 w
.53341 .46578 m
.60794 .39125 L
s
P
p
0 1 1 r
.01 w
.53341 .46578 m
.51693 .36168 L
s
P
p
1 .6 0 r
.002 w
.5 .47664 m
.46659 .46578 L
s
P
p
1 .6 0 r
.002 w
.5 .47664 m
.47935 .50506 L
s
P
p
1 .6 0 r
.002 w
.5 .47664 m
.52065 .50506 L
s
P
p
1 .6 0 r
.002 w
.5 .47664 m
.53341 .46578 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.0141093 0.782187 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.119155 0.952381 [
[ 0 0 0 0 ]
[ 1 .71407 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .71407 L
0 .71407 L
closepath
clip
newpath
p
P
p
0 1 1 r
.006 w
.42795 .38458 m
.46559 .37862 L
s
P
p
0 1 1 r
.006 w
.42795 .38458 m
.39031 .37862 L
s
P
p
0 1 1 r
.006 w
.42795 .38458 m
.46191 .40188 L
s
P
p
0 1 1 r
.006 w
.42795 .38458 m
.401 .35763 L
s
P
p
0 1 1 r
.006 w
.61969 .32228 m
.62565 .28464 L
s
P
p
0 1 1 r
.006 w
.61969 .32228 m
.60239 .35624 L
s
P
p
0 1 1 r
.006 w
.61969 .32228 m
.64664 .29533 L
s
P
p
0 1 1 r
.006 w
.61969 .32228 m
.58573 .33958 L
s
P
p
0 1 1 r
.006 w
.61969 .12067 m
.58573 .10337 L
s
P
p
0 1 1 r
.006 w
.61969 .12067 m
.64664 .14762 L
s
P
p
0 1 1 r
.006 w
.61969 .12067 m
.60239 .08672 L
s
P
p
0 1 1 r
.006 w
.61969 .12067 m
.62565 .15832 L
s
P
p
0 1 1 r
.006 w
.42795 .05837 m
.401 .08532 L
s
P
p
0 1 1 r
.006 w
.42795 .05837 m
.46191 .04107 L
s
P
p
0 1 1 r
.006 w
.42795 .05837 m
.39031 .06434 L
s
P
p
0 1 1 r
.006 w
.42795 .05837 m
.46559 .06434 L
s
P
p
.8 0 1 r
.012 w
.48094 .22148 m
.42795 .38458 L
s
P
p
.8 0 1 r
.012 w
.48094 .22148 m
.61969 .32228 L
s
P
p
.8 0 1 r
.012 w
.48094 .22148 m
.61969 .12067 L
s
P
p
.8 0 1 r
.012 w
.48094 .22148 m
.42795 .05837 L
s
P
p
0 1 1 r
.006 w
.26717 .05837 m
.22953 .06434 L
s
P
p
0 1 1 r
.006 w
.26717 .05837 m
.30481 .06434 L
s
P
p
0 1 1 r
.006 w
.26717 .05837 m
.23321 .04107 L
s
P
p
0 1 1 r
.006 w
.26717 .05837 m
.29412 .08532 L
s
P
p
0 1 1 r
.006 w
.07543 .12067 m
.06947 .15832 L
s
P
p
0 1 1 r
.006 w
.07543 .12067 m
.09273 .08672 L
s
P
p
0 1 1 r
.006 w
.07543 .12067 m
.04848 .14762 L
s
P
p
0 1 1 r
.006 w
.07543 .12067 m
.10938 .10337 L
s
P
p
0 1 1 r
.006 w
.07543 .32228 m
.10938 .33958 L
s
P
p
0 1 1 r
.006 w
.07543 .32228 m
.04848 .29533 L
s
P
p
0 1 1 r
.006 w
.07543 .32228 m
.09273 .35624 L
s
P
p
0 1 1 r
.006 w
.07543 .32228 m
.06947 .28464 L
s
P
p
0 1 1 r
.006 w
.26717 .38458 m
.29412 .35763 L
s
P
p
0 1 1 r
.006 w
.26717 .38458 m
.23321 .40188 L
s
P
p
0 1 1 r
.006 w
.26717 .38458 m
.30481 .37862 L
s
P
p
0 1 1 r
.006 w
.26717 .38458 m
.22953 .37862 L
s
P
p
.8 0 1 r
.012 w
.21417 .22148 m
.26717 .05837 L
s
P
p
.8 0 1 r
.012 w
.21417 .22148 m
.07543 .12067 L
s
P
p
.8 0 1 r
.012 w
.21417 .22148 m
.07543 .32228 L
s
P
p
.8 0 1 r
.012 w
.21417 .22148 m
.26717 .38458 L
s
P
p
0 1 .4 r
.002 w
.34756 .22148 m
.48094 .22148 L
s
P
p
0 1 .4 r
.002 w
.34756 .22148 m
.21417 .22148 L
s
P
p
0 1 1 r
.006 w
.6631 .29353 m
.65714 .25589 L
s
P
p
0 1 1 r
.006 w
.6631 .29353 m
.65714 .33117 L
s
P
p
0 1 1 r
.006 w
.6631 .29353 m
.68041 .25957 L
s
P
p
0 1 1 r
.006 w
.6631 .29353 m
.63616 .32048 L
s
P
p
0 1 1 r
.006 w
.6008 .10179 m
.56316 .09583 L
s
P
p
0 1 1 r
.006 w
.6008 .10179 m
.63476 .11909 L
s
P
p
0 1 1 r
.006 w
.6008 .10179 m
.57386 .07484 L
s
P
p
0 1 1 r
.006 w
.6008 .10179 m
.61811 .13575 L
s
P
p
0 1 1 r
.006 w
.3992 .10179 m
.38189 .13575 L
s
P
p
0 1 1 r
.006 w
.3992 .10179 m
.42614 .07484 L
s
P
p
0 1 1 r
.006 w
.3992 .10179 m
.36524 .11909 L
s
P
p
0 1 1 r
.006 w
.3992 .10179 m
.43684 .09583 L
s
P
p
0 1 1 r
.006 w
.3369 .29353 m
.36384 .32048 L
s
P
p
0 1 1 r
.006 w
.3369 .29353 m
.31959 .25957 L
s
P
p
0 1 1 r
.006 w
.3369 .29353 m
.34286 .33117 L
s
P
p
0 1 1 r
.006 w
.3369 .29353 m
.34286 .25589 L
s
P
p
.8 0 1 r
.012 w
.5 .24053 m
.6631 .29353 L
s
P
p
.8 0 1 r
.012 w
.5 .24053 m
.6008 .10179 L
s
P
p
.8 0 1 r
.012 w
.5 .24053 m
.3992 .10179 L
s
P
p
.8 0 1 r
.012 w
.5 .24053 m
.3369 .29353 L
s
P
p
0 1 1 r
.006 w
.3369 .45431 m
.34286 .49195 L
s
P
p
0 1 1 r
.006 w
.3369 .45431 m
.34286 .41667 L
s
P
p
0 1 1 r
.006 w
.3369 .45431 m
.31959 .48827 L
s
P
p
0 1 1 r
.006 w
.3369 .45431 m
.36384 .42736 L
s
P
p
0 1 1 r
.006 w
.3992 .64605 m
.43684 .65201 L
s
P
p
0 1 1 r
.006 w
.3992 .64605 m
.36524 .62875 L
s
P
p
0 1 1 r
.006 w
.3992 .64605 m
.42614 .673 L
s
P
p
0 1 1 r
.006 w
.3992 .64605 m
.38189 .61209 L
s
P
p
0 1 1 r
.006 w
.6008 .64605 m
.61811 .61209 L
s
P
p
0 1 1 r
.006 w
.6008 .64605 m
.57386 .673 L
s
P
p
0 1 1 r
.006 w
.6008 .64605 m
.63476 .62875 L
s
P
p
0 1 1 r
.006 w
.6008 .64605 m
.56316 .65201 L
s
P
p
0 1 1 r
.006 w
.6631 .45431 m
.63616 .42736 L
s
P
p
0 1 1 r
.006 w
.6631 .45431 m
.68041 .48827 L
s
P
p
0 1 1 r
.006 w
.6631 .45431 m
.65714 .41667 L
s
P
p
0 1 1 r
.006 w
.6631 .45431 m
.65714 .49195 L
s
P
p
.8 0 1 r
.012 w
.5 .50731 m
.3369 .45431 L
s
P
p
.8 0 1 r
.012 w
.5 .50731 m
.3992 .64605 L
s
P
p
.8 0 1 r
.012 w
.5 .50731 m
.6008 .64605 L
s
P
p
.8 0 1 r
.012 w
.5 .50731 m
.6631 .45431 L
s
P
p
0 1 .4 r
.002 w
.5 .37392 m
.5 .24053 L
s
P
p
0 1 .4 r
.002 w
.5 .37392 m
.5 .50731 L
s
P
p
0 1 1 r
.006 w
.57205 .05837 m
.53441 .06434 L
s
P
p
0 1 1 r
.006 w
.57205 .05837 m
.60969 .06434 L
s
P
p
0 1 1 r
.006 w
.57205 .05837 m
.53809 .04107 L
s
P
p
0 1 1 r
.006 w
.57205 .05837 m
.599 .08532 L
s
P
p
0 1 1 r
.006 w
.38031 .12067 m
.37435 .15832 L
s
P
p
0 1 1 r
.006 w
.38031 .12067 m
.39761 .08672 L
s
P
p
0 1 1 r
.006 w
.38031 .12067 m
.35336 .14762 L
s
P
p
0 1 1 r
.006 w
.38031 .12067 m
.41427 .10337 L
s
P
p
0 1 1 r
.006 w
.38031 .32228 m
.41427 .33958 L
s
P
p
0 1 1 r
.006 w
.38031 .32228 m
.35336 .29533 L
s
P
p
0 1 1 r
.006 w
.38031 .32228 m
.39761 .35624 L
s
P
p
0 1 1 r
.006 w
.38031 .32228 m
.37435 .28464 L
s
P
p
0 1 1 r
.006 w
.57205 .38458 m
.599 .35763 L
s
P
p
0 1 1 r
.006 w
.57205 .38458 m
.53809 .40188 L
s
P
p
0 1 1 r
.006 w
.57205 .38458 m
.60969 .37862 L
s
P
p
0 1 1 r
.006 w
.57205 .38458 m
.53441 .37862 L
s
P
p
.8 0 1 r
.012 w
.51906 .22148 m
.57205 .05837 L
s
P
p
.8 0 1 r
.012 w
.51906 .22148 m
.38031 .12067 L
s
P
p
.8 0 1 r
.012 w
.51906 .22148 m
.38031 .32228 L
s
P
p
.8 0 1 r
.012 w
.51906 .22148 m
.57205 .38458 L
s
P
p
0 1 1 r
.006 w
.73283 .38458 m
.77047 .37862 L
s
P
p
0 1 1 r
.006 w
.73283 .38458 m
.69519 .37862 L
s
P
p
0 1 1 r
.006 w
.73283 .38458 m
.76679 .40188 L
s
P
p
0 1 1 r
.006 w
.73283 .38458 m
.70588 .35763 L
s
P
p
0 1 1 r
.006 w
.92457 .32228 m
.93053 .28464 L
s
P
p
0 1 1 r
.006 w
.92457 .32228 m
.90727 .35624 L
s
P
p
0 1 1 r
.006 w
.92457 .32228 m
.95152 .29533 L
s
P
p
0 1 1 r
.006 w
.92457 .32228 m
.89062 .33958 L
s
P
p
0 1 1 r
.006 w
.92457 .12067 m
.89062 .10337 L
s
P
p
0 1 1 r
.006 w
.92457 .12067 m
.95152 .14762 L
s
P
p
0 1 1 r
.006 w
.92457 .12067 m
.90727 .08672 L
s
P
p
0 1 1 r
.006 w
.92457 .12067 m
.93053 .15832 L
s
P
p
0 1 1 r
.006 w
.73283 .05837 m
.70588 .08532 L
s
P
p
0 1 1 r
.006 w
.73283 .05837 m
.76679 .04107 L
s
P
p
0 1 1 r
.006 w
.73283 .05837 m
.69519 .06434 L
s
P
p
0 1 1 r
.006 w
.73283 .05837 m
.77047 .06434 L
s
P
p
.8 0 1 r
.012 w
.78583 .22148 m
.73283 .38458 L
s
P
p
.8 0 1 r
.012 w
.78583 .22148 m
.92457 .32228 L
s
P
p
.8 0 1 r
.012 w
.78583 .22148 m
.92457 .12067 L
s
P
p
.8 0 1 r
.012 w
.78583 .22148 m
.73283 .05837 L
s
P
p
0 1 .4 r
.002 w
.65244 .22148 m
.51906 .22148 L
s
P
p
0 1 .4 r
.002 w
.65244 .22148 m
.78583 .22148 L
s
P
p
1 .6 0 r
.004 w
.5 .22148 m
.34756 .22148 L
s
P
p
1 .6 0 r
.004 w
.5 .22148 m
.5 .37392 L
s
P
p
1 .6 0 r
.004 w
.5 .22148 m
.65244 .22148 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.0141093 0.97619 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.000503103 0.952381 [
[ 0 0 0 0 ]
[ 1 .95339 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95339 L
0 .95339 L
closepath
clip
newpath
p
P
p
0 1 .4 r
.002 w
.53816 .11136 m
.57112 .11136 L
s
P
p
0 1 .4 r
.002 w
.49501 .08001 m
.48483 .04867 L
s
P
p
0 1 .4 r
.01 w
.5052 .11136 m
.53816 .11136 L
s
P
p
0 1 .4 r
.01 w
.5052 .11136 m
.49501 .08001 L
s
P
p
0 1 .4 r
.002 w
.24141 .16241 m
.23123 .13107 L
s
P
p
0 1 .4 r
.002 w
.22493 .21313 m
.19827 .23251 L
s
P
p
0 1 .4 r
.01 w
.2516 .19376 m
.24141 .16241 L
s
P
p
0 1 .4 r
.01 w
.2516 .19376 m
.22493 .21313 L
s
P
p
.8 0 1 r
.018 w
.40833 .24469 m
.5052 .11136 L
s
P
p
.8 0 1 r
.018 w
.40833 .24469 m
.2516 .19376 L
s
P
p
0 1 .4 r
.002 w
.09309 .6189 m
.08291 .58755 L
s
P
p
0 1 .4 r
.002 w
.07661 .66962 m
.04995 .68899 L
s
P
p
0 1 .4 r
.01 w
.10328 .65025 m
.09309 .6189 L
s
P
p
0 1 .4 r
.01 w
.10328 .65025 m
.07661 .66962 L
s
P
p
0 1 .4 r
.002 w
.23335 .88535 m
.20668 .90472 L
s
P
p
0 1 .4 r
.002 w
.28668 .88535 m
.31334 .90472 L
s
P
p
0 1 .4 r
.01 w
.26001 .86597 m
.23335 .88535 L
s
P
p
0 1 .4 r
.01 w
.26001 .86597 m
.28668 .88535 L
s
P
p
.8 0 1 r
.018 w
.26001 .70117 m
.10328 .65025 L
s
P
p
.8 0 1 r
.018 w
.26001 .70117 m
.26001 .86597 L
s
P
p
0 1 .4 r
.002 w
.71332 .88535 m
.68666 .90472 L
s
P
p
0 1 .4 r
.002 w
.76665 .88535 m
.79332 .90472 L
s
P
p
0 1 .4 r
.01 w
.73999 .86597 m
.71332 .88535 L
s
P
p
0 1 .4 r
.01 w
.73999 .86597 m
.76665 .88535 L
s
P
p
0 1 .4 r
.002 w
.92339 .66962 m
.95005 .68899 L
s
P
p
0 1 .4 r
.002 w
.90691 .6189 m
.91709 .58755 L
s
P
p
0 1 .4 r
.01 w
.89672 .65025 m
.92339 .66962 L
s
P
p
0 1 .4 r
.01 w
.89672 .65025 m
.90691 .6189 L
s
P
p
.8 0 1 r
.018 w
.73999 .70117 m
.73999 .86597 L
s
P
p
.8 0 1 r
.018 w
.73999 .70117 m
.89672 .65025 L
s
P
p
0 1 .4 r
.002 w
.77507 .21313 m
.80173 .23251 L
s
P
p
0 1 .4 r
.002 w
.75859 .16241 m
.76877 .13107 L
s
P
p
0 1 .4 r
.01 w
.7484 .19376 m
.77507 .21313 L
s
P
p
0 1 .4 r
.01 w
.7484 .19376 m
.75859 .16241 L
s
P
p
0 1 .4 r
.002 w
.50499 .08001 m
.51517 .04867 L
s
P
p
0 1 .4 r
.002 w
.46184 .11136 m
.42888 .11136 L
s
P
p
0 1 .4 r
.01 w
.4948 .11136 m
.50499 .08001 L
s
P
p
0 1 .4 r
.01 w
.4948 .11136 m
.46184 .11136 L
s
P
p
.8 0 1 r
.018 w
.59167 .24469 m
.7484 .19376 L
s
P
p
.8 0 1 r
.018 w
.59167 .24469 m
.4948 .11136 L
s
P
p
.8 0 1 r
.018 w
.5 .52681 m
.40833 .24469 L
s
P
p
.8 0 1 r
.018 w
.5 .52681 m
.26001 .70117 L
s
P
p
.8 0 1 r
.018 w
.5 .52681 m
.73999 .70117 L
s
P
p
.8 0 1 r
.018 w
.5 .52681 m
.59167 .24469 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.208113 0.200176 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.00983481 0.952381 [
[ 0 0 0 0 ]
[ 1 .97205 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .97205 L
0 .97205 L
closepath
clip
newpath
p
P
p
1 .6 0 r
.012 w
.2929 .13618 m
.32602 .23812 L
s
P
p
1 .6 0 r
.012 w
.2929 .13618 m
.3559 .04946 L
s
P
p
1 .6 0 r
.012 w
.2929 .13618 m
.18571 .13618 L
s
P
p
1 .6 0 r
.012 w
.2929 .13618 m
.3559 .22289 L
s
P
p
1 .6 0 r
.012 w
.24768 .16903 m
.31068 .25574 L
s
P
p
1 .6 0 r
.012 w
.24768 .16903 m
.2808 .06709 L
s
P
p
1 .6 0 r
.012 w
.24768 .16903 m
.14574 .20215 L
s
P
p
1 .6 0 r
.012 w
.24768 .16903 m
.33439 .23203 L
s
P
p
1 0 .6 r
.01 w
.374 .29535 m
.2929 .13618 L
s
P
p
1 0 .6 r
.01 w
.374 .29535 m
.24768 .16903 L
s
P
p
1 .6 0 r
.012 w
.11968 .56296 m
.22687 .56296 L
s
P
p
1 .6 0 r
.012 w
.11968 .56296 m
.05668 .47625 L
s
P
p
1 .6 0 r
.012 w
.11968 .56296 m
.08656 .6649 L
s
P
p
1 .6 0 r
.012 w
.11968 .56296 m
.22162 .52984 L
s
P
p
1 .6 0 r
.012 w
.13695 .61612 m
.23889 .583 L
s
P
p
1 .6 0 r
.012 w
.13695 .61612 m
.05024 .55312 L
s
P
p
1 .6 0 r
.012 w
.13695 .61612 m
.13695 .72331 L
s
P
p
1 .6 0 r
.012 w
.13695 .61612 m
.22367 .55312 L
s
P
p
1 0 .6 r
.01 w
.29612 .53502 m
.11968 .56296 L
s
P
p
1 0 .6 r
.01 w
.29612 .53502 m
.13695 .61612 L
s
P
p
1 .6 0 r
.012 w
.47205 .85959 m
.50518 .75765 L
s
P
p
1 .6 0 r
.012 w
.47205 .85959 m
.37012 .89271 L
s
P
p
1 .6 0 r
.012 w
.47205 .85959 m
.55877 .92259 L
s
P
p
1 .6 0 r
.012 w
.47205 .85959 m
.47205 .7524 L
s
P
p
1 .6 0 r
.012 w
.52795 .85959 m
.52795 .7524 L
s
P
p
1 .6 0 r
.012 w
.52795 .85959 m
.44123 .92259 L
s
P
p
1 .6 0 r
.012 w
.52795 .85959 m
.62988 .89271 L
s
P
p
1 .6 0 r
.012 w
.52795 .85959 m
.49482 .75765 L
s
P
p
1 0 .6 r
.01 w
.5 .68314 m
.47205 .85959 L
s
P
p
1 0 .6 r
.01 w
.5 .68314 m
.52795 .85959 L
s
P
p
1 .6 0 r
.012 w
.86305 .61612 m
.77633 .55312 L
s
P
p
1 .6 0 r
.012 w
.86305 .61612 m
.86305 .72331 L
s
P
p
1 .6 0 r
.012 w
.86305 .61612 m
.94976 .55312 L
s
P
p
1 .6 0 r
.012 w
.86305 .61612 m
.76111 .583 L
s
P
p
1 .6 0 r
.012 w
.88032 .56296 m
.77838 .52984 L
s
P
p
1 .6 0 r
.012 w
.88032 .56296 m
.91344 .6649 L
s
P
p
1 .6 0 r
.012 w
.88032 .56296 m
.94332 .47625 L
s
P
p
1 .6 0 r
.012 w
.88032 .56296 m
.77313 .56296 L
s
P
p
1 0 .6 r
.01 w
.70388 .53502 m
.86305 .61612 L
s
P
p
1 0 .6 r
.01 w
.70388 .53502 m
.88032 .56296 L
s
P
p
1 .6 0 r
.012 w
.75232 .16903 m
.66561 .23203 L
s
P
p
1 .6 0 r
.012 w
.75232 .16903 m
.85426 .20215 L
s
P
p
1 .6 0 r
.012 w
.75232 .16903 m
.7192 .06709 L
s
P
p
1 .6 0 r
.012 w
.75232 .16903 m
.68932 .25574 L
s
P
p
1 .6 0 r
.012 w
.7071 .13618 m
.6441 .22289 L
s
P
p
1 .6 0 r
.012 w
.7071 .13618 m
.81429 .13618 L
s
P
p
1 .6 0 r
.012 w
.7071 .13618 m
.6441 .04946 L
s
P
p
1 .6 0 r
.012 w
.7071 .13618 m
.67398 .23812 L
s
P
p
1 0 .6 r
.01 w
.626 .29535 m
.75232 .16903 L
s
P
p
1 0 .6 r
.01 w
.626 .29535 m
.7071 .13618 L
s
P
p
.8 1 0 r
.002 w
.5 .46878 m
.374 .29535 L
s
P
p
.8 1 0 r
.002 w
.5 .46878 m
.29612 .53502 L
s
P
p
.8 1 0 r
.002 w
.5 .46878 m
.5 .68314 L
s
P
p
.8 1 0 r
.002 w
.5 .46878 m
.70388 .53502 L
s
P
p
.8 1 0 r
.002 w
.5 .46878 m
.626 .29535 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.208113 0.39418 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.108275 1.21655 0.0304137 1.21655 [
[ 0 0 0 0 ]
[ 1 1.27738 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.27738 L
0 1.27738 L
closepath
clip
newpath
p
P
p
0 1 .4 r
.012 w
.29777 .30524 m
.37641 .54729 L
s
P
p
0 1 .4 r
.012 w
.29777 .30524 m
.53982 .22659 L
s
P
p
0 1 .4 r
.012 w
.29777 .30524 m
.21912 .06319 L
s
P
p
0 1 .4 r
.012 w
.29777 .30524 m
.05572 .38389 L
s
P
p
1 0 0 r
.02 w
.309 .33982 m
.29777 .30524 L
s
P
p
0 1 .4 r
.012 w
.29777 .92765 m
.37641 .6856 L
s
P
p
0 1 .4 r
.012 w
.29777 .92765 m
.05572 .849 L
s
P
p
0 1 .4 r
.012 w
.29777 .92765 m
.21912 1.1697 L
s
P
p
0 1 .4 r
.012 w
.29777 .92765 m
.53982 1.0063 L
s
P
p
1 0 0 r
.02 w
.309 .89307 m
.29777 .92765 L
s
P
p
0 1 .4 r
.012 w
.66361 .42411 m
.45771 .5737 L
s
P
p
0 1 .4 r
.012 w
.66361 .42411 m
.8132 .63001 L
s
P
p
0 1 .4 r
.012 w
.66361 .42411 m
.86951 .27452 L
s
P
p
0 1 .4 r
.012 w
.66361 .42411 m
.51402 .21821 L
s
P
p
1 0 0 r
.02 w
.6342 .44548 m
.66361 .42411 L
s
P
p
.8 0 1 r
.012 w
.39888 .61645 m
.309 .33982 L
s
P
p
.8 0 1 r
.012 w
.39888 .61645 m
.309 .89307 L
s
P
p
.8 0 1 r
.012 w
.39888 .61645 m
.6342 .44548 L
s
P
p
0 1 .4 r
.012 w
.30766 .36773 m
.45726 .57363 L
s
P
p
0 1 .4 r
.012 w
.30766 .36773 m
.51356 .21814 L
s
P
p
0 1 .4 r
.012 w
.30766 .36773 m
.15807 .16183 L
s
P
p
0 1 .4 r
.012 w
.30766 .36773 m
.10177 .51733 L
s
P
p
1 0 0 r
.02 w
.32904 .39715 m
.30766 .36773 L
s
P
p
0 1 .4 r
.012 w
.5 .95968 m
.5 .70518 L
s
P
p
0 1 .4 r
.012 w
.5 .95968 m
.2455 .95968 L
s
P
p
0 1 .4 r
.012 w
.5 .95968 m
.5 1.21419 L
s
P
p
0 1 .4 r
.012 w
.5 .95968 m
.7545 .95968 L
s
P
p
1 0 0 r
.02 w
.5 .92332 m
.5 .95968 L
s
P
p
0 1 .4 r
.012 w
.69234 .36773 m
.54274 .57363 L
s
P
p
0 1 .4 r
.012 w
.69234 .36773 m
.89823 .51733 L
s
P
p
0 1 .4 r
.012 w
.69234 .36773 m
.84193 .16183 L
s
P
p
0 1 .4 r
.012 w
.69234 .36773 m
.48644 .21814 L
s
P
p
1 0 0 r
.02 w
.67096 .39715 m
.69234 .36773 L
s
P
p
.8 0 1 r
.012 w
.5 .63246 m
.32904 .39715 L
s
P
p
.8 0 1 r
.012 w
.5 .63246 m
.5 .92332 L
s
P
p
.8 0 1 r
.012 w
.5 .63246 m
.67096 .39715 L
s
P
p
0 1 .4 r
.012 w
.33639 .42411 m
.54229 .5737 L
s
P
p
0 1 .4 r
.012 w
.33639 .42411 m
.48598 .21821 L
s
P
p
0 1 .4 r
.012 w
.33639 .42411 m
.13049 .27452 L
s
P
p
0 1 .4 r
.012 w
.33639 .42411 m
.1868 .63001 L
s
P
p
1 0 0 r
.02 w
.3658 .44548 m
.33639 .42411 L
s
P
p
0 1 .4 r
.012 w
.70223 .92765 m
.62359 .6856 L
s
P
p
0 1 .4 r
.012 w
.70223 .92765 m
.46018 1.0063 L
s
P
p
0 1 .4 r
.012 w
.70223 .92765 m
.78088 1.1697 L
s
P
p
0 1 .4 r
.012 w
.70223 .92765 m
.94428 .849 L
s
P
p
1 0 0 r
.02 w
.691 .89307 m
.70223 .92765 L
s
P
p
0 1 .4 r
.012 w
.70223 .30524 m
.62359 .54729 L
s
P
p
0 1 .4 r
.012 w
.70223 .30524 m
.94428 .38389 L
s
P
p
0 1 .4 r
.012 w
.70223 .30524 m
.78088 .06319 L
s
P
p
0 1 .4 r
.012 w
.70223 .30524 m
.46018 .22659 L
s
P
p
1 0 0 r
.02 w
.691 .33982 m
.70223 .30524 L
s
P
p
.8 0 1 r
.012 w
.60112 .61645 m
.3658 .44548 L
s
P
p
.8 0 1 r
.012 w
.60112 .61645 m
.691 .89307 L
s
P
p
.8 0 1 r
.012 w
.60112 .61645 m
.691 .33982 L
s
P
p
.2 1 0 r
.012 w
.5 .30524 m
.39888 .61645 L
s
P
p
.2 1 0 r
.012 w
.5 .30524 m
.5 .63246 L
s
P
p
.2 1 0 r
.012 w
.5 .30524 m
.60112 .61645 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.208113 0.588183 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.143578 0.952381 [
[ 0 0 0 0 ]
[ 1 .66523 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .66523 L
0 .66523 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.008 w
.17716 .13085 m
.21903 .04868 L
s
P
p
.2 0 1 r
.008 w
.17716 .13085 m
.16274 .03977 L
s
P
p
.2 0 1 r
.008 w
.17716 .13085 m
.11195 .06564 L
s
P
p
.2 0 1 r
.008 w
.17716 .13085 m
.08607 .11643 L
s
P
p
.2 0 1 r
.008 w
.17716 .45954 m
.08607 .47397 L
s
P
p
.2 0 1 r
.008 w
.17716 .45954 m
.11195 .52475 L
s
P
p
.2 0 1 r
.008 w
.17716 .45954 m
.16274 .55063 L
s
P
p
.2 0 1 r
.008 w
.17716 .45954 m
.21903 .54171 L
s
P
p
.2 0 1 r
.016 w
.2609 .2952 m
.17716 .13085 L
s
P
p
.2 0 1 r
.016 w
.2609 .2952 m
.17716 .45954 L
s
P
p
.2 0 1 r
.008 w
.1395 .22177 m
.15393 .13068 L
s
P
p
.2 0 1 r
.008 w
.1395 .22177 m
.09763 .1396 L
s
P
p
.2 0 1 r
.008 w
.1395 .22177 m
.05733 .1799 L
s
P
p
.2 0 1 r
.008 w
.1395 .22177 m
.04841 .2362 L
s
P
p
.2 0 1 r
.008 w
.24107 .53437 m
.1589 .57624 L
s
P
p
.2 0 1 r
.008 w
.24107 .53437 m
.1992 .61654 L
s
P
p
.2 0 1 r
.008 w
.24107 .53437 m
.2555 .62546 L
s
P
p
.2 0 1 r
.008 w
.24107 .53437 m
.30629 .59958 L
s
P
p
.2 0 1 r
.016 w
.26993 .3522 m
.1395 .22177 L
s
P
p
.2 0 1 r
.016 w
.26993 .3522 m
.24107 .53437 L
s
P
p
0 .4 1 r
.014 w
.44535 .2952 m
.2609 .2952 L
s
P
p
0 .4 1 r
.014 w
.44535 .2952 m
.26993 .3522 L
s
P
p
.2 0 1 r
.008 w
.75893 .53437 m
.69371 .59958 L
s
P
p
.2 0 1 r
.008 w
.75893 .53437 m
.7445 .62546 L
s
P
p
.2 0 1 r
.008 w
.75893 .53437 m
.8008 .61654 L
s
P
p
.2 0 1 r
.008 w
.75893 .53437 m
.8411 .57624 L
s
P
p
.2 0 1 r
.008 w
.8605 .22177 m
.95159 .2362 L
s
P
p
.2 0 1 r
.008 w
.8605 .22177 m
.94267 .1799 L
s
P
p
.2 0 1 r
.008 w
.8605 .22177 m
.90237 .1396 L
s
P
p
.2 0 1 r
.008 w
.8605 .22177 m
.84607 .13068 L
s
P
p
.2 0 1 r
.016 w
.73007 .3522 m
.75893 .53437 L
s
P
p
.2 0 1 r
.016 w
.73007 .3522 m
.8605 .22177 L
s
P
p
.2 0 1 r
.008 w
.82284 .45954 m
.78097 .54171 L
s
P
p
.2 0 1 r
.008 w
.82284 .45954 m
.83726 .55063 L
s
P
p
.2 0 1 r
.008 w
.82284 .45954 m
.88805 .52475 L
s
P
p
.2 0 1 r
.008 w
.82284 .45954 m
.91393 .47397 L
s
P
p
.2 0 1 r
.008 w
.82284 .13085 m
.91393 .11643 L
s
P
p
.2 0 1 r
.008 w
.82284 .13085 m
.88805 .06564 L
s
P
p
.2 0 1 r
.008 w
.82284 .13085 m
.83726 .03977 L
s
P
p
.2 0 1 r
.008 w
.82284 .13085 m
.78097 .04868 L
s
P
p
.2 0 1 r
.016 w
.7391 .2952 m
.82284 .45954 L
s
P
p
.2 0 1 r
.016 w
.7391 .2952 m
.82284 .13085 L
s
P
p
0 .4 1 r
.014 w
.55465 .2952 m
.73007 .3522 L
s
P
p
0 .4 1 r
.014 w
.55465 .2952 m
.7391 .2952 L
s
P
p
0 1 1 r
.02 w
.5 .28654 m
.44535 .2952 L
s
P
p
0 1 1 r
.02 w
.5 .28654 m
.55465 .2952 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.208113 0.782187 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.27454 3.54909 0.0887271 3.54909 [
[ 0 0 0 0 ]
[ 1 3.72654 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 3.72654 L
0 3.72654 L
closepath
clip
newpath
p
P
p
.2 1 0 r
.006 w
.5 2.28028 m
.11341 3.47008 L
s
P
p
.2 1 0 r
.006 w
.5 2.28028 m
.5 3.5313 L
s
P
p
.2 1 0 r
.006 w
.5 2.28028 m
.88659 3.47008 L
s
P
p
.2 1 0 r
.02 w
.5 .19523 m
.5 2.28028 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.208113 0.97619 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.214286 0.952381 [
[ 0 0 0 0 ]
[ 1 .52381 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .52381 L
0 .52381 L
closepath
clip
newpath
p
P
p
.8 1 0 r
.008 w
.27545 .2619 m
.5 .14749 L
s
P
p
.8 1 0 r
.008 w
.27545 .2619 m
.16104 .03736 L
s
P
p
.8 1 0 r
.008 w
.27545 .2619 m
.0509 .37632 L
s
P
p
.8 1 0 r
.008 w
.27545 .2619 m
.38986 .48645 L
s
P
p
.8 1 0 r
.008 w
.72455 .2619 m
.5 .14749 L
s
P
p
.8 1 0 r
.008 w
.72455 .2619 m
.61014 .48645 L
s
P
p
.8 1 0 r
.008 w
.72455 .2619 m
.9491 .37632 L
s
P
p
.8 1 0 r
.008 w
.72455 .2619 m
.83896 .03736 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.402116 0.200176 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.00242826 0.952381 [
[ 0 0 0 0 ]
[ 1 .95724 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95724 L
0 .95724 L
closepath
clip
newpath
p
P
p
.8 1 0 r
.008 w
.28881 .43442 m
.41372 .04998 L
s
P
p
.8 1 0 r
.008 w
.28881 .43442 m
.05121 .76144 L
s
P
p
.8 1 0 r
.008 w
.28881 .43442 m
.61582 .19682 L
s
P
p
.8 1 0 r
.008 w
.38897 .48545 m
.38897 .08123 L
s
P
p
.8 1 0 r
.008 w
.38897 .48545 m
.26406 .86989 L
s
P
p
.8 1 0 r
.008 w
.38897 .48545 m
.62656 .15843 L
s
P
p
.8 1 0 r
.008 w
.5 .50304 m
.37509 .1186 L
s
P
p
.8 1 0 r
.008 w
.5 .50304 m
.5 .90725 L
s
P
p
.8 1 0 r
.008 w
.5 .50304 m
.62491 .1186 L
s
P
p
.8 1 0 r
.008 w
.61103 .48545 m
.37344 .15843 L
s
P
p
.8 1 0 r
.008 w
.61103 .48545 m
.73594 .86989 L
s
P
p
.8 1 0 r
.008 w
.61103 .48545 m
.61103 .08123 L
s
P
p
.8 1 0 r
.008 w
.71119 .43442 m
.38418 .19682 L
s
P
p
.8 1 0 r
.008 w
.71119 .43442 m
.94879 .76144 L
s
P
p
.8 1 0 r
.008 w
.71119 .43442 m
.58628 .04998 L
s
P
p
.8 1 0 r
.012 w
.5 .14373 m
.28881 .43442 L
s
P
p
.8 1 0 r
.012 w
.5 .14373 m
.38897 .48545 L
s
P
p
.8 1 0 r
.012 w
.5 .14373 m
.5 .50304 L
s
P
p
.8 1 0 r
.012 w
.5 .14373 m
.61103 .48545 L
s
P
p
.8 1 0 r
.012 w
.5 .14373 m
.71119 .43442 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.402116 0.39418 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0473091 0.952381 [
[ 0 0 0 0 ]
[ 1 .85776 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85776 L
0 .85776 L
closepath
clip
newpath
p
P
p
1 0 0 r
.012 w
.19259 .4698 m
.05072 .66508 L
s
P
p
.8 1 0 r
.018 w
.38177 .20943 m
.19259 .4698 L
s
P
p
1 0 0 r
.012 w
.33839 .54409 m
.2638 .77365 L
s
P
p
.8 1 0 r
.018 w
.43784 .238 m
.33839 .54409 L
s
P
p
1 0 0 r
.012 w
.5 .56969 m
.5 .81107 L
s
P
p
.8 1 0 r
.018 w
.5 .24785 m
.5 .56969 L
s
P
p
1 0 0 r
.012 w
.66161 .54409 m
.7362 .77365 L
s
P
p
.8 1 0 r
.018 w
.56216 .238 m
.66161 .54409 L
s
P
p
1 0 0 r
.012 w
.80741 .4698 m
.94928 .66508 L
s
P
p
.8 1 0 r
.018 w
.61823 .20943 m
.80741 .4698 L
s
P
p
.2 0 1 r
.016 w
.5 .0467 m
.38177 .20943 L
s
P
p
.2 0 1 r
.016 w
.5 .0467 m
.43784 .238 L
s
P
p
.2 0 1 r
.016 w
.5 .0467 m
.5 .24785 L
s
P
p
.2 0 1 r
.016 w
.5 .0467 m
.56216 .238 L
s
P
p
.2 0 1 r
.016 w
.5 .0467 m
.61823 .20943 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.402116 0.588183 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0343341 0.952381 [
[ 0 0 0 0 ]
[ 1 .88371 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88371 L
0 .88371 L
closepath
clip
newpath
p
P
p
1 0 0 r
.016 w
.73517 .73713 m
.77793 .79598 L
s
P
p
1 0 0 r
.016 w
.73517 .14861 m
.77793 .08976 L
s
P
p
1 0 0 r
.016 w
.17546 .33047 m
.10628 .308 L
s
P
p
.2 0 1 r
.018 w
.52138 .44287 m
.73517 .73713 L
s
P
p
.2 0 1 r
.018 w
.52138 .44287 m
.73517 .14861 L
s
P
p
.2 0 1 r
.018 w
.52138 .44287 m
.17546 .33047 L
s
P
p
1 0 0 r
.016 w
.46541 .11981 m
.46541 .04707 L
s
P
p
1 0 0 r
.016 w
.11949 .59593 m
.05031 .61841 L
s
P
p
1 0 0 r
.016 w
.6792 .77779 m
.72196 .83664 L
s
P
p
.2 0 1 r
.018 w
.46541 .48353 m
.46541 .11981 L
s
P
p
.2 0 1 r
.018 w
.46541 .48353 m
.11949 .59593 L
s
P
p
.2 0 1 r
.018 w
.46541 .48353 m
.6792 .77779 L
s
P
p
1 0 0 r
.016 w
.3208 .77779 m
.27804 .83664 L
s
P
p
1 0 0 r
.016 w
.88051 .59593 m
.94969 .61841 L
s
P
p
1 0 0 r
.016 w
.53459 .11981 m
.53459 .04707 L
s
P
p
.2 0 1 r
.018 w
.53459 .48353 m
.3208 .77779 L
s
P
p
.2 0 1 r
.018 w
.53459 .48353 m
.88051 .59593 L
s
P
p
.2 0 1 r
.018 w
.53459 .48353 m
.53459 .11981 L
s
P
p
1 0 0 r
.016 w
.82454 .33047 m
.89372 .308 L
s
P
p
1 0 0 r
.016 w
.26483 .14861 m
.22207 .08976 L
s
P
p
1 0 0 r
.016 w
.26483 .73713 m
.22207 .79598 L
s
P
p
.2 0 1 r
.018 w
.47862 .44287 m
.82454 .33047 L
s
P
p
.2 0 1 r
.018 w
.47862 .44287 m
.26483 .14861 L
s
P
p
.2 0 1 r
.018 w
.47862 .44287 m
.26483 .73713 L
s
P
p
.8 1 0 r
.008 w
.5 .4723 m
.52138 .44287 L
s
P
p
.8 1 0 r
.008 w
.5 .4723 m
.46541 .48353 L
s
P
p
.8 1 0 r
.008 w
.5 .4723 m
.53459 .48353 L
s
P
p
.8 1 0 r
.008 w
.5 .4723 m
.47862 .44287 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.402116 0.782187 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.13477 0.952381 [
[ 0 0 0 0 ]
[ 1 .68284 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .68284 L
0 .68284 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.004 w
.62462 .16844 m
.63857 .19582 L
s
P
p
.2 0 1 r
.004 w
.62462 .16844 m
.652 .15449 L
s
P
p
.2 0 1 r
.004 w
.62462 .16844 m
.61067 .14107 L
s
P
p
.2 0 1 r
.004 w
.07709 .16844 m
.09103 .14107 L
s
P
p
.2 0 1 r
.004 w
.07709 .16844 m
.04971 .15449 L
s
P
p
.2 0 1 r
.004 w
.07709 .16844 m
.06314 .19582 L
s
P
p
.2 0 1 r
.004 w
.39892 .61141 m
.36857 .61622 L
s
P
p
.2 0 1 r
.004 w
.39892 .61141 m
.40373 .64176 L
s
P
p
.2 0 1 r
.004 w
.39892 .61141 m
.42927 .6066 L
s
P
p
.2 0 1 r
.004 w
.56812 .09067 m
.58984 .1124 L
s
P
p
.2 0 1 r
.004 w
.56812 .09067 m
.58984 .06895 L
s
P
p
.2 0 1 r
.004 w
.56812 .09067 m
.54639 .06895 L
s
P
p
.8 0 1 r
.014 w
.35085 .30794 m
.62462 .16844 L
s
P
p
.8 0 1 r
.014 w
.35085 .30794 m
.07709 .16844 L
s
P
p
.8 0 1 r
.014 w
.35085 .30794 m
.39892 .61141 L
s
P
p
.8 0 1 r
.014 w
.35085 .30794 m
.56812 .09067 L
s
P
p
0 1 .4 r
.02 w
.47514 .21763 m
.35085 .30794 L
s
P
p
.2 0 1 r
.004 w
.58252 .10114 m
.6099 .11509 L
s
P
p
.2 0 1 r
.004 w
.58252 .10114 m
.59647 .07376 L
s
P
p
.2 0 1 r
.004 w
.58252 .10114 m
.55515 .08719 L
s
P
p
.2 0 1 r
.004 w
.13956 .42297 m
.13475 .39262 L
s
P
p
.2 0 1 r
.004 w
.13956 .42297 m
.10921 .42778 L
s
P
p
.2 0 1 r
.004 w
.13956 .42297 m
.14436 .45332 L
s
P
p
.2 0 1 r
.004 w
.6603 .59217 m
.63857 .6139 L
s
P
p
.2 0 1 r
.004 w
.6603 .59217 m
.68202 .6139 L
s
P
p
.2 0 1 r
.004 w
.6603 .59217 m
.68202 .57044 L
s
P
p
.2 0 1 r
.004 w
.4911 .07143 m
.52144 .07624 L
s
P
p
.2 0 1 r
.004 w
.4911 .07143 m
.4959 .04108 L
s
P
p
.2 0 1 r
.004 w
.4911 .07143 m
.46075 .06662 L
s
P
p
.8 0 1 r
.014 w
.44303 .37491 m
.58252 .10114 L
s
P
p
.8 0 1 r
.014 w
.44303 .37491 m
.13956 .42297 L
s
P
p
.8 0 1 r
.014 w
.44303 .37491 m
.6603 .59217 L
s
P
p
.8 0 1 r
.014 w
.44303 .37491 m
.4911 .07143 L
s
P
p
0 1 .4 r
.02 w
.49051 .2288 m
.44303 .37491 L
s
P
p
.2 0 1 r
.004 w
.5089 .07143 m
.53925 .06662 L
s
P
p
.2 0 1 r
.004 w
.5089 .07143 m
.5041 .04108 L
s
P
p
.2 0 1 r
.004 w
.5089 .07143 m
.47856 .07624 L
s
P
p
.2 0 1 r
.004 w
.3397 .59217 m
.31798 .57044 L
s
P
p
.2 0 1 r
.004 w
.3397 .59217 m
.31798 .6139 L
s
P
p
.2 0 1 r
.004 w
.3397 .59217 m
.36143 .6139 L
s
P
p
.2 0 1 r
.004 w
.86044 .42297 m
.85564 .45332 L
s
P
p
.2 0 1 r
.004 w
.86044 .42297 m
.89079 .42778 L
s
P
p
.2 0 1 r
.004 w
.86044 .42297 m
.86525 .39262 L
s
P
p
.2 0 1 r
.004 w
.41748 .10114 m
.44485 .08719 L
s
P
p
.2 0 1 r
.004 w
.41748 .10114 m
.40353 .07376 L
s
P
p
.2 0 1 r
.004 w
.41748 .10114 m
.3901 .11509 L
s
P
p
.8 0 1 r
.014 w
.55697 .37491 m
.5089 .07143 L
s
P
p
.8 0 1 r
.014 w
.55697 .37491 m
.3397 .59217 L
s
P
p
.8 0 1 r
.014 w
.55697 .37491 m
.86044 .42297 L
s
P
p
.8 0 1 r
.014 w
.55697 .37491 m
.41748 .10114 L
s
P
p
0 1 .4 r
.02 w
.50949 .2288 m
.55697 .37491 L
s
P
p
.2 0 1 r
.004 w
.43188 .09067 m
.45361 .06895 L
s
P
p
.2 0 1 r
.004 w
.43188 .09067 m
.41016 .06895 L
s
P
p
.2 0 1 r
.004 w
.43188 .09067 m
.41016 .1124 L
s
P
p
.2 0 1 r
.004 w
.60108 .61141 m
.57073 .6066 L
s
P
p
.2 0 1 r
.004 w
.60108 .61141 m
.59627 .64176 L
s
P
p
.2 0 1 r
.004 w
.60108 .61141 m
.63143 .61622 L
s
P
p
.2 0 1 r
.004 w
.92291 .16844 m
.93686 .19582 L
s
P
p
.2 0 1 r
.004 w
.92291 .16844 m
.95029 .15449 L
s
P
p
.2 0 1 r
.004 w
.92291 .16844 m
.90897 .14107 L
s
P
p
.2 0 1 r
.004 w
.37538 .16844 m
.38933 .14107 L
s
P
p
.2 0 1 r
.004 w
.37538 .16844 m
.348 .15449 L
s
P
p
.2 0 1 r
.004 w
.37538 .16844 m
.36143 .19582 L
s
P
p
.8 0 1 r
.014 w
.64915 .30794 m
.43188 .09067 L
s
P
p
.8 0 1 r
.014 w
.64915 .30794 m
.60108 .61141 L
s
P
p
.8 0 1 r
.014 w
.64915 .30794 m
.92291 .16844 L
s
P
p
.8 0 1 r
.014 w
.64915 .30794 m
.37538 .16844 L
s
P
p
0 1 .4 r
.02 w
.52486 .21763 m
.64915 .30794 L
s
P
p
1 0 0 r
.018 w
.5 .19957 m
.47514 .21763 L
s
P
p
1 0 0 r
.018 w
.5 .19957 m
.49051 .2288 L
s
P
p
1 0 0 r
.018 w
.5 .19957 m
.50949 .2288 L
s
P
p
1 0 0 r
.018 w
.5 .19957 m
.52486 .21763 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.402116 0.97619 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0546136 0.952381 [
[ 0 0 0 0 ]
[ 1 .84315 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .84315 L
0 .84315 L
closepath
clip
newpath
p
P
p
.2 1 0 r
.01 w
.43672 .36387 m
.49653 .42368 L
s
P
p
.2 1 0 r
.01 w
.43672 .36387 m
.52027 .35064 L
s
P
p
.2 1 0 r
.01 w
.43672 .36387 m
.47512 .2885 L
s
P
p
.2 1 0 r
.01 w
.43672 .36387 m
.39832 .2885 L
s
P
p
.2 1 0 r
.01 w
.43672 .36387 m
.35318 .35064 L
s
P
p
.2 1 0 r
.01 w
.33851 .49905 m
.30011 .42368 L
s
P
p
.2 1 0 r
.01 w
.33851 .49905 m
.25496 .48582 L
s
P
p
.2 1 0 r
.01 w
.33851 .49905 m
.2787 .55886 L
s
P
p
.2 1 0 r
.01 w
.33851 .49905 m
.35174 .58259 L
s
P
p
.2 1 0 r
.01 w
.33851 .49905 m
.41388 .53745 L
s
P
p
.2 1 0 r
.01 w
.47369 .40084 m
.48692 .48438 L
s
P
p
.2 1 0 r
.01 w
.47369 .40084 m
.54906 .43924 L
s
P
p
.2 1 0 r
.01 w
.47369 .40084 m
.54906 .36243 L
s
P
p
.2 1 0 r
.01 w
.47369 .40084 m
.48692 .31729 L
s
P
p
.2 1 0 r
.01 w
.47369 .40084 m
.41388 .34102 L
s
P
p
.2 1 0 r
.01 w
.31478 .45247 m
.32801 .36892 L
s
P
p
.2 1 0 r
.01 w
.31478 .45247 m
.25496 .39266 L
s
P
p
.2 1 0 r
.01 w
.31478 .45247 m
.23123 .4657 L
s
P
p
.2 1 0 r
.01 w
.31478 .45247 m
.27637 .52784 L
s
P
p
.2 1 0 r
.01 w
.31478 .45247 m
.35318 .52784 L
s
P
p
.2 0 1 r
.008 w
.39832 .43924 m
.43672 .36387 L
s
P
p
.2 0 1 r
.008 w
.39832 .43924 m
.33851 .49905 L
s
P
p
.2 0 1 r
.008 w
.39832 .43924 m
.47369 .40084 L
s
P
p
.2 0 1 r
.008 w
.39832 .43924 m
.31478 .45247 L
s
P
p
.2 1 0 r
.01 w
.22352 .1716 m
.21028 .08806 L
s
P
p
.2 1 0 r
.01 w
.22352 .1716 m
.14815 .1332 L
s
P
p
.2 1 0 r
.01 w
.22352 .1716 m
.14815 .21 L
s
P
p
.2 1 0 r
.01 w
.22352 .1716 m
.21028 .25515 L
s
P
p
.2 1 0 r
.01 w
.22352 .1716 m
.28333 .23141 L
s
P
p
.2 1 0 r
.01 w
.38243 .11997 m
.3692 .20351 L
s
P
p
.2 1 0 r
.01 w
.38243 .11997 m
.44224 .17978 L
s
P
p
.2 1 0 r
.01 w
.38243 .11997 m
.46597 .10673 L
s
P
p
.2 1 0 r
.01 w
.38243 .11997 m
.42083 .0446 L
s
P
p
.2 1 0 r
.01 w
.38243 .11997 m
.34403 .0446 L
s
P
p
.2 1 0 r
.01 w
.21534 .11997 m
.25374 .0446 L
s
P
p
.2 1 0 r
.01 w
.21534 .11997 m
.17694 .0446 L
s
P
p
.2 1 0 r
.01 w
.21534 .11997 m
.13179 .10673 L
s
P
p
.2 1 0 r
.01 w
.21534 .11997 m
.15553 .17978 L
s
P
p
.2 1 0 r
.01 w
.21534 .11997 m
.22857 .20351 L
s
P
p
.2 1 0 r
.01 w
.37425 .1716 m
.31444 .23141 L
s
P
p
.2 1 0 r
.01 w
.37425 .1716 m
.38748 .25515 L
s
P
p
.2 1 0 r
.01 w
.37425 .1716 m
.44962 .21 L
s
P
p
.2 1 0 r
.01 w
.37425 .1716 m
.44962 .1332 L
s
P
p
.2 1 0 r
.01 w
.37425 .1716 m
.38748 .08806 L
s
P
p
.2 0 1 r
.008 w
.29888 .1332 m
.22352 .1716 L
s
P
p
.2 0 1 r
.008 w
.29888 .1332 m
.38243 .11997 L
s
P
p
.2 0 1 r
.008 w
.29888 .1332 m
.21534 .11997 L
s
P
p
.2 0 1 r
.008 w
.29888 .1332 m
.37425 .1716 L
s
P
p
.2 1 0 r
.01 w
.28299 .45247 m
.24459 .52784 L
s
P
p
.2 1 0 r
.01 w
.28299 .45247 m
.32139 .52784 L
s
P
p
.2 1 0 r
.01 w
.28299 .45247 m
.36654 .4657 L
s
P
p
.2 1 0 r
.01 w
.28299 .45247 m
.3428 .39266 L
s
P
p
.2 1 0 r
.01 w
.28299 .45247 m
.26976 .36892 L
s
P
p
.2 1 0 r
.01 w
.12408 .40084 m
.18389 .34102 L
s
P
p
.2 1 0 r
.01 w
.12408 .40084 m
.11085 .31729 L
s
P
p
.2 1 0 r
.01 w
.12408 .40084 m
.04871 .36243 L
s
P
p
.2 1 0 r
.01 w
.12408 .40084 m
.04871 .43924 L
s
P
p
.2 1 0 r
.01 w
.12408 .40084 m
.11085 .48438 L
s
P
p
.2 1 0 r
.01 w
.25926 .49905 m
.18389 .53745 L
s
P
p
.2 1 0 r
.01 w
.25926 .49905 m
.24603 .58259 L
s
P
p
.2 1 0 r
.01 w
.25926 .49905 m
.31907 .55886 L
s
P
p
.2 1 0 r
.01 w
.25926 .49905 m
.3428 .48582 L
s
P
p
.2 1 0 r
.01 w
.25926 .49905 m
.29766 .42368 L
s
P
p
.2 1 0 r
.01 w
.16104 .36387 m
.24459 .35064 L
s
P
p
.2 1 0 r
.01 w
.16104 .36387 m
.19945 .2885 L
s
P
p
.2 1 0 r
.01 w
.16104 .36387 m
.12264 .2885 L
s
P
p
.2 1 0 r
.01 w
.16104 .36387 m
.0775 .35064 L
s
P
p
.2 1 0 r
.01 w
.16104 .36387 m
.10123 .42368 L
s
P
p
.2 0 1 r
.008 w
.19945 .43924 m
.28299 .45247 L
s
P
p
.2 0 1 r
.008 w
.19945 .43924 m
.12408 .40084 L
s
P
p
.2 0 1 r
.008 w
.19945 .43924 m
.25926 .49905 L
s
P
p
.2 0 1 r
.008 w
.19945 .43924 m
.16104 .36387 L
s
P
p
.2 1 0 r
.01 w
.39996 .19028 m
.47533 .15188 L
s
P
p
.2 1 0 r
.01 w
.39996 .19028 m
.4132 .10674 L
s
P
p
.2 1 0 r
.01 w
.39996 .19028 m
.34015 .13047 L
s
P
p
.2 1 0 r
.01 w
.39996 .19028 m
.31642 .20352 L
s
P
p
.2 1 0 r
.01 w
.39996 .19028 m
.36156 .26565 L
s
P
p
.2 1 0 r
.01 w
.49818 .32546 m
.41463 .33869 L
s
P
p
.2 1 0 r
.01 w
.49818 .32546 m
.45978 .40083 L
s
P
p
.2 1 0 r
.01 w
.49818 .32546 m
.53658 .40083 L
s
P
p
.2 1 0 r
.01 w
.49818 .32546 m
.58172 .33869 L
s
P
p
.2 1 0 r
.01 w
.49818 .32546 m
.55799 .26565 L
s
P
p
.2 1 0 r
.01 w
.44654 .16655 m
.53009 .17978 L
s
P
p
.2 1 0 r
.01 w
.44654 .16655 m
.50636 .10674 L
s
P
p
.2 1 0 r
.01 w
.44654 .16655 m
.43331 .083 L
s
P
p
.2 1 0 r
.01 w
.44654 .16655 m
.37118 .12815 L
s
P
p
.2 1 0 r
.01 w
.44654 .16655 m
.37118 .20495 L
s
P
p
.2 1 0 r
.01 w
.44654 .33364 m
.37118 .29524 L
s
P
p
.2 1 0 r
.01 w
.44654 .33364 m
.37118 .37204 L
s
P
p
.2 1 0 r
.01 w
.44654 .33364 m
.43331 .41719 L
s
P
p
.2 1 0 r
.01 w
.44654 .33364 m
.50636 .39345 L
s
P
p
.2 1 0 r
.01 w
.44654 .33364 m
.53009 .32041 L
s
P
p
.2 0 1 r
.008 w
.45978 .2501 m
.39996 .19028 L
s
P
p
.2 0 1 r
.008 w
.45978 .2501 m
.49818 .32546 L
s
P
p
.2 0 1 r
.008 w
.45978 .2501 m
.44654 .16655 L
s
P
p
.2 0 1 r
.008 w
.45978 .2501 m
.44654 .33364 L
s
P
p
.8 0 1 r
.008 w
.29888 .30237 m
.39832 .43924 L
s
P
p
.8 0 1 r
.008 w
.29888 .30237 m
.29888 .1332 L
s
P
p
.8 0 1 r
.008 w
.29888 .30237 m
.19945 .43924 L
s
P
p
.8 0 1 r
.008 w
.29888 .30237 m
.45978 .2501 L
s
P
p
.2 1 0 r
.01 w
.45969 .41665 m
.54324 .40342 L
s
P
p
.2 1 0 r
.01 w
.45969 .41665 m
.49809 .34128 L
s
P
p
.2 1 0 r
.01 w
.45969 .41665 m
.42129 .34128 L
s
P
p
.2 1 0 r
.01 w
.45969 .41665 m
.37615 .40342 L
s
P
p
.2 1 0 r
.01 w
.45969 .41665 m
.39988 .47646 L
s
P
p
.2 1 0 r
.01 w
.51133 .57556 m
.42778 .56233 L
s
P
p
.2 1 0 r
.01 w
.51133 .57556 m
.45151 .63537 L
s
P
p
.2 1 0 r
.01 w
.51133 .57556 m
.52456 .65911 L
s
P
p
.2 1 0 r
.01 w
.51133 .57556 m
.58669 .61396 L
s
P
p
.2 1 0 r
.01 w
.51133 .57556 m
.58669 .53716 L
s
P
p
.2 1 0 r
.01 w
.51133 .40847 m
.58669 .44687 L
s
P
p
.2 1 0 r
.01 w
.51133 .40847 m
.58669 .37007 L
s
P
p
.2 1 0 r
.01 w
.51133 .40847 m
.52456 .32493 L
s
P
p
.2 1 0 r
.01 w
.51133 .40847 m
.45151 .34866 L
s
P
p
.2 1 0 r
.01 w
.51133 .40847 m
.42778 .4217 L
s
P
p
.2 1 0 r
.01 w
.45969 .56738 m
.39988 .50757 L
s
P
p
.2 1 0 r
.01 w
.45969 .56738 m
.37615 .58062 L
s
P
p
.2 1 0 r
.01 w
.45969 .56738 m
.42129 .64275 L
s
P
p
.2 1 0 r
.01 w
.45969 .56738 m
.49809 .64275 L
s
P
p
.2 1 0 r
.01 w
.45969 .56738 m
.54324 .58062 L
s
P
p
.2 0 1 r
.008 w
.49809 .49202 m
.45969 .41665 L
s
P
p
.2 0 1 r
.008 w
.49809 .49202 m
.51133 .57556 L
s
P
p
.2 0 1 r
.008 w
.49809 .49202 m
.51133 .40847 L
s
P
p
.2 0 1 r
.008 w
.49809 .49202 m
.45969 .56738 L
s
P
p
.2 1 0 r
.01 w
.17882 .47612 m
.10346 .43772 L
s
P
p
.2 1 0 r
.01 w
.17882 .47612 m
.10346 .51453 L
s
P
p
.2 1 0 r
.01 w
.17882 .47612 m
.16559 .55967 L
s
P
p
.2 1 0 r
.01 w
.17882 .47612 m
.23864 .53594 L
s
P
p
.2 1 0 r
.01 w
.17882 .47612 m
.26237 .46289 L
s
P
p
.2 1 0 r
.01 w
.23046 .31721 m
.29027 .37702 L
s
P
p
.2 1 0 r
.01 w
.23046 .31721 m
.314 .30398 L
s
P
p
.2 1 0 r
.01 w
.23046 .31721 m
.26886 .24184 L
s
P
p
.2 1 0 r
.01 w
.23046 .31721 m
.19206 .24184 L
s
P
p
.2 1 0 r
.01 w
.23046 .31721 m
.14691 .30398 L
s
P
p
.2 1 0 r
.01 w
.13224 .45239 m
.09384 .37702 L
s
P
p
.2 1 0 r
.01 w
.13224 .45239 m
.0487 .43916 L
s
P
p
.2 1 0 r
.01 w
.13224 .45239 m
.07243 .5122 L
s
P
p
.2 1 0 r
.01 w
.13224 .45239 m
.14548 .53594 L
s
P
p
.2 1 0 r
.01 w
.13224 .45239 m
.20761 .49079 L
s
P
p
.2 1 0 r
.01 w
.26742 .35418 m
.28066 .43772 L
s
P
p
.2 1 0 r
.01 w
.26742 .35418 m
.34279 .39258 L
s
P
p
.2 1 0 r
.01 w
.26742 .35418 m
.34279 .31578 L
s
P
p
.2 1 0 r
.01 w
.26742 .35418 m
.28066 .27063 L
s
P
p
.2 1 0 r
.01 w
.26742 .35418 m
.20761 .29437 L
s
P
p
.2 0 1 r
.008 w
.19206 .39258 m
.17882 .47612 L
s
P
p
.2 0 1 r
.008 w
.19206 .39258 m
.23046 .31721 L
s
P
p
.2 0 1 r
.008 w
.19206 .39258 m
.13224 .45239 L
s
P
p
.2 0 1 r
.008 w
.19206 .39258 m
.26742 .35418 L
s
P
p
.2 1 0 r
.01 w
.44101 .5931 m
.47941 .66847 L
s
P
p
.2 1 0 r
.01 w
.44101 .5931 m
.52455 .60633 L
s
P
p
.2 1 0 r
.01 w
.44101 .5931 m
.50082 .53329 L
s
P
p
.2 1 0 r
.01 w
.44101 .5931 m
.42778 .50955 L
s
P
p
.2 1 0 r
.01 w
.44101 .5931 m
.36564 .5547 L
s
P
p
.2 1 0 r
.01 w
.30583 .69131 m
.2926 .60777 L
s
P
p
.2 1 0 r
.01 w
.30583 .69131 m
.23046 .65291 L
s
P
p
.2 1 0 r
.01 w
.30583 .69131 m
.23046 .72971 L
s
P
p
.2 1 0 r
.01 w
.30583 .69131 m
.2926 .77486 L
s
P
p
.2 1 0 r
.01 w
.30583 .69131 m
.36564 .75112 L
s
P
p
.2 1 0 r
.01 w
.46474 .63968 m
.45151 .72322 L
s
P
p
.2 1 0 r
.01 w
.46474 .63968 m
.52455 .69949 L
s
P
p
.2 1 0 r
.01 w
.46474 .63968 m
.54829 .62645 L
s
P
p
.2 1 0 r
.01 w
.46474 .63968 m
.50314 .56431 L
s
P
p
.2 1 0 r
.01 w
.46474 .63968 m
.42634 .56431 L
s
P
p
.2 1 0 r
.01 w
.29765 .63968 m
.33605 .56431 L
s
P
p
.2 1 0 r
.01 w
.29765 .63968 m
.25925 .56431 L
s
P
p
.2 1 0 r
.01 w
.29765 .63968 m
.21411 .62645 L
s
P
p
.2 1 0 r
.01 w
.29765 .63968 m
.23784 .69949 L
s
P
p
.2 1 0 r
.01 w
.29765 .63968 m
.31088 .72322 L
s
P
p
.2 0 1 r
.008 w
.3812 .65291 m
.44101 .5931 L
s
P
p
.2 0 1 r
.008 w
.3812 .65291 m
.30583 .69131 L
s
P
p
.2 0 1 r
.008 w
.3812 .65291 m
.46474 .63968 L
s
P
p
.2 0 1 r
.008 w
.3812 .65291 m
.29765 .63968 L
s
P
p
.2 1 0 r
.01 w
.29765 .34436 m
.31088 .26081 L
s
P
p
.2 1 0 r
.01 w
.29765 .34436 m
.23784 .28454 L
s
P
p
.2 1 0 r
.01 w
.29765 .34436 m
.21411 .35759 L
s
P
p
.2 1 0 r
.01 w
.29765 .34436 m
.25925 .41972 L
s
P
p
.2 1 0 r
.01 w
.29765 .34436 m
.33605 .41972 L
s
P
p
.2 1 0 r
.01 w
.46474 .34436 m
.42634 .41972 L
s
P
p
.2 1 0 r
.01 w
.46474 .34436 m
.50314 .41972 L
s
P
p
.2 1 0 r
.01 w
.46474 .34436 m
.54829 .35759 L
s
P
p
.2 1 0 r
.01 w
.46474 .34436 m
.52455 .28454 L
s
P
p
.2 1 0 r
.01 w
.46474 .34436 m
.45151 .26081 L
s
P
p
.2 1 0 r
.01 w
.30583 .29272 m
.36564 .23291 L
s
P
p
.2 1 0 r
.01 w
.30583 .29272 m
.2926 .20918 L
s
P
p
.2 1 0 r
.01 w
.30583 .29272 m
.23046 .25432 L
s
P
p
.2 1 0 r
.01 w
.30583 .29272 m
.23046 .33112 L
s
P
p
.2 1 0 r
.01 w
.30583 .29272 m
.2926 .37627 L
s
P
p
.2 1 0 r
.01 w
.44101 .39093 m
.36564 .42934 L
s
P
p
.2 1 0 r
.01 w
.44101 .39093 m
.42778 .47448 L
s
P
p
.2 1 0 r
.01 w
.44101 .39093 m
.50082 .45075 L
s
P
p
.2 1 0 r
.01 w
.44101 .39093 m
.52455 .3777 L
s
P
p
.2 1 0 r
.01 w
.44101 .39093 m
.47941 .31557 L
s
P
p
.2 0 1 r
.008 w
.3812 .33112 m
.29765 .34436 L
s
P
p
.2 0 1 r
.008 w
.3812 .33112 m
.46474 .34436 L
s
P
p
.2 0 1 r
.008 w
.3812 .33112 m
.30583 .29272 L
s
P
p
.2 0 1 r
.008 w
.3812 .33112 m
.44101 .39093 L
s
P
p
.8 0 1 r
.008 w
.32892 .49202 m
.49809 .49202 L
s
P
p
.8 0 1 r
.008 w
.32892 .49202 m
.19206 .39258 L
s
P
p
.8 0 1 r
.008 w
.32892 .49202 m
.3812 .65291 L
s
P
p
.8 0 1 r
.008 w
.32892 .49202 m
.3812 .33112 L
s
P
p
.2 1 0 r
.01 w
.51589 .42909 m
.55429 .35372 L
s
P
p
.2 1 0 r
.01 w
.51589 .42909 m
.47749 .35372 L
s
P
p
.2 1 0 r
.01 w
.51589 .42909 m
.43235 .41586 L
s
P
p
.2 1 0 r
.01 w
.51589 .42909 m
.45608 .4889 L
s
P
p
.2 1 0 r
.01 w
.51589 .42909 m
.52912 .51263 L
s
P
p
.2 1 0 r
.01 w
.6748 .48072 m
.61499 .54054 L
s
P
p
.2 1 0 r
.01 w
.6748 .48072 m
.68804 .56427 L
s
P
p
.2 1 0 r
.01 w
.6748 .48072 m
.75017 .51913 L
s
P
p
.2 1 0 r
.01 w
.6748 .48072 m
.75017 .44232 L
s
P
p
.2 1 0 r
.01 w
.6748 .48072 m
.68804 .39718 L
s
P
p
.2 1 0 r
.01 w
.53963 .38251 m
.61499 .34411 L
s
P
p
.2 1 0 r
.01 w
.53963 .38251 m
.55286 .29896 L
s
P
p
.2 1 0 r
.01 w
.53963 .38251 m
.47981 .3227 L
s
P
p
.2 1 0 r
.01 w
.53963 .38251 m
.45608 .39574 L
s
P
p
.2 1 0 r
.01 w
.53963 .38251 m
.50122 .45788 L
s
P
p
.2 1 0 r
.01 w
.63784 .51769 m
.55429 .53092 L
s
P
p
.2 1 0 r
.01 w
.63784 .51769 m
.59944 .59306 L
s
P
p
.2 1 0 r
.01 w
.63784 .51769 m
.67624 .59306 L
s
P
p
.2 1 0 r
.01 w
.63784 .51769 m
.72138 .53092 L
s
P
p
.2 1 0 r
.01 w
.63784 .51769 m
.69765 .45788 L
s
P
p
.2 0 1 r
.008 w
.59944 .44232 m
.51589 .42909 L
s
P
p
.2 0 1 r
.008 w
.59944 .44232 m
.6748 .48072 L
s
P
p
.2 0 1 r
.008 w
.59944 .44232 m
.53963 .38251 L
s
P
p
.2 0 1 r
.008 w
.59944 .44232 m
.63784 .51769 L
s
P
p
.2 1 0 r
.01 w
.39892 .69128 m
.32355 .72968 L
s
P
p
.2 1 0 r
.01 w
.39892 .69128 m
.38569 .77482 L
s
P
p
.2 1 0 r
.01 w
.39892 .69128 m
.45873 .75109 L
s
P
p
.2 1 0 r
.01 w
.39892 .69128 m
.48246 .67804 L
s
P
p
.2 1 0 r
.01 w
.39892 .69128 m
.43732 .61591 L
s
P
p
.2 1 0 r
.01 w
.30071 .5561 m
.38425 .54286 L
s
P
p
.2 1 0 r
.01 w
.30071 .5561 m
.33911 .48073 L
s
P
p
.2 1 0 r
.01 w
.30071 .5561 m
.2623 .48073 L
s
P
p
.2 1 0 r
.01 w
.30071 .5561 m
.21716 .54286 L
s
P
p
.2 1 0 r
.01 w
.30071 .5561 m
.24089 .61591 L
s
P
p
.2 1 0 r
.01 w
.35234 .71501 m
.26879 .70178 L
s
P
p
.2 1 0 r
.01 w
.35234 .71501 m
.29253 .77482 L
s
P
p
.2 1 0 r
.01 w
.35234 .71501 m
.36557 .79855 L
s
P
p
.2 1 0 r
.01 w
.35234 .71501 m
.42771 .75341 L
s
P
p
.2 1 0 r
.01 w
.35234 .71501 m
.42771 .67661 L
s
P
p
.2 1 0 r
.01 w
.35234 .54792 m
.42771 .58632 L
s
P
p
.2 1 0 r
.01 w
.35234 .54792 m
.42771 .50952 L
s
P
p
.2 1 0 r
.01 w
.35234 .54792 m
.36557 .46437 L
s
P
p
.2 1 0 r
.01 w
.35234 .54792 m
.29253 .48811 L
s
P
p
.2 1 0 r
.01 w
.35234 .54792 m
.26879 .56115 L
s
P
p
.2 0 1 r
.008 w
.33911 .63146 m
.39892 .69128 L
s
P
p
.2 0 1 r
.008 w
.33911 .63146 m
.30071 .5561 L
s
P
p
.2 0 1 r
.008 w
.33911 .63146 m
.35234 .71501 L
s
P
p
.2 0 1 r
.008 w
.33911 .63146 m
.35234 .54792 L
s
P
p
.2 1 0 r
.01 w
.64766 .54792 m
.73121 .56115 L
s
P
p
.2 1 0 r
.01 w
.64766 .54792 m
.70747 .48811 L
s
P
p
.2 1 0 r
.01 w
.64766 .54792 m
.63443 .46437 L
s
P
p
.2 1 0 r
.01 w
.64766 .54792 m
.57229 .50952 L
s
P
p
.2 1 0 r
.01 w
.64766 .54792 m
.57229 .58632 L
s
P
p
.2 1 0 r
.01 w
.64766 .71501 m
.57229 .67661 L
s
P
p
.2 1 0 r
.01 w
.64766 .71501 m
.57229 .75341 L
s
P
p
.2 1 0 r
.01 w
.64766 .71501 m
.63443 .79855 L
s
P
p
.2 1 0 r
.01 w
.64766 .71501 m
.70747 .77482 L
s
P
p
.2 1 0 r
.01 w
.64766 .71501 m
.73121 .70178 L
s
P
p
.2 1 0 r
.01 w
.69929 .5561 m
.75911 .61591 L
s
P
p
.2 1 0 r
.01 w
.69929 .5561 m
.78284 .54286 L
s
P
p
.2 1 0 r
.01 w
.69929 .5561 m
.7377 .48073 L
s
P
p
.2 1 0 r
.01 w
.69929 .5561 m
.66089 .48073 L
s
P
p
.2 1 0 r
.01 w
.69929 .5561 m
.61575 .54286 L
s
P
p
.2 1 0 r
.01 w
.60108 .69128 m
.56268 .61591 L
s
P
p
.2 1 0 r
.01 w
.60108 .69128 m
.51754 .67804 L
s
P
p
.2 1 0 r
.01 w
.60108 .69128 m
.54127 .75109 L
s
P
p
.2 1 0 r
.01 w
.60108 .69128 m
.61431 .77482 L
s
P
p
.2 1 0 r
.01 w
.60108 .69128 m
.67645 .72968 L
s
P
p
.2 0 1 r
.008 w
.66089 .63146 m
.64766 .54792 L
s
P
p
.2 0 1 r
.008 w
.66089 .63146 m
.64766 .71501 L
s
P
p
.2 0 1 r
.008 w
.66089 .63146 m
.69929 .5561 L
s
P
p
.2 0 1 r
.008 w
.66089 .63146 m
.60108 .69128 L
s
P
p
.2 1 0 r
.01 w
.36216 .51769 m
.30235 .45788 L
s
P
p
.2 1 0 r
.01 w
.36216 .51769 m
.27862 .53092 L
s
P
p
.2 1 0 r
.01 w
.36216 .51769 m
.32376 .59306 L
s
P
p
.2 1 0 r
.01 w
.36216 .51769 m
.40056 .59306 L
s
P
p
.2 1 0 r
.01 w
.36216 .51769 m
.44571 .53092 L
s
P
p
.2 1 0 r
.01 w
.46037 .38251 m
.49878 .45788 L
s
P
p
.2 1 0 r
.01 w
.46037 .38251 m
.54392 .39574 L
s
P
p
.2 1 0 r
.01 w
.46037 .38251 m
.52019 .3227 L
s
P
p
.2 1 0 r
.01 w
.46037 .38251 m
.44714 .29896 L
s
P
p
.2 1 0 r
.01 w
.46037 .38251 m
.38501 .34411 L
s
P
p
.2 1 0 r
.01 w
.3252 .48072 m
.31196 .39718 L
s
P
p
.2 1 0 r
.01 w
.3252 .48072 m
.24983 .44232 L
s
P
p
.2 1 0 r
.01 w
.3252 .48072 m
.24983 .51913 L
s
P
p
.2 1 0 r
.01 w
.3252 .48072 m
.31196 .56427 L
s
P
p
.2 1 0 r
.01 w
.3252 .48072 m
.38501 .54054 L
s
P
p
.2 1 0 r
.01 w
.48411 .42909 m
.47088 .51263 L
s
P
p
.2 1 0 r
.01 w
.48411 .42909 m
.54392 .4889 L
s
P
p
.2 1 0 r
.01 w
.48411 .42909 m
.56765 .41586 L
s
P
p
.2 1 0 r
.01 w
.48411 .42909 m
.52251 .35372 L
s
P
p
.2 1 0 r
.01 w
.48411 .42909 m
.44571 .35372 L
s
P
p
.2 0 1 r
.008 w
.40056 .44232 m
.36216 .51769 L
s
P
p
.2 0 1 r
.008 w
.40056 .44232 m
.46037 .38251 L
s
P
p
.2 0 1 r
.008 w
.40056 .44232 m
.3252 .48072 L
s
P
p
.2 0 1 r
.008 w
.40056 .44232 m
.48411 .42909 L
s
P
p
.8 0 1 r
.008 w
.5 .57919 m
.59944 .44232 L
s
P
p
.8 0 1 r
.008 w
.5 .57919 m
.33911 .63146 L
s
P
p
.8 0 1 r
.008 w
.5 .57919 m
.66089 .63146 L
s
P
p
.8 0 1 r
.008 w
.5 .57919 m
.40056 .44232 L
s
P
p
.2 1 0 r
.01 w
.55899 .39093 m
.52059 .31557 L
s
P
p
.2 1 0 r
.01 w
.55899 .39093 m
.47545 .3777 L
s
P
p
.2 1 0 r
.01 w
.55899 .39093 m
.49918 .45075 L
s
P
p
.2 1 0 r
.01 w
.55899 .39093 m
.57222 .47448 L
s
P
p
.2 1 0 r
.01 w
.55899 .39093 m
.63436 .42934 L
s
P
p
.2 1 0 r
.01 w
.69417 .29272 m
.7074 .37627 L
s
P
p
.2 1 0 r
.01 w
.69417 .29272 m
.76954 .33112 L
s
P
p
.2 1 0 r
.01 w
.69417 .29272 m
.76954 .25432 L
s
P
p
.2 1 0 r
.01 w
.69417 .29272 m
.7074 .20918 L
s
P
p
.2 1 0 r
.01 w
.69417 .29272 m
.63436 .23291 L
s
P
p
.2 1 0 r
.01 w
.53526 .34436 m
.54849 .26081 L
s
P
p
.2 1 0 r
.01 w
.53526 .34436 m
.47545 .28454 L
s
P
p
.2 1 0 r
.01 w
.53526 .34436 m
.45171 .35759 L
s
P
p
.2 1 0 r
.01 w
.53526 .34436 m
.49686 .41972 L
s
P
p
.2 1 0 r
.01 w
.53526 .34436 m
.57366 .41972 L
s
P
p
.2 1 0 r
.01 w
.70235 .34436 m
.66395 .41972 L
s
P
p
.2 1 0 r
.01 w
.70235 .34436 m
.74075 .41972 L
s
P
p
.2 1 0 r
.01 w
.70235 .34436 m
.78589 .35759 L
s
P
p
.2 1 0 r
.01 w
.70235 .34436 m
.76216 .28454 L
s
P
p
.2 1 0 r
.01 w
.70235 .34436 m
.68912 .26081 L
s
P
p
.2 0 1 r
.008 w
.6188 .33112 m
.55899 .39093 L
s
P
p
.2 0 1 r
.008 w
.6188 .33112 m
.69417 .29272 L
s
P
p
.2 0 1 r
.008 w
.6188 .33112 m
.53526 .34436 L
s
P
p
.2 0 1 r
.008 w
.6188 .33112 m
.70235 .34436 L
s
P
p
.2 1 0 r
.01 w
.70235 .63968 m
.68912 .72322 L
s
P
p
.2 1 0 r
.01 w
.70235 .63968 m
.76216 .69949 L
s
P
p
.2 1 0 r
.01 w
.70235 .63968 m
.78589 .62645 L
s
P
p
.2 1 0 r
.01 w
.70235 .63968 m
.74075 .56431 L
s
P
p
.2 1 0 r
.01 w
.70235 .63968 m
.66395 .56431 L
s
P
p
.2 1 0 r
.01 w
.53526 .63968 m
.57366 .56431 L
s
P
p
.2 1 0 r
.01 w
.53526 .63968 m
.49686 .56431 L
s
P
p
.2 1 0 r
.01 w
.53526 .63968 m
.45171 .62645 L
s
P
p
.2 1 0 r
.01 w
.53526 .63968 m
.47545 .69949 L
s
P
p
.2 1 0 r
.01 w
.53526 .63968 m
.54849 .72322 L
s
P
p
.2 1 0 r
.01 w
.69417 .69131 m
.63436 .75112 L
s
P
p
.2 1 0 r
.01 w
.69417 .69131 m
.7074 .77486 L
s
P
p
.2 1 0 r
.01 w
.69417 .69131 m
.76954 .72971 L
s
P
p
.2 1 0 r
.01 w
.69417 .69131 m
.76954 .65291 L
s
P
p
.2 1 0 r
.01 w
.69417 .69131 m
.7074 .60777 L
s
P
p
.2 1 0 r
.01 w
.55899 .5931 m
.63436 .5547 L
s
P
p
.2 1 0 r
.01 w
.55899 .5931 m
.57222 .50955 L
s
P
p
.2 1 0 r
.01 w
.55899 .5931 m
.49918 .53329 L
s
P
p
.2 1 0 r
.01 w
.55899 .5931 m
.47545 .60633 L
s
P
p
.2 1 0 r
.01 w
.55899 .5931 m
.52059 .66847 L
s
P
p
.2 0 1 r
.008 w
.6188 .65291 m
.70235 .63968 L
s
P
p
.2 0 1 r
.008 w
.6188 .65291 m
.53526 .63968 L
s
P
p
.2 0 1 r
.008 w
.6188 .65291 m
.69417 .69131 L
s
P
p
.2 0 1 r
.008 w
.6188 .65291 m
.55899 .5931 L
s
P
p
.2 1 0 r
.01 w
.73258 .35418 m
.79239 .29437 L
s
P
p
.2 1 0 r
.01 w
.73258 .35418 m
.71934 .27063 L
s
P
p
.2 1 0 r
.01 w
.73258 .35418 m
.65721 .31578 L
s
P
p
.2 1 0 r
.01 w
.73258 .35418 m
.65721 .39258 L
s
P
p
.2 1 0 r
.01 w
.73258 .35418 m
.71934 .43772 L
s
P
p
.2 1 0 r
.01 w
.86776 .45239 m
.79239 .49079 L
s
P
p
.2 1 0 r
.01 w
.86776 .45239 m
.85452 .53594 L
s
P
p
.2 1 0 r
.01 w
.86776 .45239 m
.92757 .5122 L
s
P
p
.2 1 0 r
.01 w
.86776 .45239 m
.9513 .43916 L
s
P
p
.2 1 0 r
.01 w
.86776 .45239 m
.90616 .37702 L
s
P
p
.2 1 0 r
.01 w
.76954 .31721 m
.85309 .30398 L
s
P
p
.2 1 0 r
.01 w
.76954 .31721 m
.80794 .24184 L
s
P
p
.2 1 0 r
.01 w
.76954 .31721 m
.73114 .24184 L
s
P
p
.2 1 0 r
.01 w
.76954 .31721 m
.686 .30398 L
s
P
p
.2 1 0 r
.01 w
.76954 .31721 m
.70973 .37702 L
s
P
p
.2 1 0 r
.01 w
.82118 .47612 m
.73763 .46289 L
s
P
p
.2 1 0 r
.01 w
.82118 .47612 m
.76136 .53594 L
s
P
p
.2 1 0 r
.01 w
.82118 .47612 m
.83441 .55967 L
s
P
p
.2 1 0 r
.01 w
.82118 .47612 m
.89654 .51453 L
s
P
p
.2 1 0 r
.01 w
.82118 .47612 m
.89654 .43772 L
s
P
p
.2 0 1 r
.008 w
.80794 .39258 m
.73258 .35418 L
s
P
p
.2 0 1 r
.008 w
.80794 .39258 m
.86776 .45239 L
s
P
p
.2 0 1 r
.008 w
.80794 .39258 m
.76954 .31721 L
s
P
p
.2 0 1 r
.008 w
.80794 .39258 m
.82118 .47612 L
s
P
p
.2 1 0 r
.01 w
.54031 .56738 m
.45676 .58062 L
s
P
p
.2 1 0 r
.01 w
.54031 .56738 m
.50191 .64275 L
s
P
p
.2 1 0 r
.01 w
.54031 .56738 m
.57871 .64275 L
s
P
p
.2 1 0 r
.01 w
.54031 .56738 m
.62385 .58062 L
s
P
p
.2 1 0 r
.01 w
.54031 .56738 m
.60012 .50757 L
s
P
p
.2 1 0 r
.01 w
.48867 .40847 m
.57222 .4217 L
s
P
p
.2 1 0 r
.01 w
.48867 .40847 m
.54849 .34866 L
s
P
p
.2 1 0 r
.01 w
.48867 .40847 m
.47544 .32493 L
s
P
p
.2 1 0 r
.01 w
.48867 .40847 m
.41331 .37007 L
s
P
p
.2 1 0 r
.01 w
.48867 .40847 m
.41331 .44687 L
s
P
p
.2 1 0 r
.01 w
.48867 .57556 m
.41331 .53716 L
s
P
p
.2 1 0 r
.01 w
.48867 .57556 m
.41331 .61396 L
s
P
p
.2 1 0 r
.01 w
.48867 .57556 m
.47544 .65911 L
s
P
p
.2 1 0 r
.01 w
.48867 .57556 m
.54849 .63537 L
s
P
p
.2 1 0 r
.01 w
.48867 .57556 m
.57222 .56233 L
s
P
p
.2 1 0 r
.01 w
.54031 .41665 m
.60012 .47646 L
s
P
p
.2 1 0 r
.01 w
.54031 .41665 m
.62385 .40342 L
s
P
p
.2 1 0 r
.01 w
.54031 .41665 m
.57871 .34128 L
s
P
p
.2 1 0 r
.01 w
.54031 .41665 m
.50191 .34128 L
s
P
p
.2 1 0 r
.01 w
.54031 .41665 m
.45676 .40342 L
s
P
p
.2 0 1 r
.008 w
.50191 .49202 m
.54031 .56738 L
s
P
p
.2 0 1 r
.008 w
.50191 .49202 m
.48867 .40847 L
s
P
p
.2 0 1 r
.008 w
.50191 .49202 m
.48867 .57556 L
s
P
p
.2 0 1 r
.008 w
.50191 .49202 m
.54031 .41665 L
s
P
p
.8 0 1 r
.008 w
.67108 .49202 m
.6188 .33112 L
s
P
p
.8 0 1 r
.008 w
.67108 .49202 m
.6188 .65291 L
s
P
p
.8 0 1 r
.008 w
.67108 .49202 m
.80794 .39258 L
s
P
p
.8 0 1 r
.008 w
.67108 .49202 m
.50191 .49202 L
s
P
p
.2 1 0 r
.01 w
.55346 .33364 m
.46991 .32041 L
s
P
p
.2 1 0 r
.01 w
.55346 .33364 m
.49364 .39345 L
s
P
p
.2 1 0 r
.01 w
.55346 .33364 m
.56669 .41719 L
s
P
p
.2 1 0 r
.01 w
.55346 .33364 m
.62882 .37204 L
s
P
p
.2 1 0 r
.01 w
.55346 .33364 m
.62882 .29524 L
s
P
p
.2 1 0 r
.01 w
.55346 .16655 m
.62882 .20495 L
s
P
p
.2 1 0 r
.01 w
.55346 .16655 m
.62882 .12815 L
s
P
p
.2 1 0 r
.01 w
.55346 .16655 m
.56669 .083 L
s
P
p
.2 1 0 r
.01 w
.55346 .16655 m
.49364 .10674 L
s
P
p
.2 1 0 r
.01 w
.55346 .16655 m
.46991 .17978 L
s
P
p
.2 1 0 r
.01 w
.50182 .32546 m
.44201 .26565 L
s
P
p
.2 1 0 r
.01 w
.50182 .32546 m
.41828 .33869 L
s
P
p
.2 1 0 r
.01 w
.50182 .32546 m
.46342 .40083 L
s
P
p
.2 1 0 r
.01 w
.50182 .32546 m
.54022 .40083 L
s
P
p
.2 1 0 r
.01 w
.50182 .32546 m
.58537 .33869 L
s
P
p
.2 1 0 r
.01 w
.60004 .19028 m
.63844 .26565 L
s
P
p
.2 1 0 r
.01 w
.60004 .19028 m
.68358 .20352 L
s
P
p
.2 1 0 r
.01 w
.60004 .19028 m
.65985 .13047 L
s
P
p
.2 1 0 r
.01 w
.60004 .19028 m
.5868 .10674 L
s
P
p
.2 1 0 r
.01 w
.60004 .19028 m
.52467 .15188 L
s
P
p
.2 0 1 r
.008 w
.54022 .2501 m
.55346 .33364 L
s
P
p
.2 0 1 r
.008 w
.54022 .2501 m
.55346 .16655 L
s
P
p
.2 0 1 r
.008 w
.54022 .2501 m
.50182 .32546 L
s
P
p
.2 0 1 r
.008 w
.54022 .2501 m
.60004 .19028 L
s
P
p
.2 1 0 r
.01 w
.83896 .36387 m
.89877 .42368 L
s
P
p
.2 1 0 r
.01 w
.83896 .36387 m
.9225 .35064 L
s
P
p
.2 1 0 r
.01 w
.83896 .36387 m
.87736 .2885 L
s
P
p
.2 1 0 r
.01 w
.83896 .36387 m
.80055 .2885 L
s
P
p
.2 1 0 r
.01 w
.83896 .36387 m
.75541 .35064 L
s
P
p
.2 1 0 r
.01 w
.74074 .49905 m
.70234 .42368 L
s
P
p
.2 1 0 r
.01 w
.74074 .49905 m
.6572 .48582 L
s
P
p
.2 1 0 r
.01 w
.74074 .49905 m
.68093 .55886 L
s
P
p
.2 1 0 r
.01 w
.74074 .49905 m
.75397 .58259 L
s
P
p
.2 1 0 r
.01 w
.74074 .49905 m
.81611 .53745 L
s
P
p
.2 1 0 r
.01 w
.87592 .40084 m
.88915 .48438 L
s
P
p
.2 1 0 r
.01 w
.87592 .40084 m
.95129 .43924 L
s
P
p
.2 1 0 r
.01 w
.87592 .40084 m
.95129 .36243 L
s
P
p
.2 1 0 r
.01 w
.87592 .40084 m
.88915 .31729 L
s
P
p
.2 1 0 r
.01 w
.87592 .40084 m
.81611 .34102 L
s
P
p
.2 1 0 r
.01 w
.71701 .45247 m
.73024 .36892 L
s
P
p
.2 1 0 r
.01 w
.71701 .45247 m
.6572 .39266 L
s
P
p
.2 1 0 r
.01 w
.71701 .45247 m
.63346 .4657 L
s
P
p
.2 1 0 r
.01 w
.71701 .45247 m
.67861 .52784 L
s
P
p
.2 1 0 r
.01 w
.71701 .45247 m
.75541 .52784 L
s
P
p
.2 0 1 r
.008 w
.80055 .43924 m
.83896 .36387 L
s
P
p
.2 0 1 r
.008 w
.80055 .43924 m
.74074 .49905 L
s
P
p
.2 0 1 r
.008 w
.80055 .43924 m
.87592 .40084 L
s
P
p
.2 0 1 r
.008 w
.80055 .43924 m
.71701 .45247 L
s
P
p
.2 1 0 r
.01 w
.62575 .1716 m
.61252 .08806 L
s
P
p
.2 1 0 r
.01 w
.62575 .1716 m
.55038 .1332 L
s
P
p
.2 1 0 r
.01 w
.62575 .1716 m
.55038 .21 L
s
P
p
.2 1 0 r
.01 w
.62575 .1716 m
.61252 .25515 L
s
P
p
.2 1 0 r
.01 w
.62575 .1716 m
.68556 .23141 L
s
P
p
.2 1 0 r
.01 w
.78466 .11997 m
.77143 .20351 L
s
P
p
.2 1 0 r
.01 w
.78466 .11997 m
.84447 .17978 L
s
P
p
.2 1 0 r
.01 w
.78466 .11997 m
.86821 .10673 L
s
P
p
.2 1 0 r
.01 w
.78466 .11997 m
.82306 .0446 L
s
P
p
.2 1 0 r
.01 w
.78466 .11997 m
.74626 .0446 L
s
P
p
.2 1 0 r
.01 w
.61757 .11997 m
.65597 .0446 L
s
P
p
.2 1 0 r
.01 w
.61757 .11997 m
.57917 .0446 L
s
P
p
.2 1 0 r
.01 w
.61757 .11997 m
.53403 .10673 L
s
P
p
.2 1 0 r
.01 w
.61757 .11997 m
.55776 .17978 L
s
P
p
.2 1 0 r
.01 w
.61757 .11997 m
.6308 .20351 L
s
P
p
.2 1 0 r
.01 w
.77648 .1716 m
.71667 .23141 L
s
P
p
.2 1 0 r
.01 w
.77648 .1716 m
.78972 .25515 L
s
P
p
.2 1 0 r
.01 w
.77648 .1716 m
.85185 .21 L
s
P
p
.2 1 0 r
.01 w
.77648 .1716 m
.85185 .1332 L
s
P
p
.2 1 0 r
.01 w
.77648 .1716 m
.78972 .08806 L
s
P
p
.2 0 1 r
.008 w
.70112 .1332 m
.62575 .1716 L
s
P
p
.2 0 1 r
.008 w
.70112 .1332 m
.78466 .11997 L
s
P
p
.2 0 1 r
.008 w
.70112 .1332 m
.61757 .11997 L
s
P
p
.2 0 1 r
.008 w
.70112 .1332 m
.77648 .1716 L
s
P
p
.2 1 0 r
.01 w
.68522 .45247 m
.64682 .52784 L
s
P
p
.2 1 0 r
.01 w
.68522 .45247 m
.72363 .52784 L
s
P
p
.2 1 0 r
.01 w
.68522 .45247 m
.76877 .4657 L
s
P
p
.2 1 0 r
.01 w
.68522 .45247 m
.74504 .39266 L
s
P
p
.2 1 0 r
.01 w
.68522 .45247 m
.67199 .36892 L
s
P
p
.2 1 0 r
.01 w
.52631 .40084 m
.58612 .34102 L
s
P
p
.2 1 0 r
.01 w
.52631 .40084 m
.51308 .31729 L
s
P
p
.2 1 0 r
.01 w
.52631 .40084 m
.45094 .36243 L
s
P
p
.2 1 0 r
.01 w
.52631 .40084 m
.45094 .43924 L
s
P
p
.2 1 0 r
.01 w
.52631 .40084 m
.51308 .48438 L
s
P
p
.2 1 0 r
.01 w
.66149 .49905 m
.58612 .53745 L
s
P
p
.2 1 0 r
.01 w
.66149 .49905 m
.64826 .58259 L
s
P
p
.2 1 0 r
.01 w
.66149 .49905 m
.7213 .55886 L
s
P
p
.2 1 0 r
.01 w
.66149 .49905 m
.74504 .48582 L
s
P
p
.2 1 0 r
.01 w
.66149 .49905 m
.69989 .42368 L
s
P
p
.2 1 0 r
.01 w
.56328 .36387 m
.64682 .35064 L
s
P
p
.2 1 0 r
.01 w
.56328 .36387 m
.60168 .2885 L
s
P
p
.2 1 0 r
.01 w
.56328 .36387 m
.52488 .2885 L
s
P
p
.2 1 0 r
.01 w
.56328 .36387 m
.47973 .35064 L
s
P
p
.2 1 0 r
.01 w
.56328 .36387 m
.50347 .42368 L
s
P
p
.2 0 1 r
.008 w
.60168 .43924 m
.68522 .45247 L
s
P
p
.2 0 1 r
.008 w
.60168 .43924 m
.52631 .40084 L
s
P
p
.2 0 1 r
.008 w
.60168 .43924 m
.66149 .49905 L
s
P
p
.2 0 1 r
.008 w
.60168 .43924 m
.56328 .36387 L
s
P
p
.8 0 1 r
.008 w
.70112 .30237 m
.54022 .2501 L
s
P
p
.8 0 1 r
.008 w
.70112 .30237 m
.80055 .43924 L
s
P
p
.8 0 1 r
.008 w
.70112 .30237 m
.70112 .1332 L
s
P
p
.8 0 1 r
.008 w
.70112 .30237 m
.60168 .43924 L
s
P
p
.8 0 1 r
.008 w
.5 .36772 m
.29888 .30237 L
s
P
p
.8 0 1 r
.008 w
.5 .36772 m
.32892 .49202 L
s
P
p
.8 0 1 r
.008 w
.5 .36772 m
.5 .57919 L
s
P
p
.8 0 1 r
.008 w
.5 .36772 m
.67108 .49202 L
s
P
p
.8 0 1 r
.008 w
.5 .36772 m
.70112 .30237 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{438, 258},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006f00010PP10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0]`000?l0]`000?l0]`000?l0]`000?l0
]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`000=L000=<00000P000d`0
002R0003]`2g0380003G0003C@00008000==0000XP000kL0]`0b0000e`000d`000020003C0000:<0
0[Lb0000L@0380P00b0?00<P200283d000E=0000C@2U00:g<P00030000GO0000g`0o00<P1`0480X0
0b0700<P?`001D`0001<0:D00[Lb0000<0001Mh0003N04800b030003800000800b0400<P0`001200
0003848000DS00008`2P00Fg0T85]bd0000`0005g`000=l0A@0380P0120700<PA@001B<0000S0940
00>g00004@02@Q<000>g0000700002l000?N00000P000mh000140003800P008P0`0380800b0200<P
00<08000A@001B<0000S094000>g00004@02@Q<000>g0000700002l000?O00000P000ml000130003
800000<000<P];@01`02]0038000008000<P0000A0001B<0000S094000>g000040001480048A0003
]`0001d0000_0003gP0000<000?N0000@@000b0000050003802d00:d00H0];Bd02060003800002`0
00==00005@000b<08`0G0003C@0002@00[@>00:d1@03]0h00[@Z0003]`0000l000E20000@P0A0003
]`0001d0000_0003g`0000<000?O0000@@000b0000060003802d00Bd00<080001`000b00000/0003
C00001@000<S02<05P000d`0000T00>d00A2];Bd1P03]003@[Bd00D00k@014:d];@500>d00A2];Bd
:P000kL0000>0003@P0000<000=200003P000kL0000M0000;`000mh000030003gP00040000<P0000
1P02]003800000<00k@80003800002`000==00004`000b<08`0E0003C@0002P000=2]0002@000kA2
00090003@[@000P000>d@P00;@03@Pd000=2000010000d80000;0092800002h000?O000010000ml0
000o0003800000@00[@014`0020500048000C0:d1@000b00000]00038`00018000<S02<050000b<0
000L0003]00000X000=20;@01`02]003048000T000=2];@01`000k@0@P0<0003]00001h000Bg0000
0d890003@P0000H000=200001`03@P8000>g00007@0002h000?N000010000mh0000n0004800000Bd
0P001Dd0000P00<000DP0000C@0200Bd0P000b00000]00038`00014000<S02<04`000b<0000M00:d
2P000d80000800Bd00=200001P0014:d]48:0003@P0000P00[@N00:g1`03@PD000=200001`000d80
000400=21P02]ad0000^0003g`0000@000?O0000?@000b2d]002]0H000=<00000P000b0080040003
C00000@00k@00b00000]00038`00010000<S02<04P000b<0000M00:d2`000d80000700:d0`000d80
00060005@P00@[@02@000d80000:0003]00001X000>g00002P03@P03048000X000=200000d8;0003
]`0001X0000^0003gP0000@000?N0000>`00122d]20:0003C@00008000<P00000P000dd0000800:d
0R0]00038`00010000<S000040000b<0000N00922`000d8000060004]492@P8000=200001P001480
@T82]0P000=200002P02@R/000=200002`02@R/0000^0003g`0000D000?O0000=`0380@00b070003
C000008000<P00000P000d`0000500<P100382/000<S00003`000b<0000?00038`0001h00[@00`12
00080003@P0000L00[@00`12@P020003@P0000@000E204920002]0T000=2000020001480];@Z0003
@P0000/000=20000:P0002d000?N00001P02gSD00b0:00<P10001dd0000P02000`000dd0000200<P
2P0382T000<S00003P000b<0000>00038`0001h00[@30003@P0000H000=200001P000k@0]0020092
00<0@P001@03@P<00[@80003@P0000L000I2002d0;@Y0003@P0000/000=20000:P0002d000?O0000
1P02gc800b0@00<P0P000d`080030003801<00800b0@00<P9`000b<0000=00038`0000d000<S0000
80000k@000020003@P0000D000=2000020001;@00003@PH00T840003]00000L000=200001@02@P<0
00>d0000:P000d8000090003@P0002/0000]0003gP0000H000==gP00;P0381H00R000dd080030003
801=008P5P0382D000<S000030000b<0000<00038`0002L00T840003@P0000h00d84009240000d80
00030003@P00030000=200002@000d80000[0000;@000ml000060003C=l002`00R0K0003C20000<0
0R000d`0000I0003800001<00T`>00038`0000/000<S00002`000b<0000<009<70001D8000120140
0d8200924@0014800002@S<000=200002@000d80000[0000;@000mh000060003C@0004T000<PC@00
10000ddP000b009=3@000b<0000900038`0S00/000<S00002P03CAl000A200124@02@P0504920480
4@001480048f0003@P0000L000=20000;00002d000=<g`001P000mm<001:0003C00000<000=<0000
=0028``000<S000020000b<08`0:00038`0000T00R<S00924`05@Q<00T8g0003@P0000L000=20000
;00002d000==gP001P000mi=001:0003C@0000<000==0000=P028`/000<S00001`000k@0]0090003
8`0000P00R<U0003@[Ng00Rg6A4:]`03@P0003D000=200001`000d80000/0000;0000d`0g`070003
gd`004/000E<0000C00k008S2P000b<000060003]02d00P000<S000020000b<0000T0003@P1201@0
00A24D924`000d80@P0g0003@P0000D000=20000;@0002`000==0=h01`000mi=001;0005C@0004d0
?@028`T000<S00001@000k@0]00700038`0000L00R<U00920`000d8000040003]02d00L014800a40
@P03@PH000>d0;@01P0014800002@SD000=200001@000d80000]0000;0000d`0g`030006]`00g`1<
C0001D`0001<03l00R<80003]00000<000Fd0000]0050003]00000H00R<V0003@P0000<000=20000
10000k@0]00400I200@04@000T801012@T830003]02d00H000=200000`02@S<000=200001@000d80
000]0000;0000dd0gP030004]`00gP8000==0000BP000dd0C@1200038`0000H000>d00000P001K@0
002d00@000>d00001@028b8000>d00000P000d8000040003@P0000D00[@01012]4820006@P00@P0A
0P000d80@P0300=200<0]0001P000d8000050005@P000;@0;`000d8000030003@P0002h0000/0003
C03O00<000Bg003O0P000d`0001:0003C01<04<00R<70005]0000;@00`001K@0002d00H00R<S00:d
0P02@PP000=200001@001D:d0;@000920P00148001430004@P12@P800[@2@PH000=200001`02@P04
0;@0]2d000=200000`000d80000^0000;0000dd0gP030004]`00gP8000==0000BP000dd0C@15008S
1P001;@00;@30004]000]0H000<S00009002]003@P0000P000=200001@04]003@P00008000A2000A
0`001D80001200:d00<0];@01P000d8000090003@[Bd02h000=200000`000d80000^0000;00014`0
0=l20004]`00g`8000=<0000:@02820000=<00007P0282H00R<500:d1@02]0D00R<X0003@P0000T0
00=200001@001K@0]4:d00@000A2000A0`000d8000020004@P2d]0L000=200002@000kA2000_0005
@P000480<@0002/000E=0000gP020003]`3N00<000==0000:`000b00000M0003C@0001d000<P0000
:002]0800[@34@800Q42]0800[@Z00:d2`000d8000040006]000]02d0P001D80000A00@000=20000
0[@20003]00000@000=200002@000k@0]00`0005@P000480<@0002/000E<0000g`020003]`3O00@0
00=<0000:`000b00000L0003C00001`000<P0000:@05]0040;@0008A00<0]0001;@/00:d2P000d80
00080005]02d04800`000a4000020004@P2d]0X000=2000020000k@0]00a0005@P000480<@0002/0
00E=0000C@020003]`1=00@000==0000;0000b00000J00==6`0282L00b<2]0D00[@01@0A014000:d
1002]0<S9`000k@000090004@P00]0L00[@20005@P000140100014800;@70004]000@P/000>d0000
<@000d80@P0b0000:P03C08000I<002g04`300=<;P000b00000H0005C01<04`06@000b00000Q00HS
2P02]0054@0001400[@900LS;@000d:d00090003]48000<000<A00000`000d:d00080003]48003l0
00=20480<P0002P00Td200A=0P001;L0C@03C@800Td]008P5`0014d004d20003C@0001D000<P0000
70068`l00[@0102d]002]0030;Bd00l01R<T00>d00A2];Bd1P03]003@[Bd008000>g00000k@014:d
];@500>d00A2];Bd?@000d80@P0b00009P02C0D014`00`2g0004C0D00T`]0003800001@000A<001<
0P000d`0000D0003800001D01D`38a@00[@20005]02d0;@00P02]1@00b<5C1d000>d00003P001;@0
0;L200:d40000k@0000l0003@P000340000T009=20001Dd0CDfg009=00<0C@001`02CB`000<P0000
4P001Dd0001=00<000==00004@0283800[@0102d0002]0030;Bd008000Bd0;Bd?`000k@000090003
]`0000T000>d0000A003@S80000R009<2`03C004]da<C0/000=<0000:P000b00000@0003C0000080
00=<00000P000d`0000?00038000030000<S]0000P001;@00;@30004]000]0<000>d8`00?0000k@0
]0090003]`0000P00[A50005@P000480<@0002000Td<00==00<0]dd00dd;009=:`000b00000=0003
84d000@000==00000`000ddP000=0003800002l00R<40004]000]0D000Bd002d10028c/00[@:0003
]`0000T00[A30003@P0000<00T8_00007P02C0`00T`200A<0`02C0/00T`Z00:d3R000d`000030003
C000008000<PC2003202]3000R<600048`2d]0D00[@00`0S000500038`0003P00d890003]`0000P0
0d91009220000d80000/000070000mi=000;0003gTd000@00dd50003CMh000X000==gP009`000b00
]00<0003CB0000<000<PCB0010000b1=000:0003]00P02h00R<700058`0S0;@01@001K@08`0S00H0
0R<h0003]00000=21P000kL0000500=20P000k@0000T0003]`0001L000=200002@02@QP000>g0000
4@0001X00]l<00;O1`03C0L00]l;00;O9`001200];@90003C00P00@000<PC20010000b00C0090003
]00P02d00R<9008S0P000k@000030003]000008S20028cD00[@500=20`000kL0000200=210000k@0
]00U0003]`0001D00T8>0003@P0001D000>g00004@0001P00]h<00;N2005C@P00]h;00;N9@001B00
002d00L000A=000P0`001B00C@0P00<000@P001=1P02]08000<P0000:P000b<00008008S0`000b<0
000300048`00008S2@028c8000>d0;@02003@P03]`1200921`000k@0]00V0003]`0001<000=20000
3`02@Q@000>g00004P0001H00]l<00;O2@000d`0C002C00304`000P00]l;00;O8`000b0000020003
]00000@000A<00000b020003C00000<P0`000d`000030003]000008000<P0000:0028`X00R<40003
8`0000<000<S00000P028`X00R<n0003]d80038000>g00004P000d80000B0003@P00014000>g0000
4P0001@00]h<00;N2P000dd00002C@<000==000020000mh0000:00;N8P000b00000200:d0`000dd0
000200038000008000==00000P000b0000020005C@000;@010000b00000W008S30000b<000030003
8`0000<000<S00000`000b<0000:00038`0003/000=20000<P000kL0000@00925P000d80000@0003
]`000180000B00;O3002g`/000?O00000P000d`000020003g`0000P00]l<00;O80000b0000040003
]01<00@00R040003C00000800R040003C02d00D000<P00009@028`d000<S00000`000b<000050003
8`0000<000<S00002P028cX000=20480=003@Ph000=200005`02@Pl00T8D00004002gP`00]h<0003
gP0000<000==00000`000mh0000900;N3002gQh000<P00001@000dfd00020004800080<000E=0000
8002000680000;A=1P000b00000S0003CB<000d00R<500038`0000D000<S00000`028`d000<SC@00
=P001D800012038000Bg00000d89009270000d80000900=20P000kL0000A00003`000ml0000;0003
g`0000/000?O00000`03C0D000?O00002P000ml0000;0003g`0001`000<P00001P000k@P80030005
800004`00`00120000028003]00000D000<P00008P02C0l00R<600038`0000D000<S000010028`h0
0d`c0003@P0000<000=20000;@02]`L00d850003@P0001d00T8600=21P02]a40000Z0003gP000080
0Td3009=10000mh0000f0003800000H000<P];@00`001B00001=00<000@P00000[@00b0000050003
8000024000==00003P000b<08`0600038`0000D000<S000010000b<08`0@0003C@00030000=20000
0`000d80000/0003]`0000X00d800`12000Q0003@P0000=22`000kL0000>0000:@001=l00002C0L0
0T`30003g`0003D000<P00001@001B00002d00<000@P001<0P001B00002d00<000<P000010000b00
000a00038`0S00L000<S00001@000b<0000500038`0S044000=200001@000d80000k0003@P000280
0T8O0000:0000mh00002C@/00Td20003gP0002/04209]0048;BdC@bd420X00048`008`L000<S0000
1@000b<0000500048`008cl000=200001`000d80000j0003@P00028000=200007P0002L000CO04a<
3`0014`00=lf0003800000D000<P00000P02]003800000<000<P];@010000b000004000380000300
00@S000S1`000b<0000700038`0000D000@S000S>P001K@0001200T000E20000]00h0003@P000280
00=200007P0002H000?NCDd04P02C@030=h003@000<P00001P0280@000>d80000P000b2d0003008P
1`000b00000_00048`008`P000<S00001`000b<0000600048`008cT000Bd00122`0014800;@h0003
@P00028000=200007P0002D000?OC0005@02C003g`00038042001K@P022d010P;`001D`0000S00P0
00<S00001`000b<0000600058`0004`0=`03]003@P0000/000A2];Bd=`000d80000R0003@P0001h0
000S00;N6P000dgN000c0003800000P00R040003800000800R090003800002h000E=00008`090003
8`0000L000<S00001`001B<0001=03P000A2];Bd2@03]003@P0003L000=200008P000d80000N0000
8@03gad00]lo0005800P80000R000`0P000j0003C000008000=<00001`000b<0000700038`0000L0
00=<00000P000d`0000f0003]00000/000>d0000>0000d80000R0003@P0001h0000O00;N8P02gSh0
00<P00000`000b00000i0003C@00008000==000020000b<0000700038`0000P000==00000P000dd0
000f0003]00000T000>d0000>@000d80000R0003@P0001h0000M00;O9P02gcX00R00100P80028003
020P03h000=<000020000b<0000700038`0000P000=<0000P`000d80000R0003@P0001h0000K00;N
:P02gSL000<P00000`000b0000030003800003/000==00001`000b<0000900038`0000L000==0000
P`000d80000R0003@P0001h0000I00;O;P02gc@000<P00000`000b0080050003800003T000=<0000
20000b<0000900038`0000P000=<0000PP000d80000R0003@P0001h0000G00;N<P02gS000R0?008P
A0000b<0000900038`0008d000=200008P000d80000N00005P000ml0000d0003g`0002`000<P0000
4@000b0000110003C00000T000=<0000S@000d80000R0003@P0001h0001k0003800001<000<P0000
@0000dd000090003C@0008`000>g@[L08P000kM2]`0O0000d`000d`0000;0003C00008X000Fg0000
]`0P0005]`000;L07P000=<000==00002`000dd000290003]`0000<000>g000070000kL000030003
]`0001/0003C0003C00000/000=<0000R0000kL000050003]`0001X000>g00001@000kL0000J0000
o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000
o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000M@000kL0000O0003]`0009@000>E0000
Q@0002L000<A00004`000a40000e0003]`0001l000>g0000U0000iD0002500008@000a4000030003
4@0001<000<A00000P000a40000a0003]`0001d000>g0000U@000iD0002500008@000a4000020003
4@0001D000DA00004@0c0003]`0001d000>g0000U@000iD00025000080000a40000200034@0001L0
00DA00004@0b0003]`0001d000>g0000U@000iD00025000080001A40000A01/000@A000A;@000kL0
00030003]`0001/000>g00000P000kL0002A0003U@0008D0000P00044@004Ad000<A0140;@000kL0
00030003]`0001/000>g00000P000kL0002A0003U@0008D0000J00PA00<P00007@000b0A4@064BL0
00>g00000P000kL0000K0005]`000;L0U0000iD0002500007`001140020O0003800A02h000>g0000
0P000kL0000I0005]`000;L0U@000iD0002500007`001A40014P01d000@P000A;P000kL000020003
]`0000P01[L;0005]`000;L0U@000iD00025000070024@8P0`000b0A000J00044B00008P0Q4/0005
]`000;L02`05]`/000Bg002gUP000iD0002500006@034@8000<A02000P000a4P4@0I00074B0A0200
4@0200@A:@001KL0002g00L01;L300Bg1`001;L00;NG0003U@0008D0000G008A1P000a4080024@03
814001P000HP4A4P0147008A8P02]`@000Bg002g1003]`030;Ng00D00[L0102g]kL40003]`2g00D0
0[LS0005C@0004d0:P000dd000020003C@0003L000>E0000Q@00020000LA020A020A01L000HA814P
014^0005]`000;L00P000kL0]`02]`800kL700:g0`03]`040;L0]`@000>g00008`001D`0001<02X0
00=<00000P000d`0000g0003U@0008D0000Q00074@0P4B004@0E00064B0A800A<0002;L0002g0;LS
10001;L00;L30007U@000;L0]`0500038kNg00@000>g000080001Dd0001=008000==0000:P001Dd0
001=00<000==0000<`000iD0002500008P001A40814P01L00R000`0A000a00Fg00<08`000P001;L0
0;L40003U@00008000Bg0;Ng0`000b>g]`04]b@000A<001<0P000d`0000Z0005C00004`00P000d`0
000d0003U@0008D0000S00044@0P81H00R000`0A000a00Bg00D0]`120002]`8000>g00000`000iD0
00030008]`00]`120;L200Bg90000dd00002CBh000==04d00P000dd0000e0003U@0008D0000V008P
500283800kL40005]`2g@[L00`000kL0000300>E1@001[L00;M2]`8000>g00000P03]b8000A<04a<
;`02C00304`003L000>E0000=`000ml0000a0003g`0001L0000W00038000018000<P0000;P03]`P0
0[L00b=200020003]`0000<00iD50005]`0004800kL800>g6P05C@0404e=CBl00dd200A=<`000iD0
000g0003gP00034000?N00005`0002P000?O000040000ml0000]00:g2`001;L0]b<20003]`0000@0
0iD60004]`128`:g30000kL0000H0004C00000=<<@04C08000=<0000<P000iD0000h0003g`0002l0
00?O0000600002P000?N000040000mh0000i0007]`000;M2]`060005U@2E09D01P000kM2]`0200:g
9@000dd00002009=<@02C@@000==0000<P000iD0000h0003gP0002l000?N0000600002T000?O0000
3P000ml0000h00:g1@028`H000FE09D0U@060003]d8000@000>g00008`001d`0001<04`0;`000d`0
C0030003C00003<000>E0000>@000ml0000]0003g`0001T0000Z0003gP0000`000?N0000>0000kL0
00050004]d92@P@000FE09D0U@040004@[M2]`H00[LO009=0P0014d004d20003C@0002d000A=001=
0P000dd00002CC4000>E0000>@000mh0000]0003gP0001T0000[0003g`0000/000?O0000=`000kL0
00050006]d:g@[M20P0019D009D20005U@00@[L00T800`2g00060003]`0001h000I<001<04`30003
C00002/000M<0000C01<008000=<0000<@000iD0000j0003g`0002/000?O00006P0002/000?N0000
2P000mh0000f00:g1`002[L004:g@[M209D2000:U@00U@120480@P8000>g00001@000kL0000N00==
00<0C@000`000dd0000Y0003C@00008000==04d00Tdd0003U@0003X000?N0000:`000mh0000J0000
;0000ml000080003g`0003H000>g00001`001[L00480@P8000E2U@00U@020004UD80]`920`000kL0
000600:g8002C0D000=<0000:@000d`00003009<=P000iD0000k0003g`0001800mlD0003g`0001/0
000]0003gP0000L000?N0000=@000kL000070005]`0004800P000d80U@02@P0309D0009200FE]d80
@P040003]`0000L000>g00006`04C@H000==00009`000dd0000400A==0000iD0000l0003gP0000l0
0]h300;N4@000mh0000L0000;@000ml000060003g`0003D000>g00001`000kL00002000;]d80]d:E
0;M2UD800P001IE2001200D000>g00001`000kL0000F00A<10000d`000030003C00002L000=<0000
0`000d`0000200=<<@000iD0000l0003g`0000d00]l700;O3`000ml0000L0000;P000mh000050003
gP0003h000>g000010001D8004:E008000>gU@000P001IE20;M200H000>g0000:0000dd000030003
C@0002D000==00000`000dd0000g0003U@0003d000?N00002P02gP/00]h<0003gP0001d0000_0003
g`0000<000?O0000?`000kL000040006@P00UD800T8029E2@[M2U@121`000kL0000Y0003C00000<0
00=<00008`000d`000030003C00003P000>E0000?@000ml0000800;O3`02g`X000?O00007@000300
00GN0000gP110003]`0000H000E209D0@P020008U@2g@P2E04880003]`0002T000==00000P000dd0
000S0003C@00008000==0000>@000iD0000n0003gP0000H000?N00004@000mh000060003gP0001h0
000`0005g`000=l0@0000kL00007000?@P2E@P1209D0@P12U@1200T000>g0000:@000d`0000200k6
2K@>aP@000=<0000>P000iD0000n0003g`0000@00]lE00;O1P000ml0000N0000<@000mh0gP110003
]`0000L000=2UD800P001D80U@12008000=2U@002@000kL0000Z0005C@0004d02@03aP/00lH90005
C@0004d0?@000iD0000o0004gP0000;N6@02gP<000?N00007`00010000<A00007@05gal000<A0000
7@000kL000090003U@00008000=2UD8010000iD000090003]`0002X000=<04`01`03aQ400lH70003
C01<03h000>E0000?`001=l0gmlM00;O00<0g`008000010000<A00006P03gP8000?N00000mhL0003
4@0001`000>g00002P000d8000030003U@0000<000=200002P000kL0000Z009=1003aQL00lH4009=
?`000iD0000o00;N8@02gR40000A00034@0001H00ml50003g`0000<00mlH00034@0002T000=20000
10000d8000030003@P0003L00T`01036a/HM00?600<0C4`0?`000iD0000m00;O00<0g`0080001=l0
gmlO00004P000a40000B00?N20000mh0000600?N50000a40000Z0003@P0000@000=2000010000d80
000f0003C@3602<000?604d0?`000iD0000k00;N10000mh0000M0003gP0000800]hM00004`000a40
0005008A1`03g`/000?O00002@03g`H00Q4800034@0002X000>g@P001@000d8000040003@P0003D0
00A<001<8`0014`004`n0003U@0003T00]l60003g`0001d000?O00001002ga/0000C00034@000080
0a4400<P0]h>0003gP0000`000?N82000R0300<A1@000a40000Z0003@P0000D000=2000010000d80
000d0005C@0004d08`001Dd0001=03d000>E0000=`02gPT000?N00006`000mh0000700;N6@0000l0
0Q4300044@0A4@TP4@000ml0000>008P00<082001B024@040140008A:@000d8000050003@P0000D0
00=20000<`001D`0001<02<000E<0000C00m0003U@0003H000?O00002@000ml0000K0003g`0000T0
0]lG00004@001140000380DA0R0C0003gP0001000R064@<P0P000a40000X0003]d8000H000=20000
1@000d80000b0005C@0004d09@001Dd0001=03`000>E0000=002gPd000?N00006@000mh0000<00;N
5@0001800Q400`0A0002008A0R024A<000?O00004@001A4P800A00@00a4[0003@P0000H000=20000
1@000d80000b0005C00004`09@001D`0001<03`000>E0000<P02g`l000?O00006@000ml0000>00;O
4`0001@000DA00004@02808A5@000mh0000C00044B0P4@<000<A0000:`000d8000060003@P0000H0
00=20000<0000dd000020003C@0002<000==00000P000dd0000i0003U@0003000]hB0003gP0001L0
00?N00004@02gQ40000D008A00@0820A60000ml0000F008P00@04@0A:`000d8000070003@P0000H0
00=20000<0000d`000020003C00002<000=<00000P000d`0000i0003U@0002l000?O00004`000ml0
000F0003g`0001<000?O00003P0001@000<A02006`000mh0000H000480004B/000=200001`000d80
00060003@P0002`014d50003C@0002<000==00000`05CCH000>E0000A@000mh0000F0003gP0002@0
000C00044@004A/000?O000060001140014[0003@P0000L000=200001`000d80000W00A<0P02C0D0
00=<00008`000d`00003009<0`03C3800iE70003g`0001@000?O00009@0001<000@A000A6`000mh0
000H00044@004BX000=2]`0020000d8000070003@P0002`000A=04e=10000dd0000S0003C@000080
0Td00`1=000f00>EA`000mh0000D0003gP0002D0000C00044@004A/000?O000060001A40000A01T0
0kL=0003@P0000P000=200001`000d80000;00>g7@000d`00002C0<000=<00009@001T`004`0C080
00=<0000=003UDP000?O00004P000ml0000V00004P001A40000A01/000?N000060001A40000A01`0
1;L90003@P0000P000=2000020000d80000700>g7`0014d004d20004C@00CBL000A=001=0P0014d0
04dd0005U@2E09D0A`000mh0000B0003gP0002H0000F00034@0001T000?O000060000a40000R00>g
1@000d:g00090003@P0000P000=200000`04]b4000E<0000C0020004C01<C2L00d`30005C00004`0
<`001ID0U@2E04P000?O000040000ml0000W00005P000a40000I0003800001P000<A00009@04]`03
02<000X000=2000020000b<00003]bT000I=0000C@02CBD014d30003C@0003D000FE09D0U@180003
gP00010000?N00009`0001H000<A00006@000b00000H00034@0002T000>g8kL02P000d8000080003
]b>g02`000E<04a<0002C00304`0028000E<04a<0002C00304`003D000BE002E0P000iD000160003
g`0000h000?O0000:00001H000<A00006@000b00000H00034@0002X000>g0;L00[L700038`0000D0
0kL00`2g000]0004C@00009=0P000dd0000O0003C@00009=0`000dd0000e0004U@00U@8000>E0000
PP00034000<P0200@`0?]`038kNg00fg:P001D`0001<008000A<001<7`0014`004`20005C00004`0
=P0019D009D20003U@000880000`00054B008140A0000kL0000600>g00<0]`000kL80003]`0002h0
00A=001=0`000dd0000K0005C@0004d00P000dd0000g0005U@0009D00`000iD000210000<0001A4P
4B0A04@000>g00002@03]`/000>g0000;P0014`004`U0004C000C3T000FE0000U@030003U@000840
000`00054B0A8140@`000kL0000800:g00@0]`2g2`000kL0000/0005C@0004d09@001Dd0001=03P0
00FE0000U@030003U@000840000`00054B0A8140@`000kL0000;0003]`0000/000>g0000TP000iD0
00020003U@00008000>E0000P000030000DA814P4@130003]`0000/000>g00002`000kL0002B0003
U@00008000>E00000P000iD000200000<0001A4P4B0A048000>g000030000kL0000<0003]`000940
00>E00000P000iD000020003U@000800000`000581404B00@P000kL0000<0003]`0000`000>g0000
T0000iD000030003U@0000<000>E0000O`00030000DP4@0A80120003]`0000`000>g000030000kL0
002@0003U@0000<000>E00000`000iD0001o0000<0001B00014P044000>g00003@000kL0000=0003
]`0008l000>E00000`000iD000030003U@0007l0000^008A00DP4@0A80024Cl000>g00003@000kL0
000=0003]`0008h000>E000010000iD000040003U@0007h0000Z00@A0`024@@0114k0003]`0000d0
00>g00003@000kL0002>0003U@0000@000>E000010000iD0001n0000:0024@H000<A00000Q46008A
>0000kL0000>0003]`0000h000>g0000S@000iD000040003U@0000@000>E0000OP0002h00Q450003
4@0003d000>g00003P000kL0000>0003]`0008`000>E00001@000iD000050003U@0007d0000]0003
4@0000H000<A0000C@000kL0002M0003U@0000D000>E00001@000iD0001m0000QP000kL0002U0003
U@0008D0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0
003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0000[0003g`0000X000?O0000
o`1l0000:`000mh0000:0003gP000?l0O00002/000?O00002`000ml0003o07/0000Y00;N3P02gY`0
00<S00000`000b<0003F0000:@02g`h00]m;0003C00004h000<S00000`000b<0002:0003U@000080
00>E000010000iD000030003U@0000T000>E00000`000iD000040003U@0000<000>E0000600002T0
0]h?0003gP0004T000==0000CP000b<0000300038`0008X000>E00000P000iD000040003U@0000<0
00>E00002@000iD000030003U@0000@000>E00000`000iD0000H0000:002ga000]m900=<?@000b<0
000?00038`0000<000<S00003`000b<0001i0004U@00U@P000FE0000U@0=0005U@0009D020001ID0
002E01/0000X00;N4002gTP01Ddl00038`0000l000<S00000`000b<0000?00038`0007T000BE002E
20001iD0002E09D02@000iD0U@030003U@0000H000FE0000U@0K0000:@000ml000060003g`0000D0
0]m70003C01<009<00<0C000>`000b<0000>00038`0000<000<S00003P000b<0001j00>E2P000iD0
U@020003U@0000L000>E00000iD:00>E700002P00]h80003gP0000D00]i7009=00<0C@000Tdm0003
8`0000d000==00000`000dd0000=00038`0007H019D200:E2P0019D0U@05U@0409FE00RE2P03U@03
09FE00:E5`0002P00]l700?O1P02gdH000U<04`0C01<04`0?0000b<0000=0003C00000<000=<0000
3@000b<0000n0003C00003T00YD5C0D014`4U@@000>E00000P0019D0UID5C0D014`2UA/0000X00?N
1@05gPD000?N0=h0A00024d004d0C@1=0P000dd0000j0003C@0000`000==00000`000dd0000<0003
C@0003l000==0000=P02U@<000>E00000P02C@03@Te=00FE00@0UIFE0P000iD0U@0200:E00<0U@00
0YD00`2E0002C@03@Te=00<00YD200:E600002P00ml40003g`3O00;O00<0g`000P04gd<000A<001<
0P0014`004`20003C00003T000=<000030000d`000030003C00000`000=<0000>00014`00003C003
04a<009<0P000d`0000a00FE0P02C0030480009<00<0UID00iD0102E09D30004U@2E00JE00H0C4`0
@P02C00409FE00:E6P0002L000?N0=h00]h300;N00D0g]h0gP0200?N00<0gP00@P0014d004d20004
C@00C@8000==0000>P000dd0000;0003C@0000<000==00002`000dd0000i009=00<0C@000dd0249=
04d0C@1=<`04U@9=0`0014800002C@RE0`09U@9=0`001D80001=00>E00<0U@006@0002L000CO0=l0
0]l02`3O0=l0g`3O0=l000?O0P000ml0000o0005C00004`00P0014`004`30003C00003X000=<0000
2P000d`000030003C00000X000=<0000>P0014`0@T`20003@P1200800T`00`1<000b0005U@00UD`0
1@000d8000020003UDbE00>E00=<UID01ID00dbEU@03U@03C00000<000=200000P000dbE00020003
U@0001L0000W0004gP3N00CN00L0gP3N0=h000?N00D0gP00gP100005C@0004d00`001Dd0001=00<0
00==0000>P000dd000090003C@0000<000==00002@000dd0000k009=00L0@P00@P1200<00T82CC40
00FE09FE0002U@@000=200000P03U@05CID0C@001YD00dfEU@04U@D000=200000P0019D0UID20003
U@0001H0000V000:g`00g`3O0=l0g`8000?O0=l01=l01@3O003O03l000=<00000P001D`0001<00<0
00=<00000P000d`0000i0003C00000T000=<00000`000d`000090003C00003X00T`024800480@P12
0P001T80@T`0C3000YD30003U@2E00<000=200001ID014`0UD`70004C9FEC0JE0P0014800002U@<0
0YDI00009P001=h00=h200;N00<0g]h01]h0103N0=h30003gP0003`000?N00000P001Dd0001=00<0
00==00000P000mh0000j0003C@0000P000==00000`000dd000080003C@0003h000=200000T801P12
0480@S<000>E00000`001iD009D0UD800iD0202EUID0C@1=1`000iD0C@0200:E00H0U@2E04820003
U@2E00D000>E00005P0002H000GO003O0002g`030=oO008000OO003O0=l000;O0`000ml0000k0003
g`00008000=<00000P000d`000020003C000008000?O0000>P000d`000070003C00000<000=<0000
1`000d`0000U0003C00001@000A<00120P02@P8000A200120`000d`0000C0003C00001`000>E0000
0P02U@03@P2E00@000JE001<04`50003C01<00<000FE0000U@020003@P2E00<000>E00006`0002D0
00CN00000]h00`3N0002gP030=kN00?N00D0gP00gP030003gP0003X000?N00000`000dd000020003
C@00008000==00000`000mh0000i0003C@0000L000==00000`000dd000070003C@0002800Td00`1=
000A00==00<0C@000P001480@P03@P03048000<000A=04e=4P000dd00002CAT00YD400:E00A2U@00
19D3009=1@02C@@00iD20003U@1200:E0`000iD0U@0K00009@001=l00002g`801=l00`3Og`04g`80
00?O00000P000ml0000h0003g`0000@000?O00000P000ml000020003g`0000<000?O0000>P000d`0
00060003C00000<000=<00001P000d`0000U00925@02@P<000A204800d800`12000300925002@P03
C00001T00YD0102EU@02U@04@P00U@800YD300921@03@P<00YD00`2E00020004@P2E00>E00<0U@00
6P0002D000GN0000gP0300;N00<0gP000]h20004gP0000;N0`000mh0000h0003gP0000<000?N0000
0`000mh000020003gP0000@000?N0000>P000dd000050003C@0000<000==00001@000dd0000V0004
C@12@Q<000A=04920P03@P800T83009200<0C@004@02@P8000==00006P0019D00002U@0409FEU@80
00>E00000d82U@D000==UID00d820007U@2E09E20002U@<000>E00006P0002D000?O00000]l200;O
0`02g`<00ml0103O0=l20003g`0003L000?O000010000ml000030003g`0000<000?O000010000ml0
000j0003C00000@000=<00000`000d`000040003C00002H000=<00000P02@Q0000=<00000P04@P03
02<0009200<0@T8010000d`0000=00921@000d`0000I0004U@0000FE0`03@P<00YD014`00002C003
U@0000800d8200:E00A2U@2E0`000iD0000J000090002Mh00=h0gP3N0002gP800]h30003gP0000;N
0P001=h00=hg0003gP0000D000?N00000`000mh000030003gP0000D000?N00009@028a8000==0000
10000dd000030003C@0000@000==000040028a/00T8E00920b<3@QD000=200006P000iD0000300FE
00<0UID00Td3@P8000>E00000P03U@8000>ECID00`0019D00003@P03CD:E008000BE09FE1@000iD0
000D000090001Ml00=l000;O0P02g`800]l300;O0P001=l00=l20003g`0003@000?O00001@000ml0
00040003g`0000<000?O00001@000ml0000W00<S40000d`000030003C00000<000=<00000`000d`0
000>00<S7`02@Q8000E2]b<S@P028`03]`1201800T8M0003U@2E00JE00<0UID00YD3@P03C02E00:E
0`03U@06C9E<U@1<0`03U@0304a<00=219D00`2EU@04U@0309D001D0000T0004gP3N00;N0P001]h0
gP3N00;N00@0gP3N0P03gP040=h0gSH000?N00001@000mh000040003gP0000@000?N00001@000mh0
000Y00==3P000dd000020003C@0000<000==00000P000dd0000<00==9002@Pl000M2]d808d8S0092
00>g04803`02@Qh000>E09D00`001ID0UIE=00>E00@0U@2E0d8200^E00==09D00YD00`1=@P02@P03
09E200BE00A=UIFE0`000iD0U@0E00008`001ml0g`3O0=l00P001=l00=l20006g`3Og`3O0P002=l0
0=l0g`3O=0000ml000060003g`0000@000?O000010000ml000060003g`0002/00d`<0005C00004`0
1@001D`0001<00`00d`Y0003@P0000/000=2]`000d801@2g048000:g00=200002P02@R0000>E09D0
0`0029D0002E09D00iD0101<C4`3@P9<19D024bEUIE<UDbE0d83C008UD:E@YD0UD`20007U@0009D0
U@0E00008`001=h0g]h20005gP00gP000]h20004gP00gP8000?N0=h00`02gP030=h0038000?N0000
1P000mh000050003gP0000@000?N00001P000mh0000^00==2@001Dd0001=00D000E=0000C@0900==
;@02@PX00[L02012@P120;L00d800`2g@P0900928P001ID009D000:E0P000dd0U@03U@==0`03U@=2
00==UID00iD00dfE@P02@P03UD8000<000I2CIFE@YD20006C@2EU@2E0P000iD0000C00008`02g`@0
00?O0=l00P02g`8000CO0=oO0P000ml0g`0500;O<P000ml000070003g`0000D000?O00001@000ml0
00060003g`00030014`60004C000C0D000A<001<1P04C3800T87000<]`12@P12]`120;M20P02@P03
]d8000H000=200008004U@0409D0U@8019D01dbEUID0@P000YD01T:EUID0U@=20YD3@P0309FE00BE
00@0@P000YD00d9<U@03U@0409D0U@8019DB00008P02gPD000GN0=h0gP02000;gP3N0=h0gP3N0=h0
1P02gS4000?N00001`000mh000050003gP0000D000?N00001`000mh0000c00==10000dd0C@050003
C@1=00@00ddh009210000kM2@P030007@[L0@P2g@P040003@[Ng00@00T8Q00:E0`03U@04CIFEU@==
00<0UID019D00d80@P0200JE0d83U@03CIFE008000FE00120004U@05@Te=04d00YD014fEUID400:E
4000028000?O000010001=l0gml30005g`3O0=l00P001=l0gml70003g`0002h000?O00001`000ml0
00060003g`0000D000?O00001`000ml0000f00E<00<0C00010000d`0C004C3d00T800`2g@P050007
@[M204:g@P060003@[L000929@02U@0509D0UD`00`0014`00483U@0409FE009210002TbEUD:E@YE2
C9D2C0<000=204801YD00`120002C08000E<UIFE0003UA80000R0003gP0000@00]h00`3N00020004
gP3NgP<000CN0=kN1`000mh0000]0003gP0000P000?N00001P000mh000060003gP0000L000?N0000
>@03C@D00de30003]`0000D000Ng0480@P2g00P000>g00009P04U@8000M=0492048000:E0P03U@92
0`0014fECD82U@04@YFE@P:E00A=00000T84U@800YD00d800002@P03C@0000BE5000024000?O0000
1@03g`D00ml400?O20000ml0000[0003g`0000T000?O00001P000ml000060003g`0000P000?O0000
>P07C4D000=200001@000kM200020003@[L000L000=200009`000iE<C00200=<00@0@T800YD200>E
0T84U@920YD00da2U@02C09200=<UID00YD00d80U@02U@0309FE00800T800`1<C002009<00>E0000
4`00020000?N00001P02gPH00mh500;N2@000mh0000Z0003gP0000P000?N00001`000mh000060003
gP0000T000?N0000>@001dgNC@1=gTd0A@000d8000040003@[M200<000=2]d801`000d80000U00BE
00<0CDd00dd01012@P07U@920YD00de2C@04U@03@YFE00==00A2C@2E0T800`2EU@03U@0409D0@P80
14d00`2EU@02UA<0000O0003g`0000L000?O00001@02g`L000?O000020000ml0000X0003g`0000T0
00?O00001`000ml000060003g`0000T000?O0000>@000dcO00020003gd`004@000=2000010000d:g
00040003]d8000H000=2000090000iD00002U@8014`01D80048000BE0P0024:E@P12C9E<0YD014a2
UID2C007UDa20480@P0200BE00H0@T80@P03C0800iD00`2EU@0A00007`000mh000070003gP0000H0
00?N00001@000mh000080003gP0002L000?N00002P000mh000070003gP0000L000?N00002@000mh0
000h0007C@3N0=h0C@150003@P0000@000>g@P0010000d:g00050003@P0002@019D0102EUDd20003
CD9=009=0YD00d:EU@02U@04@Te=C@9200BECID00Td02D:EU@2E09E=@P03C@03@P2E00>E00=2UDd0
0Td01D80C@1=00:E0P04UA00000N0003g`0000P000?O00001P000ml000060003g`0000P000?O0000
9@000ml0000:0003g`0000P000?O00001`000ml0000:0003g`0003H000=<gml01Ml00d`000130003
@P1200=200>g00001@000kM2@P02@P8000=20000:002U@05C9FEUD`00P09U@06@P12@P120YD20005
C9E2UD`00`02U@=200BEC4a<19D014bEUD`20004C9FEC0>E500001d000?N000020000mh000070003
gP0000H000?N00002@000mh0000T00038`0000X000?N000020000mh000070003gP0000X000<S0000
<`05C@D01Dd`0003C@0000T024850003@P0000<000=200000`08@P/000==00005`03U@8000JECIFE
04d7U@08CD:E04fE@YD200:E00A2U@2E0P001YE2UDfE@P>E00=209D019D02@2EUDfE09D0U@0E0000
70000ml000090003g`0000L000?O00001P000ml000090003g`0002<000<S00002`000ml000080003
g`0000P000?O00002P000b<0000_00=<0P0014`004`30004C000C0800d`]0003C00000801d860003
@P0000D000E20000@P080003@P0000<024830003C00001L000>E09D00YD0102E09D20003C9FE00>E
00I<@TbE04`20006@P2EUDa20YD0102E04820004C02E@PNE00=<00000iD0102EU@02UA@0000L0003
gP0000T000?N00001`000mh000070003gP0000T000?N00008@000b<0000;0003gP0000T000?N0000
20000mh0000;00038`0002/00dd40003C@00008000==04d010000dd0000200==:P000de2@P02@Pd0
00=200001P000d80@P090003@P0000/014800dd0000E0004U@2EU@<00YD300JE00E2UD:EC@06@P03
UD9200]200>E@YD019D01dfE002E09D00P03U@0309D00180000K0003g`0000T000?O000020000ml0
00070003g`0000X000?O00007`000b<0000<0003g`0000T000?O000020000ml0000<00038`0002L0
0d`60003C00000@000=<000010000d`0000400=<9@02C00304`000l000=200001`000d8000080003
@P0000h000=<04`05@000iD0U@020005U@00U@000iD01@2EUID000FE00=<09D00YD02T80U@1209D0
@P03U@0309FE00RE00<0UID00P000iD0U@030003U@2E0180000J0003gP0000X000?N000020000mh0
00070003gP0000/000?N00007P000b<0000<0003gP0000T000?N00002@000mh0000;00038`0002@0
0dd90003C@0000@000==000010000dd0000700==9@000dd0000>0003@P0000H000=2048020000d80
000>0003C@0001/000BE09D00iD00`2EU@02U@0309FE00:E00==UID00iD01P1204e2C@8000A209D0
19D014:EU@02U@0609FEU@2E0P02UAP0000I0003g`0000/000?O000020000ml000080003g`0000X0
00?O00007@000b<0000<0003g`0000X000?O00002@000ml0000<00038`0002000d`;0003C00000@0
00=<04`01P000d`0000900=<8P000d`0000>0003@P0000D000E20000@P070003@P0000h000=<0000
6`0019D0UID200RE00<0UID00YD200>E00L0@P12UDa200BE00D0UIFE@P05U@0309FE00:E00<0U@00
0YDH000060000mh0000;0003gP0000T000?N000020000mh0000;0003gP0001/000<S00003@000b<0
000:0003gP0000T000<S00003@000b<0000L00==3@000dd000040005C@0004d01P000dd0000;00==
<@000d8000030003@P0000<000=2000010000d80000^0003U@0000<000FE09FEC@06U@<00iD00d9=
@P02C@0409FEU@<02ID00`2E00040003U@0001L0000H0003g`0000/000?O00002@000ml000080003
g`0000`000?O00006@000b<0000>00038`0000X000?O00002P000b<0000=00038`0001P00d`@0003
C00000<000=<00000`000d`000030003C00000h00d`^0003@P00008000=200001@000d8000030003
@P0002h000>E00000`04U@06C9D0UD`01YD014bEC482U@03C9FE00FE00E2UIFEC005U@D000>E0000
5`0001L000?N000030000mh000090003gP0000T000?N00002`000mh0000I00038`0000d000<S0000
2`000b<0000:00038`0000d000<S00005P000b==000A0003C@0000@000==00000`000dd000040003
C@00010000==8`00:`001D80001200T000=200000P000d80000d00>E0P001Dd0UDd000RE00==@YD0
2ID014:EUDd20004U@2EUAl0000F0003g`0000`000?O00002P000ml000090003g`0000`000?O0000
5`000b<0000>00038`0000/000<S00002P000b<0000>00038`0001800b<C0003C00000@000=<0000
1@000d`000040003C00001400b<Y0004@P00@P/000A20012=`03U@8000A<U@1<0`000iD0U@02U@03
@YFE00BE00A<U@2E0P0014:E09D30003U@2E01l0000E0003gP0000d000?N00002P000mh000090003
gP0000d000?N00005@000b<0000?00038`0000/000<S00002`000b<0000>00038`00010000<S0000
50000dd000030003C@0000L000==00000`000dd0000D00038`0002H000=204803@000d80@P0g0004
U@2EU@800Td010120002@P:E00<0UID00iD00`2EC@03@P09048004fE09D000:E800001D000?O0000
3@000ml0000:0003g`0000X000?O00003@000ml0000D00038`0000h000<S000030000b<0000;0003
8`0000h000<S00009P000d`000030003C00000T000=<00000`000d`0000l00923`02@SH000NE0000
U@2E009<00D0@T920002U@0509D0U@000YD01P2EUDbE00=200<0C0000iD20003U@0001d0000D0003
gP0000d000?N00002`000mh0000:0003gP0000d000?N00004`000b<0000?00038`0000`000<S0000
2`000b<0000?00038`0002@000==000010000dd000090003C@0000@000==0000>`000d80000?0003
@P0003801ID01@2E09D000=20P0014d0U@09U@0604d004800T801@2EUID000BE7@0001<000?O0000
3P000ml0000;0003g`0000X000?O00003P000ml0000A00038`00010000<S000030000b<0000<0003
8`0000l000<S00008`000d`000030003C00000/000=<00000`000d`0000j00924@02@SP00YD5C005
049<09D00d`5U@07C9E<U@1<@P0200E<0YDQ00004P000mh0000?0003gP0000/000?N00002`000mh0
000>0003gP0000l000<S00004@000b<0000<00038`0000`000<S000040000b<0000Q0003C@0000<0
00==00003@000dd000030003C@0003D00Td01@120012010000A204800Tda00:E00@0U@2E0P03C@04
@Te=U@<00YD0102EUID20004UDe=@PA=00@0UIFE0P02UAh0000B0003g`0000l000?O00002`000ml0
000;0003g`0000h000?O00008P000b<0000=00038`0000`000<S0000<`000d`000040003C00000d0
00=<000010000d`0000f0005@P0004803`001D80001203D00YD0102E0002C00504`009D00`03U@03
09FE00<000>E000014`0102EU@02UB00000A0003gP0000l000?N000030000mh0000;0003gP0000l0
00?N00008@000b<0000=00038`0000d000<S0000<@000dd000040003C@0000l000==000010000dd0
000d0003C@1=008000A204e=2P02C@04@P00009=<`000iD00002U@9=00D0C@00C@07U@0309FE00FE
00@0C@000dd3U@0309D001l0000@0003g`00010000?O000030000ml0000<0003g`0000l000?O0000
80000b<0000=00038`0000d000<S0000<@000d`000030003C000014000=<00000`000d`0000c0004
C000009<00=2C0003@00149<C4`20003C00002l000NE0000UDbE008000E<002EC002U@0309FE00<0
00BE09D00YD01DbE001<008000=<U@000P000iD0000M00003`000mh0000A0003gP0000`000?N0000
30000mh0000@0003gP0001l000<S00003@000b<0000=00038`00030000==00000`000dd0000C0003
C@0000<000==0000>0000dd0000=0003C@0003L01YD01@1=UID000:E0P000iD000040006U@2E09D0
0YD00dd0U@04UB40000R0003g`0000d000?O000030000ml0000a00038`0000h000<S00003P000b<0
000^0003C00000@000=<00004`000d`000040003C00003P000=<00002`000d`0000g0004U@0000BE
00U<U@00U@2E09D01P02U@8000FE002EC003U@<00YDO00008P000mh0000=0003gP0000d000?N0000
<0000b<0000>00038`0000h000<S0000;P000b<000030003C@0001D000==00000`000b<0001o0003
U@00008000JE09D0U@03U@8000>E00001@0019D00003U@0309FE00:E1@000iD0000L00008P000ml0
000=0003g`0000d000?O0000<0000b<0000>00038`0000h000<S0000;@000b<000030003C00001L0
00=<00000`000b<000220003U@2E00800YD0102EUID20003U@0000<000BE00000iD01`2EU@2E09D0
8`00024000?N00003P000mh0000=0003gP0002l000<S00003`000b<0000?00038`0002/000<S0000
0`000dd0000I0003C@0000<000<S0000P@02U@<000BE002E0P000iD000080004U@00U@8000>E0000
0YDS00008@000ml0000>0003g`0000h000?O0000;P000b<0000?00038`0000l000<S0000:P000b<0
000400038`0001T000<S000010000b<000200003U@0000<000>E09D040000iD0U@040003U@000240
000Q0003gP0000h000?N00003P000mh0001000038`00048000<S00006`000b<0002<0003U@000180
00>E00009P00020000?O00003`000ml0000>0003g`00040000<S0000@@000b<0000M00038`0008/0
00>E00004P000iD0000V000080000mh0000?0003gP0000l000?N0000PP000b<0000O00038`000<P0
000b0003g`000?l0PP00038000?N0000o`220000<P000ml0003o0880003o0;L0003o0;L0003o0;L0
003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L00000\
\>"],
  ImageRangeCache->{{{0, 437}, {257, 0}} -> {-0.145065, -0.0740895, 0.0121056,
   0.0121056}, {{11.9375, 88.4375}, {250.875, 174.375}} -> {-0.188855,
   -0.109075, 0.0137256, 0.0137256}, {{96.0625, 172.562}, {250.875, 174.375}}
   -> {-1.34352, -0.109075, 0.0137256, 0.0137256}, {{180.25, 256.688}, {
  250.875, 174.375}} -> {-2.50107, -0.109572, 0.0137368, 0.0137368}, {{
  264.375, 340.875}, {250.875, 174.375}} -> {-3.65372, -0.109075, 0.0137256, 
  0.0137256}, {{348.5, 425}, {250.875, 174.375}} -> {-4.80839, -0.109073, 
  0.0137256, 0.0137256}, {{11.9375, 88.4375}, {166.688, 90.25}} -> {-0.188855,
   -1.26417, 0.0137256, 0.0137256}, {{96.0625, 172.562}, {166.688, 90.25}} ->
   {-1.34503, -1.26562, 0.0137369, 0.0137369}, {{180.25, 256.688}, {166.688, 
  90.25}} -> {-2.50107, -1.26561, 0.0137368, 0.0137368}, {{264.375, 340.875},
   {166.688, 90.25}} -> {-3.65711, -1.26561, 0.0137368, 0.0137368}, {{348.5, 
  425}, {166.688, 90.25}} -> {-4.80839, -1.26417, 0.0137256, 0.0137256}, {{
  11.9375, 88.4375}, {82.5625, 6.0625}} -> {-0.188855, -2.41927, 0.0137256, 
  0.0137256}, {{96.0625, 172.562}, {82.5625, 6.0625}} -> {-1.34352, -2.41927, 
  0.0137256, 0.0137256}, {{180.25, 256.688}, {82.5625, 6.0625}} -> {-2.50107,
   -2.42166, 0.0137368, 0.0137368}, {{264.375, 340.875}, {82.5625, 6.0625}} ->
   {-3.65372, -2.41927, 0.0137256, 0.0137256}, {{348.5, 425}, {82.5625, 
  6.0625}} -> {-4.80839, -2.41927, 0.0137256, 0.0137256}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples (2)", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(bioTable = Table[randBio, {3}, {5}]\), 
    \(\(biomorph[bioTable]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{{2, 3, 6, 4, 7, 4, 4, 3, 9, 5, 5, 4, 10, 9, 3, 4, 3, 2, 8, 9, 4}, {3, 
          2, 8, 8, 8, 2, 3, 1, 8, 4, 8, 4, 7, 8, 1, 9, 3, 7, 9, 5, 6}, {3, 1, 
          5, 4, 6, 6, 1, 9, 8, 10, 7, 4, 8, 5, 7, 10, 4, 4, 10, 10, 6}, {3, 
          1, 3, 2, 7, 2, 1, 2, 5, 8, 4, 2, 6, 5, 1, 2, 2, 6, 10, 9, 7}, {1, 
          3, 6, 1, 8, 9, 3, 10, 3, 9, 2, 1, 8, 7, 7, 5, 4, 1, 3, 1, 9}}, {{3, 
          2, 5, 7, 10, 9, 3, 8, 2, 6, 4, 5, 8, 10, 10, 3, 1, 10, 1, 8, 7}, {
          2, 1, 3, 6, 3, 6, 5, 8, 4, 1, 5, 3, 6, 1, 2, 10, 5, 5, 1, 1, 1}, {
          1, 5, 9, 10, 1, 7, 4, 9, 5, 2, 1, 4, 2, 5, 3, 2, 5, 7, 2, 2, 2}, {
          1, 3, 7, 5, 1, 7, 4, 9, 7, 9, 3, 5, 3, 7, 8, 6, 1, 8, 8, 10, 6}, {
          4, 1, 1, 6, 2, 4, 1, 4, 9, 7, 3, 4, 5, 3, 8, 5, 2, 1, 3, 8, 5}}, {{
          4, 4, 2, 7, 5, 7, 1, 10, 8, 10, 7, 3, 7, 5, 5, 6, 2, 5, 1, 2, 5}, {
          4, 1, 10, 4, 9, 10, 5, 9, 8, 1, 1, 1, 2, 5, 8, 6, 4, 9, 10, 5, 7}, {
          1, 5, 4, 5, 5, 8, 3, 7, 1, 9, 1, 4, 8, 6, 4, 5, 3, 6, 9, 5, 2}, {1, 
          1, 1, 6, 1, 3, 4, 7, 3, 9, 3, 3, 4, 5, 8, 5, 4, 2, 8, 3, 6}, {4, 4, 
          1, 8, 7, 7, 5, 3, 10, 5, 2, 2, 9, 3, 9, 1, 2, 9, 3, 10, 5}}}\)], 
  "Output",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .59259 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0141093 0.190476 [
[ 0 0 0 0 ]
[ 1 .59259 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .59259 L
0 .59259 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0141093 0.200176 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.176229 0.952381 [
[ 0 0 0 0 ]
[ 1 .59992 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .59992 L
0 .59992 L
closepath
clip
newpath
p
P
p
0 1 1 r
.004 w
.18138 .13877 m
.19994 .1202 L
s
P
p
0 1 1 r
.004 w
.18138 .13877 m
.16281 .1202 L
s
P
p
0 1 1 r
.004 w
.07517 .34721 m
.04924 .34311 L
s
P
p
0 1 1 r
.004 w
.07517 .34721 m
.07106 .37315 L
s
P
p
0 1 1 r
.004 w
.30623 .31062 m
.31815 .33401 L
s
P
p
0 1 1 r
.004 w
.30623 .31062 m
.32963 .2987 L
s
P
p
0 .4 1 r
.01 w
.18138 .27005 m
.18138 .13877 L
s
P
p
0 .4 1 r
.01 w
.18138 .27005 m
.07517 .34721 L
s
P
p
0 .4 1 r
.01 w
.18138 .27005 m
.30623 .31062 L
s
P
p
.2 0 1 r
.02 w
.35131 .14659 m
.18138 .27005 L
s
P
p
0 1 1 r
.004 w
.30113 .30691 m
.30524 .28098 L
s
P
p
0 1 1 r
.004 w
.30113 .30691 m
.2752 .3028 L
s
P
p
0 1 1 r
.004 w
.33773 .53797 m
.31434 .54989 L
s
P
p
0 1 1 r
.004 w
.33773 .53797 m
.34965 .56137 L
s
P
p
0 1 1 r
.004 w
.50315 .37255 m
.52655 .38447 L
s
P
p
0 1 1 r
.004 w
.50315 .37255 m
.51507 .34916 L
s
P
p
0 .4 1 r
.01 w
.3783 .41312 m
.30113 .30691 L
s
P
p
0 .4 1 r
.01 w
.3783 .41312 m
.33773 .53797 L
s
P
p
0 .4 1 r
.01 w
.3783 .41312 m
.50315 .37255 L
s
P
p
.2 0 1 r
.02 w
.44321 .21335 m
.3783 .41312 L
s
P
p
0 1 1 r
.004 w
.49685 .37255 m
.48493 .34916 L
s
P
p
0 1 1 r
.004 w
.49685 .37255 m
.47345 .38447 L
s
P
p
0 1 1 r
.004 w
.66227 .53797 m
.65035 .56137 L
s
P
p
0 1 1 r
.004 w
.66227 .53797 m
.68566 .54989 L
s
P
p
0 1 1 r
.004 w
.69887 .30691 m
.7248 .3028 L
s
P
p
0 1 1 r
.004 w
.69887 .30691 m
.69476 .28098 L
s
P
p
0 .4 1 r
.01 w
.6217 .41312 m
.49685 .37255 L
s
P
p
0 .4 1 r
.01 w
.6217 .41312 m
.66227 .53797 L
s
P
p
0 .4 1 r
.01 w
.6217 .41312 m
.69887 .30691 L
s
P
p
.2 0 1 r
.02 w
.55679 .21335 m
.6217 .41312 L
s
P
p
0 1 1 r
.004 w
.69377 .31062 m
.67037 .2987 L
s
P
p
0 1 1 r
.004 w
.69377 .31062 m
.68185 .33401 L
s
P
p
0 1 1 r
.004 w
.92483 .34721 m
.92894 .37315 L
s
P
p
0 1 1 r
.004 w
.92483 .34721 m
.95076 .34311 L
s
P
p
0 1 1 r
.004 w
.81862 .13877 m
.83719 .1202 L
s
P
p
0 1 1 r
.004 w
.81862 .13877 m
.80006 .1202 L
s
P
p
0 .4 1 r
.01 w
.81862 .27005 m
.69377 .31062 L
s
P
p
0 .4 1 r
.01 w
.81862 .27005 m
.92483 .34721 L
s
P
p
0 .4 1 r
.01 w
.81862 .27005 m
.81862 .13877 L
s
P
p
.2 0 1 r
.02 w
.64869 .14659 m
.81862 .27005 L
s
P
p
.2 0 1 r
.01 w
.5 .03856 m
.35131 .14659 L
s
P
p
.2 0 1 r
.01 w
.5 .03856 m
.44321 .21335 L
s
P
p
.2 0 1 r
.01 w
.5 .03856 m
.55679 .21335 L
s
P
p
.2 0 1 r
.01 w
.5 .03856 m
.64869 .14659 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.0141093 0.39418 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00481255 0.990375 0.0247594 0.990375 [
[ 0 0 0 0 ]
[ 1 1.03989 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.03989 L
0 1.03989 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.01 w
.70769 .79651 m
.83109 .55433 L
s
P
p
.2 0 1 r
.01 w
.70769 .79651 m
.5155 .98871 L
s
P
p
.2 0 1 r
.01 w
.70769 .79651 m
.94988 .67311 L
s
P
p
.2 0 1 r
.01 w
.70769 .79651 m
.43923 .83903 L
s
P
p
0 .4 1 r
.016 w
.62781 .68656 m
.70769 .79651 L
s
P
p
.2 0 1 r
.01 w
.39081 .17459 m
.19861 .36678 L
s
P
p
.2 0 1 r
.01 w
.39081 .17459 m
.63299 .05119 L
s
P
p
.2 0 1 r
.01 w
.39081 .17459 m
.12235 .21711 L
s
P
p
.2 0 1 r
.01 w
.39081 .17459 m
.65927 .21711 L
s
P
p
0 .4 1 r
.016 w
.43281 .30384 m
.39081 .17459 L
s
P
p
.2 0 1 r
.01 w
.5 .86399 m
.74218 .74059 L
s
P
p
.2 0 1 r
.01 w
.5 .86399 m
.23154 .90651 L
s
P
p
.2 0 1 r
.01 w
.5 .86399 m
.76846 .90651 L
s
P
p
.2 0 1 r
.01 w
.5 .86399 m
.25782 .74059 L
s
P
p
0 .4 1 r
.016 w
.5 .72809 m
.5 .86399 L
s
P
p
.2 0 1 r
.01 w
.60919 .17459 m
.34073 .21711 L
s
P
p
.2 0 1 r
.01 w
.60919 .17459 m
.87765 .21711 L
s
P
p
.2 0 1 r
.01 w
.60919 .17459 m
.36701 .05119 L
s
P
p
.2 0 1 r
.01 w
.60919 .17459 m
.80139 .36678 L
s
P
p
0 .4 1 r
.016 w
.56719 .30384 m
.60919 .17459 L
s
P
p
.2 0 1 r
.01 w
.29231 .79651 m
.56077 .83903 L
s
P
p
.2 0 1 r
.01 w
.29231 .79651 m
.05012 .67311 L
s
P
p
.2 0 1 r
.01 w
.29231 .79651 m
.4845 .98871 L
s
P
p
.2 0 1 r
.01 w
.29231 .79651 m
.16891 .55433 L
s
P
p
0 .4 1 r
.016 w
.37219 .68656 m
.29231 .79651 L
s
P
p
1 .6 0 r
.002 w
.5 .51064 m
.62781 .68656 L
s
P
p
1 .6 0 r
.002 w
.5 .51064 m
.43281 .30384 L
s
P
p
1 .6 0 r
.002 w
.5 .51064 m
.5 .72809 L
s
P
p
1 .6 0 r
.002 w
.5 .51064 m
.56719 .30384 L
s
P
p
1 .6 0 r
.002 w
.5 .51064 m
.37219 .68656 L
s
P
p
1 0 0 r
.018 w
.5 .40192 m
.5 .51064 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.0141093 0.588183 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.000503103 0.952381 [
[ 0 0 0 0 ]
[ 1 .95339 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95339 L
0 .95339 L
closepath
clip
newpath
p
P
p
.8 0 1 r
.01 w
.5 .43216 m
.22585 .05482 L
s
P
p
.8 0 1 r
.01 w
.5 .43216 m
.05642 .57628 L
s
P
p
.8 0 1 r
.01 w
.5 .43216 m
.5 .89856 L
s
P
p
.8 0 1 r
.01 w
.5 .43216 m
.94358 .57628 L
s
P
p
.8 0 1 r
.01 w
.5 .43216 m
.77415 .05482 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.0141093 0.782187 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.80769 4.61538 0.115385 4.61538 [
[ 0 0 0 0 ]
[ 1 4.84615 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 4.84615 L
0 4.84615 L
closepath
clip
newpath
p
P
p
.2 1 0 r
.002 w
.5 .30159 m
.5 4.54457 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.0141093 0.97619 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0943964 0.952381 [
[ 0 0 0 0 ]
[ 1 .76359 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .76359 L
0 .76359 L
closepath
clip
newpath
p
P
p
0 1 1 r
.02 w
.26838 .09786 m
.33763 .13315 L
s
P
p
0 1 1 r
.02 w
.26838 .09786 m
.21341 .0429 L
s
P
p
0 1 1 r
.02 w
.15981 .20643 m
.10484 .15147 L
s
P
p
0 1 1 r
.02 w
.15981 .20643 m
.19509 .27569 L
s
P
p
1 .6 0 r
.018 w
.22269 .16074 m
.26838 .09786 L
s
P
p
1 .6 0 r
.018 w
.22269 .16074 m
.15981 .20643 L
s
P
p
0 1 1 r
.02 w
.12597 .31056 m
.19523 .27527 L
s
P
p
0 1 1 r
.02 w
.12597 .31056 m
.0492 .32272 L
s
P
p
0 1 1 r
.02 w
.14999 .46221 m
.07322 .47437 L
s
P
p
0 1 1 r
.02 w
.14999 .46221 m
.22676 .47437 L
s
P
p
1 .6 0 r
.018 w
.14999 .38448 m
.12597 .31056 L
s
P
p
1 .6 0 r
.018 w
.14999 .38448 m
.14999 .46221 L
s
P
p
0 1 1 r
.02 w
.21435 .55079 m
.22651 .47402 L
s
P
p
0 1 1 r
.02 w
.21435 .55079 m
.17906 .62005 L
s
P
p
0 1 1 r
.02 w
.35115 .6205 m
.31587 .68975 L
s
P
p
0 1 1 r
.02 w
.35115 .6205 m
.40612 .56553 L
s
P
p
1 .6 0 r
.018 w
.28827 .57481 m
.21435 .55079 L
s
P
p
1 .6 0 r
.018 w
.28827 .57481 m
.35115 .6205 L
s
P
p
0 1 1 r
.02 w
.46064 .6205 m
.40568 .56553 L
s
P
p
0 1 1 r
.02 w
.46064 .6205 m
.49593 .68975 L
s
P
p
0 1 1 r
.02 w
.59745 .55079 m
.63274 .62005 L
s
P
p
0 1 1 r
.02 w
.59745 .55079 m
.58529 .47402 L
s
P
p
1 .6 0 r
.018 w
.52353 .57481 m
.46064 .6205 L
s
P
p
1 .6 0 r
.018 w
.52353 .57481 m
.59745 .55079 L
s
P
p
0 1 1 r
.02 w
.6618 .46221 m
.58503 .47437 L
s
P
p
0 1 1 r
.02 w
.6618 .46221 m
.73858 .47437 L
s
P
p
0 1 1 r
.02 w
.68582 .31056 m
.7626 .32272 L
s
P
p
0 1 1 r
.02 w
.68582 .31056 m
.61657 .27527 L
s
P
p
1 .6 0 r
.018 w
.6618 .38448 m
.6618 .46221 L
s
P
p
1 .6 0 r
.018 w
.6618 .38448 m
.68582 .31056 L
s
P
p
.8 1 0 r
.01 w
.4059 .34395 m
.22269 .16074 L
s
P
p
.8 1 0 r
.01 w
.4059 .34395 m
.14999 .38448 L
s
P
p
.8 1 0 r
.01 w
.4059 .34395 m
.28827 .57481 L
s
P
p
.8 1 0 r
.01 w
.4059 .34395 m
.52353 .57481 L
s
P
p
.8 1 0 r
.01 w
.4059 .34395 m
.6618 .38448 L
s
P
p
0 1 1 r
.02 w
.26074 .17244 m
.33751 .1846 L
s
P
p
0 1 1 r
.02 w
.26074 .17244 m
.19148 .13715 L
s
P
p
0 1 1 r
.02 w
.19103 .30925 m
.12177 .27396 L
s
P
p
0 1 1 r
.02 w
.19103 .30925 m
.24599 .36421 L
s
P
p
1 .6 0 r
.018 w
.23672 .24637 m
.26074 .17244 L
s
P
p
1 .6 0 r
.018 w
.23672 .24637 m
.19103 .30925 L
s
P
p
0 1 1 r
.02 w
.19103 .41874 m
.24599 .36377 L
s
P
p
0 1 1 r
.02 w
.19103 .41874 m
.12177 .45402 L
s
P
p
0 1 1 r
.02 w
.26074 .55554 m
.19148 .59083 L
s
P
p
0 1 1 r
.02 w
.26074 .55554 m
.33751 .54339 L
s
P
p
1 .6 0 r
.018 w
.23672 .48162 m
.19103 .41874 L
s
P
p
1 .6 0 r
.018 w
.23672 .48162 m
.26074 .55554 L
s
P
p
0 1 1 r
.02 w
.34931 .6199 m
.33715 .54313 L
s
P
p
0 1 1 r
.02 w
.34931 .6199 m
.33715 .69667 L
s
P
p
0 1 1 r
.02 w
.50097 .64392 m
.48881 .72069 L
s
P
p
0 1 1 r
.02 w
.50097 .64392 m
.53626 .57466 L
s
P
p
1 .6 0 r
.018 w
.42704 .6199 m
.34931 .6199 L
s
P
p
1 .6 0 r
.018 w
.42704 .6199 m
.50097 .64392 L
s
P
p
0 1 1 r
.02 w
.6051 .61009 m
.53584 .5748 L
s
P
p
0 1 1 r
.02 w
.6051 .61009 m
.66006 .66505 L
s
P
p
0 1 1 r
.02 w
.71367 .50151 m
.76863 .55648 L
s
P
p
0 1 1 r
.02 w
.71367 .50151 m
.67838 .43226 L
s
P
p
1 .6 0 r
.018 w
.65078 .5472 m
.6051 .61009 L
s
P
p
1 .6 0 r
.018 w
.65078 .5472 m
.71367 .50151 L
s
P
p
0 1 1 r
.02 w
.7475 .39739 m
.67824 .43267 L
s
P
p
0 1 1 r
.02 w
.7475 .39739 m
.82427 .38523 L
s
P
p
0 1 1 r
.02 w
.72348 .24573 m
.80025 .23357 L
s
P
p
0 1 1 r
.02 w
.72348 .24573 m
.64671 .23357 L
s
P
p
1 .6 0 r
.018 w
.72348 .32346 m
.7475 .39739 L
s
P
p
1 .6 0 r
.018 w
.72348 .32346 m
.72348 .24573 L
s
P
p
.8 1 0 r
.01 w
.46757 .36399 m
.23672 .24637 L
s
P
p
.8 1 0 r
.01 w
.46757 .36399 m
.23672 .48162 L
s
P
p
.8 1 0 r
.01 w
.46757 .36399 m
.42704 .6199 L
s
P
p
.8 1 0 r
.01 w
.46757 .36399 m
.65078 .5472 L
s
P
p
.8 1 0 r
.01 w
.46757 .36399 m
.72348 .32346 L
s
P
p
0 1 1 r
.02 w
.27652 .24573 m
.35329 .23357 L
s
P
p
0 1 1 r
.02 w
.27652 .24573 m
.19975 .23357 L
s
P
p
0 1 1 r
.02 w
.2525 .39739 m
.17573 .38523 L
s
P
p
0 1 1 r
.02 w
.2525 .39739 m
.32176 .43267 L
s
P
p
1 .6 0 r
.018 w
.27652 .32346 m
.27652 .24573 L
s
P
p
1 .6 0 r
.018 w
.27652 .32346 m
.2525 .39739 L
s
P
p
0 1 1 r
.02 w
.28633 .50151 m
.32162 .43226 L
s
P
p
0 1 1 r
.02 w
.28633 .50151 m
.23137 .55648 L
s
P
p
0 1 1 r
.02 w
.3949 .61009 m
.33994 .66505 L
s
P
p
0 1 1 r
.02 w
.3949 .61009 m
.46416 .5748 L
s
P
p
1 .6 0 r
.018 w
.34922 .5472 m
.28633 .50151 L
s
P
p
1 .6 0 r
.018 w
.34922 .5472 m
.3949 .61009 L
s
P
p
0 1 1 r
.02 w
.49903 .64392 m
.46374 .57466 L
s
P
p
0 1 1 r
.02 w
.49903 .64392 m
.51119 .72069 L
s
P
p
0 1 1 r
.02 w
.65069 .6199 m
.66285 .69667 L
s
P
p
0 1 1 r
.02 w
.65069 .6199 m
.66285 .54313 L
s
P
p
1 .6 0 r
.018 w
.57296 .6199 m
.49903 .64392 L
s
P
p
1 .6 0 r
.018 w
.57296 .6199 m
.65069 .6199 L
s
P
p
0 1 1 r
.02 w
.73926 .55554 m
.66249 .54339 L
s
P
p
0 1 1 r
.02 w
.73926 .55554 m
.80852 .59083 L
s
P
p
0 1 1 r
.02 w
.80897 .41874 m
.87823 .45402 L
s
P
p
0 1 1 r
.02 w
.80897 .41874 m
.75401 .36377 L
s
P
p
1 .6 0 r
.018 w
.76328 .48162 m
.73926 .55554 L
s
P
p
1 .6 0 r
.018 w
.76328 .48162 m
.80897 .41874 L
s
P
p
0 1 1 r
.02 w
.80897 .30925 m
.75401 .36421 L
s
P
p
0 1 1 r
.02 w
.80897 .30925 m
.87823 .27396 L
s
P
p
0 1 1 r
.02 w
.73926 .17244 m
.80852 .13715 L
s
P
p
0 1 1 r
.02 w
.73926 .17244 m
.66249 .1846 L
s
P
p
1 .6 0 r
.018 w
.76328 .24637 m
.80897 .30925 L
s
P
p
1 .6 0 r
.018 w
.76328 .24637 m
.73926 .17244 L
s
P
p
.8 1 0 r
.01 w
.53243 .36399 m
.27652 .32346 L
s
P
p
.8 1 0 r
.01 w
.53243 .36399 m
.34922 .5472 L
s
P
p
.8 1 0 r
.01 w
.53243 .36399 m
.57296 .6199 L
s
P
p
.8 1 0 r
.01 w
.53243 .36399 m
.76328 .48162 L
s
P
p
.8 1 0 r
.01 w
.53243 .36399 m
.76328 .24637 L
s
P
p
0 1 1 r
.02 w
.31418 .31056 m
.38343 .27527 L
s
P
p
0 1 1 r
.02 w
.31418 .31056 m
.2374 .32272 L
s
P
p
0 1 1 r
.02 w
.3382 .46221 m
.26142 .47437 L
s
P
p
0 1 1 r
.02 w
.3382 .46221 m
.41497 .47437 L
s
P
p
1 .6 0 r
.018 w
.3382 .38448 m
.31418 .31056 L
s
P
p
1 .6 0 r
.018 w
.3382 .38448 m
.3382 .46221 L
s
P
p
0 1 1 r
.02 w
.40255 .55079 m
.41471 .47402 L
s
P
p
0 1 1 r
.02 w
.40255 .55079 m
.36726 .62005 L
s
P
p
0 1 1 r
.02 w
.53936 .6205 m
.50407 .68975 L
s
P
p
0 1 1 r
.02 w
.53936 .6205 m
.59432 .56553 L
s
P
p
1 .6 0 r
.018 w
.47647 .57481 m
.40255 .55079 L
s
P
p
1 .6 0 r
.018 w
.47647 .57481 m
.53936 .6205 L
s
P
p
0 1 1 r
.02 w
.64885 .6205 m
.59388 .56553 L
s
P
p
0 1 1 r
.02 w
.64885 .6205 m
.68413 .68975 L
s
P
p
0 1 1 r
.02 w
.78565 .55079 m
.82094 .62005 L
s
P
p
0 1 1 r
.02 w
.78565 .55079 m
.77349 .47402 L
s
P
p
1 .6 0 r
.018 w
.71173 .57481 m
.64885 .6205 L
s
P
p
1 .6 0 r
.018 w
.71173 .57481 m
.78565 .55079 L
s
P
p
0 1 1 r
.02 w
.85001 .46221 m
.77324 .47437 L
s
P
p
0 1 1 r
.02 w
.85001 .46221 m
.92678 .47437 L
s
P
p
0 1 1 r
.02 w
.87403 .31056 m
.9508 .32272 L
s
P
p
0 1 1 r
.02 w
.87403 .31056 m
.80477 .27527 L
s
P
p
1 .6 0 r
.018 w
.85001 .38448 m
.85001 .46221 L
s
P
p
1 .6 0 r
.018 w
.85001 .38448 m
.87403 .31056 L
s
P
p
0 1 1 r
.02 w
.84019 .20643 m
.80491 .27569 L
s
P
p
0 1 1 r
.02 w
.84019 .20643 m
.89516 .15147 L
s
P
p
0 1 1 r
.02 w
.73162 .09786 m
.78659 .0429 L
s
P
p
0 1 1 r
.02 w
.73162 .09786 m
.66237 .13315 L
s
P
p
1 .6 0 r
.018 w
.77731 .16074 m
.84019 .20643 L
s
P
p
1 .6 0 r
.018 w
.77731 .16074 m
.73162 .09786 L
s
P
p
.8 1 0 r
.01 w
.5941 .34395 m
.3382 .38448 L
s
P
p
.8 1 0 r
.01 w
.5941 .34395 m
.47647 .57481 L
s
P
p
.8 1 0 r
.01 w
.5941 .34395 m
.71173 .57481 L
s
P
p
.8 1 0 r
.01 w
.5941 .34395 m
.85001 .38448 L
s
P
p
.8 1 0 r
.01 w
.5941 .34395 m
.77731 .16074 L
s
P
p
.2 0 1 r
.014 w
.5 .15927 m
.4059 .34395 L
s
P
p
.2 0 1 r
.014 w
.5 .15927 m
.46757 .36399 L
s
P
p
.2 0 1 r
.014 w
.5 .15927 m
.53243 .36399 L
s
P
p
.2 0 1 r
.014 w
.5 .15927 m
.5941 .34395 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.208113 0.200176 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.106688 0.952381 [
[ 0 0 0 0 ]
[ 1 .73901 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .73901 L
0 .73901 L
closepath
clip
newpath
p
P
p
.2 1 0 r
.02 w
.36326 .33378 m
.10051 .1999 L
s
P
p
.2 1 0 r
.02 w
.36326 .33378 m
.49714 .59653 L
s
P
p
.2 1 0 r
.02 w
.36326 .33378 m
.40939 .04252 L
s
P
p
.2 1 0 r
.02 w
.36326 .33378 m
.15474 .5423 L
s
P
p
.2 1 0 r
.02 w
.36326 .33378 m
.65452 .28765 L
s
P
p
.2 1 0 r
.02 w
.31233 .43374 m
.44621 .69649 L
s
P
p
.2 1 0 r
.02 w
.31233 .43374 m
.35846 .14247 L
s
P
p
.2 1 0 r
.02 w
.31233 .43374 m
.10381 .64226 L
s
P
p
.2 1 0 r
.02 w
.31233 .43374 m
.60359 .38761 L
s
P
p
.2 1 0 r
.02 w
.31233 .43374 m
.04958 .29986 L
s
P
p
.2 1 0 r
.02 w
.41229 .38281 m
.45842 .09154 L
s
P
p
.2 1 0 r
.02 w
.41229 .38281 m
.20377 .59133 L
s
P
p
.2 1 0 r
.02 w
.41229 .38281 m
.70355 .33667 L
s
P
p
.2 1 0 r
.02 w
.41229 .38281 m
.14954 .24893 L
s
P
p
.2 1 0 r
.02 w
.41229 .38281 m
.54617 .64556 L
s
P
p
0 1 .4 r
.012 w
.35403 .39203 m
.36326 .33378 L
s
P
p
0 1 .4 r
.012 w
.35403 .39203 m
.31233 .43374 L
s
P
p
0 1 .4 r
.012 w
.35403 .39203 m
.41229 .38281 L
s
P
p
.2 1 0 r
.02 w
.58771 .38281 m
.45383 .64556 L
s
P
p
.2 1 0 r
.02 w
.58771 .38281 m
.85046 .24893 L
s
P
p
.2 1 0 r
.02 w
.58771 .38281 m
.29645 .33667 L
s
P
p
.2 1 0 r
.02 w
.58771 .38281 m
.79623 .59133 L
s
P
p
.2 1 0 r
.02 w
.58771 .38281 m
.54158 .09154 L
s
P
p
.2 1 0 r
.02 w
.68767 .43374 m
.95042 .29986 L
s
P
p
.2 1 0 r
.02 w
.68767 .43374 m
.39641 .38761 L
s
P
p
.2 1 0 r
.02 w
.68767 .43374 m
.89619 .64226 L
s
P
p
.2 1 0 r
.02 w
.68767 .43374 m
.64154 .14247 L
s
P
p
.2 1 0 r
.02 w
.68767 .43374 m
.55379 .69649 L
s
P
p
.2 1 0 r
.02 w
.63674 .33378 m
.34548 .28765 L
s
P
p
.2 1 0 r
.02 w
.63674 .33378 m
.84526 .5423 L
s
P
p
.2 1 0 r
.02 w
.63674 .33378 m
.59061 .04252 L
s
P
p
.2 1 0 r
.02 w
.63674 .33378 m
.50286 .59653 L
s
P
p
.2 1 0 r
.02 w
.63674 .33378 m
.89949 .1999 L
s
P
p
0 1 .4 r
.012 w
.64597 .39203 m
.58771 .38281 L
s
P
p
0 1 .4 r
.012 w
.64597 .39203 m
.68767 .43374 L
s
P
p
0 1 .4 r
.012 w
.64597 .39203 m
.63674 .33378 L
s
P
p
1 0 .6 r
.02 w
.5 .24607 m
.35403 .39203 L
s
P
p
1 0 .6 r
.02 w
.5 .24607 m
.64597 .39203 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.208113 0.39418 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.116641 1.23328 0.030832 1.23328 [
[ 0 0 0 0 ]
[ 1 1.29495 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.29495 L
0 1.29495 L
closepath
clip
newpath
p
P
p
0 1 1 r
.002 w
.5 .76248 m
.93752 .90464 L
s
P
p
0 1 1 r
.002 w
.5 .76248 m
.2296 .39031 L
s
P
p
0 1 1 r
.002 w
.5 .76248 m
.5 1.22251 L
s
P
p
0 1 1 r
.002 w
.5 .76248 m
.7704 .39031 L
s
P
p
0 1 1 r
.002 w
.5 .76248 m
.06248 .90464 L
s
P
p
0 .4 1 r
.006 w
.5 .07243 m
.5 .76248 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.208113 0.588183 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.266248 1.5325 0.0383124 1.5325 [
[ 0 0 0 0 ]
[ 1 1.60912 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.60912 L
0 1.60912 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.5 .78645 m
.93501 1.38519 L
s
P
p
.2 0 1 r
.002 w
.5 .78645 m
.2713 .08259 L
s
P
p
.2 0 1 r
.002 w
.5 .78645 m
.5 1.52653 L
s
P
p
.2 0 1 r
.002 w
.5 .78645 m
.7287 .08259 L
s
P
p
.2 0 1 r
.002 w
.5 .78645 m
.06499 1.38519 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.208113 0.782187 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0149073 0.952381 [
[ 0 0 0 0 ]
[ 1 .9822 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .9822 L
0 .9822 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.5 .37853 m
.05816 .05752 L
s
P
p
.2 0 1 r
.002 w
.5 .37853 m
.5 .92467 L
s
P
p
.2 0 1 r
.002 w
.5 .37853 m
.94184 .05752 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.208113 0.97619 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.470223 1.94045 0.0485112 1.94045 [
[ 0 0 0 0 ]
[ 1 2.03747 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 2.03747 L
0 2.03747 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.30159 1.3091 m
.13667 1.0821 L
s
P
p
0 1 1 r
.016 w
.30159 1.3091 m
.07459 1.14417 L
s
P
p
0 1 1 r
.016 w
.30159 1.70591 m
.07459 1.87083 L
s
P
p
0 1 1 r
.016 w
.30159 1.70591 m
.13667 1.93291 L
s
P
p
0 1 1 r
.016 w
.69841 1.70591 m
.86333 1.93291 L
s
P
p
0 1 1 r
.016 w
.69841 1.70591 m
.92541 1.87083 L
s
P
p
0 1 1 r
.016 w
.69841 1.3091 m
.92541 1.14417 L
s
P
p
0 1 1 r
.016 w
.69841 1.3091 m
.86333 1.0821 L
s
P
p
0 1 1 r
.016 w
.5 1.5075 m
.30159 1.3091 L
s
P
p
0 1 1 r
.016 w
.5 1.5075 m
.30159 1.70591 L
s
P
p
0 1 1 r
.016 w
.5 1.5075 m
.69841 1.70591 L
s
P
p
0 1 1 r
.016 w
.5 1.5075 m
.69841 1.3091 L
s
P
p
.2 1 0 r
.014 w
.5 .66574 m
.5 1.5075 L
s
P
p
0 1 .4 r
.004 w
.5 .10456 m
.5 .66574 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.402116 0.200176 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0370116 0.952381 [
[ 0 0 0 0 ]
[ 1 .87836 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .87836 L
0 .87836 L
closepath
clip
newpath
p
P
p
0 1 1 r
.01 w
.3652 .36183 m
.41509 .04684 L
s
P
p
0 1 1 r
.01 w
.3652 .36183 m
.13969 .13632 L
s
P
p
0 1 1 r
.01 w
.3652 .36183 m
.05021 .41171 L
s
P
p
0 1 1 r
.01 w
.3652 .36183 m
.22041 .64598 L
s
P
p
0 1 1 r
.01 w
.5 .54737 m
.18501 .59726 L
s
P
p
0 1 1 r
.01 w
.5 .54737 m
.35522 .83152 L
s
P
p
0 1 1 r
.01 w
.5 .54737 m
.64478 .83152 L
s
P
p
0 1 1 r
.01 w
.5 .54737 m
.81499 .59726 L
s
P
p
0 1 1 r
.01 w
.6348 .36183 m
.77959 .64598 L
s
P
p
0 1 1 r
.01 w
.6348 .36183 m
.94979 .41171 L
s
P
p
0 1 1 r
.01 w
.6348 .36183 m
.86031 .13632 L
s
P
p
0 1 1 r
.01 w
.6348 .36183 m
.58491 .04684 L
s
P
p
0 1 .4 r
.014 w
.5 .40563 m
.3652 .36183 L
s
P
p
0 1 .4 r
.014 w
.5 .40563 m
.5 .54737 L
s
P
p
0 1 .4 r
.014 w
.5 .40563 m
.6348 .36183 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.402116 0.39418 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.230865 0.952381 [
[ 0 0 0 0 ]
[ 1 .49065 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .49065 L
0 .49065 L
closepath
clip
newpath
p
P
p
1 0 .6 r
.002 w
.16788 .18707 m
.33601 .2137 L
s
P
p
1 0 .6 r
.002 w
.16788 .18707 m
.09059 .03539 L
s
P
p
1 0 .6 r
.002 w
.16788 .18707 m
.09059 .33874 L
s
P
p
1 0 .6 r
.002 w
.16788 .18707 m
.33601 .16044 L
s
P
p
1 0 .6 r
.002 w
.17621 .23967 m
.34434 .21304 L
s
P
p
1 0 .6 r
.002 w
.17621 .23967 m
.05584 .1193 L
s
P
p
1 0 .6 r
.002 w
.17621 .23967 m
.14958 .4078 L
s
P
p
1 0 .6 r
.002 w
.17621 .23967 m
.32788 .16239 L
s
P
p
1 0 .6 r
.002 w
.20039 .28713 m
.35206 .20984 L
s
P
p
1 0 .6 r
.002 w
.20039 .28713 m
.04871 .20984 L
s
P
p
1 0 .6 r
.002 w
.20039 .28713 m
.22702 .45526 L
s
P
p
1 0 .6 r
.002 w
.20039 .28713 m
.32076 .16676 L
s
P
p
.8 0 1 r
.008 w
.3381 .18707 m
.16788 .18707 L
s
P
p
.8 0 1 r
.008 w
.3381 .18707 m
.17621 .23967 L
s
P
p
.8 0 1 r
.008 w
.3381 .18707 m
.20039 .28713 L
s
P
p
1 0 .6 r
.002 w
.79961 .28713 m
.67924 .16676 L
s
P
p
1 0 .6 r
.002 w
.79961 .28713 m
.77298 .45526 L
s
P
p
1 0 .6 r
.002 w
.79961 .28713 m
.95129 .20984 L
s
P
p
1 0 .6 r
.002 w
.79961 .28713 m
.64794 .20984 L
s
P
p
1 0 .6 r
.002 w
.82379 .23967 m
.67212 .16239 L
s
P
p
1 0 .6 r
.002 w
.82379 .23967 m
.85042 .4078 L
s
P
p
1 0 .6 r
.002 w
.82379 .23967 m
.94416 .1193 L
s
P
p
1 0 .6 r
.002 w
.82379 .23967 m
.65566 .21304 L
s
P
p
1 0 .6 r
.002 w
.83212 .18707 m
.66399 .16044 L
s
P
p
1 0 .6 r
.002 w
.83212 .18707 m
.90941 .33874 L
s
P
p
1 0 .6 r
.002 w
.83212 .18707 m
.90941 .03539 L
s
P
p
1 0 .6 r
.002 w
.83212 .18707 m
.66399 .2137 L
s
P
p
.8 0 1 r
.008 w
.6619 .18707 m
.79961 .28713 L
s
P
p
.8 0 1 r
.008 w
.6619 .18707 m
.82379 .23967 L
s
P
p
.8 0 1 r
.008 w
.6619 .18707 m
.83212 .18707 L
s
P
p
.8 1 0 r
.016 w
.5 .13446 m
.3381 .18707 L
s
P
p
.8 1 0 r
.016 w
.5 .13446 m
.6619 .18707 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.402116 0.588183 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.164769 1.32954 0.0332384 1.32954 [
[ 0 0 0 0 ]
[ 1 1.39601 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.39601 L
0 1.39601 L
closepath
clip
newpath
p
P
p
1 0 0 r
.014 w
.5 1.17917 m
.77051 .80684 L
s
P
p
1 0 0 r
.014 w
.5 1.17917 m
.0623 1.32138 L
s
P
p
1 0 0 r
.014 w
.5 1.17917 m
.9377 1.32138 L
s
P
p
1 0 0 r
.014 w
.5 1.17917 m
.22949 .80684 L
s
P
p
.2 0 1 r
.02 w
.5 .44281 m
.5 1.17917 L
s
P
p
0 .4 1 r
.012 w
.5 .07463 m
.5 .44281 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.402116 0.782187 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0787115 1.15742 0.0289356 1.15742 [
[ 0 0 0 0 ]
[ 1 1.21529 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.21529 L
0 1.21529 L
closepath
clip
newpath
p
P
p
.8 1 0 r
.002 w
.5 .82813 m
.06077 1.14725 L
s
P
p
.8 1 0 r
.002 w
.5 .82813 m
.93923 1.14725 L
s
P
p
0 1 .4 r
.016 w
.5 .28521 m
.5 .82813 L
s
P
p
.8 1 0 r
.014 w
.5 .06805 m
.5 .28521 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.402116 0.97619 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.124671 0.952381 [
[ 0 0 0 0 ]
[ 1 .70304 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .70304 L
0 .70304 L
closepath
clip
newpath
p
P
p
1 0 .6 r
.016 w
.5 .20482 m
.09616 .0736 L
s
P
p
1 0 .6 r
.016 w
.5 .20482 m
.5 .62944 L
s
P
p
1 0 .6 r
.016 w
.5 .20482 m
.90384 .0736 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{438, 258},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006f00010PP10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0]`000?l0]`000?l0]`000?l0]`000?l0
]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`0007`00T`A009<o`0V0000OP02C@d00TfO0003
U@0008D00020009<2@02C:4000>E0000Q@0008800Td5009=>P000d80000W0003@P0003`000>E0000
Q@0008@00T`00`1<C00l0003@P0002L000=20000?0000iD000250000Q@03CCh000=200009@000d80
000m0003U@0008D00023009<0`02C3d000=200008`000d80000n0003U@0008D00021009=1`02CC`0
00=200008@000d80000o0003U@0008D0001o009<2`02C3X000=200008@000d80000o0003U@0008D0
001l009=00C6CDe=2P02C@04aTe=CCL000=200007`000d8000100003U@0003/00[@Z0003]00001/0
001g00E<0P001<H0000:C08000C600001D`c0003@P0001d000=20000@@000iD0000m0003]00002H0
00>d0000700007801Dd60003CLH000802Td20003aTd000H01Dd_0003@P0001/000=20000@P000iD0
000n0003]00002@000>d00007@0006d01D`:00I<2P000dc6C002C0/01D`Z0003@P0001/000=20000
@P000iD0000o0003]000028000>d00007P0006X00dd=00==0P000lH0000;0004aP00009=3P02CBT0
00=200006@000d8000130003U@00040000<A]0007`000k@A000P0000NP000d`000020003aP0000/0
00?600000P000d`0000h0003@P0001L000=20000A0000iD0001000044@2d]1`00[@00`0A000P0000
<@03CDD000==000010000lH000090003aP0000@000==0000>0000d80000E0003@P0004D000>E0000
?`000a4000020003]00001P000>d00000P000a40000N0000<0001D`0C01<04<000=<00001@000lH0
00090003aP0000D000=<0000=`000d80000E0003@P0004D000>E0000>P02]08000<A000010000k@0
000F0003]00000@000<A00000[@K0000;P02C@0304e=008000==0000?`000dd000060003aP0000T0
00?600001P000dd0000g0003@P0001<000=20000AP000iD0000c0003]00000H00[@W00034KBd00L0
00>d00004`0002d000M<0000C01<00800T`n0003C00000P000?600001`000lH000080003C00003L0
00=200004@000d8000170003U@0003@000>d00001000117O0;@B0003C000014000>dga401P000k@0
000D0000:`02C@@000==04d010000dd0000j0003C@0000T000<A00001`000a4000090003C@0003L0
00=200003`000d8000180003U@0003D000Bd00000Q420003gP0A00>d3P000dd0000=00>d00@AgP00
0Q430003]00001D0000Z0003C00000<000A<001<1@02C3T000=<00002P000a40000700034@0000X0
00=<0000=P000d80000?0003@P0004P000>E0000=P000k@04@050003ga4000800k@:00=<2`03]0<0
00?O00000`000a40]00H000060001;@00;@<009=1P001Dd0001=00H000==00002`000k@0]00W0003
C@0000`000<A00001@000a40000<0003C@0003H000=200003@000d8000190003U@0003L000<A0000
10000a7N000?00==40000mhA000500034@0001L0000H0003]02d00`000=<00001@000d`000020003
C00000D000=<00002P000k@0]00V0003C00000d000<A00001@000a40000=0003C00003H000=20000
2`000d80001:0003U@0003L000>d000010000a40g`0>0003C01<009<3P000ml04@060003]00001L0
000I0003aP0000T00Td80003C@00008000==00001P02C@/000?6000090000dd0000>00034@0000D0
00<A00003P000dd0000f0003@P0000T000=20000B`000iD0000h0003]00000<000@A003N3@02C@03
04e=00d000GN00004@040003]00001P0000I0003aP0000P000=<000020000d`000030003C00000L0
00=<000020000lH0000S0003C000010000<A00000`000a40000@0003C00003D000=200002@000d80
001;0003U@0003P000>d0;@01K@00a6d]004]0L000M<04`0C01<00L01;@00mnd4@02]0064KBd]02d
6P0001T000?600001`000dd000080003C@0000@000==000020000dd000070003aP0003H000<A0000
0`000a4000190003@P0000L000=20000C0000iD0000i0004]00000;N00D04@00gP0:0007C@1=04d0
C@0:0005gP004@000]h40003]00001P0000I0003aP0000D00T`;0003C00000@000=<00002@02C0L0
00?60000=P00114002<200034@0004X000=200001@000d80001=0003U@0003T000Rd00004@3O4@<0
00?O00001P001T`004`0C08000=<00001P001=l00002g`8000@A002d6`0001T000?6000010000dd0
000;0003C@0000D000==00002P000dd000040003aP0003L000DA02<04@1>0003@P0000<000=20000
CP000iD0000d00>d0P02]0030140008000<Ag]h00P001=h0];@40004C@00C@8000==04d01002]004
0=h000;N00<A00000P001140];@200:d5P0001T000?600000`000d`0000;0003C00000H000=<0000
2`000d`000030003aP0003L000DA02<04@1>0003@P0000<000=20000CP000iD0000f00Bd00<04@00
0`0011400=l3]0D000E<0000C0020004C000C0D000CO]=oO0P000a40000300034@2d00>d5`0001T0
00?600000P000dd0000<0003C@0000H000==000030000dd000020003aP0003L000DA02<04@1?0005
@P000480D@000iD0000b00>d00<A00000P000a40000300>d00<A0=h00]h40005C@0004d00P0014d0
04d400?N00D04KBd4@0600034@00008000@A];Bd4`0001T000?600000T`?0003C00000H000=<0000
3@02C08000?60000>0000a4S4@1A0003@P12058000>E0000;`03]0<000<A00000P000k@00003]0?O
00@A00000]l20003C000008000A<001<0`000d`00002g`<000@AgmoO0k@30003]000008000@A0000
0k@@00006@000lH0C@0@0003C@0000P000==00003P000dd0aP0j00034B<A05001D9A0003U@0003D0
00<A00000`000k@0000200054@0001401]h01Dd0001=00<000I=0000C@07gP8000<A00000`000k@0
000200034@0001D0000I0003aT`0010000=<000020000d`0000?0003C<H003T000<A8a40C@03@P80
00=200000d9>0003U@0003D000<A000010001;@0014400034@0000?O00I<gmoO04`40005C=oOgd`0
0ml300054@0001400`000k@0000300034@0001D0000H0004aTg6aPL000>d00001P000dd000080003
C@0000L000>d00001@000lI=aP0j00038`0004T00d850003@P0000<00d9;0003U@0003H000<A0000
1002]0034MkN00;N00<Ag]h00`000mh00002gP03CMkN00;N00E=g]h0gP0300ON00@A0;Bd1P000a40
000E00005`000lH0000200?610000k@000050003C00000X000=<00001P000k@0000200?60`000lH0
000g00038`0004H00d880003@P0000H00d980003U@0003H000<A00001Ml00k@A000400034@0000OO
00I<g`00gd`7g`8000<A00000P07g`8000<A00005P0001D00/H80005a[BdaP000[@50003C@0000X0
00==00001002]003a[C600;61`02aSL000<A0000@`03@P/000=200002@03@TD000>E0000=P02gPBd
00<0]1401P03gP030=h000?N00<0g]h00P02gP050=kN0=h00P03gPD000<A0;@00k@3gQP0000C00;6
3@02aPL000=<00002P000d`0000600;63002aS@00a5100=23P000d80000<00=2@P000iD0000f0003
4@0000<00[@00a6d000400054@00g`000ml20009g`3Og`3O0=l000?O0`000a4000020003]16d00:d
10000a40000F00004P000lH0000>0003a[@000@000==000030000dd000040003]00000h000?60000
6@000dd0000D00054@0A01405@000dd0000U00=24@000d80000?00=2?`000iD0000f00034@000080
00>d00000P02]0<000<A00000]h20005gP00gP000]h0103N0=h300;N0P000a400002]0D000Fd0000
4@0H00003`02]003aP00010000?600000`000d`0000<0003C00000<000?6000040000lJd]00H0003
C00001<000HA000A014E0003C00002800d8D0003@P0001800d8l0003U@0003H000DA002d4@0700:d
00@04MoO1@02g`070=l00=l0g`0500?O00<A0;@02000116d014H00004@000k@0000@0003aP0000<0
00==000010000k@0]0050003C@0000<000?6000040000k@0000I0003C@00018000@A000A0P000a40
000A0003C@0002000d8G0003@P0001D00d8i0003U@0003H00k@00`0A00080004]140gPD00mh400;N
1@001Mh00=jd00T000DA0;@A]00G00004@000k@0000A0005aP0004`01`02aP03]00000@000E<0000
aP0D0003]00001P000=<00004@001A40000A00<000<A000040000d`0000M00=26P000d80000H00=2
=P000iD0000d00:d00<A00000P000a40000400;O00>d4Ml01`000ml0000300;O1P000ml04@02g`L0
00LA00004@2d01H0000V0004aP00C@@00/H00k@00003aP@000A=0036<@000dd0000?00034@000080
00<A00000P000a40000>0003C@0001/00d8M0003@P0001/00d8c0003U@0003@00[@0116d];@20004
4@0000;N0k@0116d];@400;N1@03gP@000Bdg[@A0[@2gP@000<A0;@00[@0116d];@E00009P001<H0
04`200;62002aP8000A<0036<P000d`0000=00034@0000<000<A00000P000a40000>0003C00001T0
0T8P0003@P0001h00T8a0003U@0003400k@600:d00<A0=l01;@20004g`0000>d00CO0=oO0`001Ml0
g`3O00>d0P001=l00002]0;O00@0];Bd1`03]180000W0003aTg600;63003aP03CLH0038000==0000
30000a40000400034@0000<000<A000030000dd0000l0003@P00054000>E0000?0000kCN00030004
]000gPD000>d00000]h30003gP3N008000?N00000P001Mh0002d00<000?N]0007@0002P000=<0000
40000d`0000c0003C00000/000<A000010000a40000400034@0000/000=<0000?0000d80001A0003
U@0003`000>d4@000P024@030=l000@000CO]03O0P000ml0g`030004g`2dg`@000?O00000Q420003
4K@001d0000X0003aP00010000?60000<`000dd0000:00034@0000D000<A000010000a40000:0003
C@0003d000=20000D@000iD0000l0005]00A0;@00P000a7N00030005gP2d0=h00P000mh0gP030005
gP2d0=h00`000mh04@020004]00A]1h0000W0003aP00018000?600009P02C0/000=<000020000a40
000600034@0000D000<A00002@000d`00009009<<P000d80001A0003U@0003/000Fd000A]0030003
ga40008000?O0;@00P001Ml0003O00@000KO002d0=l30003g`00008000@A002d7@0002L000?60000
4P000lH0000X009=2@000dd0000700034@0000L000<A00001P000a4000070003C@0000P00Tdd0003
@P00054000>E0000>`001;@00;@300>d00<A0=h00P001;@00=h30003gP00008000CN002d0P001=h0
]=h2]08000@A]02d7@0002L000?600004P000lH0000Z009<20000d`000060003aP0000L000<A0000
1P000lH000070003C00000H00T`f0003@P00054000>E0000>`024@:d00@A];CO0P000kCO0002008A
00L0g`00g`3O00<000CO014A0`001Mnd0=l000:d00@A]14A7@0002H000?6000050000lH0000[009=
1P000dd000050003aP0000P000<A00001`000lH000050003C@0000D00Tdh0003@P00054000>E0000
>`03]0<A00H0gP00]1430003]00A008A00@0gP3N0P000a7N4@02]08000DA0;@0gP0200<A0[@M0000
9P000lH0000D0003aP0002d00T`50003C00000<000?600002@000a4000080003aP0000@000=<0000
0`02C3X000=20000D@000iD0000j00:d1@004mlA002d0140]02d0=ndga404Ml00[@01]nd002d4@80
00Fd017O4@050003]00001X0000V0003aP0001@000?60000;`02C@<00Td40003aP0000T000?60000
2@000lH00002009=0`02CC`000=20000D@000iD0000j0003]00000H00Q40102d0;@200Bd01404A4A
0;@0]=jd016d0;@04@090003]00001T0000U0003aP0001H000?60000<002C0800d`00`36000;0003
aP0000T000?600000d`2009<?P000d80001A0003U@0003X000>d000020002a6d];@A]03O]02d00<0
00TA0;@0g`0A]0000[@00a4000080003]00001T0000T0003]<H001L000?6]000<P02C@0504d0CLH0
30000lH0000:009=00<0C@000Te00003@P00054000>E0000>@000k@0000:00044K@A]08A00cN4A40
]02d01404Mh64@`000>d0000600002<000>d0;@060000k@0]00d009<00<0aP000T`:0003aP0000P0
0T`00`360002C48000=20000D@000iD000160003]02d00D00Q401[@0]16d4@@000Bd002d9`0002H0
00>d000050000k@0000g0005aTe=C@000Td80003aP0000H00Td01@1=CDg604@000=20000D@000iD0
001500>d1`001K@04A6d00L000Bd0;Bd9P0007P000=<00001d`40003aP0000801d`20003C00004<0
00=20000D@000iD000140003]02d00T00[@00`2d000700>d9P0007T000==0000100=C@H000==0000
A0000d80001A0003U@0004@00[@:00:d00<0]0002002]2H0001j0003C00000@00d`20003aP1<009<
1`000d`000150003@P00054000>E0000@`000k@0]00;00:d2`02]2D0001k0003C@0000H00Td00lI=
C@080003C@0004H000=20000D@000iD000150003]00000P000>d0;@02`000k@0000T0000O0000d`0
000400=<00C6C4a<1P000d`000170003@P00054000>E0000D0000k@0]00b0000O007C@L01de90003
@P00054000>E0000D0000k@0]00b0000M@07C08000=<00003@000d`00007C48000=20000D@000iD0
00250000LP03C@X000==00002`000dd0000800==?`000d80001A0003U@0008D000200003C00000T0
00=<0000B`000d80001A0003U@0008D000210003C@0000L000==0000C0000d80001A0003U@0008D0
00220003C00000D000=<0000C@000d80001A0003U@0008D000230003C@0000<000==0000CP000d80
001A0003U@0008D000240005C00004`0Y@000iD000250000Q@000dd0C@3o02l0003o0;L0003o0;L0
003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0
003o0;L0003o0;L0003o0;L000260003aP0004H000==00004`000dd0002J0003]`00034000260003
aP0004H000=<00004`000d`0000T009<@@02C34000>g0000<@0008H000?60000A`000dd0000A0003
C@0002L000==0000?@000dd0000a0003]`00034000260003aP0004L000=<00004@000d`0000X009<
>`02C3@000>g0000<@0008H000?60000A`000dd0000A0003C@0002X000==0000=`000dd0000d0003
]`00034000260003aP0004P000=<00003`000d`0000/0003C00003D000=<0000=@000kL0000a0000
QP000lH000180003C@0000l000==0000;@02CC<00Tdh0003]`00034000260003aP0004P000=<0000
3`000d`0000_0003C00002l000=<0000>0000kL0000a0000QP000lH000190003C@0000d000==0000
<@02CBd00Tdk0003]`000340000[0003U@0000/000>E0000BP000lH000190003C00000d000=<0000
<`000d`0000Y0003C00003/000>g0000<@0002/000>E00002`000iD0001:0003aP0004T000==0000
3@000dd0000d0003C@0002L000==0000?0000kL0000a0000:`000iD0000;0003U@0004X000?60000
BP000d`0000;0003C00003H00T`U009<?`000kL0000a0000:`000iD0000;0003U@0004X000?60000
BP000dd0000;0003C@0003P000==00008@000dd0000o0003]`000340000Z0003U@00008000>E0000
0`001ID0002E04`000?60000BP000d`0000;0003C00003T00T`O009<@P000kL0000a0000:P000iD0
00020003U@0000<000>E00000P000iD000190003aP0004/000==00002@000dd0000l0003C@0001/0
00==0000@P000kL0000a0000:P000iD000020003U@0000<000>E00000P000iD000190003aP0004/0
00=<00002@000d`0000m009<6@02C4D000>g0000<@0002X000>E00000P000iD000030003U@000080
00>E0000B@000lH0001;0003C@0000T000==0000?`000dd0000E0003C@0004D000>g0000<@0002L0
00BE002E0`000iD000040003U@00008000BE002EB0000lH0001<0003C00000L000=<0000@@000d`0
000C0003C00004H000>g0000<@0002L000>E09D010000iD000050005U@0009D00P000iD000160003
aP0004`000==00001`000dd00012009=4@02CDT000>g0000<@0002L000>E09D010000iD000050005
U@0009D00P000iD0000f0003]00000d000?600003@000k@0000l0003C00000L000=<0000A0000d`0
000=0003C00004T000>g0000<@0002L000>E09D010000iD000050005U@0009D00P000iD0000f0003
]00000d000?600003@000k@0000m0003C@0000D000==0000AP02C@/00Te<0003]`000340000C00:E
4@0019D009D40003U@0000D000>E00000P000iD0U@0A00:E9P000k@0000<0003aP0000`000>d0000
?P000d`000050003C00004P000=<00001`000d`0001<0003]`000340000E00:E3`0019D009D30003
U@0000H000>E00000P0019D009D>00:E:@000k@0000;0003aP0000/000>d0000?`000dd000050003
C@0004T000==00001@000dd0001=0003U@000340000G00:E3@0019D009D30003U@0000H000>E0000
0P0019D009D<00:E;0000k@0000:0003aP0000X000>d0000@@000d`000030003C00004/00T`3009<
D0000iD0000a00006@02U@/000>E09D010000iD000060003U@00008000BE002E2P02UBh000>d0000
2P000lH0000:0003]000044000==00000`000dd0001=0003C@1=058000>E0000<@0001L00YD200:E
2@000iD0U@040003U@00008000<P00000P001ID0002E008000>E00001P02U@800YD]0003]00000T0
00?600002@000k@000120003C00000<000=<0000CP000d`0001A0003U@000340000I00:E0P02U@H0
00BE002E10001iD0000P02000`001ID0002E008000>E00001002U@800YD`0003]00000P000?60000
20000k@000140005C@0004d0D@000dd0001A0003U@000340000K00:E0P02U@@000BE002E100019D0
020300048000U@<000BE002E1002U@800YDb0003]00000P000?6000020000k@000140005C00004`0
D@000d`0001A0003U@000340000M00:E0P02U@801YD01@2E000P00D000<P09D00P05U@800YD200:E
=@000k@000070003aP0000L000>d0000A@001Dd0001=054000==0000D@000iD0000a00003`02U@h0
0YD200>E00<0U@000P03U@0389FE00FE00@PUIFE0P000iD00002U@800YD>00:E:0000k@000060003
aP0000H000>d0000A`000d`0C01B0003C000054000>E0000<@0001400YD>00:E0P03U@<00YD00b2E
U@07U@0389D0008019D00`2EU@0>00:E:`000k@000050003aP0000D000>d0000B0000dd0C@1B0003
C@00054000>E0000<@0001<00YD>00>E00<0]iD00YD00`0P00090003UB2E00:E00>g00000YD>00:E
;@000k@000050003aP0000D000>d0000B0000d`0C01B0003C000054000>E0000<@0001D00YD;00FE
00Jg000089D;0005UB000;L01ID;00:E<0000k@000040003aP0000@000>d0000BP000dd0001A0003
C@00054000>E0000<@0001L00YD;00:E00D0UIFE8003U@P019D0122E]`02U@/00YDc0003]00000<0
00?600000`000k@0001;0003C000054000=<0000D@000iD0000a00006@02U@T000JE002gUB02U@80
29D200>E00DP0;L0U@0900:E=P000k@000020003aP00008000>d0000C0000dd0001A0003C@000540
00>E0000<@0001/00YD600:E0P000kLP]`05U@H00iD4]`038;L000:E1P02UCP000>d00000P000lH0
00020003]00004/00daB0003C000054000>E0000<@0001d00YD30007U@2E0;LP]`03U@802ID01`2E
UID0]b000P02U@<00YDk0005]0000<H00`000k@0001;0005C@1=04d0D@000dd000140003]00000X0
00>E00002`000k@0000S00007`03U@0409D0]`<00YD00`2EU@03U@8029D30004]`2E00>E?P001;@0
0<H20003]00004/000A<001<0P000d`0001>0003C00004@000>d00002P000iD0000;0003]00002<0
000P00BE00>g09D01YD:0003U@2E00BE00<0]iD00iDo0004]000aP8000>d0000B`0014d004d20003
C@0004h000==0000A@000k@000090003U@0000X000>d0000900001l000FE0000]`02U@0309D00080
00>E09D020000iD0U@030005U@2EUKL00`000iD0000m0005]0360;@0C@001D`0001<00<000=<0000
C@000d`0001100:d0`000k@000080003U@0000T000>d00000[@S00007P0019D00002U@8000>E0000
0P000iD0U@080003U@2E00@000>E00000YD30003U@0003d000>da[@0C@000dd000020003C@000080
00==0000C0000dd000130004]000]0X000>E00002@000k@0]00U00007@001ID0002E00800YD60003
U@2E00H000>E09D01P02U@8000FE0000U@0m00:d00?6];@0C0000d`000020003C000008000=<0000
C0000d`0001400:d00<0]00020000iD000080003]02d02H0000L0005U@0009D00`000iD000050003
U@2E00H000>E09D01`001ID0002E00<000>E0000=`03]08000>d00000kA80003C@0000<000==0000
0`000dd0001;0003C@0004H000>d0;@020000iD0000700>d9`0001/000FE0000U@030003U@2E00L0
00>E09D010000iD0U@070003U@2E00<000FE0000U@0e00>d1@000k@0000300>dA0000d`000040003
C00000@000=<0000BP000d`0001700:d20000iD000070003]00002L0000J0005U@0009D00`0019D0
09D70003U@2E00@000>E09D01`0019D009D30005U@0009D0<@03]0P000>d00001P03]40000==0000
1@000dd000050003C@0004T000==0000B@000k@000050003U@0000H000>d0000:00001T000FE0000
U@030003U@00008000>E00001@000iD0U@020003U@2E00L000>E00000P001ID0002E00<000>E0000
:P04]0/000>d00002@04]3`000=<00001@000d`000050003C00004T000=<0000BP000k@000040003
U@0000@00[@[000060001ID0002E00<000>E000010000iD000040003U@2E008000>E09D01`000iD0
00030005U@0009D00`000iD0000V00>d3`000k@0000=00>d>0000dd000060003C@0000H000==0000
B0000dd0001;0003]00000<000>E00000`000k@0000[00005`001ID0002E00<000>E00001@000iD0
00050006U@2EU@2E1`000iD000050005U@0009D00`000iD0000R00>d4P000k@0000@00>d=0000d`0
00070003C00000L000=<0000A`000d`0001<0003]000008000>E00000P000k@0000/00006P001ID0
002E00T000>E000010001YD0UID0U@L000>E00001P001ID0002E02@00k@E0003]00001<00k@`0003
C@0000P000==000020000dd000160003C@0004d000Fd0000U@030003]00002d0000I0005U@0009D0
2P000iD0000500BE1`000iD000080005U@0009D08@02]1P000>d00005P02]2h000=<000020000d`0
00080003C00004H000=<0000CP001;@009D20003]00002h0000H0005U@0009D030000iD0000400BE
1`000iD000090005U@0009D0>P000k@000150003C@0000T000==00002@000dd000150003C@0004l0
00Fd09D0]00a00005`001ID0002E00d000>E00001004U@H000>E00002`001ID0002E03T000>d0000
A0000d`0000:0003C00000X000=<0000A0000d`0001@0003]9Fd0380000F0003U@00014000>E0000
0`0019D009D60003U@00010000>E0000=P000k@000140003C@0000X000==00002P000dd000140003
C@00054000>E0000<@0001D000>E00004P000iD000020003U@00008000>E00000P000iD0000B0003
U@0003D000>d0000@`000d`0000;0003C00000/000=<0000@`000d`0001A00:d<P0001@000>E0000
50001ID0002E00@000>E00000P000iD0000C0003U@0003@000>d0000@P000dd0000<0003C@0000`0
00==0000@P000dd0001@0004]000]340000C0003U@0001H000>E09D01P0019D009DG0003U@0003<0
00>d0000@@000d`0000=0003C00000d000=<0000@@000d`0001?0003]000008000>d0000;P0002`0
00>E00002@000iD0001;0003]000044000==00003@000dd0000=0003C@00044000==0000CP000k@0
00040003]00002d0000]0003U@0000L000>E0000C0000k@000100003C00000h000=<00003P000d`0
00100003C00004d000>d00001P000k@0000/0000;@000iD000070003U@0004`000>d0000?`000dd0
000?0003C@0000l000==0000?`000dd0001<0003]00000P000>d0000:`0002h000>E00001@000iD0
001=0003]00003l000=<00003`000d`0000?0003C00003l000=<0000B`000k@0000:0003]00002X0
00260003]00003h000==000040000dd0000@0003C@0003h000==0000B@02]0h00[@Z0000QP000k@0
000m0003C000014000=<00004@000d`0000m0003C00004P000>d0;@03P000k@0]00Y0000QP000k@0
000l0003C@00018000==00004P000dd0000l0003C@0004H00[@00`2d000?0003]02d02P000260003
]000054000=<0000D@000d`000150004]000]18000Bd0;Bd9P0008H000>d0000D@000dd0001A0003
C@0004<00[@20003]000018000Bd002d9@0008H000>d0000D@000d`0001A0003C000048000>d0000
0P000k@0000B0005]0000;@0900008H000>d0000D@000dd0001A0003C@00044000>d00000P000k@0
000D0005]0000;@08`0008H000>d0000D@000d`0001A0003C00004D000>d00005P000k@0000T0000
QP000k@0001A0003C@0009P000>d000060000k@0000S0000o`2g0000o`2g0000o`2g0000o`2g0000
o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000
o`2g0000fP000lH0001A0003gP0008D0003J0003aP00054000?O0000Q@000=X000?60000D@000mh0
00250000fP000lH0001A0003g`0008D0000[0003]00000X000>d0000W`000lH0001A0003gP0008D0
000[0003]00000X000>d0000W`000lH0001A0003g`0008D0000[0003]00000X000>d0000W`000lH0
001A0003gP0008D0000[0003]00000X000>d0000W`000lH0001A0003g`0008D0000Z0003]00000`0
00>d0000WP000lH0001A0003gP0008D0000Z0003]00000`000>d0000WP000lH0001A0003g`0008D0
000Z0003]00000`000>d0000WP000lH0001A0003gP0008D0000F0003]000014000>d000030000k@0
000A0003]00008X000?60000D@000ml0002500005`000k@0000@0003]00000`000>d000040000k@0
002;0003aP00054000?N0000Q@0001P000>d00003`000k@0000<0003]00000l000>d0000S0000lH0
001A0003g`0003800b0i00<P500001T000>d00003@000k@0000>0003]00000d000>d0000S@000lH0
001A0003gP0003D00b0c00<P5`0001X000>d000030000k@0000>0003]00000`000>d0000SP000lH0
001A0003]`0003P00b0]00<P6P0001/000>d00002`000k@0000>0003]00000/000>d0000S`000lH0
001A0003]`0003/00b0W00<P7@0001`000>d00002P000k@0000>0003]00000X000>d0000T0000lH0
001A0003]`0003h00b0Q00<P800001d000>d00002@000k@0000>0003]00000T000>d00007@000b00
000l00038000038000?60000D@000kL0001100<P6`0382<0000N0003]00000P000>d00003P000k@0
00080003]00001h000<P0000?0000b00000b0003aP00054000>g0000A00381D00b0V00007`000k@0
00060003]000010000>d00001P000k@0000P0003800003X000<P0000<`000lH0001A0003]`0004L0
0b0?00<P:@00020000>d00001@000k@0000@0003]00000D000>d00008@000b00000j0003800003<0
00=<0000D@000kL0001:00<P2@0382`0000Q0003]00000@000>d000040000k@000040003]00002<0
00<P0000>0000b00000d0003C@00054000>g0000C@0380<00b0_00008P000k@000030003]0000100
00>d00000`000k@0000T0003800003P000<P0000=0000d`0001A0003]`0005000b0b00008`000k@0
00020003]000010000>d00000P000k@0000V0003800003H000<P0000=@000dd0001A0003]`000540
00<P0000<@0002@000Fd0000]00B0005]0000;@090000b0000020003800003H000<P00000`000b00
000_0003C000054000>g0000D@000b00000a00009@000k@0]00D0003]02d02H000<P00000P000b00
000G00GN60000b00000300038000030000==0000D@000kL0001A000380000340000V00:d5002]2P0
00DP0000800F00?O1@03gaD000<P00000P000b00000a0003C000054000>g0000D@000b00000a0000
9003]0:g4P02]`>d9`001B00000P00X0120400?N2`03gP<0120:00038000008000<P0000<P000dd0
001A0003]`00054000<P0000<@0001h01[@30003]02g00:g3003]`030;@000801[@R0004800080<0
2B0300?O4@03g`<02203000580000200=@000d`0001A0003]`00054000<P0000<@0001P01[@80003
]00000<00kL700:g1@000k@0000600Jd7@000b00000=@P;N5`000mi2@P0;@P<000<P0000=0000dd0
001A0003]`00054000<P0000<@0001801[@>0003]00000H00kL0102g]kL70003]00000`01[@A008P
1@000b00800300DP0d800`0P800F008P00<0@T800T8480<000@P000P1002834000=<0000D@000kL0
001A000380000340000?00>d4`000k@0000:0003]`0000T000>d00004@03]1000R04000380000080
0R05@P@P5`03809200@0@T920R03008P0`0283<000==0000D@000kL0001A000380000340000U0003
]00000X000>g00002@000k@0000V008P0P028003021200920R000d8P800N008P0T8280=200<P0200
0P0283D000=<0000D@000kL0001A000380000340000T0003]00000/000>g00002P000k@0000W008P
0P02@P068000848P8P028005@R0002000T800`0P800g0003C@00054000>g0000D@000b00000a0000
90000k@0000;0003]`0000X000>d0000:00480<00T800b00000S0003849200<00b0h0003C0000540
00>g0000D@000b00000a00008`000k@0000<0003]`0000/000>d00009P00120000028003048P02T0
00<P@P000R020003800003D000==0000D@000kL0001A000380000340000S0003]00000`000>g0000
2`000k@0000U00038000008000<P0480;@000d8080030003800003@000=<0000D@000kL0001A0003
80000340000R0003]00000d000>g000030000k@0000T0005800002000P000b00000[000480008080
00<P0000=0000dd0001A0003]`00054000<P0000<@00028000>d00003@000kL0000<0003]00002<0
00<P00000P001200020]0004800080<000<P0000<`000d`0001A0003]`00054000<P0000<@000240
00>d00003P000kL0000=0003]000028000<P00000P001200020]0004800080<000<P000090000b<0
000<0003C@0000`000<S0000@P000kL0001A000380000340000Q0003]00000h000>g00003@000k@0
000Q0003800000<000DP0000800[00058000020010000b00000S00038`0000`000=<000030000b<0
00120003]`00054000<P0000<@00020000>d00003003]004]kBd]0d000>d00009P001B00000P02/0
00DP0000800[00038`0000/000==00002`000b<000130003]`00054000<P0000<@00020000>d0000
1P06]0<000Bd00001[@70003]00002H000DP0000800[000580000200;0000b<0000:0003C00000X0
00<S0000A0000kL0001A000380000340000O0004]00000Jd20000k@0]00800Jd0P000k@0000U0005
80000200:`001B00000P02d000<S00002@000dd0000900038`0004D000>g0000D@000b00000a0000
7@06]0h000>d0;@03P06]2<000<P00000P000b00000Y00038000008000<P0000:P000b<000090003
C00000T000<S0000A@000kL0001A000380000340000J00>d00<0]00040001K@0002d010000>d0000
0k@P00038000008000<P0000:@000b0000020003800002/000<S000020000dd0000800038`0004H0
00>g0000D@000b00000a00007P000k@0000?0005]0000;@040000k@0000S00038000008000<P0000
:@000b0000020003800002`000<S00001`000d`0000700038`0004L000>g0000D@000b00000a0000
7@000k@0000?0003]00000<000>d00003P000k@0000X0003800002L000<P0000<P000b<000070003
C@0000L000<S0000AP000mjggP1B000380000340000M0003]00000l000>d00000`000k@0000>0003
]00002P000<P00009`000b00000c00038`0000H000=<00001P000b<000160005g`000=l0D@000b00
000a000070000k@0000?0003]00000D000>d00003P000k@0000W0003800002L000<P0000=0000b<0
00050003C@0000D000<S0000A@02gPD00]i?000380000340000^0003]00000D000>d0000VP000b<0
00040003C00000@000<S0000A@000ml000070003g`0004`000<P0000<@0002d000>d00001`000k@0
002I00038`0000@000==000010000b<000140003gP0000T000?N0000B`000b00000a0000;@000k@0
00070003]00009X000<S00000`000d`0000300038`0004<00]l=00;OB`000b00000a0000;0000k@0
00090003]00009X000<S00000P000dd0000200038`0004<000?N00003`000mh00018000380000340
000/0003]00000T000>d0000VP000b<000020003C000008000<S0000@@02ga<00]m8000380000340
000[0003]00000/000>d0000VP001B<0001=00<000<S0000@@000mh0000E0003gP0007T0000[0003
]00000/000>d0000V`0012<004`200038`00044000?O00005`000ml0001h0000:P000k@0000=0003
]00009/000DS04d08`1200;N6`02gWP0000Z0003]00000d000>d0000V`001B<0C00S044000?O0000
7@000ml0001e0000:@000k@0000?0003]00009/000<SCB<0@002gR400]ie0000:@000k@0000?0003
]00009X00R<00d`S8`0n0003g`0002<000?O0000LP0002P000>d00004@000k@0002F00<S1@038cX0
00?N00009@000mh0001a0000:0000k@0000A0003]000098012<;00@S=002gbT00]ma00009`000k@0
000C0003]00008h00b<C00<S<0000mh0000[0003gP0006h0003;00<S6@038b/00]l_00;OKP000<L0
12<O00@S9P000mh0000a0003gP0006/0003400<S9`038b8000?O0000<`000ml0001Z0000`P028bd0
0R<O0003gP0003D000?N0000J@000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0
]`000?l0]`000?l0]`000?l0]`000001\
\>"],
  ImageRangeCache->{{{0, 437}, {257, 0}} -> {-0.145065, -0.0740895, 0.0121056,
   0.0121056}, {{11.9375, 88.4375}, {250.875, 174.375}} -> {-0.188855,
   -0.109076, 0.0137256, 0.0137256}, {{96.0625, 172.562}, {250.875, 174.375}}
   -> {-1.34352, -0.109074, 0.0137256, 0.0137256}, {{180.25, 256.688}, {
  250.875, 174.375}} -> {-2.50107, -0.109571, 0.0137368, 0.0137368}, {{
  264.375, 340.875}, {250.875, 174.375}} -> {-3.65372, -0.109075, 0.0137256, 
  0.0137256}, {{348.5, 425}, {250.875, 174.375}} -> {-4.80839, -0.109074, 
  0.0137256, 0.0137256}, {{11.9375, 88.4375}, {166.688, 90.25}} -> {-0.188855,
   -1.26417, 0.0137256, 0.0137256}, {{96.0625, 172.562}, {166.688, 90.25}} ->
   {-1.34504, -1.26562, 0.0137369, 0.0137369}, {{180.25, 256.688}, {166.688, 
  90.25}} -> {-2.50106, -1.26561, 0.0137368, 0.0137368}, {{264.375, 340.875},
   {166.688, 90.25}} -> {-3.65372, -1.26417, 0.0137256, 0.0137256}, {{348.5, 
  425}, {166.688, 90.25}} -> {-4.81272, -1.26561, 0.0137368, 0.0137368}, {{
  11.9375, 88.4375}, {82.5625, 6.0625}} -> {-0.188855, -2.41927, 0.0137256, 
  0.0137256}, {{96.0625, 172.562}, {82.5625, 6.0625}} -> {-1.34352, -2.41927, 
  0.0137256, 0.0137256}, {{180.25, 256.688}, {82.5625, 6.0625}} -> {-2.49861,
   -2.41926, 0.0137256, 0.0137256}, {{264.375, 340.875}, {82.5625, 6.0625}} ->
   {-3.65371, -2.41927, 0.0137256, 0.0137256}, {{348.5, 425}, {82.5625, 
  6.0625}} -> {-4.80839, -2.41927, 0.0137256, 0.0137256}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples (3)", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(bioTable = Table[randBio, {3}, {5}]\), 
    \(\(biomorph[bioTable]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{{4, 3, 6, 10, 8, 6, 3, 1, 10, 1, 7, 2, 1, 5, 8, 2, 3, 1, 9, 2, 5}, {
          1, 3, 9, 6, 1, 2, 3, 8, 6, 6, 9, 2, 9, 8, 2, 2, 5, 1, 5, 4, 4}, {2, 
          4, 3, 2, 1, 2, 2, 7, 3, 3, 5, 1, 4, 7, 1, 7, 3, 1, 8, 4, 2}, {4, 1, 
          9, 2, 7, 9, 5, 9, 6, 9, 7, 3, 6, 7, 2, 7, 1, 4, 10, 9, 1}, {4, 1, 
          6, 8, 8, 4, 1, 7, 4, 2, 3, 4, 5, 6, 9, 7, 4, 6, 3, 5, 10}}, {{1, 3, 
          7, 7, 8, 9, 3, 5, 5, 6, 8, 3, 6, 9, 7, 1, 3, 7, 7, 5, 9}, {1, 3, 1, 
          1, 8, 4, 3, 3, 9, 5, 2, 2, 7, 5, 5, 10, 5, 5, 2, 7, 5}, {4, 4, 10, 
          7, 7, 7, 1, 9, 4, 3, 7, 1, 9, 7, 1, 9, 4, 4, 8, 4, 2}, {1, 4, 7, 7, 
          3, 7, 2, 7, 3, 5, 2, 4, 3, 8, 2, 7, 3, 1, 1, 6, 9}, {2, 2, 3, 8, 6, 
          5, 4, 3, 4, 3, 2, 1, 1, 6, 10, 8, 1, 1, 1, 1, 8}}, {{1, 2, 5, 3, 4, 
          8, 2, 2, 8, 5, 1, 1, 10, 8, 3, 2, 3, 10, 9, 10, 10}, {1, 5, 5, 3, 
          6, 10, 4, 9, 4, 5, 9, 3, 8, 8, 5, 9, 2, 4, 3, 9, 5}, {1, 2, 2, 6, 
          1, 1, 1, 8, 9, 5, 4, 2, 8, 5, 4, 6, 1, 6, 9, 2, 5}, {1, 4, 1, 10, 
          3, 8, 3, 5, 9, 5, 5, 5, 10, 5, 7, 9, 4, 9, 8, 10, 2}, {4, 3, 1, 9, 
          1, 2, 1, 6, 6, 6, 6, 3, 6, 5, 5, 4, 3, 2, 2, 9, 1}}}\)], "Output",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .59259 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0141093 0.190476 [
[ 0 0 0 0 ]
[ 1 .59259 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .59259 L
0 .59259 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0141093 0.200176 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.214286 0.952381 [
[ 0 0 0 0 ]
[ 1 .52381 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .52381 L
0 .52381 L
closepath
clip
newpath
p
P
p
.8 0 1 r
.008 w
.5 .04628 m
.06875 .47753 L
s
P
p
.8 0 1 r
.008 w
.5 .04628 m
.93125 .47753 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.0141093 0.39418 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
P
p
1 0 0 r
.012 w
.5 .5 m
.5 .06223 L
s
P
p
1 0 0 r
.012 w
.5 .5 m
.06223 .5 L
s
P
p
1 0 0 r
.012 w
.5 .5 m
.5 .93777 L
s
P
p
1 0 0 r
.012 w
.5 .5 m
.93777 .5 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.0141093 0.588183 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.21445 1.4289 0.0357225 1.4289 [
[ 0 0 0 0 ]
[ 1 1.50034 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.50034 L
0 1.50034 L
closepath
clip
newpath
p
P
p
1 .6 0 r
.002 w
.5 .09459 m
.07397 1.40576 L
s
P
p
1 .6 0 r
.002 w
.5 .09459 m
.92603 1.40576 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.0141093 0.782187 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0158367 1.03167 0.0257918 1.03167 [
[ 0 0 0 0 ]
[ 1 1.08326 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.08326 L
0 1.08326 L
closepath
clip
newpath
p
P
p
.8 0 1 r
.006 w
.5 .06072 m
.0579 .92839 L
s
P
p
.8 0 1 r
.006 w
.5 .06072 m
.34766 1.02254 L
s
P
p
.8 0 1 r
.006 w
.5 .06072 m
.65234 1.02254 L
s
P
p
.8 0 1 r
.006 w
.5 .06072 m
.9421 .92839 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.0141093 0.97619 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0102553 0.979489 0.0244872 0.979489 [
[ 0 0 0 0 ]
[ 1 1.02846 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.02846 L
0 1.02846 L
closepath
clip
newpath
p
P
p
1 .6 0 r
.018 w
.13542 .52796 m
.10946 .44807 L
s
P
p
1 .6 0 r
.018 w
.13542 .52796 m
.06746 .47859 L
s
P
p
1 .6 0 r
.018 w
.13542 .52796 m
.05142 .52796 L
s
P
p
1 .6 0 r
.018 w
.24042 .85112 m
.17246 .9005 L
s
P
p
1 .6 0 r
.018 w
.24042 .85112 m
.21446 .93101 L
s
P
p
1 .6 0 r
.018 w
.24042 .85112 m
.26638 .93101 L
s
P
p
1 .6 0 r
.018 w
.51532 .6514 m
.58328 .70077 L
s
P
p
1 .6 0 r
.018 w
.51532 .6514 m
.59932 .6514 L
s
P
p
1 .6 0 r
.018 w
.51532 .6514 m
.58328 .60202 L
s
P
p
0 1 .4 r
.01 w
.30532 .6514 m
.13542 .52796 L
s
P
p
0 1 .4 r
.01 w
.30532 .6514 m
.24042 .85112 L
s
P
p
0 1 .4 r
.01 w
.30532 .6514 m
.51532 .6514 L
s
P
p
0 .4 1 r
.012 w
.38319 .41173 m
.30532 .6514 L
s
P
p
1 .6 0 r
.018 w
.30028 .61734 m
.2509 .54938 L
s
P
p
1 .6 0 r
.018 w
.30028 .61734 m
.22039 .59138 L
s
P
p
1 .6 0 r
.018 w
.30028 .61734 m
.22039 .6433 L
s
P
p
1 .6 0 r
.018 w
.5 .89224 m
.45063 .9602 L
s
P
p
1 .6 0 r
.018 w
.5 .89224 m
.5 .97624 L
s
P
p
1 .6 0 r
.018 w
.5 .89224 m
.54937 .9602 L
s
P
p
1 .6 0 r
.018 w
.69972 .61734 m
.77961 .6433 L
s
P
p
1 .6 0 r
.018 w
.69972 .61734 m
.77961 .59138 L
s
P
p
1 .6 0 r
.018 w
.69972 .61734 m
.7491 .54938 L
s
P
p
0 1 .4 r
.01 w
.5 .68223 m
.30028 .61734 L
s
P
p
0 1 .4 r
.01 w
.5 .68223 m
.5 .89224 L
s
P
p
0 1 .4 r
.01 w
.5 .68223 m
.69972 .61734 L
s
P
p
0 .4 1 r
.012 w
.5 .43023 m
.5 .68223 L
s
P
p
1 .6 0 r
.018 w
.48468 .6514 m
.41672 .60202 L
s
P
p
1 .6 0 r
.018 w
.48468 .6514 m
.40068 .6514 L
s
P
p
1 .6 0 r
.018 w
.48468 .6514 m
.41672 .70077 L
s
P
p
1 .6 0 r
.018 w
.75958 .85112 m
.73362 .93101 L
s
P
p
1 .6 0 r
.018 w
.75958 .85112 m
.78554 .93101 L
s
P
p
1 .6 0 r
.018 w
.75958 .85112 m
.82754 .9005 L
s
P
p
1 .6 0 r
.018 w
.86458 .52796 m
.94858 .52796 L
s
P
p
1 .6 0 r
.018 w
.86458 .52796 m
.93254 .47859 L
s
P
p
1 .6 0 r
.018 w
.86458 .52796 m
.89054 .44807 L
s
P
p
0 1 .4 r
.01 w
.69468 .6514 m
.48468 .6514 L
s
P
p
0 1 .4 r
.01 w
.69468 .6514 m
.75958 .85112 L
s
P
p
0 1 .4 r
.01 w
.69468 .6514 m
.86458 .52796 L
s
P
p
0 .4 1 r
.012 w
.61681 .41173 m
.69468 .6514 L
s
P
p
.8 1 0 r
.002 w
.5 .05223 m
.38319 .41173 L
s
P
p
.8 1 0 r
.002 w
.5 .05223 m
.5 .43023 L
s
P
p
.8 1 0 r
.002 w
.5 .05223 m
.61681 .41173 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.208113 0.200176 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0149073 0.952381 [
[ 0 0 0 0 ]
[ 1 .9822 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .9822 L
0 .9822 L
closepath
clip
newpath
p
P
p
1 0 .6 r
.016 w
.5 .37768 m
.05483 .05425 L
s
P
p
1 0 .6 r
.016 w
.5 .37768 m
.5 .92795 L
s
P
p
1 0 .6 r
.016 w
.5 .37768 m
.94517 .05425 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.208113 0.39418 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.248465 1.49693 0.0374232 1.49693 [
[ 0 0 0 0 ]
[ 1 1.57178 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.57178 L
0 1.57178 L
closepath
clip
newpath
p
P
p
0 1 .4 r
.016 w
.5 .22157 m
.15123 1.29497 L
s
P
p
0 1 .4 r
.016 w
.5 .22157 m
.5 1.35021 L
s
P
p
0 1 .4 r
.016 w
.5 .22157 m
.84877 1.29497 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.208113 0.588183 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.442652 0.952381 [
[ 0 0 0 0 ]
[ 1 .06708 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .06708 L
0 .06708 L
closepath
clip
newpath
p
P
p
.8 1 0 r
.008 w
.82901 .04323 m
.83215 .03354 L
s
P
p
.8 1 0 r
.008 w
.84549 .04323 m
.83215 .03354 L
s
P
p
.8 1 0 r
.008 w
.84549 .02385 m
.83215 .03354 L
s
P
p
.8 1 0 r
.008 w
.82901 .02385 m
.83215 .03354 L
s
P
p
1 0 .6 r
.002 w
.70298 .03354 m
.83215 .03354 L
s
P
p
.2 0 1 r
.006 w
.62917 .03354 m
.70298 .03354 L
s
P
p
.8 1 0 r
.008 w
.17099 .02385 m
.16785 .03354 L
s
P
p
.8 1 0 r
.008 w
.15451 .02385 m
.16785 .03354 L
s
P
p
.8 1 0 r
.008 w
.15451 .04323 m
.16785 .03354 L
s
P
p
.8 1 0 r
.008 w
.17099 .04323 m
.16785 .03354 L
s
P
p
1 0 .6 r
.002 w
.29702 .03354 m
.16785 .03354 L
s
P
p
.2 0 1 r
.006 w
.37083 .03354 m
.29702 .03354 L
s
P
p
.2 0 1 r
.014 w
.5 .03354 m
.62917 .03354 L
s
P
p
.2 0 1 r
.014 w
.5 .03354 m
.37083 .03354 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.208113 0.782187 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0671348 0.952381 [
[ 0 0 0 0 ]
[ 1 .81811 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .81811 L
0 .81811 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.006 w
.5 .54261 m
.57829 .04828 L
s
P
p
.2 0 1 r
.006 w
.5 .54261 m
.05406 .76983 L
s
P
p
.2 0 1 r
.006 w
.5 .54261 m
.94594 .76983 L
s
P
p
.2 0 1 r
.006 w
.5 .54261 m
.42171 .04828 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.208113 0.97619 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0960761 0.952381 [
[ 0 0 0 0 ]
[ 1 .76023 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .76023 L
0 .76023 L
closepath
clip
newpath
p
P
p
.8 1 0 r
.006 w
.2816 .47416 m
.05284 .39984 L
s
P
p
.8 1 0 r
.006 w
.2816 .47416 m
.087 .61555 L
s
P
p
.8 1 0 r
.006 w
.2816 .47416 m
.2816 .7147 L
s
P
p
.8 1 0 r
.006 w
.2816 .47416 m
.4762 .61555 L
s
P
p
.8 1 0 r
.006 w
.7184 .47416 m
.5238 .61555 L
s
P
p
.8 1 0 r
.006 w
.7184 .47416 m
.7184 .7147 L
s
P
p
.8 1 0 r
.006 w
.7184 .47416 m
.913 .61555 L
s
P
p
.8 1 0 r
.006 w
.7184 .47416 m
.94716 .39984 L
s
P
p
0 1 1 r
.012 w
.5 .04553 m
.2816 .47416 L
s
P
p
0 1 1 r
.012 w
.5 .04553 m
.7184 .47416 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.402116 0.200176 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0642216 0.952381 [
[ 0 0 0 0 ]
[ 1 .82394 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .82394 L
0 .82394 L
closepath
clip
newpath
p
P
p
0 1 1 r
.004 w
.21337 .15219 m
.15796 .04345 L
s
P
p
0 1 1 r
.004 w
.21337 .15219 m
.12707 .06589 L
s
P
p
0 1 1 r
.004 w
.21337 .15219 m
.10463 .09679 L
s
P
p
0 1 1 r
.004 w
.2009 .16936 m
.1146 .08306 L
s
P
p
0 1 1 r
.004 w
.2009 .16936 m
.09216 .11395 L
s
P
p
0 1 1 r
.004 w
.2009 .16936 m
.08036 .15026 L
s
P
p
.8 1 0 r
.016 w
.26132 .20014 m
.21337 .15219 L
s
P
p
.8 1 0 r
.016 w
.26132 .20014 m
.2009 .16936 L
s
P
p
0 1 1 r
.004 w
.18164 .20716 m
.09534 .12086 L
s
P
p
0 1 1 r
.004 w
.18164 .20716 m
.07289 .15175 L
s
P
p
0 1 1 r
.004 w
.18164 .20716 m
.06109 .18807 L
s
P
p
0 1 1 r
.004 w
.17509 .22734 m
.06634 .17193 L
s
P
p
0 1 1 r
.004 w
.17509 .22734 m
.05454 .20824 L
s
P
p
0 1 1 r
.004 w
.17509 .22734 m
.05454 .24643 L
s
P
p
.8 1 0 r
.016 w
.24206 .23794 m
.18164 .20716 L
s
P
p
.8 1 0 r
.016 w
.24206 .23794 m
.17509 .22734 L
s
P
p
0 1 1 r
.004 w
.16845 .26924 m
.0597 .21383 L
s
P
p
0 1 1 r
.004 w
.16845 .26924 m
.0479 .25015 L
s
P
p
0 1 1 r
.004 w
.16845 .26924 m
.0479 .28833 L
s
P
p
0 1 1 r
.004 w
.16845 .29046 m
.0479 .27136 L
s
P
p
0 1 1 r
.004 w
.16845 .29046 m
.0479 .30955 L
s
P
p
0 1 1 r
.004 w
.16845 .29046 m
.0597 .34586 L
s
P
p
.8 1 0 r
.016 w
.23542 .27985 m
.16845 .26924 L
s
P
p
.8 1 0 r
.016 w
.23542 .27985 m
.16845 .29046 L
s
P
p
.2 0 1 r
.002 w
.37103 .27985 m
.26132 .20014 L
s
P
p
.2 0 1 r
.002 w
.37103 .27985 m
.24206 .23794 L
s
P
p
.2 0 1 r
.002 w
.37103 .27985 m
.23542 .27985 L
s
P
p
0 1 1 r
.004 w
.42731 .64675 m
.34101 .73305 L
s
P
p
0 1 1 r
.004 w
.42731 .64675 m
.3719 .7555 L
s
P
p
0 1 1 r
.004 w
.42731 .64675 m
.40822 .7673 L
s
P
p
0 1 1 r
.004 w
.44749 .65331 m
.39208 .76205 L
s
P
p
0 1 1 r
.004 w
.44749 .65331 m
.42839 .77385 L
s
P
p
0 1 1 r
.004 w
.44749 .65331 m
.46658 .77385 L
s
P
p
.8 1 0 r
.016 w
.45809 .58634 m
.42731 .64675 L
s
P
p
.8 1 0 r
.016 w
.45809 .58634 m
.44749 .65331 L
s
P
p
0 1 1 r
.004 w
.48939 .65994 m
.43398 .76869 L
s
P
p
0 1 1 r
.004 w
.48939 .65994 m
.4703 .78049 L
s
P
p
0 1 1 r
.004 w
.48939 .65994 m
.50849 .78049 L
s
P
p
0 1 1 r
.004 w
.51061 .65994 m
.49151 .78049 L
s
P
p
0 1 1 r
.004 w
.51061 .65994 m
.5297 .78049 L
s
P
p
0 1 1 r
.004 w
.51061 .65994 m
.56602 .76869 L
s
P
p
.8 1 0 r
.016 w
.5 .59297 m
.48939 .65994 L
s
P
p
.8 1 0 r
.016 w
.5 .59297 m
.51061 .65994 L
s
P
p
0 1 1 r
.004 w
.55251 .65331 m
.53342 .77385 L
s
P
p
0 1 1 r
.004 w
.55251 .65331 m
.57161 .77385 L
s
P
p
0 1 1 r
.004 w
.55251 .65331 m
.60792 .76205 L
s
P
p
0 1 1 r
.004 w
.57269 .64675 m
.59178 .7673 L
s
P
p
0 1 1 r
.004 w
.57269 .64675 m
.6281 .7555 L
s
P
p
0 1 1 r
.004 w
.57269 .64675 m
.65899 .73305 L
s
P
p
.8 1 0 r
.016 w
.54191 .58634 m
.55251 .65331 L
s
P
p
.8 1 0 r
.016 w
.54191 .58634 m
.57269 .64675 L
s
P
p
.2 0 1 r
.002 w
.5 .45736 m
.45809 .58634 L
s
P
p
.2 0 1 r
.002 w
.5 .45736 m
.5 .59297 L
s
P
p
.2 0 1 r
.002 w
.5 .45736 m
.54191 .58634 L
s
P
p
0 1 1 r
.004 w
.83155 .29046 m
.9403 .34586 L
s
P
p
0 1 1 r
.004 w
.83155 .29046 m
.9521 .30955 L
s
P
p
0 1 1 r
.004 w
.83155 .29046 m
.9521 .27136 L
s
P
p
0 1 1 r
.004 w
.83155 .26924 m
.9521 .28833 L
s
P
p
0 1 1 r
.004 w
.83155 .26924 m
.9521 .25015 L
s
P
p
0 1 1 r
.004 w
.83155 .26924 m
.9403 .21383 L
s
P
p
.8 1 0 r
.016 w
.76458 .27985 m
.83155 .29046 L
s
P
p
.8 1 0 r
.016 w
.76458 .27985 m
.83155 .26924 L
s
P
p
0 1 1 r
.004 w
.82491 .22734 m
.94546 .24643 L
s
P
p
0 1 1 r
.004 w
.82491 .22734 m
.94546 .20824 L
s
P
p
0 1 1 r
.004 w
.82491 .22734 m
.93366 .17193 L
s
P
p
0 1 1 r
.004 w
.81836 .20716 m
.93891 .18807 L
s
P
p
0 1 1 r
.004 w
.81836 .20716 m
.92711 .15175 L
s
P
p
0 1 1 r
.004 w
.81836 .20716 m
.90466 .12086 L
s
P
p
.8 1 0 r
.016 w
.75794 .23794 m
.82491 .22734 L
s
P
p
.8 1 0 r
.016 w
.75794 .23794 m
.81836 .20716 L
s
P
p
0 1 1 r
.004 w
.7991 .16936 m
.91964 .15026 L
s
P
p
0 1 1 r
.004 w
.7991 .16936 m
.90784 .11395 L
s
P
p
0 1 1 r
.004 w
.7991 .16936 m
.8854 .08306 L
s
P
p
0 1 1 r
.004 w
.78663 .15219 m
.89537 .09679 L
s
P
p
0 1 1 r
.004 w
.78663 .15219 m
.87293 .06589 L
s
P
p
0 1 1 r
.004 w
.78663 .15219 m
.84204 .04345 L
s
P
p
.8 1 0 r
.016 w
.73868 .20014 m
.7991 .16936 L
s
P
p
.8 1 0 r
.016 w
.73868 .20014 m
.78663 .15219 L
s
P
p
.2 0 1 r
.002 w
.62897 .27985 m
.76458 .27985 L
s
P
p
.2 0 1 r
.002 w
.62897 .27985 m
.75794 .23794 L
s
P
p
.2 0 1 r
.002 w
.62897 .27985 m
.73868 .20014 L
s
P
p
0 .4 1 r
.016 w
.5 .32175 m
.37103 .27985 L
s
P
p
0 .4 1 r
.016 w
.5 .32175 m
.5 .45736 L
s
P
p
0 .4 1 r
.016 w
.5 .32175 m
.62897 .27985 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.402116 0.39418 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.863256 2.72651 0.0681628 2.72651 [
[ 0 0 0 0 ]
[ 1 2.86284 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 2.86284 L
0 2.86284 L
closepath
clip
newpath
p
P
p
.8 1 0 r
.002 w
.5 1.39943 m
.09605 .15619 L
s
P
p
.8 1 0 r
.002 w
.5 1.39943 m
.5 2.70665 L
s
P
p
.8 1 0 r
.002 w
.5 1.39943 m
.90395 .15619 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.402116 0.588183 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0671348 0.952381 [
[ 0 0 0 0 ]
[ 1 .81811 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .81811 L
0 .81811 L
closepath
clip
newpath
p
P
p
0 1 1 r
.006 w
.27687 .32608 m
.07769 .05193 L
s
P
p
0 1 1 r
.006 w
.27687 .32608 m
.17216 .64836 L
s
P
p
0 1 1 r
.006 w
.39744 .49203 m
.05857 .49203 L
s
P
p
0 1 1 r
.006 w
.39744 .49203 m
.59662 .76618 L
s
P
p
0 1 1 r
.006 w
.60256 .49203 m
.40338 .76618 L
s
P
p
0 1 1 r
.006 w
.60256 .49203 m
.94143 .49203 L
s
P
p
0 1 1 r
.006 w
.72313 .32608 m
.82784 .64836 L
s
P
p
0 1 1 r
.006 w
.72313 .32608 m
.92231 .05193 L
s
P
p
.8 1 0 r
.002 w
.5 .29074 m
.27687 .32608 L
s
P
p
.8 1 0 r
.002 w
.5 .29074 m
.39744 .49203 L
s
P
p
.8 1 0 r
.002 w
.5 .29074 m
.60256 .49203 L
s
P
p
.8 1 0 r
.002 w
.5 .29074 m
.72313 .32608 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.402116 0.782187 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.148854 1.29771 0.0324427 1.29771 [
[ 0 0 0 0 ]
[ 1 1.36259 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.36259 L
0 1.36259 L
closepath
clip
newpath
p
P
p
1 .6 0 r
.018 w
.41418 .85824 m
.15346 .94295 L
s
P
p
1 .6 0 r
.018 w
.70947 .95418 m
.87061 1.17597 L
s
P
p
1 .6 0 r
.018 w
.70947 .64369 m
.87061 .42191 L
s
P
p
.2 0 1 r
.004 w
.59668 .79894 m
.41418 .85824 L
s
P
p
.2 0 1 r
.004 w
.59668 .79894 m
.70947 .95418 L
s
P
p
.2 0 1 r
.004 w
.59668 .79894 m
.70947 .64369 L
s
P
p
1 .6 0 r
.018 w
.64107 .50943 m
.91521 .50943 L
s
P
p
1 .6 0 r
.018 w
.38987 .32693 m
.30516 .06621 L
s
P
p
1 .6 0 r
.018 w
.29392 .62223 m
.07214 .78336 L
s
P
p
.2 0 1 r
.004 w
.44917 .50943 m
.64107 .50943 L
s
P
p
.2 0 1 r
.004 w
.44917 .50943 m
.38987 .32693 L
s
P
p
.2 0 1 r
.004 w
.44917 .50943 m
.29392 .62223 L
s
P
p
1 .6 0 r
.018 w
.3175 .77105 m
.05677 .68634 L
s
P
p
1 .6 0 r
.018 w
.5 1.02225 m
.5 1.29638 L
s
P
p
1 .6 0 r
.018 w
.6825 .77105 m
.94323 .68634 L
s
P
p
.2 0 1 r
.004 w
.5 .83035 m
.3175 .77105 L
s
P
p
.2 0 1 r
.004 w
.5 .83035 m
.5 1.02225 L
s
P
p
.2 0 1 r
.004 w
.5 .83035 m
.6825 .77105 L
s
P
p
1 .6 0 r
.018 w
.70608 .62223 m
.92786 .78336 L
s
P
p
1 .6 0 r
.018 w
.61013 .32693 m
.69484 .06621 L
s
P
p
1 .6 0 r
.018 w
.35893 .50943 m
.08479 .50943 L
s
P
p
.2 0 1 r
.004 w
.55083 .50943 m
.70608 .62223 L
s
P
p
.2 0 1 r
.004 w
.55083 .50943 m
.61013 .32693 L
s
P
p
.2 0 1 r
.004 w
.55083 .50943 m
.35893 .50943 L
s
P
p
1 .6 0 r
.018 w
.29053 .64369 m
.12939 .42191 L
s
P
p
1 .6 0 r
.018 w
.29053 .95418 m
.12939 1.17597 L
s
P
p
1 .6 0 r
.018 w
.58582 .85824 m
.84654 .94295 L
s
P
p
.2 0 1 r
.004 w
.40332 .79894 m
.29053 .64369 L
s
P
p
.2 0 1 r
.004 w
.40332 .79894 m
.29053 .95418 L
s
P
p
.2 0 1 r
.004 w
.40332 .79894 m
.58582 .85824 L
s
P
p
.2 0 1 r
.018 w
.5 .66587 m
.59668 .79894 L
s
P
p
.2 0 1 r
.018 w
.5 .66587 m
.44917 .50943 L
s
P
p
.2 0 1 r
.018 w
.5 .66587 m
.5 .83035 L
s
P
p
.2 0 1 r
.018 w
.5 .66587 m
.55083 .50943 L
s
P
p
.2 0 1 r
.018 w
.5 .66587 m
.40332 .79894 L
s
P
p
1 0 .6 r
.014 w
.5 .61104 m
.5 .66587 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.402116 0.97619 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.12471 1.24942 0.0312355 1.24942 [
[ 0 0 0 0 ]
[ 1 1.31189 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.31189 L
0 1.31189 L
closepath
clip
newpath
p
P
p
1 0 0 r
.01 w
.23999 .54284 m
.40381 .62631 L
s
P
p
1 0 0 r
.01 w
.23999 .54284 m
.26875 .36125 L
s
P
p
1 0 0 r
.01 w
.23999 .54284 m
.0584 .57161 L
s
P
p
1 0 0 r
.01 w
.23999 .54284 m
.32346 .70666 L
s
P
p
1 0 0 r
.01 w
.23999 1.06286 m
.32346 .89905 L
s
P
p
1 0 0 r
.01 w
.23999 1.06286 m
.0584 1.0341 L
s
P
p
1 0 0 r
.01 w
.23999 1.06286 m
.26875 1.24445 L
s
P
p
1 0 0 r
.01 w
.23999 1.06286 m
.40381 .97939 L
s
P
p
1 0 0 r
.01 w
.76001 1.06286 m
.59619 .97939 L
s
P
p
1 0 0 r
.01 w
.76001 1.06286 m
.73125 1.24445 L
s
P
p
1 0 0 r
.01 w
.76001 1.06286 m
.9416 1.0341 L
s
P
p
1 0 0 r
.01 w
.76001 1.06286 m
.67654 .89905 L
s
P
p
1 0 0 r
.01 w
.76001 .54284 m
.67654 .70666 L
s
P
p
1 0 0 r
.01 w
.76001 .54284 m
.9416 .57161 L
s
P
p
1 0 0 r
.01 w
.76001 .54284 m
.73125 .36125 L
s
P
p
1 0 0 r
.01 w
.76001 .54284 m
.59619 .62631 L
s
P
p
.2 0 1 r
.018 w
.5 .80285 m
.23999 .54284 L
s
P
p
.2 0 1 r
.018 w
.5 .80285 m
.23999 1.06286 L
s
P
p
.2 0 1 r
.018 w
.5 .80285 m
.76001 1.06286 L
s
P
p
.2 0 1 r
.018 w
.5 .80285 m
.76001 .54284 L
s
P
p
.2 1 0 r
.004 w
.5 .55772 m
.5 .80285 L
s
P
p
0 1 .4 r
.016 w
.5 .06744 m
.5 .55772 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{438, 258},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006f00010PP10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0]`000?l0]`000?l0]`000?l0]`000?l0
]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`0008H000<S0000D@000a40001A0003
@P00054000?N0000<@0008H000<S0000D@000a40001A0003@P00054000?O0000<@0008H000<S0000
D@000a40001@00=2DP02gS80002600038`00050000<A0140D@03@U400mlb0000QP000b<0001@0003
4@0A05000T800`12@P1@00?N<P0008H000<S0000D0000a404@1@009200<0@T80D002g`030=l00300
002600038`0004l000DA00004@1>0007@P120480@P1>0005gP3N0=h0<@0008H000<S0000C`001A40
000A04h000M20480@P1204h000GO0=l0g`0a0000QP000b<0001?00054@000140C@001T800480@P80
00=20000B`000mh0gP020003gP0002h0002600038`0004h000<A00000`000a40001:0006@P00@P12
0P000d80001:0004g`00g`8000?O0000;P0008H000<S0000CP000a40000300034@0004T000A20012
0`001480049;0004gP00gP8000?N0000;P0008H000<S0000CP000a40000300034@0004T000A20012
0`001480049;0004g`00g`<000?O0000;@0008H000<S0000C@000a40000500034@0004L000E20000
@P030005@P000480B@001Mh0003N00<000?N0000;@0008H000<S0000C@000a40000500034@0004L0
00E20000@P030005@P000480B@001Ml0003O00<000?O0000;@0008H000<S0000C@000a4000050003
4@0004H000=200000P001D80001200@000=20000AP001Mh0003N00@000?N0000;00008H000<S0000
C0000a40000700034@0004D000=200000P001D80001200@000=20000AP001Ml0003O00@000?O0000
;00008H000<S0000C0000a40000700034@0004@000=200000P000d8000030003@P00008000=20000
A0000mh000020003gP00008000?N0000;000038000=20000D@000b<0001<00034@0000L000<A0000
A0000d8000020003@P0000<000=200000P000d8000140003g`00008000?O00000`000ml0000[0000
<@000d80@P1B00038`0004/000<A00002@000a4000120003@P0000<000=200000`000d8000030003
@P0004<000?N00000P000mh000030003gP0002/0000`0005@P000480D@000b<0001;00034@0000T0
00<A0000@P000d8000030003@P0000<000=200000`000d8000120003g`0000<000?O00000`000ml0
000[0000;`000d8000030003@P0004h000<S0000B`000a40000900034@00044000=2000010000d80
00030003@P0000@000=20000@@000mh000030003gP0000@000?N0000:P0002h000=200001@000d80
001=00038`0004X000<A00002`000a4000100003@P0000@000=200000`000d8000040003@P000440
00?O00000`000ml000040003g`0002X0000]0003@P0000L000=20000C0000b<0001:00034@0000/0
00<A0000?`000d8000050003@P0000<000=200001@000d80000o0003gP0000@000?N000010000mh0
000Z0000;0000d8000090003@P0004/000<S0000BP000a40000;00034@0003l000=2000010000d80
00050003@P0000@000=20000?`000ml000040003g`0000D000?O0000:@0002/000=200002`000d80
001:00038`0004T000<A00003@000a40000m0003@P0000D000=200001@000d8000050003@P0003h0
00?N000010000mh000050003gP0002T0000Z0003@P0000d000=20000B@000b<0001900034@0000d0
00<A0000?@000d8000050003@P0000D000=200001@000d80000m0003g`0000D000?O00001@000ml0
000Y0000:@000d80000?0003@P0004P000<S0000B@000a40000=00034@0003`000=200001P000d80
00050003@P0000H000=20000?0000mh000050003gP0000H000?N0000:00002P000=200004@000d80
001700038`0004P000<A00003`000a40000k0003@P0000H000=200001@000d8000060003@P0003`0
00?600001@000ml000060003aP0002P0000W0003@P0001<000=20000AP000b<0001800034@0000l0
00<A0000>P000d8000070003@P0000D000=200001`000d80000j0003aP0000H000?N00001`000lH0
000W00009P000d80000E0003@P0004D000<S0000B0000a40000?00034@0003X000=200001P000d80
00070003@P0000H000=200009P000a40000A0003aP0000H000?600001`000lH0000@00034@0001@0
000U0003@P0001L000=20000A0000b<0001700034@00014000<A0000>0000d8000070003@P0000L0
00=200001`000d80000U00034@00014000?600001P000lH000070003aP00010000<A0000500002@0
00=200006@000d80001300038`0004L000<A00004@000a40000g0003@P0000P000=200001`000d80
00080003@P0002400Q4200034@0000l000?600001`000lH000080003aP0000h000<A00000Q4C0000
8`000d80000K0003@P00048000<S0000A`000a40000A00034@0003L000=2000020000d8000070003
@P0000P000=200008`000a404@0A0003aP0000L000?6000020000lH0000>00034@0A01D0000R0003
@P0001d000=20000@@000b<0001600034@0001<000<A0000=@000d8000090003@P0000L000=20000
2@000d80000S008A4@000lH000070003aP0000P000?600003P024AH0000Q0003@P0001l000=20000
7P148bL000<A00004`000a40000e0003@P0000T000=200001`000d8000090003@P0002@00Q4?0003
aP0000P000?600002@000lH0000<008A5`00020000=200008@000d80000o00038`0004H000<A0000
4`000a40000d0003@P0000T000=200002@000d8000090003@P0001h01Q42]`h000?6000020000lH0
00090003aP0000/00[L74A40000O0003@P0002<000=20000?P000b<0001500034@0001D000<A0000
<`000d8000090003@P0000T000=200002@000d80000V0003]`0000@000<A000010000lH000080003
aP0000T000?6000010000a4000030003]`0001P0000N0003@P0002D000=20000?@000b<000150003
4@0001D000<A0000<P000d80000:0003@P0000T000=200002P000d80000V00:g10000a4000030003
aP0000T000?600002P000lH0000300034@00008000>g00006@0001d000=200009`000d80000l0003
8`0004D000<A00005@000a40000b0003@P0000X000=200002@000d80000:0003@P0002P000>g0000
0P000a4000020003aP0000T000?600002P000lH0000200044@0000:g700001`000=20000:@000d80
000k00038`0004@000<A00005`000a40000`0003@P0000/000=200002@000d80000;0003@P0002P0
0[L200034@00008000?600002@000lH0000:0005aP0001400`000kL0000L00006`000d80000[0003
@P0003X000<S0000A0000a40000G00034@00030000=200002`000d8000090003@P0000/000=20000
:0034@8000@A00361P024@@000?600000P024@L000C6000A0P000kLA000M00006P000d80000]0003
@P0003T000<S0000A0000a40000G00034@0002l000=200002`000d80000;0003@P0000/000=20000
:P034@8000?600001P001A40003600<000<A00001`001<H04A42]b00000I0003@P0002l000=20000
>0000b<0001300034@0001T000<A0000;P000d80000;0003@P0000/000=200002`000d80000Z00<A
0kL900044@00aP8000<A00001`001[O6]a6g4B40000H0003@P00034000=20000=`000b<000130003
4@0001T000<A0000;@000d80000<0003@P0000/000=2000030000d80000V00<A0`000kO60004]`H0
00DA0<H04@0600Bg0P001<Jg00034Ah0000G0003@P0003<000=20000=P000b<0001300034@0001T0
00<A0000;@000d80000<0003@P0000/000=2000030000d80000]0003a[Ng00Bg1Q4@]`03aP000280
000F0003@P0003D000=20000=@000b<0001200034@0001/000<A0000:`000d80000=0003@P0000/0
00=200003@000d80000/0003]`0000H00[L01A6g0<H000Bg2@000kL0000R00005@000d80000g0003
@P0003@000<S0000@P000a40000K00034@0002/000=200003@000d80000;0003@P0000d000=20000
:`000kL0000800064@00]lJg0P000a4000090003]`000240000D0003@P0003T000=20000<`000b<0
001200034@0001/000<A0000:P000d80000=0003@P0000d000=200003@000d80000Z0003]`0000L0
00<A00000P000kL0000200034@0000P000>g00008@0001<000=20000>`000d80000b00038`000440
00<A00007@000a40000Y0003@P0000d000=200003@000d80000=0003@P0002X000>g00001P000a40
00030003]`0000<000<A00001`000kL0000Q00004P000d80000m0003@P00034000<S0000@@000a40
000M00034@0002P000=200003P000d80000=0003@P0000h000=20000:0000kL0000=0003]`0000h0
00>g00008000014000=20000?`000d80000`00038`00044000<A00007@000a40000X0003@P0000h0
00=200003@000d80000>0003@P0002P000>g00003@000kL0000>0003]`000200002600038`000400
00<A00007`000a40000V0003@P0000l000=200003@000d80000?0003@P0002L000>g00003@000kL0
000>0003]`000200002600038`00040000<A00007`000a40000V0003@P0000l000=200003@000d80
000?0003@P0002H000>g00003P000kL0000?0003]`0001l0002600038`00040000<A00007`000a40
000U0003@P00010000=200003@000d80000@0003@P0002D000>g00003P000kL0000?0003]`0001l0
002600038`0003l000<A00008@000a40000T0003@P0000l000=200003`000d80000?0003@P0002D0
00>g00003P000kL0000?0003]`0001l0002600038`0003l000<A00008@000a40000S0003@P000100
00=200003`000d80000@0003@P0002<000>g00003`000kL0000@0003]`0001h0002600038`0003l0
00<A00008@000a40000S0003@P00010000=200003`000d80000@0003@P0002<000>g00003`000kL0
000@0003]`0001h0002600038`0003h000<A00008`000a40000Q0003@P00014000=200003`000d80
000A0003@P00028000>g00003`000kL0000@0003]`0001h0002600038`0003h000<A00008`000a40
000Q0003@P00014000=200003`000d80000A0003@P00024000>g000040000kL0000A0003]`0001d0
002600038`0003h000<A00008`000a40000P0003@P00018000=200003`000d80000B0003@P0001l0
00<A]`004@000kL0000A0003]a4001d0002600038`0003d000<A00009@000a40000O0003@P000140
00=200004@000d80000A0003@P0001h000<A01404P000kL0000A00034@0A01d0002600038`0003d0
00<A00009@000a40000N0003@P00018000=200004@000d80000B0003@P0001`000DA01404@0A0003
]`0001000Q4200034@0001X0002600038`0003d000<A00009@000a40000c0003@P00014000=20000
<0001Q4001404A4000>g000040024@<000<A00006@0008H000<S0000?0000a40000W00034@000380
00=200004@000d80000_00074@0001404@0A00034@00010000<A01400`000a40000H0000QP000b<0
000l00034@0002L000<A0000<P000d80000A0003@P00038000DA00004@0?00<A40001140014N0000
QP000b<0000l00034@0002L000<A0000<P000d80000A0003@P00038000DA00004@0>00054@0A0140
3`001140014N0000QP000b<0000k00034@0002T000<A0000<0000d80000C0003@P0004@000<A0140
0P000a40000^0000QP000b<0000k00034@0002T000<A0000<0000d80000C0003@P0004<000@A000A
0`000a40000]0000o`0T0003@P0001<000=20000AP000a40000a0000o`2g0000o`2g0000o`2g0000
o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000
o`2g0000o`2g0000o`2g0000400284400R3o0680000B0003800003d000<P0000o`1R00004`0283/0
0R3o06D0000E0003800003L000<P0000o`1U00005P000b00000e000380000?l0IP0001L00R0c008P
fP000dd000090003C@0007l0000I0003800002l000<P0000>0000kL0002O0003C00000T000=<0000
O`0001X00R0]008P>`000kL0002O0003C@0000T000==0000B`000k@0000a000070000b00000Y0003
800003/000>g0000W`000d`000090003C00004/000>d0000<@0001d000<P00009`000b00000k00>g
X@000dd000070003C@0004/000>d0;@0<P0001h00R0U008P?P03]j4000=<00001`000d`0001;0003
]02d0380000P00038000024000<P0000?P03]j4000==00001`000dd0001:0005]0000;@0<@000240
0R0O008P@0001KL0]`2g0:0000=<00001`000d`0001:0005]0000;@0<@0002<000<P00006`000b00
00100005]`2g0;L0X0000dd000070003C@0004T000>d00000`000k@0000^0000900281T00R130005
]`2g0;L0X0000d`000070003C00004T000>d00000`000k@0000^00009P000b00000E000380000480
00Bg002g0P000kL0002N0003C@0000D000==0000B@000k@000050003]00002d0000W0003800001<0
00<P0000@`001;L00;L20003]`0009h000=<00001@000d`000190003]00000D000>d0000;@0002P0
0R0A008PAP001;L00;L20003]`0009h000==00001@000dd000180003]00000L000>d0000;00002X0
00<P00003@000b0000150005]`000;L00`000kL0002M0003C00000D000=<0000B0000k@000070003
]00002`0000[008P2`0284P000Fg0000]`030003]`0009d000==00001@000dd000170003]00000T0
00>d0000:`0002d000<P00001`000b0000180005]`000;L00`000kL0002M0003C00000D000=<0000
A`000k@000090003]00002/0000^0003800000D000<P0000B0000kL000020003]`00008000>g0000
W0000dd000050003C@0004H000>d00002`000k@0000Z0000;`0280<00R1;0003]`00008000>g0000
0P000kL0002M0003C00000<000=<0000A`000k@0000;0003]00002X0000a0003800P04d000>g0000
0P000kL000020003]`0009d000==00000`000dd000160003]00000d000>d0000:@00038000<P0000
B`000kL000030003]`0000<000>g0000W0000d`000030003C00004H000>d00003P000k@0000X0000
<P000b00001;0003]`0000<000>g00000`000kL0002L0003C@0000<000==0000AP000k@0000>0003
]00002P0000b0003800004/000>g00000`000kL000030003]`0009`000=<00000`000d`000150003
]000010000>d00009`00038000<P0000BP000kL000040003]`0000@000>g0000V`000dd000030003
C@0004D000>d000040000k@0000W0000<P000b00001:0003]`0000@000>g000010000kL0002L0005
C00004`0A`000k@0000B0003]00002H0000b0003800004X000>g000010000kL000040003]`0009`0
00E=0000C@170003]000018000>d00009P00038000<P0000B@000kL000050003]`0000D000>g0000
V`001D`0001<04H000>d000050000k@0000U0000<P000b0000190003]`0000D000>g00001@000kL0
002K0005C@0004d0AP000k@0000D0003]00002D0000b0003800004T000>g00001@000kL000050003
]`0002l00]la00;O=`001D`0001<04D000>d00005P000k@0000T0000<P000b0000180003]`0000H0
00>g00001P000kL0000_00TP84d:83P000E=0000C@150003]00001H000>d00009000038000<P0000
B0000kL000060003]`0000H000>g0000;P02gc400]lh0003C01<04D000>d000060000k@0000S0000
<P000b0000180003]`0000H000>g00001P000kL0002K0003C@1=03000mhB0003]00001P000>d0000
3`03gQ40000b0003800004L000>g00001`000kL000070003]`0009X000=<04`0<`03g`h000>d0000
6P000k@0000;00?O5000038000<P0000A`000kL000070003]`0000L000>g0000VP000dd0C@0f00CN
2P000k@0000J0003]00000L01=hG0000<P000b0000170003]`0000L000>g00001`000kL0002J0003
C01<03X01=l50003]00001`000>d00000`03ga/0000b0003800004H000>g000020000kL000080003
]`0009T000==04d0?P03gP8000>d000070000k@00003gQh0000b0003800004H000>g000020000kL0
00080003]`0009T000=<04`0@@000mndg`0N0003gkCO0240000b0003800004H000>g000020000kL0
00080003]`0009X000==0000?`001Mh0gP3N01`000GN0=h0gP0P0000<P000b0000150003]`0000T0
00>g00002@000kL0002I0003C00003h000CO003O0P000ml0000H0004g`00g`8000?O00007@000380
00<P0000A@000kL000090003]`0000T000>g0000V003CCd00]h30005gP000=h05`02gP<000CN0000
0]hM0000<P000b0000150003]`0000T000>g00002@000kL0002F009<0`02C3X000?O00000`000ml0
000200;O50000ml000030003g`0000<000?O00006P00038000<P0000A0000kL0000:0003]`0000X0
00>g0000T`02C@L00Tdf00;N1P000mh000040003gP0000l00]h60003gP0000@00]hJ0000<P000b00
00140003]`0000X000>g00002P000kL0002A009<2`02C3<000?O00001P000ml000050003g`0000d0
00?O00001P000ml000060003g`0001L0000b0003800004@000>g00002P000kL0000:0003]`0008l0
0Td?009=<0000mh000070003gP0000H00]h<0003gP0000L000?N00001`000mh0000F0000<P000b00
00130003]`0000/000>g00002`000kL0002=0003C000014000=<0000:`02g`X000?O000020000ml0
000700;O2P000ml0000800;O5P00038000<P0000@`000kL0000;0003]`0000/000>g0000R`02CAD0
0TdZ0003gP0000X000?N00002@000mh000050003gP0000X000?N00002P000mh0000C0000<P000b00
00130003]`0000/000>g00002`000kL00029009<6@02C2L000?O00002`000ml0000:0003g`0000<0
00?O00002`000ml0000;0003g`000180000b00038000048000>g000030000kL0000<0003]`0008H0
0TdM009=90000mh0000<0003gP0000/000GN0000gP0>0003gP0000`000?N00004@00038000<P0000
@P000kL0000<0003]`0000`000>g0000Q002C2400T`a0003g`0001h000?O00008000038000<P0000
@P000kL0000<0003]`0000`000>g0000PP02CBD00Td_0003gP0001h000?N00008000038000<P0000
@@000kL0000=0003]`0000d000>g0000O`02C2T00T`]0003g`0001h000?O00008000038000<P0000
@@000kL0000=0003]`0000d000>g0000O@02CBd00Td[0003gP0001h000?N00008000038000<P0000
@@000kL0000=0003]`0000d000>g0000N`02C3400T`Y0003g`0001h000?O00008000038000<P0000
@0000kL0000>0003]`0000h000>g0000N@000dd0000c0003C@0002H000?N00007P000mh0000P0000
<P000b0000100003]`0000h000>g00003P000kL0001g009<=`02C2H000?O00007P000ml0000P0000
<P000b00001A0003]`0008H00Tdk009=90000mh0000N0003gP000200000b00038000054000>g0000
Q002C3l00TaV0000<P000b00003G0003C@00044000==0000H`00038000<P0000o`220000<P000b00
003o0880000b000380000?l0PP00038000<P0000o`220000<P000b00003o0880003o0;L0003o0;L0
003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0
003o0;L0003o0;L0003o0;L0003o0;L0001k0003gP0001<000?N0000S`000a40000C00034@0004H0
00>g0000<@0007/000?O00004`000ml0002?00034@0001<000<A0000AP000kL0000a0000O0000mh0
000A0003gP00094000<A00004@000a4000170003]`000340001l0003g`00014000?O0000T@000a40
000A00034@0004L000>g0000<@0007`000?N00004@000mh0002A00034@00014000<A0000A`000kL0
000a0000O@000ml0000?0003g`0009<000<A00003`000a4000180003]`000340000H0003]0000340
00>d0000;P000mh0000?0003gP0009<000<A00003`000a4000180003]`000340000H0003]0000340
00>d0000;P000ml0000?0003g`0002P000>d0000?@000k@0000X00034@0000l000<A0000B0000kL0
000a00005@02]08000>d0000;`001;@00;@_0003gP0000d000?N0000:@000k@0000m0003]00002T0
00<A00003@000a4000190003]`000340000D0006]000]02d<@001K@0]02d02h000?O00003@000ml0
000Z0003]00003/000>d0000:P000a40000=00034@0004T000>g0000<@0001<00k@20003]02d02l0
00>d0;@00P02]2d000?N00003@000mh0000[0003]00003T000>d0000:`000a40000=00034@0004T0
00>g0000<@0001800[@00`2d]00200:d;`02]0040;Bd00:d;@000ml0000;0003g`0002d000>d0000
=`000k@0000]00034@0000/000<A0000BP000kL0000a00004`03]0030;Bd00>d;@05]0040;@0]2d0
00?N00002`000mh0000]0003]00003L000>d0000;@000a40000;00034@0004X000>g0000<@0001<0
00>d00000k@00`2d]00]00:d00H0];Bd0;@^0003g`0000/000?O0000;P000k@0000e0003]00002h0
00<A00002`000a40001:0003]`000340000A00Bd0`02]08000?N0000:@000mh00002]0801;@]0003
gP0000T000?N0000<0000k@0000c0003]000030000==00002@000dd0001;0003]`000340000C0003
]02d00Fd00<0g`00:@000ml00007]2l000?O00002@000ml0000`0003]00003<000>d0000<0000d`0
00090003C00004/000>g0000<@0001400[@0102d];@30004]=kNgRP000GN0=kN]00200>d0P02]2`0
00?N00002@000mh0000a0003]000034000>d0000<@000dd000090003C@0004/000>g0000<@000100
1K@00`2d]00500;O9P03g`@00[@200Bd;@000ml000070003g`0003<000>d0000;`000k@0000c0003
C00000L000=<0000?`000b<0000:0003]`0000/000<S00008`0001<01[@6009=8P02C@H01[@`0003
gP0000L000?N0000=0000k@0000]0003]00003@000==00001`000dd0000o00038`0000X000>g0000
2`000b<0000S00004006]0030;Bd00;O1P000d`0000N0003C00000@00]l3]0801K@/0003g`0000L0
00?O0000=0000k@0000]0003]00003@000=<00001`000d`0000o00038`0000X000>g00002`000b<0
000S00004P02]0800k@5gP@00TdM0003C@0000801]h6]30000?N00001@000mh0000f0003]00002/0
00>d00009@000a40000>0003C@0000D000==00003P000a40000_00038`0000X000>g00002`000b<0
000S00004P05]0H000COC4a<0`000d`0000H009<0`02C0;O1P05]2l000?O00001@000ml0000g0003
]00002T000>d00009P000a40000>0003C00000D000=<00003P000a40000^00038`0000/000>g0000
2`000b<0000S00003`06]0030;Bd00T00dd00`1=C@0G0003C@0000==2002]0801K@]0003gP0000D0
00?N0000=`000k@0000Y0003]00002L000<A00003@000dd000050003C@0000d000<A0000;`000b<0
000;0003]`0000/000<S00008`0000l00k@300>d1=l800A<5@04C0P00ml4]0800k@^0003g`0000<0
00?O0000>@000k@0000W0003]00002T000<A000030000d`000050003C00000`000<A0000<0000b<0
000;0003]`0000`000<S00008P0001401[@400;N2dd3aPl00lH:C@?N0`06]30000?N00000`000mh0
000j0003]00002D000>d0000:`000a40000<0003C@0000<000==000030000a40000a00038`0000/0
00>g000030000b<0000R00003`02]0<01;@3ga000lH900?64002g`Fd0P02]2h000?O00000`000ml0
000k0003]00000d01ml?0003]00002L03a4AC0lA;P000b<0000;0003]`0000`000<S00008P0000l0
1K@00`2d]00G00?60`03aQH00[@200Bd;`001Mh0003N03h000>d00001`06gP<000CN00001]h90003
]00002d000<A00002@000dd0C@050003C@1=00/000<A0000<@000b<0000<0003]`0000`000<S0000
8P0001<00[@L00?66`02]3<000GO0000g`0o0004]00000GO20000ml0g`0800GO0`000k@0000_0003
4@0000L000E<0000C0030004C000009<20000a40000b00038`0000`000>g000030000b<0000R0000
4@02]1l000?600007002]34000GN0000gP1000?N3@000mh0gP0=00?N<`000a400004009=10001Dd0
001=00D000==000010000a40000^00DS00==8`0030000kL0000;00038ddS00DS7P00010000>d0000
7`000lH0000N0003]00002l000?O0=l0@@000k@0000<0005g`000=l03P000k@0000a00034@0000<0
00=<000010001D`0001<00H00T`400034@0002T01B<500038d`S008S2P000iD00009008S00=<8`00
1@058aT0000b0003aP00050000?N0=h0@0000k@0000=0005gP000=h03`000k@0000a00054@0004d0
20000ddPC@090004C@004CL000@SC@000R<80003U@0000H00b<00`1=8`0U0000<P000lH0001@0003
g`3O040000>d000030000ml000030003g`0000`000>d0000<P024@03C00000L000=<84`02P000d`A
000g00038`1<00<00b<50003U@0000@00R<30003C00S02D0000b0003aP00054000?N0000?`000k@0
000<0003gP0000<000?N000030000k@0000b00034Dd000T000==84d02P000dd04@0h00038`1=00D0
00<S00000P000iD0000300038`00008000==02<09P00038000?60000D@000ml0000n0003]00000`0
00?O00001@000ml0000<0003]00002l00Q400`1<000:0003800000T000A<000A>0000b<0C0090003
U@0000L000A<000S9P00038000?60000D@000mh0000n0003]00000`000?N00001@000mh0000<0003
]00002D00a4600034@00008000==000020000dd000080003C@0000800Q46008A;P0012<004d80003
U@0000H000E=00008`0V0000<P000lH0001A0003g`0003h000>d00002`000ml000070003g`0000/0
00>d0000:0034@03014A00H000=<00001P03C0P000=<00001@000a4000034C4000@S001<1`000iD0
00050005C00002<09`00038000?60000D@000mh0000m0003]00000`000?N00001`000mh0000<0003
]00002X00a470003C@0000@000E=04d0C@070003C@0000D00a4d00058`0004d01P000iD000040003
C@00008000<S00009@00038000?60000D@000ml0000m0003]00000/000?O00002@000ml0000;0003
]00002T000@A00000a450003C00000<000=<04`00P000d`000030003C00000<00a42008A=0001B<0
001<00D000>E00000`000d`0000200038`0002H0000b0003aP00054000?N0000?@000k@0000;0003
gP0000T000?N00002`000k@0000W008A1`034@8000==00000P0014d004d20003C@00008000A=0000
0a4700034@0003H000==00000P000iD000020003C@0002`0000b0003C000054000?O0000?0000k@0
000;0003g`0000/000?O00002`000k@0000U00034@0000X00T`00`1<00020004C000C0<000A<0000
0d`00a40000900034@0003H000E<0000U@030003C00002d0000a009=D`000mh0000l0003]00000/0
00?N00002`000mh0000;0003]00002@000<A00003@03C@0304d0008000==00000P04C@l000<A0000
=P0014d009D20003C@0002h0000a00=<DP000ml0000_01Zd00?O00003@000mnd]00H]2`00d`20004
C00000=<B`001D`0U@1<0340000a00==DP000mh0000k0003]00000/000>d00003@000k@0000;0003
]00003H000==04d01Td20003C@0004X000==UDd0<P00030000A<04a<DP000ml0000k0003]00000`0
00>d00002`000k@0000<0003]00003D000=<00001d`30003C00004X000>E0000<@00030000E=04d0
C@1A0003gP0003/000>d00003@000k@000090003]00000d000>d0000=00014dACDd30004C@00009=
0Q400dd000180003C@1=0380000_0006C000C01<D@000ml0000j0003]00000l000>d00001`000k@0
000?0003]000034000<AC1401P000d`0000500<AA`001D`0001<0340000_0006C@00C@1=D@000mh0
000j0003]00000l000>d00001`000k@0000?0003]00002h00a400dd000060003C@0000H000==0140
0Q530003C@0000<000==0000;P0002l000A<001<0P000d`0001>0003g`0003X000>d000040000k@0
00050003]000010000>d0000:`034@<000=<00001P000d`000070004C00000<A?`000d`000050003
C00002d0000^0005C@0004d00P000dd0001>0003gP0003T000>d00004P000k@000030003]0000180
00>d00009`034@D000==00001`000dd000070003C@0000@00a4f00038`00008000==00001`000dd0
000300038`0002H0000^0005g`000=l00P000ml0001>0003g`0003T000>d00004`001K@0002d01D0
00>d00009P000a4000050003C00000P000=<000020000d`0000600034@0003<000DS0000C00;0003
C000008000<S00009P0002d00]h30003gP0000;NC`000mh0000i0003]00001<000Fd0000]00E0003
]00002d000==00002@000dd000090003C@0003X000DS0000C@0=0003C@00008000<S00009@0002d0
0]l20003g`3O008000?O0000C@000ml0000h0003]00001D000>d0;@05`000k@0000/00034@0000T0
00=<00002@000a40000j00048`00C0l000E<00008`0W0000;0000mh0gP020003gP3N00800]i>0003
gP0003P000>d00005P000k@0000F0003]00002/000<A00002P000dd0000:00034@0003P000@S001=
4@0014d002<W0000;0000k@0g`020003g`3O008000?O];@0C@000ml0001@0003]02d04@000<A0000
2`000d`0000;00034@0003L000<S04`00`028`X00R<20004C0008bH0000[00:d00L0]000]02d0080
1;A<0003gP00050000>d0;@0@`000a40000<00034@0000`000<A0000=@000b<0C@02008S3P028`04
04d08bH0000Z00Fd00@0];@00[@01P2d];@0]4/000?O0000C`001K@0002d048000<A000030000a40
000<00034@0003D000<SC0000R<B008S00=<02<09@0002T00[@01@2d];@000Zd00<0]000B@000mh0
001>0003]00000<000>d0000?P000a40000=00034@0000d000<A0000:0048`L000@SCB<S5P000b==
8`0800@S6@0002P000>d0;@02K@0102d]002]08000>d0000A`000ml0001=0003]00000D000>d0000
?0000a40000>00034@0000h000<A0000:`058`8000=<8`0060000b=<000200DS7@0002L000Rd0;@0
]02d00:d00<0]0000[@01@2d]02d008000>d0000AP000mh0001=0003]00000D000>d0000>`000a40
000?00034@0000l000<A0000;`000b==000L0003CB<S0280000V0007]000]02d0004]0030;@000Nd
0`000k@000150003g`0004`000>d00001`000k@0000j00034@0000l000<A00003`000a40000`0003
8`0001/000<S00008P0002P000Fd0;Bd0004]0030;@000Bd00@0]02dBP000mh0001;0003]00000T0
00>d0000>0000a40000@00034@00010000<A0000;`000b<0000K00038`000280000Y0003]02d00:d
00<0]0000[@01P2d002d00:dB`000ml0001:0003]00000/000>d0000=P000a40000A00034@000140
00<A0000;P000b<0000K00038`000280000/0005]000]0000[@01@2d002d04h000?N0000T0000a40
000B00034@00018000<A0000;P000b<0000J00038`00028000260003g`000:D000<A0000@`000b<0
000J00038`00028000260003gP000:D000<A0000@`000b<0000I00038`0002<000260003g`000:D0
00<A0000@`000b<0000I00038`0002<000260003gP000:D000<A0000@`000b<0000I00038`0002<0
00260003g`000:D000<A0000A0000b<0000H00038`0002<000260003gP000:D000<A0000A0000b<0
000H00038`0002<0003o02l000<A0000A0000b<0000H00038`0002<0003o0;L0003o0;L0003o0;L0
003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L00000\
\>"],
  ImageRangeCache->{{{0, 437}, {257, 0}} -> {-0.145065, -0.0740895, 0.0121056,
   0.0121056}, {{11.9375, 88.4375}, {250.875, 174.375}} -> {-0.188855,
   -0.109074, 0.0137256, 0.0137256}, {{96.0625, 172.562}, {250.875, 174.375}}
   -> {-1.34352, -0.109075, 0.0137256, 0.0137256}, {{180.25, 256.688}, {
  250.875, 174.375}} -> {-2.49861, -0.109074, 0.0137256, 0.0137256}, {{
  264.375, 340.875}, {250.875, 174.375}} -> {-3.65374, -0.109075, 0.0137257, 
  0.0137257}, {{348.5, 425}, {250.875, 174.375}} -> {-4.80837, -0.109074, 
  0.0137256, 0.0137256}, {{11.9375, 88.4375}, {166.688, 90.25}} -> {-0.188855,
   -1.26417, 0.0137256, 0.0137256}, {{96.0625, 172.562}, {166.688, 90.25}} ->
   {-1.34503, -1.26562, 0.0137369, 0.0137369}, {{180.25, 256.688}, {166.688, 
  90.25}} -> {-2.50107, -1.26561, 0.0137368, 0.0137368}, {{264.375, 340.875},
   {166.688, 90.25}} -> {-3.65372, -1.26417, 0.0137256, 0.0137256}, {{348.5, 
  425}, {166.688, 90.25}} -> {-4.80839, -1.26417, 0.0137256, 0.0137256}, {{
  11.9375, 88.4375}, {82.5625, 6.0625}} -> {-0.188855, -2.41927, 0.0137256, 
  0.0137256}, {{96.0625, 172.562}, {82.5625, 6.0625}} -> {-1.34353, -2.41927, 
  0.0137256, 0.0137256}, {{180.25, 256.688}, {82.5625, 6.0625}} -> {-2.50107,
   -2.42166, 0.0137368, 0.0137368}, {{264.375, 340.875}, {82.5625, 6.0625}} ->
   {-3.6537, -2.41926, 0.0137256, 0.0137256}, {{348.5, 425}, {82.5625, 
  6.0625}} -> {-4.80838, -2.41927, 0.0137256, 0.0137256}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples (4)", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(bioTable = Table[randBio, {3}, {5}]\), 
    \(\(biomorph[bioTable]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{{3, 1, 4, 5, 7, 5, 3, 5, 1, 8, 3, 3, 5, 10, 4, 9, 3, 9, 8, 10, 3}, {
          3, 4, 3, 1, 4, 5, 2, 5, 7, 1, 5, 4, 9, 5, 7, 7, 4, 1, 7, 2, 1}, {4, 
          5, 1, 5, 1, 10, 2, 5, 2, 4, 8, 3, 1, 7, 9, 4, 5, 1, 10, 6, 4}, {3, 
          3, 1, 6, 2, 6, 4, 10, 6, 8, 7, 2, 2, 1, 1, 2, 5, 10, 10, 5, 7}, {4, 
          5, 2, 2, 2, 4, 5, 5, 9, 2, 6, 3, 7, 9, 10, 10, 1, 3, 7, 6, 4}}, {{
          2, 4, 10, 5, 7, 8, 4, 10, 5, 7, 6, 2, 8, 1, 6, 6, 4, 10, 8, 6, 9}, {
          2, 4, 2, 10, 1, 3, 5, 2, 4, 3, 7, 1, 8, 9, 10, 9, 4, 4, 4, 1, 4}, {
          4, 5, 4, 4, 7, 9, 5, 4, 3, 8, 4, 5, 6, 5, 9, 5, 4, 2, 8, 3, 7}, {2, 
          3, 2, 10, 7, 5, 1, 10, 6, 7, 5, 3, 4, 8, 4, 1, 3, 9, 2, 7, 6}, {3, 
          1, 4, 5, 3, 8, 4, 4, 10, 2, 10, 4, 8, 2, 2, 9, 4, 5, 9, 5, 9}}, {{
          4, 5, 6, 4, 3, 10, 2, 3, 4, 6, 8, 4, 5, 5, 2, 10, 2, 1, 1, 5, 7}, {
          4, 4, 7, 10, 9, 7, 5, 8, 8, 8, 1, 5, 6, 9, 6, 8, 4, 10, 3, 9, 2}, {
          1, 5, 3, 8, 10, 8, 1, 3, 5, 4, 4, 4, 2, 1, 6, 5, 3, 5, 1, 8, 1}, {
          1, 1, 6, 8, 10, 9, 5, 3, 9, 1, 3, 2, 4, 3, 8, 4, 5, 7, 2, 5, 1}, {
          4, 2, 7, 10, 10, 4, 3, 5, 1, 3, 2, 1, 6, 4, 9, 10, 1, 10, 9, 10, 
          10}}}\)], "Output",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .59259 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0141093 0.190476 [
[ 0 0 0 0 ]
[ 1 .59259 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .59259 L
0 .59259 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0141093 0.200176 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0229561 0.954088 0.0238522 0.954088 [
[ 0 0 0 0 ]
[ 1 1.00179 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.00179 L
0 1.00179 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.01 w
.65487 .4694 m
.63878 .50097 L
s
P
p
.2 0 1 r
.01 w
.65487 .4694 m
.64933 .5044 L
s
P
p
.2 0 1 r
.01 w
.87815 .35563 m
.90973 .37172 L
s
P
p
.2 0 1 r
.01 w
.87815 .35563 m
.91315 .36118 L
s
P
p
.2 0 1 r
.01 w
.76438 .13235 m
.78047 .10078 L
s
P
p
.2 0 1 r
.01 w
.76438 .13235 m
.76993 .09735 L
s
P
p
.2 0 1 r
.01 w
.54111 .24612 m
.50953 .23003 L
s
P
p
.2 0 1 r
.01 w
.54111 .24612 m
.5061 .24058 L
s
P
p
1 0 0 r
.004 w
.70963 .30088 m
.65487 .4694 L
s
P
p
1 0 0 r
.004 w
.70963 .30088 m
.87815 .35563 L
s
P
p
1 0 0 r
.004 w
.70963 .30088 m
.76438 .13235 L
s
P
p
1 0 0 r
.004 w
.70963 .30088 m
.54111 .24612 L
s
P
p
.2 0 1 r
.01 w
.70965 .36857 m
.72574 .40015 L
s
P
p
.2 0 1 r
.01 w
.70965 .36857 m
.73471 .39363 L
s
P
p
.2 0 1 r
.01 w
.74885 .12107 m
.78043 .10498 L
s
P
p
.2 0 1 r
.01 w
.74885 .12107 m
.77391 .09601 L
s
P
p
.2 0 1 r
.01 w
.50135 .08187 m
.48526 .05029 L
s
P
p
.2 0 1 r
.01 w
.50135 .08187 m
.47629 .05681 L
s
P
p
.2 0 1 r
.01 w
.46214 .32937 m
.43057 .34546 L
s
P
p
.2 0 1 r
.01 w
.46214 .32937 m
.43708 .35443 L
s
P
p
1 0 0 r
.004 w
.6055 .22522 m
.70965 .36857 L
s
P
p
1 0 0 r
.004 w
.6055 .22522 m
.74885 .12107 L
s
P
p
1 0 0 r
.004 w
.6055 .22522 m
.50135 .08187 L
s
P
p
1 0 0 r
.004 w
.6055 .22522 m
.46214 .32937 L
s
P
p
.8 0 1 r
.012 w
.58332 .36523 m
.70963 .30088 L
s
P
p
.8 0 1 r
.012 w
.58332 .36523 m
.6055 .22522 L
s
P
p
.2 0 1 r
.01 w
.44214 .33587 m
.47714 .34142 L
s
P
p
.2 0 1 r
.01 w
.44214 .33587 m
.47714 .33033 L
s
P
p
.2 0 1 r
.01 w
.26495 .15868 m
.27049 .12368 L
s
P
p
.2 0 1 r
.01 w
.26495 .15868 m
.2594 .12368 L
s
P
p
.2 0 1 r
.01 w
.08775 .33587 m
.05275 .33033 L
s
P
p
.2 0 1 r
.01 w
.08775 .33587 m
.05275 .34142 L
s
P
p
.2 0 1 r
.01 w
.26495 .51307 m
.2594 .54807 L
s
P
p
.2 0 1 r
.01 w
.26495 .51307 m
.27049 .54807 L
s
P
p
1 0 0 r
.004 w
.26495 .33587 m
.44214 .33587 L
s
P
p
1 0 0 r
.004 w
.26495 .33587 m
.26495 .15868 L
s
P
p
1 0 0 r
.004 w
.26495 .33587 m
.08775 .33587 L
s
P
p
1 0 0 r
.004 w
.26495 .33587 m
.26495 .51307 L
s
P
p
.2 0 1 r
.01 w
.32932 .31493 m
.35438 .28987 L
s
P
p
.2 0 1 r
.01 w
.32932 .31493 m
.34541 .28335 L
s
P
p
.2 0 1 r
.01 w
.08182 .35413 m
.05676 .32907 L
s
P
p
.2 0 1 r
.01 w
.08182 .35413 m
.05024 .33804 L
s
P
p
.2 0 1 r
.01 w
.12102 .60164 m
.09596 .6267 L
s
P
p
.2 0 1 r
.01 w
.12102 .60164 m
.10493 .63322 L
s
P
p
.2 0 1 r
.01 w
.36852 .56244 m
.39358 .5875 L
s
P
p
.2 0 1 r
.01 w
.36852 .56244 m
.4001 .57853 L
s
P
p
1 0 0 r
.004 w
.22517 .45829 m
.32932 .31493 L
s
P
p
1 0 0 r
.004 w
.22517 .45829 m
.08182 .35413 L
s
P
p
1 0 0 r
.004 w
.22517 .45829 m
.12102 .60164 L
s
P
p
1 0 0 r
.004 w
.22517 .45829 m
.36852 .56244 L
s
P
p
.8 0 1 r
.012 w
.36518 .43611 m
.26495 .33587 L
s
P
p
.8 0 1 r
.012 w
.36518 .43611 m
.22517 .45829 L
s
P
p
.2 0 1 r
.01 w
.38089 .57945 m
.37534 .54445 L
s
P
p
.2 0 1 r
.01 w
.38089 .57945 m
.3648 .54788 L
s
P
p
.2 0 1 r
.01 w
.26712 .80273 m
.23212 .80828 L
s
P
p
.2 0 1 r
.01 w
.26712 .80273 m
.23555 .81882 L
s
P
p
.2 0 1 r
.01 w
.4904 .9165 m
.49594 .9515 L
s
P
p
.2 0 1 r
.01 w
.4904 .9165 m
.50649 .94808 L
s
P
p
.2 0 1 r
.01 w
.60417 .69322 m
.63917 .68768 L
s
P
p
.2 0 1 r
.01 w
.60417 .69322 m
.63574 .67713 L
s
P
p
1 0 0 r
.004 w
.43564 .74798 m
.38089 .57945 L
s
P
p
1 0 0 r
.004 w
.43564 .74798 m
.26712 .80273 L
s
P
p
1 0 0 r
.004 w
.43564 .74798 m
.4904 .9165 L
s
P
p
1 0 0 r
.004 w
.43564 .74798 m
.60417 .69322 L
s
P
p
.2 0 1 r
.01 w
.39583 .69322 m
.36426 .67713 L
s
P
p
.2 0 1 r
.01 w
.39583 .69322 m
.36083 .68768 L
s
P
p
.2 0 1 r
.01 w
.5096 .9165 m
.49351 .94808 L
s
P
p
.2 0 1 r
.01 w
.5096 .9165 m
.50406 .9515 L
s
P
p
.2 0 1 r
.01 w
.73288 .80273 m
.76445 .81882 L
s
P
p
.2 0 1 r
.01 w
.73288 .80273 m
.76788 .80828 L
s
P
p
.2 0 1 r
.01 w
.61911 .57945 m
.6352 .54788 L
s
P
p
.2 0 1 r
.01 w
.61911 .57945 m
.62466 .54445 L
s
P
p
1 0 0 r
.004 w
.56436 .74798 m
.39583 .69322 L
s
P
p
1 0 0 r
.004 w
.56436 .74798 m
.5096 .9165 L
s
P
p
1 0 0 r
.004 w
.56436 .74798 m
.73288 .80273 L
s
P
p
1 0 0 r
.004 w
.56436 .74798 m
.61911 .57945 L
s
P
p
.8 0 1 r
.012 w
.5 .62167 m
.43564 .74798 L
s
P
p
.8 0 1 r
.012 w
.5 .62167 m
.56436 .74798 L
s
P
p
.2 0 1 r
.01 w
.63148 .56244 m
.5999 .57853 L
s
P
p
.2 0 1 r
.01 w
.63148 .56244 m
.60642 .5875 L
s
P
p
.2 0 1 r
.01 w
.87898 .60164 m
.89507 .63322 L
s
P
p
.2 0 1 r
.01 w
.87898 .60164 m
.90404 .6267 L
s
P
p
.2 0 1 r
.01 w
.91818 .35413 m
.94976 .33804 L
s
P
p
.2 0 1 r
.01 w
.91818 .35413 m
.94324 .32907 L
s
P
p
.2 0 1 r
.01 w
.67068 .31493 m
.65459 .28335 L
s
P
p
.2 0 1 r
.01 w
.67068 .31493 m
.64562 .28987 L
s
P
p
1 0 0 r
.004 w
.77483 .45829 m
.63148 .56244 L
s
P
p
1 0 0 r
.004 w
.77483 .45829 m
.87898 .60164 L
s
P
p
1 0 0 r
.004 w
.77483 .45829 m
.91818 .35413 L
s
P
p
1 0 0 r
.004 w
.77483 .45829 m
.67068 .31493 L
s
P
p
.2 0 1 r
.01 w
.73505 .51307 m
.72951 .54807 L
s
P
p
.2 0 1 r
.01 w
.73505 .51307 m
.7406 .54807 L
s
P
p
.2 0 1 r
.01 w
.91225 .33587 m
.94725 .34142 L
s
P
p
.2 0 1 r
.01 w
.91225 .33587 m
.94725 .33033 L
s
P
p
.2 0 1 r
.01 w
.73505 .15868 m
.7406 .12368 L
s
P
p
.2 0 1 r
.01 w
.73505 .15868 m
.72951 .12368 L
s
P
p
.2 0 1 r
.01 w
.55786 .33587 m
.52286 .33033 L
s
P
p
.2 0 1 r
.01 w
.55786 .33587 m
.52286 .34142 L
s
P
p
1 0 0 r
.004 w
.73505 .33587 m
.73505 .51307 L
s
P
p
1 0 0 r
.004 w
.73505 .33587 m
.91225 .33587 L
s
P
p
1 0 0 r
.004 w
.73505 .33587 m
.73505 .15868 L
s
P
p
1 0 0 r
.004 w
.73505 .33587 m
.55786 .33587 L
s
P
p
.8 0 1 r
.012 w
.63482 .43611 m
.77483 .45829 L
s
P
p
.8 0 1 r
.012 w
.63482 .43611 m
.73505 .33587 L
s
P
p
.2 0 1 r
.01 w
.53786 .32937 m
.56292 .35443 L
s
P
p
.2 0 1 r
.01 w
.53786 .32937 m
.56943 .34546 L
s
P
p
.2 0 1 r
.01 w
.49865 .08187 m
.52371 .05681 L
s
P
p
.2 0 1 r
.01 w
.49865 .08187 m
.51474 .05029 L
s
P
p
.2 0 1 r
.01 w
.25115 .12107 m
.22609 .09601 L
s
P
p
.2 0 1 r
.01 w
.25115 .12107 m
.21957 .10498 L
s
P
p
.2 0 1 r
.01 w
.29035 .36857 m
.26529 .39363 L
s
P
p
.2 0 1 r
.01 w
.29035 .36857 m
.27426 .40015 L
s
P
p
1 0 0 r
.004 w
.3945 .22522 m
.53786 .32937 L
s
P
p
1 0 0 r
.004 w
.3945 .22522 m
.49865 .08187 L
s
P
p
1 0 0 r
.004 w
.3945 .22522 m
.25115 .12107 L
s
P
p
1 0 0 r
.004 w
.3945 .22522 m
.29035 .36857 L
s
P
p
.2 0 1 r
.01 w
.45889 .24612 m
.4939 .24058 L
s
P
p
.2 0 1 r
.01 w
.45889 .24612 m
.49047 .23003 L
s
P
p
.2 0 1 r
.01 w
.23562 .13235 m
.23007 .09735 L
s
P
p
.2 0 1 r
.01 w
.23562 .13235 m
.21953 .10078 L
s
P
p
.2 0 1 r
.01 w
.12185 .35563 m
.08685 .36118 L
s
P
p
.2 0 1 r
.01 w
.12185 .35563 m
.09027 .37172 L
s
P
p
.2 0 1 r
.01 w
.34513 .4694 m
.35067 .5044 L
s
P
p
.2 0 1 r
.01 w
.34513 .4694 m
.36122 .50097 L
s
P
p
1 0 0 r
.004 w
.29037 .30088 m
.45889 .24612 L
s
P
p
1 0 0 r
.004 w
.29037 .30088 m
.23562 .13235 L
s
P
p
1 0 0 r
.004 w
.29037 .30088 m
.12185 .35563 L
s
P
p
1 0 0 r
.004 w
.29037 .30088 m
.34513 .4694 L
s
P
p
.8 0 1 r
.012 w
.41668 .36523 m
.3945 .22522 L
s
P
p
.8 0 1 r
.012 w
.41668 .36523 m
.29037 .30088 L
s
P
p
1 0 0 r
.006 w
.5 .47991 m
.58332 .36523 L
s
P
p
1 0 0 r
.006 w
.5 .47991 m
.36518 .43611 L
s
P
p
1 0 0 r
.006 w
.5 .47991 m
.5 .62167 L
s
P
p
1 0 0 r
.006 w
.5 .47991 m
.63482 .43611 L
s
P
p
1 0 0 r
.006 w
.5 .47991 m
.41668 .36523 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.0141093 0.39418 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.00599865 0.952381 [
[ 0 0 0 0 ]
[ 1 .96438 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .96438 L
0 .96438 L
closepath
clip
newpath
p
P
p
.8 1 0 r
.018 w
.47374 .43206 m
.52124 .40786 L
s
P
p
.8 1 0 r
.018 w
.47374 .43206 m
.42625 .45626 L
s
P
p
.8 1 0 r
.018 w
.51422 .1765 m
.47653 .13881 L
s
P
p
.8 1 0 r
.018 w
.51422 .1765 m
.55191 .21419 L
s
P
p
.8 1 0 r
.018 w
.25866 .21697 m
.23446 .26447 L
s
P
p
.8 1 0 r
.018 w
.25866 .21697 m
.28286 .16948 L
s
P
p
.8 1 0 r
.018 w
.37613 .44752 m
.42877 .45586 L
s
P
p
.8 1 0 r
.018 w
.37613 .44752 m
.32348 .43918 L
s
P
p
.8 1 0 r
.018 w
.55909 .26456 m
.55075 .21191 L
s
P
p
.8 1 0 r
.018 w
.55909 .26456 m
.56743 .31721 L
s
P
p
.8 0 1 r
.012 w
.40114 .28957 m
.47374 .43206 L
s
P
p
.8 0 1 r
.012 w
.40114 .28957 m
.51422 .1765 L
s
P
p
.8 0 1 r
.012 w
.40114 .28957 m
.25866 .21697 L
s
P
p
.8 0 1 r
.012 w
.40114 .28957 m
.37613 .44752 L
s
P
p
.8 0 1 r
.012 w
.40114 .28957 m
.55909 .26456 L
s
P
p
.8 1 0 r
.018 w
.61735 .32282 m
.5647 .31448 L
s
P
p
.8 1 0 r
.018 w
.61735 .32282 m
.66999 .33115 L
s
P
p
.8 1 0 r
.018 w
.43438 .50578 m
.44272 .55843 L
s
P
p
.8 1 0 r
.018 w
.43438 .50578 m
.42604 .45313 L
s
P
p
.8 1 0 r
.018 w
.66493 .62325 m
.71242 .59905 L
s
P
p
.8 1 0 r
.018 w
.66493 .62325 m
.61743 .64745 L
s
P
p
.8 1 0 r
.018 w
.70541 .36768 m
.66771 .32999 L
s
P
p
.8 1 0 r
.018 w
.70541 .36768 m
.7431 .40538 L
s
P
p
.8 1 0 r
.018 w
.44984 .40816 m
.42564 .45566 L
s
P
p
.8 1 0 r
.018 w
.44984 .40816 m
.47404 .36067 L
s
P
p
.8 0 1 r
.012 w
.59233 .48076 m
.61735 .32282 L
s
P
p
.8 0 1 r
.012 w
.59233 .48076 m
.43438 .50578 L
s
P
p
.8 0 1 r
.012 w
.59233 .48076 m
.66493 .62325 L
s
P
p
.8 0 1 r
.012 w
.59233 .48076 m
.70541 .36768 L
s
P
p
.8 0 1 r
.012 w
.59233 .48076 m
.44984 .40816 L
s
P
p
.8 1 0 r
.018 w
.43696 .32679 m
.47465 .36448 L
s
P
p
.8 1 0 r
.018 w
.43696 .32679 m
.39926 .2891 L
s
P
p
.8 1 0 r
.018 w
.69252 .28631 m
.71672 .23882 L
s
P
p
.8 1 0 r
.018 w
.69252 .28631 m
.66832 .33381 L
s
P
p
.8 1 0 r
.018 w
.57505 .05576 m
.5224 .04743 L
s
P
p
.8 1 0 r
.018 w
.57505 .05576 m
.6277 .0641 L
s
P
p
.8 1 0 r
.018 w
.39209 .23873 m
.40042 .29138 L
s
P
p
.8 1 0 r
.018 w
.39209 .23873 m
.38375 .18608 L
s
P
p
.8 1 0 r
.018 w
.62263 .3562 m
.67013 .332 L
s
P
p
.8 1 0 r
.018 w
.62263 .3562 m
.57514 .3804 L
s
P
p
.8 0 1 r
.012 w
.55003 .21371 m
.43696 .32679 L
s
P
p
.8 0 1 r
.012 w
.55003 .21371 m
.69252 .28631 L
s
P
p
.8 0 1 r
.012 w
.55003 .21371 m
.57505 .05576 L
s
P
p
.8 0 1 r
.012 w
.55003 .21371 m
.39209 .23873 L
s
P
p
.8 0 1 r
.012 w
.55003 .21371 m
.62263 .3562 L
s
P
p
.8 1 0 r
.018 w
.58523 .4296 m
.57689 .37696 L
s
P
p
.8 1 0 r
.018 w
.58523 .4296 m
.59357 .48225 L
s
P
p
.8 1 0 r
.018 w
.35468 .31214 m
.30719 .33634 L
s
P
p
.8 1 0 r
.018 w
.35468 .31214 m
.40218 .28794 L
s
P
p
.8 1 0 r
.018 w
.31421 .5677 m
.3519 .60539 L
s
P
p
.8 1 0 r
.018 w
.31421 .5677 m
.27651 .53001 L
s
P
p
.8 1 0 r
.018 w
.56977 .52722 m
.59397 .47973 L
s
P
p
.8 1 0 r
.018 w
.56977 .52722 m
.54557 .57472 L
s
P
p
.8 1 0 r
.018 w
.4523 .29667 m
.39965 .28834 L
s
P
p
.8 1 0 r
.018 w
.4523 .29667 m
.50495 .30501 L
s
P
p
.8 0 1 r
.012 w
.42728 .45462 m
.58523 .4296 L
s
P
p
.8 0 1 r
.012 w
.42728 .45462 m
.35468 .31214 L
s
P
p
.8 0 1 r
.012 w
.42728 .45462 m
.31421 .5677 L
s
P
p
.8 0 1 r
.012 w
.42728 .45462 m
.56977 .52722 L
s
P
p
.8 0 1 r
.012 w
.42728 .45462 m
.4523 .29667 L
s
P
p
.8 1 0 r
.018 w
.52571 .25927 m
.50151 .30677 L
s
P
p
.8 1 0 r
.018 w
.52571 .25927 m
.54991 .21178 L
s
P
p
.8 1 0 r
.018 w
.64318 .48982 m
.69583 .49816 L
s
P
p
.8 1 0 r
.018 w
.64318 .48982 m
.59053 .48148 L
s
P
p
.8 1 0 r
.018 w
.82614 .30685 m
.8178 .25421 L
s
P
p
.8 1 0 r
.018 w
.82614 .30685 m
.83448 .3595 L
s
P
p
.8 1 0 r
.018 w
.59559 .18939 m
.5481 .21359 L
s
P
p
.8 1 0 r
.018 w
.59559 .18939 m
.64309 .16519 L
s
P
p
.8 1 0 r
.018 w
.55512 .44495 m
.59281 .48264 L
s
P
p
.8 1 0 r
.018 w
.55512 .44495 m
.51742 .40726 L
s
P
p
.8 0 1 r
.012 w
.66819 .33187 m
.52571 .25927 L
s
P
p
.8 0 1 r
.012 w
.66819 .33187 m
.64318 .48982 L
s
P
p
.8 0 1 r
.012 w
.66819 .33187 m
.82614 .30685 L
s
P
p
.8 0 1 r
.012 w
.66819 .33187 m
.59559 .18939 L
s
P
p
.8 0 1 r
.012 w
.66819 .33187 m
.55512 .44495 L
s
P
p
1 .6 0 r
.016 w
.5278 .35411 m
.40114 .28957 L
s
P
p
1 .6 0 r
.016 w
.5278 .35411 m
.59233 .48076 L
s
P
p
1 .6 0 r
.016 w
.5278 .35411 m
.55003 .21371 L
s
P
p
1 .6 0 r
.016 w
.5278 .35411 m
.42728 .45462 L
s
P
p
1 .6 0 r
.016 w
.5278 .35411 m
.66819 .33187 L
s
P
p
.8 1 0 r
.018 w
.43652 .60818 m
.38902 .58398 L
s
P
p
.8 1 0 r
.018 w
.43652 .60818 m
.48401 .63238 L
s
P
p
.8 1 0 r
.018 w
.20597 .72565 m
.19763 .7783 L
s
P
p
.8 1 0 r
.018 w
.20597 .72565 m
.21431 .673 L
s
P
p
.8 1 0 r
.018 w
.38894 .90861 m
.44158 .90027 L
s
P
p
.8 1 0 r
.018 w
.38894 .90861 m
.33629 .91695 L
s
P
p
.8 1 0 r
.018 w
.5064 .67807 m
.4822 .63057 L
s
P
p
.8 1 0 r
.018 w
.5064 .67807 m
.5306 .72556 L
s
P
p
.8 1 0 r
.018 w
.25084 .63759 m
.21315 .67528 L
s
P
p
.8 1 0 r
.018 w
.25084 .63759 m
.28853 .5999 L
s
P
p
.8 0 1 r
.012 w
.36392 .75067 m
.43652 .60818 L
s
P
p
.8 0 1 r
.012 w
.36392 .75067 m
.20597 .72565 L
s
P
p
.8 0 1 r
.012 w
.36392 .75067 m
.38894 .90861 L
s
P
p
.8 0 1 r
.012 w
.36392 .75067 m
.5064 .67807 L
s
P
p
.8 0 1 r
.012 w
.36392 .75067 m
.25084 .63759 L
s
P
p
.8 1 0 r
.018 w
.26373 .55622 m
.28793 .60371 L
s
P
p
.8 1 0 r
.018 w
.26373 .55622 m
.23953 .50872 L
s
P
p
.8 1 0 r
.018 w
.51929 .59669 m
.55699 .559 L
s
P
p
.8 1 0 r
.018 w
.51929 .59669 m
.4816 .63439 L
s
P
p
.8 1 0 r
.018 w
.47882 .34113 m
.43132 .31693 L
s
P
p
.8 1 0 r
.018 w
.47882 .34113 m
.52631 .36533 L
s
P
p
.8 1 0 r
.018 w
.24827 .4586 m
.23993 .51125 L
s
P
p
.8 1 0 r
.018 w
.24827 .4586 m
.25661 .40595 L
s
P
p
.8 1 0 r
.018 w
.43123 .64156 m
.48388 .63322 L
s
P
p
.8 1 0 r
.018 w
.43123 .64156 m
.37858 .6499 L
s
P
p
.8 0 1 r
.012 w
.40622 .48362 m
.26373 .55622 L
s
P
p
.8 0 1 r
.012 w
.40622 .48362 m
.51929 .59669 L
s
P
p
.8 0 1 r
.012 w
.40622 .48362 m
.47882 .34113 L
s
P
p
.8 0 1 r
.012 w
.40622 .48362 m
.24827 .4586 L
s
P
p
.8 0 1 r
.012 w
.40622 .48362 m
.43123 .64156 L
s
P
p
.8 1 0 r
.018 w
.37298 .69982 m
.38131 .64717 L
s
P
p
.8 1 0 r
.018 w
.37298 .69982 m
.36464 .75247 L
s
P
p
.8 1 0 r
.018 w
.19001 .51686 m
.13736 .5252 L
s
P
p
.8 1 0 r
.018 w
.19001 .51686 m
.24266 .50852 L
s
P
p
.8 1 0 r
.018 w
.07254 .7474 m
.09674 .7949 L
s
P
p
.8 1 0 r
.018 w
.07254 .7474 m
.04834 .69991 L
s
P
p
.8 1 0 r
.018 w
.32811 .78788 m
.3658 .75019 L
s
P
p
.8 1 0 r
.018 w
.32811 .78788 m
.29041 .82557 L
s
P
p
.8 1 0 r
.018 w
.28763 .53232 m
.24013 .50812 L
s
P
p
.8 1 0 r
.018 w
.28763 .53232 m
.33512 .55652 L
s
P
p
.8 0 1 r
.012 w
.21503 .6748 m
.37298 .69982 L
s
P
p
.8 0 1 r
.012 w
.21503 .6748 m
.19001 .51686 L
s
P
p
.8 0 1 r
.012 w
.21503 .6748 m
.07254 .7474 L
s
P
p
.8 0 1 r
.012 w
.21503 .6748 m
.32811 .78788 L
s
P
p
.8 0 1 r
.012 w
.21503 .6748 m
.28763 .53232 L
s
P
p
.8 1 0 r
.018 w
.369 .51943 m
.33131 .55712 L
s
P
p
.8 1 0 r
.018 w
.369 .51943 m
.40669 .48174 L
s
P
p
.8 1 0 r
.018 w
.40948 .77499 m
.45697 .79919 L
s
P
p
.8 1 0 r
.018 w
.40948 .77499 m
.36198 .75079 L
s
P
p
.8 1 0 r
.018 w
.64003 .65752 m
.64836 .60487 L
s
P
p
.8 1 0 r
.018 w
.64003 .65752 m
.63169 .71017 L
s
P
p
.8 1 0 r
.018 w
.45706 .47456 m
.40441 .4829 L
s
P
p
.8 1 0 r
.018 w
.45706 .47456 m
.50971 .46622 L
s
P
p
.8 1 0 r
.018 w
.33959 .70511 m
.36379 .7526 L
s
P
p
.8 1 0 r
.018 w
.33959 .70511 m
.31539 .65761 L
s
P
p
.8 0 1 r
.012 w
.48208 .63251 m
.369 .51943 L
s
P
p
.8 0 1 r
.012 w
.48208 .63251 m
.40948 .77499 L
s
P
p
.8 0 1 r
.012 w
.48208 .63251 m
.64003 .65752 L
s
P
p
.8 0 1 r
.012 w
.48208 .63251 m
.45706 .47456 L
s
P
p
.8 0 1 r
.012 w
.48208 .63251 m
.33959 .70511 L
s
P
p
.8 1 0 r
.018 w
.26619 .6677 m
.31883 .65936 L
s
P
p
.8 1 0 r
.018 w
.26619 .6677 m
.21354 .67604 L
s
P
p
.8 1 0 r
.018 w
.38366 .43716 m
.35946 .38966 L
s
P
p
.8 1 0 r
.018 w
.38366 .43716 m
.40786 .48465 L
s
P
p
.8 1 0 r
.018 w
.12809 .39668 m
.0904 .43437 L
s
P
p
.8 1 0 r
.018 w
.12809 .39668 m
.16579 .35899 L
s
P
p
.8 1 0 r
.018 w
.16857 .65224 m
.21607 .67644 L
s
P
p
.8 1 0 r
.018 w
.16857 .65224 m
.12107 .62804 L
s
P
p
.8 1 0 r
.018 w
.39912 .53477 m
.40745 .48212 L
s
P
p
.8 1 0 r
.018 w
.39912 .53477 m
.39078 .58742 L
s
P
p
.8 0 1 r
.012 w
.24117 .50976 m
.26619 .6677 L
s
P
p
.8 0 1 r
.012 w
.24117 .50976 m
.38366 .43716 L
s
P
p
.8 0 1 r
.012 w
.24117 .50976 m
.12809 .39668 L
s
P
p
.8 0 1 r
.012 w
.24117 .50976 m
.16857 .65224 L
s
P
p
.8 0 1 r
.012 w
.24117 .50976 m
.39912 .53477 L
s
P
p
1 .6 0 r
.016 w
.34168 .61027 m
.36392 .75067 L
s
P
p
1 .6 0 r
.016 w
.34168 .61027 m
.40622 .48362 L
s
P
p
1 .6 0 r
.016 w
.34168 .61027 m
.21503 .6748 L
s
P
p
1 .6 0 r
.016 w
.34168 .61027 m
.48208 .63251 L
s
P
p
1 .6 0 r
.016 w
.34168 .61027 m
.24117 .50976 L
s
P
p
.8 1 0 r
.018 w
.60088 .53477 m
.60922 .58742 L
s
P
p
.8 1 0 r
.018 w
.60088 .53477 m
.59255 .48212 L
s
P
p
.8 1 0 r
.018 w
.83143 .65224 m
.87893 .62804 L
s
P
p
.8 1 0 r
.018 w
.83143 .65224 m
.78393 .67644 L
s
P
p
.8 1 0 r
.018 w
.87191 .39668 m
.83421 .35899 L
s
P
p
.8 1 0 r
.018 w
.87191 .39668 m
.9096 .43437 L
s
P
p
.8 1 0 r
.018 w
.61634 .43716 m
.59214 .48465 L
s
P
p
.8 1 0 r
.018 w
.61634 .43716 m
.64054 .38966 L
s
P
p
.8 1 0 r
.018 w
.73381 .6677 m
.78646 .67604 L
s
P
p
.8 1 0 r
.018 w
.73381 .6677 m
.68117 .65936 L
s
P
p
.8 0 1 r
.012 w
.75883 .50976 m
.60088 .53477 L
s
P
p
.8 0 1 r
.012 w
.75883 .50976 m
.83143 .65224 L
s
P
p
.8 0 1 r
.012 w
.75883 .50976 m
.87191 .39668 L
s
P
p
.8 0 1 r
.012 w
.75883 .50976 m
.61634 .43716 L
s
P
p
.8 0 1 r
.012 w
.75883 .50976 m
.73381 .6677 L
s
P
p
.8 1 0 r
.018 w
.66041 .70511 m
.68461 .65761 L
s
P
p
.8 1 0 r
.018 w
.66041 .70511 m
.63621 .7526 L
s
P
p
.8 1 0 r
.018 w
.54294 .47456 m
.49029 .46622 L
s
P
p
.8 1 0 r
.018 w
.54294 .47456 m
.59559 .4829 L
s
P
p
.8 1 0 r
.018 w
.35997 .65752 m
.36831 .71017 L
s
P
p
.8 1 0 r
.018 w
.35997 .65752 m
.35164 .60487 L
s
P
p
.8 1 0 r
.018 w
.59052 .77499 m
.63802 .75079 L
s
P
p
.8 1 0 r
.018 w
.59052 .77499 m
.54303 .79919 L
s
P
p
.8 1 0 r
.018 w
.631 .51943 m
.59331 .48174 L
s
P
p
.8 1 0 r
.018 w
.631 .51943 m
.66869 .55712 L
s
P
p
.8 0 1 r
.012 w
.51792 .63251 m
.66041 .70511 L
s
P
p
.8 0 1 r
.012 w
.51792 .63251 m
.54294 .47456 L
s
P
p
.8 0 1 r
.012 w
.51792 .63251 m
.35997 .65752 L
s
P
p
.8 0 1 r
.012 w
.51792 .63251 m
.59052 .77499 L
s
P
p
.8 0 1 r
.012 w
.51792 .63251 m
.631 .51943 L
s
P
p
.8 1 0 r
.018 w
.71237 .53232 m
.66488 .55652 L
s
P
p
.8 1 0 r
.018 w
.71237 .53232 m
.75987 .50812 L
s
P
p
.8 1 0 r
.018 w
.67189 .78788 m
.70959 .82557 L
s
P
p
.8 1 0 r
.018 w
.67189 .78788 m
.6342 .75019 L
s
P
p
.8 1 0 r
.018 w
.92746 .7474 m
.95166 .69991 L
s
P
p
.8 1 0 r
.018 w
.92746 .7474 m
.90326 .7949 L
s
P
p
.8 1 0 r
.018 w
.80999 .51686 m
.75734 .50852 L
s
P
p
.8 1 0 r
.018 w
.80999 .51686 m
.86264 .5252 L
s
P
p
.8 1 0 r
.018 w
.62702 .69982 m
.63536 .75247 L
s
P
p
.8 1 0 r
.018 w
.62702 .69982 m
.61869 .64717 L
s
P
p
.8 0 1 r
.012 w
.78497 .6748 m
.71237 .53232 L
s
P
p
.8 0 1 r
.012 w
.78497 .6748 m
.67189 .78788 L
s
P
p
.8 0 1 r
.012 w
.78497 .6748 m
.92746 .7474 L
s
P
p
.8 0 1 r
.012 w
.78497 .6748 m
.80999 .51686 L
s
P
p
.8 0 1 r
.012 w
.78497 .6748 m
.62702 .69982 L
s
P
p
.8 1 0 r
.018 w
.56877 .64156 m
.62142 .6499 L
s
P
p
.8 1 0 r
.018 w
.56877 .64156 m
.51612 .63322 L
s
P
p
.8 1 0 r
.018 w
.75173 .4586 m
.74339 .40595 L
s
P
p
.8 1 0 r
.018 w
.75173 .4586 m
.76007 .51125 L
s
P
p
.8 1 0 r
.018 w
.52118 .34113 m
.47369 .36533 L
s
P
p
.8 1 0 r
.018 w
.52118 .34113 m
.56868 .31693 L
s
P
p
.8 1 0 r
.018 w
.48071 .59669 m
.5184 .63439 L
s
P
p
.8 1 0 r
.018 w
.48071 .59669 m
.44301 .559 L
s
P
p
.8 1 0 r
.018 w
.73627 .55622 m
.76047 .50872 L
s
P
p
.8 1 0 r
.018 w
.73627 .55622 m
.71207 .60371 L
s
P
p
.8 0 1 r
.012 w
.59378 .48362 m
.56877 .64156 L
s
P
p
.8 0 1 r
.012 w
.59378 .48362 m
.75173 .4586 L
s
P
p
.8 0 1 r
.012 w
.59378 .48362 m
.52118 .34113 L
s
P
p
.8 0 1 r
.012 w
.59378 .48362 m
.48071 .59669 L
s
P
p
.8 0 1 r
.012 w
.59378 .48362 m
.73627 .55622 L
s
P
p
.8 1 0 r
.018 w
.74916 .63759 m
.71147 .5999 L
s
P
p
.8 1 0 r
.018 w
.74916 .63759 m
.78685 .67528 L
s
P
p
.8 1 0 r
.018 w
.4936 .67807 m
.4694 .72556 L
s
P
p
.8 1 0 r
.018 w
.4936 .67807 m
.5178 .63057 L
s
P
p
.8 1 0 r
.018 w
.61106 .90861 m
.66371 .91695 L
s
P
p
.8 1 0 r
.018 w
.61106 .90861 m
.55842 .90027 L
s
P
p
.8 1 0 r
.018 w
.79403 .72565 m
.78569 .673 L
s
P
p
.8 1 0 r
.018 w
.79403 .72565 m
.80237 .7783 L
s
P
p
.8 1 0 r
.018 w
.56348 .60818 m
.51599 .63238 L
s
P
p
.8 1 0 r
.018 w
.56348 .60818 m
.61098 .58398 L
s
P
p
.8 0 1 r
.012 w
.63608 .75067 m
.74916 .63759 L
s
P
p
.8 0 1 r
.012 w
.63608 .75067 m
.4936 .67807 L
s
P
p
.8 0 1 r
.012 w
.63608 .75067 m
.61106 .90861 L
s
P
p
.8 0 1 r
.012 w
.63608 .75067 m
.79403 .72565 L
s
P
p
.8 0 1 r
.012 w
.63608 .75067 m
.56348 .60818 L
s
P
p
1 .6 0 r
.016 w
.65832 .61027 m
.75883 .50976 L
s
P
p
1 .6 0 r
.016 w
.65832 .61027 m
.51792 .63251 L
s
P
p
1 .6 0 r
.016 w
.65832 .61027 m
.78497 .6748 L
s
P
p
1 .6 0 r
.016 w
.65832 .61027 m
.59378 .48362 L
s
P
p
1 .6 0 r
.016 w
.65832 .61027 m
.63608 .75067 L
s
P
p
.8 1 0 r
.018 w
.44488 .44495 m
.48258 .40726 L
s
P
p
.8 1 0 r
.018 w
.44488 .44495 m
.40719 .48264 L
s
P
p
.8 1 0 r
.018 w
.40441 .18939 m
.35691 .16519 L
s
P
p
.8 1 0 r
.018 w
.40441 .18939 m
.4519 .21359 L
s
P
p
.8 1 0 r
.018 w
.17386 .30685 m
.16552 .3595 L
s
P
p
.8 1 0 r
.018 w
.17386 .30685 m
.1822 .25421 L
s
P
p
.8 1 0 r
.018 w
.35682 .48982 m
.40947 .48148 L
s
P
p
.8 1 0 r
.018 w
.35682 .48982 m
.30417 .49816 L
s
P
p
.8 1 0 r
.018 w
.47429 .25927 m
.45009 .21178 L
s
P
p
.8 1 0 r
.018 w
.47429 .25927 m
.49849 .30677 L
s
P
p
.8 0 1 r
.012 w
.33181 .33187 m
.44488 .44495 L
s
P
p
.8 0 1 r
.012 w
.33181 .33187 m
.40441 .18939 L
s
P
p
.8 0 1 r
.012 w
.33181 .33187 m
.17386 .30685 L
s
P
p
.8 0 1 r
.012 w
.33181 .33187 m
.35682 .48982 L
s
P
p
.8 0 1 r
.012 w
.33181 .33187 m
.47429 .25927 L
s
P
p
.8 1 0 r
.018 w
.5477 .29667 m
.49505 .30501 L
s
P
p
.8 1 0 r
.018 w
.5477 .29667 m
.60035 .28834 L
s
P
p
.8 1 0 r
.018 w
.43023 .52722 m
.45443 .57472 L
s
P
p
.8 1 0 r
.018 w
.43023 .52722 m
.40603 .47973 L
s
P
p
.8 1 0 r
.018 w
.68579 .5677 m
.72349 .53001 L
s
P
p
.8 1 0 r
.018 w
.68579 .5677 m
.6481 .60539 L
s
P
p
.8 1 0 r
.018 w
.64532 .31214 m
.59782 .28794 L
s
P
p
.8 1 0 r
.018 w
.64532 .31214 m
.69281 .33634 L
s
P
p
.8 1 0 r
.018 w
.41477 .4296 m
.40643 .48225 L
s
P
p
.8 1 0 r
.018 w
.41477 .4296 m
.42311 .37696 L
s
P
p
.8 0 1 r
.012 w
.57272 .45462 m
.5477 .29667 L
s
P
p
.8 0 1 r
.012 w
.57272 .45462 m
.43023 .52722 L
s
P
p
.8 0 1 r
.012 w
.57272 .45462 m
.68579 .5677 L
s
P
p
.8 0 1 r
.012 w
.57272 .45462 m
.64532 .31214 L
s
P
p
.8 0 1 r
.012 w
.57272 .45462 m
.41477 .4296 L
s
P
p
.8 1 0 r
.018 w
.37737 .3562 m
.42486 .3804 L
s
P
p
.8 1 0 r
.018 w
.37737 .3562 m
.32987 .332 L
s
P
p
.8 1 0 r
.018 w
.60791 .23873 m
.61625 .18608 L
s
P
p
.8 1 0 r
.018 w
.60791 .23873 m
.59958 .29138 L
s
P
p
.8 1 0 r
.018 w
.42495 .05576 m
.3723 .0641 L
s
P
p
.8 1 0 r
.018 w
.42495 .05576 m
.4776 .04743 L
s
P
p
.8 1 0 r
.018 w
.30748 .28631 m
.33168 .33381 L
s
P
p
.8 1 0 r
.018 w
.30748 .28631 m
.28328 .23882 L
s
P
p
.8 1 0 r
.018 w
.56304 .32679 m
.60074 .2891 L
s
P
p
.8 1 0 r
.018 w
.56304 .32679 m
.52535 .36448 L
s
P
p
.8 0 1 r
.012 w
.44997 .21371 m
.37737 .3562 L
s
P
p
.8 0 1 r
.012 w
.44997 .21371 m
.60791 .23873 L
s
P
p
.8 0 1 r
.012 w
.44997 .21371 m
.42495 .05576 L
s
P
p
.8 0 1 r
.012 w
.44997 .21371 m
.30748 .28631 L
s
P
p
.8 0 1 r
.012 w
.44997 .21371 m
.56304 .32679 L
s
P
p
.8 1 0 r
.018 w
.55016 .40816 m
.52596 .36067 L
s
P
p
.8 1 0 r
.018 w
.55016 .40816 m
.57436 .45566 L
s
P
p
.8 1 0 r
.018 w
.29459 .36768 m
.2569 .40538 L
s
P
p
.8 1 0 r
.018 w
.29459 .36768 m
.33229 .32999 L
s
P
p
.8 1 0 r
.018 w
.33507 .62325 m
.38257 .64745 L
s
P
p
.8 1 0 r
.018 w
.33507 .62325 m
.28758 .59905 L
s
P
p
.8 1 0 r
.018 w
.56562 .50578 m
.57396 .45313 L
s
P
p
.8 1 0 r
.018 w
.56562 .50578 m
.55728 .55843 L
s
P
p
.8 1 0 r
.018 w
.38265 .32282 m
.33001 .33115 L
s
P
p
.8 1 0 r
.018 w
.38265 .32282 m
.4353 .31448 L
s
P
p
.8 0 1 r
.012 w
.40767 .48076 m
.55016 .40816 L
s
P
p
.8 0 1 r
.012 w
.40767 .48076 m
.29459 .36768 L
s
P
p
.8 0 1 r
.012 w
.40767 .48076 m
.33507 .62325 L
s
P
p
.8 0 1 r
.012 w
.40767 .48076 m
.56562 .50578 L
s
P
p
.8 0 1 r
.012 w
.40767 .48076 m
.38265 .32282 L
s
P
p
.8 1 0 r
.018 w
.44091 .26456 m
.43257 .31721 L
s
P
p
.8 1 0 r
.018 w
.44091 .26456 m
.44925 .21191 L
s
P
p
.8 1 0 r
.018 w
.62387 .44752 m
.67652 .43918 L
s
P
p
.8 1 0 r
.018 w
.62387 .44752 m
.57123 .45586 L
s
P
p
.8 1 0 r
.018 w
.74134 .21697 m
.71714 .16948 L
s
P
p
.8 1 0 r
.018 w
.74134 .21697 m
.76554 .26447 L
s
P
p
.8 1 0 r
.018 w
.48578 .1765 m
.44809 .21419 L
s
P
p
.8 1 0 r
.018 w
.48578 .1765 m
.52347 .13881 L
s
P
p
.8 1 0 r
.018 w
.52626 .43206 m
.57375 .45626 L
s
P
p
.8 1 0 r
.018 w
.52626 .43206 m
.47876 .40786 L
s
P
p
.8 0 1 r
.012 w
.59886 .28957 m
.44091 .26456 L
s
P
p
.8 0 1 r
.012 w
.59886 .28957 m
.62387 .44752 L
s
P
p
.8 0 1 r
.012 w
.59886 .28957 m
.74134 .21697 L
s
P
p
.8 0 1 r
.012 w
.59886 .28957 m
.48578 .1765 L
s
P
p
.8 0 1 r
.012 w
.59886 .28957 m
.52626 .43206 L
s
P
p
1 .6 0 r
.016 w
.4722 .35411 m
.33181 .33187 L
s
P
p
1 .6 0 r
.016 w
.4722 .35411 m
.57272 .45462 L
s
P
p
1 .6 0 r
.016 w
.4722 .35411 m
.44997 .21371 L
s
P
p
1 .6 0 r
.016 w
.4722 .35411 m
.40767 .48076 L
s
P
p
1 .6 0 r
.016 w
.4722 .35411 m
.59886 .28957 L
s
P
p
.2 0 1 r
.018 w
.5 .5296 m
.5278 .35411 L
s
P
p
.2 0 1 r
.018 w
.5 .5296 m
.34168 .61027 L
s
P
p
.2 0 1 r
.018 w
.5 .5296 m
.65832 .61027 L
s
P
p
.2 0 1 r
.018 w
.5 .5296 m
.4722 .35411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.0141093 0.588183 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.124671 0.952381 [
[ 0 0 0 0 ]
[ 1 .70304 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .70304 L
0 .70304 L
closepath
clip
newpath
p
P
p
.8 0 1 r
.02 w
.5 .18903 m
.05269 .04369 L
s
P
p
.8 0 1 r
.02 w
.5 .18903 m
.1195 .46548 L
s
P
p
.8 0 1 r
.02 w
.5 .18903 m
.5 .65935 L
s
P
p
.8 0 1 r
.02 w
.5 .18903 m
.8805 .46548 L
s
P
p
.8 0 1 r
.02 w
.5 .18903 m
.94731 .04369 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.0141093 0.782187 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.35714 5.71429 0.142857 5.71429 [
[ 0 0 0 0 ]
[ 1 6 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 6 L
0 6 L
closepath
clip
newpath
p
P
p
1 0 .6 r
.02 w
.5 .34977 m
.5 5.65023 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.0141093 0.97619 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.174603 0.952381 [
[ 0 0 0 0 ]
[ 1 .60317 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .60317 L
0 .60317 L
closepath
clip
newpath
p
P
p
1 0 0 r
.02 w
.26405 .20757 m
.17782 .03833 L
s
P
p
1 0 0 r
.018 w
.30237 .28278 m
.26405 .20757 L
s
P
p
1 0 0 r
.02 w
.21793 .34949 m
.04869 .43573 L
s
P
p
1 0 0 r
.018 w
.29315 .31117 m
.21793 .34949 L
s
P
p
1 0 0 r
.02 w
.35986 .39561 m
.44609 .56485 L
s
P
p
1 0 0 r
.018 w
.32154 .32039 m
.35986 .39561 L
s
P
p
.8 1 0 r
.006 w
.31196 .30159 m
.30237 .28278 L
s
P
p
.8 1 0 r
.006 w
.31196 .30159 m
.29315 .31117 L
s
P
p
.8 1 0 r
.006 w
.31196 .30159 m
.32154 .32039 L
s
P
p
1 0 0 r
.02 w
.64014 .39561 m
.55391 .56485 L
s
P
p
1 0 0 r
.018 w
.67846 .32039 m
.64014 .39561 L
s
P
p
1 0 0 r
.02 w
.78207 .34949 m
.95131 .43573 L
s
P
p
1 0 0 r
.018 w
.70685 .31117 m
.78207 .34949 L
s
P
p
1 0 0 r
.02 w
.73595 .20757 m
.82218 .03833 L
s
P
p
1 0 0 r
.018 w
.69763 .28278 m
.73595 .20757 L
s
P
p
.8 1 0 r
.006 w
.68804 .30159 m
.67846 .32039 L
s
P
p
.8 1 0 r
.006 w
.68804 .30159 m
.70685 .31117 L
s
P
p
.8 1 0 r
.006 w
.68804 .30159 m
.69763 .28278 L
s
P
p
0 1 .4 r
.02 w
.5 .20577 m
.31196 .30159 L
s
P
p
0 1 .4 r
.02 w
.5 .20577 m
.68804 .30159 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.208113 0.200176 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.014 w
.94407 .5 m
.94407 .05593 L
s
P
p
0 .4 1 r
.014 w
.94407 .5 m
.94407 .94407 L
s
P
p
0 .4 1 r
.014 w
.05593 .5 m
.05593 .94407 L
s
P
p
0 .4 1 r
.014 w
.05593 .5 m
.05593 .05593 L
s
P
p
.8 0 1 r
.014 w
.5 .5 m
.94407 .5 L
s
P
p
.8 0 1 r
.014 w
.5 .5 m
.05593 .5 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.208113 0.39418 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.190169 0.952381 [
[ 0 0 0 0 ]
[ 1 .57204 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .57204 L
0 .57204 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.006 w
.19914 .25703 m
.0788 .1696 L
s
P
p
.2 0 1 r
.006 w
.19914 .25703 m
.05039 .25703 L
s
P
p
.2 0 1 r
.006 w
.19914 .25703 m
.0788 .34447 L
s
P
p
.2 0 1 r
.006 w
.19914 .25703 m
.15318 .3985 L
s
P
p
.2 0 1 r
.006 w
.19914 .25703 m
.24511 .3985 L
s
P
p
.2 0 1 r
.006 w
.38508 .39212 m
.23633 .39212 L
s
P
p
.2 0 1 r
.006 w
.38508 .39212 m
.26474 .47956 L
s
P
p
.2 0 1 r
.006 w
.38508 .39212 m
.33912 .5336 L
s
P
p
.2 0 1 r
.006 w
.38508 .39212 m
.43105 .5336 L
s
P
p
.2 0 1 r
.006 w
.38508 .39212 m
.50543 .47956 L
s
P
p
.2 0 1 r
.006 w
.61492 .39212 m
.49457 .47956 L
s
P
p
.2 0 1 r
.006 w
.61492 .39212 m
.56895 .5336 L
s
P
p
.2 0 1 r
.006 w
.61492 .39212 m
.66088 .5336 L
s
P
p
.2 0 1 r
.006 w
.61492 .39212 m
.73526 .47956 L
s
P
p
.2 0 1 r
.006 w
.61492 .39212 m
.76367 .39212 L
s
P
p
.2 0 1 r
.006 w
.80086 .25703 m
.75489 .3985 L
s
P
p
.2 0 1 r
.006 w
.80086 .25703 m
.84682 .3985 L
s
P
p
.2 0 1 r
.006 w
.80086 .25703 m
.9212 .34447 L
s
P
p
.2 0 1 r
.006 w
.80086 .25703 m
.94961 .25703 L
s
P
p
.2 0 1 r
.006 w
.80086 .25703 m
.9212 .1696 L
s
P
p
.2 1 0 r
.002 w
.5 .03845 m
.19914 .25703 L
s
P
p
.2 1 0 r
.002 w
.5 .03845 m
.38508 .39212 L
s
P
p
.2 1 0 r
.002 w
.5 .03845 m
.61492 .39212 L
s
P
p
.2 1 0 r
.002 w
.5 .03845 m
.80086 .25703 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.208113 0.588183 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.000503103 0.952381 [
[ 0 0 0 0 ]
[ 1 .95339 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95339 L
0 .95339 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.006 w
.44338 .30242 m
.50082 .12563 L
s
P
p
.2 0 1 r
.006 w
.44338 .30242 m
.38593 .12563 L
s
P
p
.2 0 1 r
.006 w
.44338 .30242 m
.29299 .19316 L
s
P
p
.2 0 1 r
.006 w
.44338 .30242 m
.25748 .30242 L
s
P
p
.2 0 1 r
.006 w
.44338 .49041 m
.25748 .49041 L
s
P
p
.2 0 1 r
.006 w
.44338 .49041 m
.29299 .59967 L
s
P
p
.2 0 1 r
.006 w
.44338 .49041 m
.38593 .6672 L
s
P
p
.2 0 1 r
.006 w
.44338 .49041 m
.50082 .6672 L
s
P
p
.2 0 1 r
.006 w
.62216 .43232 m
.6796 .60911 L
s
P
p
.2 0 1 r
.006 w
.62216 .43232 m
.77255 .54158 L
s
P
p
.2 0 1 r
.006 w
.62216 .43232 m
.80805 .43232 L
s
P
p
.2 0 1 r
.006 w
.62216 .43232 m
.77255 .32305 L
s
P
p
.2 0 1 r
.006 w
.51167 .28023 m
.66205 .17097 L
s
P
p
.2 0 1 r
.006 w
.51167 .28023 m
.56911 .10344 L
s
P
p
.2 0 1 r
.006 w
.51167 .28023 m
.45422 .10344 L
s
P
p
.2 0 1 r
.006 w
.51167 .28023 m
.36128 .17097 L
s
P
p
.2 0 1 r
.006 w
.40117 .43232 m
.25078 .32305 L
s
P
p
.2 0 1 r
.006 w
.40117 .43232 m
.21528 .43232 L
s
P
p
.2 0 1 r
.006 w
.40117 .43232 m
.25078 .54158 L
s
P
p
.2 0 1 r
.006 w
.40117 .43232 m
.34373 .60911 L
s
P
p
0 1 1 r
.018 w
.51167 .39641 m
.44338 .30242 L
s
P
p
0 1 1 r
.018 w
.51167 .39641 m
.44338 .49041 L
s
P
p
0 1 1 r
.018 w
.51167 .39641 m
.62216 .43232 L
s
P
p
0 1 1 r
.018 w
.51167 .39641 m
.51167 .28023 L
s
P
p
0 1 1 r
.018 w
.51167 .39641 m
.40117 .43232 L
s
P
p
.2 0 1 r
.006 w
.37585 .35438 m
.22546 .24511 L
s
P
p
.2 0 1 r
.006 w
.37585 .35438 m
.18995 .35438 L
s
P
p
.2 0 1 r
.006 w
.37585 .35438 m
.22546 .46364 L
s
P
p
.2 0 1 r
.006 w
.37585 .35438 m
.3184 .53117 L
s
P
p
.2 0 1 r
.006 w
.55463 .41247 m
.49719 .58926 L
s
P
p
.2 0 1 r
.006 w
.55463 .41247 m
.61208 .58926 L
s
P
p
.2 0 1 r
.006 w
.55463 .41247 m
.70502 .52173 L
s
P
p
.2 0 1 r
.006 w
.55463 .41247 m
.74052 .41247 L
s
P
p
.2 0 1 r
.006 w
.55463 .22448 m
.74052 .22448 L
s
P
p
.2 0 1 r
.006 w
.55463 .22448 m
.70502 .11522 L
s
P
p
.2 0 1 r
.006 w
.55463 .22448 m
.61208 .04769 L
s
P
p
.2 0 1 r
.006 w
.55463 .22448 m
.49719 .04769 L
s
P
p
.2 0 1 r
.006 w
.37585 .28257 m
.3184 .10578 L
s
P
p
.2 0 1 r
.006 w
.37585 .28257 m
.22546 .17331 L
s
P
p
.2 0 1 r
.006 w
.37585 .28257 m
.18995 .28257 L
s
P
p
.2 0 1 r
.006 w
.37585 .28257 m
.22546 .39184 L
s
P
p
.2 0 1 r
.006 w
.48634 .43466 m
.33595 .54392 L
s
P
p
.2 0 1 r
.006 w
.48634 .43466 m
.4289 .61145 L
s
P
p
.2 0 1 r
.006 w
.48634 .43466 m
.54379 .61145 L
s
P
p
.2 0 1 r
.006 w
.48634 .43466 m
.63673 .54392 L
s
P
p
0 1 1 r
.018 w
.48634 .31848 m
.37585 .35438 L
s
P
p
0 1 1 r
.018 w
.48634 .31848 m
.55463 .41247 L
s
P
p
0 1 1 r
.018 w
.48634 .31848 m
.55463 .22448 L
s
P
p
0 1 1 r
.018 w
.48634 .31848 m
.37585 .28257 L
s
P
p
0 1 1 r
.018 w
.48634 .31848 m
.48634 .43466 L
s
P
p
.2 0 1 r
.006 w
.40439 .43466 m
.254 .54392 L
s
P
p
.2 0 1 r
.006 w
.40439 .43466 m
.34695 .61145 L
s
P
p
.2 0 1 r
.006 w
.40439 .43466 m
.46184 .61145 L
s
P
p
.2 0 1 r
.006 w
.40439 .43466 m
.55478 .54392 L
s
P
p
.2 0 1 r
.006 w
.51489 .28257 m
.66528 .39184 L
s
P
p
.2 0 1 r
.006 w
.51489 .28257 m
.70078 .28257 L
s
P
p
.2 0 1 r
.006 w
.51489 .28257 m
.66528 .17331 L
s
P
p
.2 0 1 r
.006 w
.51489 .28257 m
.57233 .10578 L
s
P
p
.2 0 1 r
.006 w
.3361 .22448 m
.39355 .04769 L
s
P
p
.2 0 1 r
.006 w
.3361 .22448 m
.27866 .04769 L
s
P
p
.2 0 1 r
.006 w
.3361 .22448 m
.18571 .11522 L
s
P
p
.2 0 1 r
.006 w
.3361 .22448 m
.15021 .22448 L
s
P
p
.2 0 1 r
.006 w
.3361 .41247 m
.15021 .41247 L
s
P
p
.2 0 1 r
.006 w
.3361 .41247 m
.18571 .52173 L
s
P
p
.2 0 1 r
.006 w
.3361 .41247 m
.27866 .58926 L
s
P
p
.2 0 1 r
.006 w
.3361 .41247 m
.39355 .58926 L
s
P
p
.2 0 1 r
.006 w
.51489 .35438 m
.57233 .53117 L
s
P
p
.2 0 1 r
.006 w
.51489 .35438 m
.66528 .46364 L
s
P
p
.2 0 1 r
.006 w
.51489 .35438 m
.70078 .35438 L
s
P
p
.2 0 1 r
.006 w
.51489 .35438 m
.66528 .24511 L
s
P
p
0 1 1 r
.018 w
.40439 .31848 m
.40439 .43466 L
s
P
p
0 1 1 r
.018 w
.40439 .31848 m
.51489 .28257 L
s
P
p
0 1 1 r
.018 w
.40439 .31848 m
.3361 .22448 L
s
P
p
0 1 1 r
.018 w
.40439 .31848 m
.3361 .41247 L
s
P
p
0 1 1 r
.018 w
.40439 .31848 m
.51489 .35438 L
s
P
p
.2 0 1 r
.006 w
.48957 .43232 m
.54701 .60911 L
s
P
p
.2 0 1 r
.006 w
.48957 .43232 m
.63996 .54158 L
s
P
p
.2 0 1 r
.006 w
.48957 .43232 m
.67546 .43232 L
s
P
p
.2 0 1 r
.006 w
.48957 .43232 m
.63996 .32305 L
s
P
p
.2 0 1 r
.006 w
.37907 .28023 m
.52946 .17097 L
s
P
p
.2 0 1 r
.006 w
.37907 .28023 m
.43651 .10344 L
s
P
p
.2 0 1 r
.006 w
.37907 .28023 m
.32163 .10344 L
s
P
p
.2 0 1 r
.006 w
.37907 .28023 m
.22868 .17097 L
s
P
p
.2 0 1 r
.006 w
.26857 .43232 m
.11819 .32305 L
s
P
p
.2 0 1 r
.006 w
.26857 .43232 m
.08268 .43232 L
s
P
p
.2 0 1 r
.006 w
.26857 .43232 m
.11819 .54158 L
s
P
p
.2 0 1 r
.006 w
.26857 .43232 m
.21113 .60911 L
s
P
p
.2 0 1 r
.006 w
.44736 .49041 m
.38992 .6672 L
s
P
p
.2 0 1 r
.006 w
.44736 .49041 m
.5048 .6672 L
s
P
p
.2 0 1 r
.006 w
.44736 .49041 m
.59775 .59967 L
s
P
p
.2 0 1 r
.006 w
.44736 .49041 m
.63325 .49041 L
s
P
p
.2 0 1 r
.006 w
.44736 .30242 m
.63325 .30242 L
s
P
p
.2 0 1 r
.006 w
.44736 .30242 m
.59775 .19316 L
s
P
p
.2 0 1 r
.006 w
.44736 .30242 m
.5048 .12563 L
s
P
p
.2 0 1 r
.006 w
.44736 .30242 m
.38992 .12563 L
s
P
p
0 1 1 r
.018 w
.37907 .39641 m
.48957 .43232 L
s
P
p
0 1 1 r
.018 w
.37907 .39641 m
.37907 .28023 L
s
P
p
0 1 1 r
.018 w
.37907 .39641 m
.26857 .43232 L
s
P
p
0 1 1 r
.018 w
.37907 .39641 m
.44736 .49041 L
s
P
p
0 1 1 r
.018 w
.37907 .39641 m
.44736 .30242 L
s
P
p
.2 0 1 r
.006 w
.51366 .35059 m
.69955 .35059 L
s
P
p
.2 0 1 r
.006 w
.51366 .35059 m
.66405 .24132 L
s
P
p
.2 0 1 r
.006 w
.51366 .35059 m
.5711 .1738 L
s
P
p
.2 0 1 r
.006 w
.51366 .35059 m
.45621 .1738 L
s
P
p
.2 0 1 r
.006 w
.33487 .40868 m
.27743 .23189 L
s
P
p
.2 0 1 r
.006 w
.33487 .40868 m
.18448 .29942 L
s
P
p
.2 0 1 r
.006 w
.33487 .40868 m
.14898 .40868 L
s
P
p
.2 0 1 r
.006 w
.33487 .40868 m
.18448 .51794 L
s
P
p
.2 0 1 r
.006 w
.44537 .56076 m
.29498 .67003 L
s
P
p
.2 0 1 r
.006 w
.44537 .56076 m
.38792 .73756 L
s
P
p
.2 0 1 r
.006 w
.44537 .56076 m
.50281 .73756 L
s
P
p
.2 0 1 r
.006 w
.44537 .56076 m
.59576 .67003 L
s
P
p
.2 0 1 r
.006 w
.55586 .40868 m
.70625 .51794 L
s
P
p
.2 0 1 r
.006 w
.55586 .40868 m
.74176 .40868 L
s
P
p
.2 0 1 r
.006 w
.55586 .40868 m
.70625 .29942 L
s
P
p
.2 0 1 r
.006 w
.55586 .40868 m
.61331 .23189 L
s
P
p
.2 0 1 r
.006 w
.37708 .35059 m
.43452 .1738 L
s
P
p
.2 0 1 r
.006 w
.37708 .35059 m
.31963 .1738 L
s
P
p
.2 0 1 r
.006 w
.37708 .35059 m
.22669 .24132 L
s
P
p
.2 0 1 r
.006 w
.37708 .35059 m
.19119 .35059 L
s
P
p
0 1 1 r
.018 w
.44537 .44458 m
.51366 .35059 L
s
P
p
0 1 1 r
.018 w
.44537 .44458 m
.33487 .40868 L
s
P
p
0 1 1 r
.018 w
.44537 .44458 m
.44537 .56076 L
s
P
p
0 1 1 r
.018 w
.44537 .44458 m
.55586 .40868 L
s
P
p
0 1 1 r
.018 w
.44537 .44458 m
.37708 .35059 L
s
P
p
0 1 .4 r
.016 w
.44537 .37487 m
.51167 .39641 L
s
P
p
0 1 .4 r
.016 w
.44537 .37487 m
.48634 .31848 L
s
P
p
0 1 .4 r
.016 w
.44537 .37487 m
.40439 .31848 L
s
P
p
0 1 .4 r
.016 w
.44537 .37487 m
.37907 .39641 L
s
P
p
0 1 .4 r
.016 w
.44537 .37487 m
.44537 .44458 L
s
P
p
.2 0 1 r
.006 w
.34208 .4583 m
.19169 .34903 L
s
P
p
.2 0 1 r
.006 w
.34208 .4583 m
.15619 .4583 L
s
P
p
.2 0 1 r
.006 w
.34208 .4583 m
.19169 .56756 L
s
P
p
.2 0 1 r
.006 w
.34208 .4583 m
.28464 .63509 L
s
P
p
.2 0 1 r
.006 w
.52087 .51639 m
.46342 .69318 L
s
P
p
.2 0 1 r
.006 w
.52087 .51639 m
.57831 .69318 L
s
P
p
.2 0 1 r
.006 w
.52087 .51639 m
.67126 .62565 L
s
P
p
.2 0 1 r
.006 w
.52087 .51639 m
.70676 .51639 L
s
P
p
.2 0 1 r
.006 w
.52087 .3284 m
.70676 .3284 L
s
P
p
.2 0 1 r
.006 w
.52087 .3284 m
.67126 .21914 L
s
P
p
.2 0 1 r
.006 w
.52087 .3284 m
.57831 .15161 L
s
P
p
.2 0 1 r
.006 w
.52087 .3284 m
.46342 .15161 L
s
P
p
.2 0 1 r
.006 w
.34208 .38649 m
.28464 .2097 L
s
P
p
.2 0 1 r
.006 w
.34208 .38649 m
.19169 .27723 L
s
P
p
.2 0 1 r
.006 w
.34208 .38649 m
.15619 .38649 L
s
P
p
.2 0 1 r
.006 w
.34208 .38649 m
.19169 .49575 L
s
P
p
.2 0 1 r
.006 w
.45258 .53857 m
.30219 .64784 L
s
P
p
.2 0 1 r
.006 w
.45258 .53857 m
.39513 .71537 L
s
P
p
.2 0 1 r
.006 w
.45258 .53857 m
.51002 .71537 L
s
P
p
.2 0 1 r
.006 w
.45258 .53857 m
.60297 .64784 L
s
P
p
0 1 1 r
.018 w
.45258 .42239 m
.34208 .4583 L
s
P
p
0 1 1 r
.018 w
.45258 .42239 m
.52087 .51639 L
s
P
p
0 1 1 r
.018 w
.45258 .42239 m
.52087 .3284 L
s
P
p
0 1 1 r
.018 w
.45258 .42239 m
.34208 .38649 L
s
P
p
0 1 1 r
.018 w
.45258 .42239 m
.45258 .53857 L
s
P
p
.2 0 1 r
.006 w
.37063 .53857 m
.22024 .64784 L
s
P
p
.2 0 1 r
.006 w
.37063 .53857 m
.31319 .71537 L
s
P
p
.2 0 1 r
.006 w
.37063 .53857 m
.42807 .71537 L
s
P
p
.2 0 1 r
.006 w
.37063 .53857 m
.52102 .64784 L
s
P
p
.2 0 1 r
.006 w
.48113 .38649 m
.63151 .49575 L
s
P
p
.2 0 1 r
.006 w
.48113 .38649 m
.66702 .38649 L
s
P
p
.2 0 1 r
.006 w
.48113 .38649 m
.63151 .27723 L
s
P
p
.2 0 1 r
.006 w
.48113 .38649 m
.53857 .2097 L
s
P
p
.2 0 1 r
.006 w
.30234 .3284 m
.35978 .15161 L
s
P
p
.2 0 1 r
.006 w
.30234 .3284 m
.2449 .15161 L
s
P
p
.2 0 1 r
.006 w
.30234 .3284 m
.15195 .21914 L
s
P
p
.2 0 1 r
.006 w
.30234 .3284 m
.11645 .3284 L
s
P
p
.2 0 1 r
.006 w
.30234 .51639 m
.11645 .51639 L
s
P
p
.2 0 1 r
.006 w
.30234 .51639 m
.15195 .62565 L
s
P
p
.2 0 1 r
.006 w
.30234 .51639 m
.2449 .69318 L
s
P
p
.2 0 1 r
.006 w
.30234 .51639 m
.35978 .69318 L
s
P
p
.2 0 1 r
.006 w
.48113 .4583 m
.53857 .63509 L
s
P
p
.2 0 1 r
.006 w
.48113 .4583 m
.63151 .56756 L
s
P
p
.2 0 1 r
.006 w
.48113 .4583 m
.66702 .4583 L
s
P
p
.2 0 1 r
.006 w
.48113 .4583 m
.63151 .34903 L
s
P
p
0 1 1 r
.018 w
.37063 .42239 m
.37063 .53857 L
s
P
p
0 1 1 r
.018 w
.37063 .42239 m
.48113 .38649 L
s
P
p
0 1 1 r
.018 w
.37063 .42239 m
.30234 .3284 L
s
P
p
0 1 1 r
.018 w
.37063 .42239 m
.30234 .51639 L
s
P
p
0 1 1 r
.018 w
.37063 .42239 m
.48113 .4583 L
s
P
p
.2 0 1 r
.006 w
.4558 .53623 m
.51325 .71303 L
s
P
p
.2 0 1 r
.006 w
.4558 .53623 m
.60619 .6455 L
s
P
p
.2 0 1 r
.006 w
.4558 .53623 m
.64169 .53623 L
s
P
p
.2 0 1 r
.006 w
.4558 .53623 m
.60619 .42697 L
s
P
p
.2 0 1 r
.006 w
.34531 .38415 m
.4957 .27488 L
s
P
p
.2 0 1 r
.006 w
.34531 .38415 m
.40275 .20735 L
s
P
p
.2 0 1 r
.006 w
.34531 .38415 m
.28786 .20735 L
s
P
p
.2 0 1 r
.006 w
.34531 .38415 m
.19492 .27488 L
s
P
p
.2 0 1 r
.006 w
.23481 .53623 m
.08442 .42697 L
s
P
p
.2 0 1 r
.006 w
.23481 .53623 m
.04892 .53623 L
s
P
p
.2 0 1 r
.006 w
.23481 .53623 m
.08442 .6455 L
s
P
p
.2 0 1 r
.006 w
.23481 .53623 m
.17737 .71303 L
s
P
p
.2 0 1 r
.006 w
.4136 .59432 m
.35615 .77112 L
s
P
p
.2 0 1 r
.006 w
.4136 .59432 m
.47104 .77112 L
s
P
p
.2 0 1 r
.006 w
.4136 .59432 m
.56399 .70359 L
s
P
p
.2 0 1 r
.006 w
.4136 .59432 m
.59949 .59432 L
s
P
p
.2 0 1 r
.006 w
.4136 .40634 m
.59949 .40634 L
s
P
p
.2 0 1 r
.006 w
.4136 .40634 m
.56399 .29707 L
s
P
p
.2 0 1 r
.006 w
.4136 .40634 m
.47104 .22954 L
s
P
p
.2 0 1 r
.006 w
.4136 .40634 m
.35615 .22954 L
s
P
p
0 1 1 r
.018 w
.34531 .50033 m
.4558 .53623 L
s
P
p
0 1 1 r
.018 w
.34531 .50033 m
.34531 .38415 L
s
P
p
0 1 1 r
.018 w
.34531 .50033 m
.23481 .53623 L
s
P
p
0 1 1 r
.018 w
.34531 .50033 m
.4136 .59432 L
s
P
p
0 1 1 r
.018 w
.34531 .50033 m
.4136 .40634 L
s
P
p
.2 0 1 r
.006 w
.47989 .4545 m
.66578 .4545 L
s
P
p
.2 0 1 r
.006 w
.47989 .4545 m
.63028 .34524 L
s
P
p
.2 0 1 r
.006 w
.47989 .4545 m
.53734 .27771 L
s
P
p
.2 0 1 r
.006 w
.47989 .4545 m
.42245 .27771 L
s
P
p
.2 0 1 r
.006 w
.30111 .5126 m
.24366 .3358 L
s
P
p
.2 0 1 r
.006 w
.30111 .5126 m
.15072 .40333 L
s
P
p
.2 0 1 r
.006 w
.30111 .5126 m
.11522 .5126 L
s
P
p
.2 0 1 r
.006 w
.30111 .5126 m
.15072 .62186 L
s
P
p
.2 0 1 r
.006 w
.4116 .66468 m
.26121 .77394 L
s
P
p
.2 0 1 r
.006 w
.4116 .66468 m
.35416 .84147 L
s
P
p
.2 0 1 r
.006 w
.4116 .66468 m
.46905 .84147 L
s
P
p
.2 0 1 r
.006 w
.4116 .66468 m
.56199 .77394 L
s
P
p
.2 0 1 r
.006 w
.5221 .5126 m
.67249 .62186 L
s
P
p
.2 0 1 r
.006 w
.5221 .5126 m
.70799 .5126 L
s
P
p
.2 0 1 r
.006 w
.5221 .5126 m
.67249 .40333 L
s
P
p
.2 0 1 r
.006 w
.5221 .5126 m
.57954 .3358 L
s
P
p
.2 0 1 r
.006 w
.34331 .4545 m
.40076 .27771 L
s
P
p
.2 0 1 r
.006 w
.34331 .4545 m
.28587 .27771 L
s
P
p
.2 0 1 r
.006 w
.34331 .4545 m
.19292 .34524 L
s
P
p
.2 0 1 r
.006 w
.34331 .4545 m
.15742 .4545 L
s
P
p
0 1 1 r
.018 w
.4116 .5485 m
.47989 .4545 L
s
P
p
0 1 1 r
.018 w
.4116 .5485 m
.30111 .5126 L
s
P
p
0 1 1 r
.018 w
.4116 .5485 m
.4116 .66468 L
s
P
p
0 1 1 r
.018 w
.4116 .5485 m
.5221 .5126 L
s
P
p
0 1 1 r
.018 w
.4116 .5485 m
.34331 .4545 L
s
P
p
.2 0 1 r
.006 w
.40961 .40634 m
.46705 .22954 L
s
P
p
.2 0 1 r
.006 w
.40961 .40634 m
.35217 .22954 L
s
P
p
.2 0 1 r
.006 w
.40961 .40634 m
.25922 .29707 L
s
P
p
.2 0 1 r
.006 w
.40961 .40634 m
.22372 .40634 L
s
P
p
.2 0 1 r
.006 w
.40961 .59432 m
.22372 .59432 L
s
P
p
.2 0 1 r
.006 w
.40961 .59432 m
.25922 .70359 L
s
P
p
.2 0 1 r
.006 w
.40961 .59432 m
.35217 .77112 L
s
P
p
.2 0 1 r
.006 w
.40961 .59432 m
.46705 .77112 L
s
P
p
.2 0 1 r
.006 w
.5884 .53623 m
.64584 .71303 L
s
P
p
.2 0 1 r
.006 w
.5884 .53623 m
.73879 .6455 L
s
P
p
.2 0 1 r
.006 w
.5884 .53623 m
.77429 .53623 L
s
P
p
.2 0 1 r
.006 w
.5884 .53623 m
.73879 .42697 L
s
P
p
.2 0 1 r
.006 w
.4779 .38415 m
.62829 .27488 L
s
P
p
.2 0 1 r
.006 w
.4779 .38415 m
.53534 .20735 L
s
P
p
.2 0 1 r
.006 w
.4779 .38415 m
.42046 .20735 L
s
P
p
.2 0 1 r
.006 w
.4779 .38415 m
.32751 .27488 L
s
P
p
.2 0 1 r
.006 w
.36741 .53623 m
.21702 .42697 L
s
P
p
.2 0 1 r
.006 w
.36741 .53623 m
.18151 .53623 L
s
P
p
.2 0 1 r
.006 w
.36741 .53623 m
.21702 .6455 L
s
P
p
.2 0 1 r
.006 w
.36741 .53623 m
.30996 .71303 L
s
P
p
0 1 1 r
.018 w
.4779 .50033 m
.40961 .40634 L
s
P
p
0 1 1 r
.018 w
.4779 .50033 m
.40961 .59432 L
s
P
p
0 1 1 r
.018 w
.4779 .50033 m
.5884 .53623 L
s
P
p
0 1 1 r
.018 w
.4779 .50033 m
.4779 .38415 L
s
P
p
0 1 1 r
.018 w
.4779 .50033 m
.36741 .53623 L
s
P
p
0 1 .4 r
.016 w
.4116 .47879 m
.45258 .42239 L
s
P
p
0 1 .4 r
.016 w
.4116 .47879 m
.37063 .42239 L
s
P
p
0 1 .4 r
.016 w
.4116 .47879 m
.34531 .50033 L
s
P
p
0 1 .4 r
.016 w
.4116 .47879 m
.4116 .5485 L
s
P
p
0 1 .4 r
.016 w
.4116 .47879 m
.4779 .50033 L
s
P
p
.2 0 1 r
.006 w
.45903 .6028 m
.30864 .71206 L
s
P
p
.2 0 1 r
.006 w
.45903 .6028 m
.40158 .77959 L
s
P
p
.2 0 1 r
.006 w
.45903 .6028 m
.51647 .77959 L
s
P
p
.2 0 1 r
.006 w
.45903 .6028 m
.60942 .71206 L
s
P
p
.2 0 1 r
.006 w
.56952 .45071 m
.71991 .55998 L
s
P
p
.2 0 1 r
.006 w
.56952 .45071 m
.75541 .45071 L
s
P
p
.2 0 1 r
.006 w
.56952 .45071 m
.71991 .34145 L
s
P
p
.2 0 1 r
.006 w
.56952 .45071 m
.62697 .27392 L
s
P
p
.2 0 1 r
.006 w
.39074 .39262 m
.44818 .21583 L
s
P
p
.2 0 1 r
.006 w
.39074 .39262 m
.33329 .21583 L
s
P
p
.2 0 1 r
.006 w
.39074 .39262 m
.24035 .28336 L
s
P
p
.2 0 1 r
.006 w
.39074 .39262 m
.20484 .39262 L
s
P
p
.2 0 1 r
.006 w
.39074 .58061 m
.20484 .58061 L
s
P
p
.2 0 1 r
.006 w
.39074 .58061 m
.24035 .68987 L
s
P
p
.2 0 1 r
.006 w
.39074 .58061 m
.33329 .7574 L
s
P
p
.2 0 1 r
.006 w
.39074 .58061 m
.44818 .7574 L
s
P
p
.2 0 1 r
.006 w
.56952 .52252 m
.62697 .69931 L
s
P
p
.2 0 1 r
.006 w
.56952 .52252 m
.71991 .63178 L
s
P
p
.2 0 1 r
.006 w
.56952 .52252 m
.75541 .52252 L
s
P
p
.2 0 1 r
.006 w
.56952 .52252 m
.71991 .41325 L
s
P
p
0 1 1 r
.018 w
.45903 .48662 m
.45903 .6028 L
s
P
p
0 1 1 r
.018 w
.45903 .48662 m
.56952 .45071 L
s
P
p
0 1 1 r
.018 w
.45903 .48662 m
.39074 .39262 L
s
P
p
0 1 1 r
.018 w
.45903 .48662 m
.39074 .58061 L
s
P
p
0 1 1 r
.018 w
.45903 .48662 m
.56952 .52252 L
s
P
p
.2 0 1 r
.006 w
.5442 .60046 m
.60164 .77725 L
s
P
p
.2 0 1 r
.006 w
.5442 .60046 m
.69459 .70972 L
s
P
p
.2 0 1 r
.006 w
.5442 .60046 m
.73009 .60046 L
s
P
p
.2 0 1 r
.006 w
.5442 .60046 m
.69459 .49119 L
s
P
p
.2 0 1 r
.006 w
.4337 .44837 m
.58409 .33911 L
s
P
p
.2 0 1 r
.006 w
.4337 .44837 m
.49115 .27158 L
s
P
p
.2 0 1 r
.006 w
.4337 .44837 m
.37626 .27158 L
s
P
p
.2 0 1 r
.006 w
.4337 .44837 m
.28331 .33911 L
s
P
p
.2 0 1 r
.006 w
.32321 .60046 m
.17282 .49119 L
s
P
p
.2 0 1 r
.006 w
.32321 .60046 m
.13732 .60046 L
s
P
p
.2 0 1 r
.006 w
.32321 .60046 m
.17282 .70972 L
s
P
p
.2 0 1 r
.006 w
.32321 .60046 m
.26576 .77725 L
s
P
p
.2 0 1 r
.006 w
.50199 .65855 m
.44455 .83534 L
s
P
p
.2 0 1 r
.006 w
.50199 .65855 m
.55944 .83534 L
s
P
p
.2 0 1 r
.006 w
.50199 .65855 m
.65238 .76781 L
s
P
p
.2 0 1 r
.006 w
.50199 .65855 m
.68788 .65855 L
s
P
p
.2 0 1 r
.006 w
.50199 .47056 m
.68788 .47056 L
s
P
p
.2 0 1 r
.006 w
.50199 .47056 m
.65238 .3613 L
s
P
p
.2 0 1 r
.006 w
.50199 .47056 m
.55944 .29377 L
s
P
p
.2 0 1 r
.006 w
.50199 .47056 m
.44455 .29377 L
s
P
p
0 1 1 r
.018 w
.4337 .56455 m
.5442 .60046 L
s
P
p
0 1 1 r
.018 w
.4337 .56455 m
.4337 .44837 L
s
P
p
0 1 1 r
.018 w
.4337 .56455 m
.32321 .60046 L
s
P
p
0 1 1 r
.018 w
.4337 .56455 m
.50199 .65855 L
s
P
p
0 1 1 r
.018 w
.4337 .56455 m
.50199 .47056 L
s
P
p
.2 0 1 r
.006 w
.56829 .51873 m
.75418 .51873 L
s
P
p
.2 0 1 r
.006 w
.56829 .51873 m
.71868 .40946 L
s
P
p
.2 0 1 r
.006 w
.56829 .51873 m
.62573 .34194 L
s
P
p
.2 0 1 r
.006 w
.56829 .51873 m
.51085 .34194 L
s
P
p
.2 0 1 r
.006 w
.3895 .57682 m
.33206 .40003 L
s
P
p
.2 0 1 r
.006 w
.3895 .57682 m
.23911 .46756 L
s
P
p
.2 0 1 r
.006 w
.3895 .57682 m
.20361 .57682 L
s
P
p
.2 0 1 r
.006 w
.3895 .57682 m
.23911 .68608 L
s
P
p
.2 0 1 r
.006 w
.5 .7289 m
.34961 .83817 L
s
P
p
.2 0 1 r
.006 w
.5 .7289 m
.44256 .9057 L
s
P
p
.2 0 1 r
.006 w
.5 .7289 m
.55744 .9057 L
s
P
p
.2 0 1 r
.006 w
.5 .7289 m
.65039 .83817 L
s
P
p
.2 0 1 r
.006 w
.6105 .57682 m
.76089 .68608 L
s
P
p
.2 0 1 r
.006 w
.6105 .57682 m
.79639 .57682 L
s
P
p
.2 0 1 r
.006 w
.6105 .57682 m
.76089 .46756 L
s
P
p
.2 0 1 r
.006 w
.6105 .57682 m
.66794 .40003 L
s
P
p
.2 0 1 r
.006 w
.43171 .51873 m
.48915 .34194 L
s
P
p
.2 0 1 r
.006 w
.43171 .51873 m
.37427 .34194 L
s
P
p
.2 0 1 r
.006 w
.43171 .51873 m
.28132 .40946 L
s
P
p
.2 0 1 r
.006 w
.43171 .51873 m
.24582 .51873 L
s
P
p
0 1 1 r
.018 w
.5 .61272 m
.56829 .51873 L
s
P
p
0 1 1 r
.018 w
.5 .61272 m
.3895 .57682 L
s
P
p
0 1 1 r
.018 w
.5 .61272 m
.5 .7289 L
s
P
p
0 1 1 r
.018 w
.5 .61272 m
.6105 .57682 L
s
P
p
0 1 1 r
.018 w
.5 .61272 m
.43171 .51873 L
s
P
p
.2 0 1 r
.006 w
.49801 .47056 m
.55545 .29377 L
s
P
p
.2 0 1 r
.006 w
.49801 .47056 m
.44056 .29377 L
s
P
p
.2 0 1 r
.006 w
.49801 .47056 m
.34762 .3613 L
s
P
p
.2 0 1 r
.006 w
.49801 .47056 m
.31212 .47056 L
s
P
p
.2 0 1 r
.006 w
.49801 .65855 m
.31212 .65855 L
s
P
p
.2 0 1 r
.006 w
.49801 .65855 m
.34762 .76781 L
s
P
p
.2 0 1 r
.006 w
.49801 .65855 m
.44056 .83534 L
s
P
p
.2 0 1 r
.006 w
.49801 .65855 m
.55545 .83534 L
s
P
p
.2 0 1 r
.006 w
.67679 .60046 m
.73424 .77725 L
s
P
p
.2 0 1 r
.006 w
.67679 .60046 m
.82718 .70972 L
s
P
p
.2 0 1 r
.006 w
.67679 .60046 m
.86268 .60046 L
s
P
p
.2 0 1 r
.006 w
.67679 .60046 m
.82718 .49119 L
s
P
p
.2 0 1 r
.006 w
.5663 .44837 m
.71669 .33911 L
s
P
p
.2 0 1 r
.006 w
.5663 .44837 m
.62374 .27158 L
s
P
p
.2 0 1 r
.006 w
.5663 .44837 m
.50885 .27158 L
s
P
p
.2 0 1 r
.006 w
.5663 .44837 m
.41591 .33911 L
s
P
p
.2 0 1 r
.006 w
.4558 .60046 m
.30541 .49119 L
s
P
p
.2 0 1 r
.006 w
.4558 .60046 m
.26991 .60046 L
s
P
p
.2 0 1 r
.006 w
.4558 .60046 m
.30541 .70972 L
s
P
p
.2 0 1 r
.006 w
.4558 .60046 m
.39836 .77725 L
s
P
p
0 1 1 r
.018 w
.5663 .56455 m
.49801 .47056 L
s
P
p
0 1 1 r
.018 w
.5663 .56455 m
.49801 .65855 L
s
P
p
0 1 1 r
.018 w
.5663 .56455 m
.67679 .60046 L
s
P
p
0 1 1 r
.018 w
.5663 .56455 m
.5663 .44837 L
s
P
p
0 1 1 r
.018 w
.5663 .56455 m
.4558 .60046 L
s
P
p
.2 0 1 r
.006 w
.43048 .52252 m
.28009 .41325 L
s
P
p
.2 0 1 r
.006 w
.43048 .52252 m
.24459 .52252 L
s
P
p
.2 0 1 r
.006 w
.43048 .52252 m
.28009 .63178 L
s
P
p
.2 0 1 r
.006 w
.43048 .52252 m
.37303 .69931 L
s
P
p
.2 0 1 r
.006 w
.60926 .58061 m
.55182 .7574 L
s
P
p
.2 0 1 r
.006 w
.60926 .58061 m
.66671 .7574 L
s
P
p
.2 0 1 r
.006 w
.60926 .58061 m
.75965 .68987 L
s
P
p
.2 0 1 r
.006 w
.60926 .58061 m
.79516 .58061 L
s
P
p
.2 0 1 r
.006 w
.60926 .39262 m
.79516 .39262 L
s
P
p
.2 0 1 r
.006 w
.60926 .39262 m
.75965 .28336 L
s
P
p
.2 0 1 r
.006 w
.60926 .39262 m
.66671 .21583 L
s
P
p
.2 0 1 r
.006 w
.60926 .39262 m
.55182 .21583 L
s
P
p
.2 0 1 r
.006 w
.43048 .45071 m
.37303 .27392 L
s
P
p
.2 0 1 r
.006 w
.43048 .45071 m
.28009 .34145 L
s
P
p
.2 0 1 r
.006 w
.43048 .45071 m
.24459 .45071 L
s
P
p
.2 0 1 r
.006 w
.43048 .45071 m
.28009 .55998 L
s
P
p
.2 0 1 r
.006 w
.54097 .6028 m
.39058 .71206 L
s
P
p
.2 0 1 r
.006 w
.54097 .6028 m
.48353 .77959 L
s
P
p
.2 0 1 r
.006 w
.54097 .6028 m
.59842 .77959 L
s
P
p
.2 0 1 r
.006 w
.54097 .6028 m
.69136 .71206 L
s
P
p
0 1 1 r
.018 w
.54097 .48662 m
.43048 .52252 L
s
P
p
0 1 1 r
.018 w
.54097 .48662 m
.60926 .58061 L
s
P
p
0 1 1 r
.018 w
.54097 .48662 m
.60926 .39262 L
s
P
p
0 1 1 r
.018 w
.54097 .48662 m
.43048 .45071 L
s
P
p
0 1 1 r
.018 w
.54097 .48662 m
.54097 .6028 L
s
P
p
0 1 .4 r
.016 w
.5 .54301 m
.45903 .48662 L
s
P
p
0 1 .4 r
.016 w
.5 .54301 m
.4337 .56455 L
s
P
p
0 1 .4 r
.016 w
.5 .54301 m
.5 .61272 L
s
P
p
0 1 .4 r
.016 w
.5 .54301 m
.5663 .56455 L
s
P
p
0 1 .4 r
.016 w
.5 .54301 m
.54097 .48662 L
s
P
p
.2 0 1 r
.006 w
.63259 .53623 m
.69004 .71303 L
s
P
p
.2 0 1 r
.006 w
.63259 .53623 m
.78298 .6455 L
s
P
p
.2 0 1 r
.006 w
.63259 .53623 m
.81849 .53623 L
s
P
p
.2 0 1 r
.006 w
.63259 .53623 m
.78298 .42697 L
s
P
p
.2 0 1 r
.006 w
.5221 .38415 m
.67249 .27488 L
s
P
p
.2 0 1 r
.006 w
.5221 .38415 m
.57954 .20735 L
s
P
p
.2 0 1 r
.006 w
.5221 .38415 m
.46466 .20735 L
s
P
p
.2 0 1 r
.006 w
.5221 .38415 m
.37171 .27488 L
s
P
p
.2 0 1 r
.006 w
.4116 .53623 m
.26121 .42697 L
s
P
p
.2 0 1 r
.006 w
.4116 .53623 m
.22571 .53623 L
s
P
p
.2 0 1 r
.006 w
.4116 .53623 m
.26121 .6455 L
s
P
p
.2 0 1 r
.006 w
.4116 .53623 m
.35416 .71303 L
s
P
p
.2 0 1 r
.006 w
.59039 .59432 m
.53295 .77112 L
s
P
p
.2 0 1 r
.006 w
.59039 .59432 m
.64783 .77112 L
s
P
p
.2 0 1 r
.006 w
.59039 .59432 m
.74078 .70359 L
s
P
p
.2 0 1 r
.006 w
.59039 .59432 m
.77628 .59432 L
s
P
p
.2 0 1 r
.006 w
.59039 .40634 m
.77628 .40634 L
s
P
p
.2 0 1 r
.006 w
.59039 .40634 m
.74078 .29707 L
s
P
p
.2 0 1 r
.006 w
.59039 .40634 m
.64783 .22954 L
s
P
p
.2 0 1 r
.006 w
.59039 .40634 m
.53295 .22954 L
s
P
p
0 1 1 r
.018 w
.5221 .50033 m
.63259 .53623 L
s
P
p
0 1 1 r
.018 w
.5221 .50033 m
.5221 .38415 L
s
P
p
0 1 1 r
.018 w
.5221 .50033 m
.4116 .53623 L
s
P
p
0 1 1 r
.018 w
.5221 .50033 m
.59039 .59432 L
s
P
p
0 1 1 r
.018 w
.5221 .50033 m
.59039 .40634 L
s
P
p
.2 0 1 r
.006 w
.65669 .4545 m
.84258 .4545 L
s
P
p
.2 0 1 r
.006 w
.65669 .4545 m
.80708 .34524 L
s
P
p
.2 0 1 r
.006 w
.65669 .4545 m
.71413 .27771 L
s
P
p
.2 0 1 r
.006 w
.65669 .4545 m
.59924 .27771 L
s
P
p
.2 0 1 r
.006 w
.4779 .5126 m
.42046 .3358 L
s
P
p
.2 0 1 r
.006 w
.4779 .5126 m
.32751 .40333 L
s
P
p
.2 0 1 r
.006 w
.4779 .5126 m
.29201 .5126 L
s
P
p
.2 0 1 r
.006 w
.4779 .5126 m
.32751 .62186 L
s
P
p
.2 0 1 r
.006 w
.5884 .66468 m
.43801 .77394 L
s
P
p
.2 0 1 r
.006 w
.5884 .66468 m
.53095 .84147 L
s
P
p
.2 0 1 r
.006 w
.5884 .66468 m
.64584 .84147 L
s
P
p
.2 0 1 r
.006 w
.5884 .66468 m
.73879 .77394 L
s
P
p
.2 0 1 r
.006 w
.69889 .5126 m
.84928 .62186 L
s
P
p
.2 0 1 r
.006 w
.69889 .5126 m
.88478 .5126 L
s
P
p
.2 0 1 r
.006 w
.69889 .5126 m
.84928 .40333 L
s
P
p
.2 0 1 r
.006 w
.69889 .5126 m
.75634 .3358 L
s
P
p
.2 0 1 r
.006 w
.52011 .4545 m
.57755 .27771 L
s
P
p
.2 0 1 r
.006 w
.52011 .4545 m
.46266 .27771 L
s
P
p
.2 0 1 r
.006 w
.52011 .4545 m
.36972 .34524 L
s
P
p
.2 0 1 r
.006 w
.52011 .4545 m
.33422 .4545 L
s
P
p
0 1 1 r
.018 w
.5884 .5485 m
.65669 .4545 L
s
P
p
0 1 1 r
.018 w
.5884 .5485 m
.4779 .5126 L
s
P
p
0 1 1 r
.018 w
.5884 .5485 m
.5884 .66468 L
s
P
p
0 1 1 r
.018 w
.5884 .5485 m
.69889 .5126 L
s
P
p
0 1 1 r
.018 w
.5884 .5485 m
.52011 .4545 L
s
P
p
.2 0 1 r
.006 w
.5864 .40634 m
.64385 .22954 L
s
P
p
.2 0 1 r
.006 w
.5864 .40634 m
.52896 .22954 L
s
P
p
.2 0 1 r
.006 w
.5864 .40634 m
.43601 .29707 L
s
P
p
.2 0 1 r
.006 w
.5864 .40634 m
.40051 .40634 L
s
P
p
.2 0 1 r
.006 w
.5864 .59432 m
.40051 .59432 L
s
P
p
.2 0 1 r
.006 w
.5864 .59432 m
.43601 .70359 L
s
P
p
.2 0 1 r
.006 w
.5864 .59432 m
.52896 .77112 L
s
P
p
.2 0 1 r
.006 w
.5864 .59432 m
.64385 .77112 L
s
P
p
.2 0 1 r
.006 w
.76519 .53623 m
.82263 .71303 L
s
P
p
.2 0 1 r
.006 w
.76519 .53623 m
.91558 .6455 L
s
P
p
.2 0 1 r
.006 w
.76519 .53623 m
.95108 .53623 L
s
P
p
.2 0 1 r
.006 w
.76519 .53623 m
.91558 .42697 L
s
P
p
.2 0 1 r
.006 w
.65469 .38415 m
.80508 .27488 L
s
P
p
.2 0 1 r
.006 w
.65469 .38415 m
.71214 .20735 L
s
P
p
.2 0 1 r
.006 w
.65469 .38415 m
.59725 .20735 L
s
P
p
.2 0 1 r
.006 w
.65469 .38415 m
.5043 .27488 L
s
P
p
.2 0 1 r
.006 w
.5442 .53623 m
.39381 .42697 L
s
P
p
.2 0 1 r
.006 w
.5442 .53623 m
.35831 .53623 L
s
P
p
.2 0 1 r
.006 w
.5442 .53623 m
.39381 .6455 L
s
P
p
.2 0 1 r
.006 w
.5442 .53623 m
.48675 .71303 L
s
P
p
0 1 1 r
.018 w
.65469 .50033 m
.5864 .40634 L
s
P
p
0 1 1 r
.018 w
.65469 .50033 m
.5864 .59432 L
s
P
p
0 1 1 r
.018 w
.65469 .50033 m
.76519 .53623 L
s
P
p
0 1 1 r
.018 w
.65469 .50033 m
.65469 .38415 L
s
P
p
0 1 1 r
.018 w
.65469 .50033 m
.5442 .53623 L
s
P
p
.2 0 1 r
.006 w
.51887 .4583 m
.36849 .34903 L
s
P
p
.2 0 1 r
.006 w
.51887 .4583 m
.33298 .4583 L
s
P
p
.2 0 1 r
.006 w
.51887 .4583 m
.36849 .56756 L
s
P
p
.2 0 1 r
.006 w
.51887 .4583 m
.46143 .63509 L
s
P
p
.2 0 1 r
.006 w
.69766 .51639 m
.64022 .69318 L
s
P
p
.2 0 1 r
.006 w
.69766 .51639 m
.7551 .69318 L
s
P
p
.2 0 1 r
.006 w
.69766 .51639 m
.84805 .62565 L
s
P
p
.2 0 1 r
.006 w
.69766 .51639 m
.88355 .51639 L
s
P
p
.2 0 1 r
.006 w
.69766 .3284 m
.88355 .3284 L
s
P
p
.2 0 1 r
.006 w
.69766 .3284 m
.84805 .21914 L
s
P
p
.2 0 1 r
.006 w
.69766 .3284 m
.7551 .15161 L
s
P
p
.2 0 1 r
.006 w
.69766 .3284 m
.64022 .15161 L
s
P
p
.2 0 1 r
.006 w
.51887 .38649 m
.46143 .2097 L
s
P
p
.2 0 1 r
.006 w
.51887 .38649 m
.36849 .27723 L
s
P
p
.2 0 1 r
.006 w
.51887 .38649 m
.33298 .38649 L
s
P
p
.2 0 1 r
.006 w
.51887 .38649 m
.36849 .49575 L
s
P
p
.2 0 1 r
.006 w
.62937 .53857 m
.47898 .64784 L
s
P
p
.2 0 1 r
.006 w
.62937 .53857 m
.57193 .71537 L
s
P
p
.2 0 1 r
.006 w
.62937 .53857 m
.68681 .71537 L
s
P
p
.2 0 1 r
.006 w
.62937 .53857 m
.77976 .64784 L
s
P
p
0 1 1 r
.018 w
.62937 .42239 m
.51887 .4583 L
s
P
p
0 1 1 r
.018 w
.62937 .42239 m
.69766 .51639 L
s
P
p
0 1 1 r
.018 w
.62937 .42239 m
.69766 .3284 L
s
P
p
0 1 1 r
.018 w
.62937 .42239 m
.51887 .38649 L
s
P
p
0 1 1 r
.018 w
.62937 .42239 m
.62937 .53857 L
s
P
p
.2 0 1 r
.006 w
.54742 .53857 m
.39703 .64784 L
s
P
p
.2 0 1 r
.006 w
.54742 .53857 m
.48998 .71537 L
s
P
p
.2 0 1 r
.006 w
.54742 .53857 m
.60487 .71537 L
s
P
p
.2 0 1 r
.006 w
.54742 .53857 m
.69781 .64784 L
s
P
p
.2 0 1 r
.006 w
.65792 .38649 m
.80831 .49575 L
s
P
p
.2 0 1 r
.006 w
.65792 .38649 m
.84381 .38649 L
s
P
p
.2 0 1 r
.006 w
.65792 .38649 m
.80831 .27723 L
s
P
p
.2 0 1 r
.006 w
.65792 .38649 m
.71536 .2097 L
s
P
p
.2 0 1 r
.006 w
.47913 .3284 m
.53658 .15161 L
s
P
p
.2 0 1 r
.006 w
.47913 .3284 m
.42169 .15161 L
s
P
p
.2 0 1 r
.006 w
.47913 .3284 m
.32874 .21914 L
s
P
p
.2 0 1 r
.006 w
.47913 .3284 m
.29324 .3284 L
s
P
p
.2 0 1 r
.006 w
.47913 .51639 m
.29324 .51639 L
s
P
p
.2 0 1 r
.006 w
.47913 .51639 m
.32874 .62565 L
s
P
p
.2 0 1 r
.006 w
.47913 .51639 m
.42169 .69318 L
s
P
p
.2 0 1 r
.006 w
.47913 .51639 m
.53658 .69318 L
s
P
p
.2 0 1 r
.006 w
.65792 .4583 m
.71536 .63509 L
s
P
p
.2 0 1 r
.006 w
.65792 .4583 m
.80831 .56756 L
s
P
p
.2 0 1 r
.006 w
.65792 .4583 m
.84381 .4583 L
s
P
p
.2 0 1 r
.006 w
.65792 .4583 m
.80831 .34903 L
s
P
p
0 1 1 r
.018 w
.54742 .42239 m
.54742 .53857 L
s
P
p
0 1 1 r
.018 w
.54742 .42239 m
.65792 .38649 L
s
P
p
0 1 1 r
.018 w
.54742 .42239 m
.47913 .3284 L
s
P
p
0 1 1 r
.018 w
.54742 .42239 m
.47913 .51639 L
s
P
p
0 1 1 r
.018 w
.54742 .42239 m
.65792 .4583 L
s
P
p
0 1 .4 r
.016 w
.5884 .47879 m
.5221 .50033 L
s
P
p
0 1 .4 r
.016 w
.5884 .47879 m
.5884 .5485 L
s
P
p
0 1 .4 r
.016 w
.5884 .47879 m
.65469 .50033 L
s
P
p
0 1 .4 r
.016 w
.5884 .47879 m
.62937 .42239 L
s
P
p
0 1 .4 r
.016 w
.5884 .47879 m
.54742 .42239 L
s
P
p
.2 0 1 r
.006 w
.62292 .35059 m
.80881 .35059 L
s
P
p
.2 0 1 r
.006 w
.62292 .35059 m
.77331 .24132 L
s
P
p
.2 0 1 r
.006 w
.62292 .35059 m
.68037 .1738 L
s
P
p
.2 0 1 r
.006 w
.62292 .35059 m
.56548 .1738 L
s
P
p
.2 0 1 r
.006 w
.44414 .40868 m
.38669 .23189 L
s
P
p
.2 0 1 r
.006 w
.44414 .40868 m
.29375 .29942 L
s
P
p
.2 0 1 r
.006 w
.44414 .40868 m
.25824 .40868 L
s
P
p
.2 0 1 r
.006 w
.44414 .40868 m
.29375 .51794 L
s
P
p
.2 0 1 r
.006 w
.55463 .56076 m
.40424 .67003 L
s
P
p
.2 0 1 r
.006 w
.55463 .56076 m
.49719 .73756 L
s
P
p
.2 0 1 r
.006 w
.55463 .56076 m
.61208 .73756 L
s
P
p
.2 0 1 r
.006 w
.55463 .56076 m
.70502 .67003 L
s
P
p
.2 0 1 r
.006 w
.66513 .40868 m
.81552 .51794 L
s
P
p
.2 0 1 r
.006 w
.66513 .40868 m
.85102 .40868 L
s
P
p
.2 0 1 r
.006 w
.66513 .40868 m
.81552 .29942 L
s
P
p
.2 0 1 r
.006 w
.66513 .40868 m
.72257 .23189 L
s
P
p
.2 0 1 r
.006 w
.48634 .35059 m
.54379 .1738 L
s
P
p
.2 0 1 r
.006 w
.48634 .35059 m
.4289 .1738 L
s
P
p
.2 0 1 r
.006 w
.48634 .35059 m
.33595 .24132 L
s
P
p
.2 0 1 r
.006 w
.48634 .35059 m
.30045 .35059 L
s
P
p
0 1 1 r
.018 w
.55463 .44458 m
.62292 .35059 L
s
P
p
0 1 1 r
.018 w
.55463 .44458 m
.44414 .40868 L
s
P
p
0 1 1 r
.018 w
.55463 .44458 m
.55463 .56076 L
s
P
p
0 1 1 r
.018 w
.55463 .44458 m
.66513 .40868 L
s
P
p
0 1 1 r
.018 w
.55463 .44458 m
.48634 .35059 L
s
P
p
.2 0 1 r
.006 w
.55264 .30242 m
.61008 .12563 L
s
P
p
.2 0 1 r
.006 w
.55264 .30242 m
.4952 .12563 L
s
P
p
.2 0 1 r
.006 w
.55264 .30242 m
.40225 .19316 L
s
P
p
.2 0 1 r
.006 w
.55264 .30242 m
.36675 .30242 L
s
P
p
.2 0 1 r
.006 w
.55264 .49041 m
.36675 .49041 L
s
P
p
.2 0 1 r
.006 w
.55264 .49041 m
.40225 .59967 L
s
P
p
.2 0 1 r
.006 w
.55264 .49041 m
.4952 .6672 L
s
P
p
.2 0 1 r
.006 w
.55264 .49041 m
.61008 .6672 L
s
P
p
.2 0 1 r
.006 w
.73143 .43232 m
.78887 .60911 L
s
P
p
.2 0 1 r
.006 w
.73143 .43232 m
.88181 .54158 L
s
P
p
.2 0 1 r
.006 w
.73143 .43232 m
.91732 .43232 L
s
P
p
.2 0 1 r
.006 w
.73143 .43232 m
.88181 .32305 L
s
P
p
.2 0 1 r
.006 w
.62093 .28023 m
.77132 .17097 L
s
P
p
.2 0 1 r
.006 w
.62093 .28023 m
.67837 .10344 L
s
P
p
.2 0 1 r
.006 w
.62093 .28023 m
.56349 .10344 L
s
P
p
.2 0 1 r
.006 w
.62093 .28023 m
.47054 .17097 L
s
P
p
.2 0 1 r
.006 w
.51043 .43232 m
.36004 .32305 L
s
P
p
.2 0 1 r
.006 w
.51043 .43232 m
.32454 .43232 L
s
P
p
.2 0 1 r
.006 w
.51043 .43232 m
.36004 .54158 L
s
P
p
.2 0 1 r
.006 w
.51043 .43232 m
.45299 .60911 L
s
P
p
0 1 1 r
.018 w
.62093 .39641 m
.55264 .30242 L
s
P
p
0 1 1 r
.018 w
.62093 .39641 m
.55264 .49041 L
s
P
p
0 1 1 r
.018 w
.62093 .39641 m
.73143 .43232 L
s
P
p
0 1 1 r
.018 w
.62093 .39641 m
.62093 .28023 L
s
P
p
0 1 1 r
.018 w
.62093 .39641 m
.51043 .43232 L
s
P
p
.2 0 1 r
.006 w
.48511 .35438 m
.33472 .24511 L
s
P
p
.2 0 1 r
.006 w
.48511 .35438 m
.29922 .35438 L
s
P
p
.2 0 1 r
.006 w
.48511 .35438 m
.33472 .46364 L
s
P
p
.2 0 1 r
.006 w
.48511 .35438 m
.42767 .53117 L
s
P
p
.2 0 1 r
.006 w
.6639 .41247 m
.60645 .58926 L
s
P
p
.2 0 1 r
.006 w
.6639 .41247 m
.72134 .58926 L
s
P
p
.2 0 1 r
.006 w
.6639 .41247 m
.81429 .52173 L
s
P
p
.2 0 1 r
.006 w
.6639 .41247 m
.84979 .41247 L
s
P
p
.2 0 1 r
.006 w
.6639 .22448 m
.84979 .22448 L
s
P
p
.2 0 1 r
.006 w
.6639 .22448 m
.81429 .11522 L
s
P
p
.2 0 1 r
.006 w
.6639 .22448 m
.72134 .04769 L
s
P
p
.2 0 1 r
.006 w
.6639 .22448 m
.60645 .04769 L
s
P
p
.2 0 1 r
.006 w
.48511 .28257 m
.42767 .10578 L
s
P
p
.2 0 1 r
.006 w
.48511 .28257 m
.33472 .17331 L
s
P
p
.2 0 1 r
.006 w
.48511 .28257 m
.29922 .28257 L
s
P
p
.2 0 1 r
.006 w
.48511 .28257 m
.33472 .39184 L
s
P
p
.2 0 1 r
.006 w
.59561 .43466 m
.44522 .54392 L
s
P
p
.2 0 1 r
.006 w
.59561 .43466 m
.53816 .61145 L
s
P
p
.2 0 1 r
.006 w
.59561 .43466 m
.65305 .61145 L
s
P
p
.2 0 1 r
.006 w
.59561 .43466 m
.746 .54392 L
s
P
p
0 1 1 r
.018 w
.59561 .31848 m
.48511 .35438 L
s
P
p
0 1 1 r
.018 w
.59561 .31848 m
.6639 .41247 L
s
P
p
0 1 1 r
.018 w
.59561 .31848 m
.6639 .22448 L
s
P
p
0 1 1 r
.018 w
.59561 .31848 m
.48511 .28257 L
s
P
p
0 1 1 r
.018 w
.59561 .31848 m
.59561 .43466 L
s
P
p
.2 0 1 r
.006 w
.51366 .43466 m
.36327 .54392 L
s
P
p
.2 0 1 r
.006 w
.51366 .43466 m
.45621 .61145 L
s
P
p
.2 0 1 r
.006 w
.51366 .43466 m
.5711 .61145 L
s
P
p
.2 0 1 r
.006 w
.51366 .43466 m
.66405 .54392 L
s
P
p
.2 0 1 r
.006 w
.62415 .28257 m
.77454 .39184 L
s
P
p
.2 0 1 r
.006 w
.62415 .28257 m
.81005 .28257 L
s
P
p
.2 0 1 r
.006 w
.62415 .28257 m
.77454 .17331 L
s
P
p
.2 0 1 r
.006 w
.62415 .28257 m
.6816 .10578 L
s
P
p
.2 0 1 r
.006 w
.44537 .22448 m
.50281 .04769 L
s
P
p
.2 0 1 r
.006 w
.44537 .22448 m
.38792 .04769 L
s
P
p
.2 0 1 r
.006 w
.44537 .22448 m
.29498 .11522 L
s
P
p
.2 0 1 r
.006 w
.44537 .22448 m
.25948 .22448 L
s
P
p
.2 0 1 r
.006 w
.44537 .41247 m
.25948 .41247 L
s
P
p
.2 0 1 r
.006 w
.44537 .41247 m
.29498 .52173 L
s
P
p
.2 0 1 r
.006 w
.44537 .41247 m
.38792 .58926 L
s
P
p
.2 0 1 r
.006 w
.44537 .41247 m
.50281 .58926 L
s
P
p
.2 0 1 r
.006 w
.62415 .35438 m
.6816 .53117 L
s
P
p
.2 0 1 r
.006 w
.62415 .35438 m
.77454 .46364 L
s
P
p
.2 0 1 r
.006 w
.62415 .35438 m
.81005 .35438 L
s
P
p
.2 0 1 r
.006 w
.62415 .35438 m
.77454 .24511 L
s
P
p
0 1 1 r
.018 w
.51366 .31848 m
.51366 .43466 L
s
P
p
0 1 1 r
.018 w
.51366 .31848 m
.62415 .28257 L
s
P
p
0 1 1 r
.018 w
.51366 .31848 m
.44537 .22448 L
s
P
p
0 1 1 r
.018 w
.51366 .31848 m
.44537 .41247 L
s
P
p
0 1 1 r
.018 w
.51366 .31848 m
.62415 .35438 L
s
P
p
.2 0 1 r
.006 w
.59883 .43232 m
.65627 .60911 L
s
P
p
.2 0 1 r
.006 w
.59883 .43232 m
.74922 .54158 L
s
P
p
.2 0 1 r
.006 w
.59883 .43232 m
.78472 .43232 L
s
P
p
.2 0 1 r
.006 w
.59883 .43232 m
.74922 .32305 L
s
P
p
.2 0 1 r
.006 w
.48833 .28023 m
.63872 .17097 L
s
P
p
.2 0 1 r
.006 w
.48833 .28023 m
.54578 .10344 L
s
P
p
.2 0 1 r
.006 w
.48833 .28023 m
.43089 .10344 L
s
P
p
.2 0 1 r
.006 w
.48833 .28023 m
.33795 .17097 L
s
P
p
.2 0 1 r
.006 w
.37784 .43232 m
.22745 .32305 L
s
P
p
.2 0 1 r
.006 w
.37784 .43232 m
.19195 .43232 L
s
P
p
.2 0 1 r
.006 w
.37784 .43232 m
.22745 .54158 L
s
P
p
.2 0 1 r
.006 w
.37784 .43232 m
.3204 .60911 L
s
P
p
.2 0 1 r
.006 w
.55662 .49041 m
.49918 .6672 L
s
P
p
.2 0 1 r
.006 w
.55662 .49041 m
.61407 .6672 L
s
P
p
.2 0 1 r
.006 w
.55662 .49041 m
.70701 .59967 L
s
P
p
.2 0 1 r
.006 w
.55662 .49041 m
.74252 .49041 L
s
P
p
.2 0 1 r
.006 w
.55662 .30242 m
.74252 .30242 L
s
P
p
.2 0 1 r
.006 w
.55662 .30242 m
.70701 .19316 L
s
P
p
.2 0 1 r
.006 w
.55662 .30242 m
.61407 .12563 L
s
P
p
.2 0 1 r
.006 w
.55662 .30242 m
.49918 .12563 L
s
P
p
0 1 1 r
.018 w
.48833 .39641 m
.59883 .43232 L
s
P
p
0 1 1 r
.018 w
.48833 .39641 m
.48833 .28023 L
s
P
p
0 1 1 r
.018 w
.48833 .39641 m
.37784 .43232 L
s
P
p
0 1 1 r
.018 w
.48833 .39641 m
.55662 .49041 L
s
P
p
0 1 1 r
.018 w
.48833 .39641 m
.55662 .30242 L
s
P
p
0 1 .4 r
.016 w
.55463 .37487 m
.55463 .44458 L
s
P
p
0 1 .4 r
.016 w
.55463 .37487 m
.62093 .39641 L
s
P
p
0 1 .4 r
.016 w
.55463 .37487 m
.59561 .31848 L
s
P
p
0 1 .4 r
.016 w
.55463 .37487 m
.51366 .31848 L
s
P
p
0 1 .4 r
.016 w
.55463 .37487 m
.48833 .39641 L
s
P
p
1 0 .6 r
.014 w
.5 .45007 m
.44537 .37487 L
s
P
p
1 0 .6 r
.014 w
.5 .45007 m
.4116 .47879 L
s
P
p
1 0 .6 r
.014 w
.5 .45007 m
.5 .54301 L
s
P
p
1 0 .6 r
.014 w
.5 .45007 m
.5884 .47879 L
s
P
p
1 0 .6 r
.014 w
.5 .45007 m
.55463 .37487 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.208113 0.782187 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0473091 0.952381 [
[ 0 0 0 0 ]
[ 1 .85776 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85776 L
0 .85776 L
closepath
clip
newpath
p
P
p
0 1 1 r
.014 w
.21969 .43318 m
.05151 .66467 L
s
P
p
0 1 1 r
.014 w
.5 .52426 m
.5 .81039 L
s
P
p
0 1 1 r
.014 w
.78031 .43318 m
.94849 .66467 L
s
P
p
0 1 1 r
.014 w
.5 .04737 m
.21969 .43318 L
s
P
p
0 1 1 r
.014 w
.5 .04737 m
.5 .52426 L
s
P
p
0 1 1 r
.014 w
.5 .04737 m
.78031 .43318 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.208113 0.97619 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.122662 0.952381 [
[ 0 0 0 0 ]
[ 1 .70706 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .70706 L
0 .70706 L
closepath
clip
newpath
p
P
p
1 0 .6 r
.004 w
.10031 .12662 m
.14971 .19462 L
s
P
p
1 0 .6 r
.004 w
.10031 .12662 m
.10031 .04257 L
s
P
p
1 0 .6 r
.004 w
.10031 .12662 m
.05091 .19462 L
s
P
p
1 0 .6 r
.004 w
.10031 .12662 m
.18025 .10065 L
s
P
p
1 0 .6 r
.004 w
.25298 .59649 m
.33292 .57051 L
s
P
p
1 0 .6 r
.004 w
.25298 .59649 m
.17304 .57051 L
s
P
p
1 0 .6 r
.004 w
.25298 .59649 m
.30238 .66449 L
s
P
p
1 0 .6 r
.004 w
.25298 .59649 m
.25298 .51243 L
s
P
p
1 0 .6 r
.004 w
.74702 .59649 m
.74702 .51243 L
s
P
p
1 0 .6 r
.004 w
.74702 .59649 m
.69762 .66449 L
s
P
p
1 0 .6 r
.004 w
.74702 .59649 m
.82696 .57051 L
s
P
p
1 0 .6 r
.004 w
.74702 .59649 m
.66708 .57051 L
s
P
p
1 0 .6 r
.004 w
.89969 .12662 m
.81975 .10065 L
s
P
p
1 0 .6 r
.004 w
.89969 .12662 m
.94909 .19462 L
s
P
p
1 0 .6 r
.004 w
.89969 .12662 m
.89969 .04257 L
s
P
p
1 0 .6 r
.004 w
.89969 .12662 m
.85029 .19462 L
s
P
p
1 0 0 r
.004 w
.5 .25649 m
.10031 .12662 L
s
P
p
1 0 0 r
.004 w
.5 .25649 m
.25298 .59649 L
s
P
p
1 0 0 r
.004 w
.5 .25649 m
.74702 .59649 L
s
P
p
1 0 0 r
.004 w
.5 .25649 m
.89969 .12662 L
s
P
p
.8 0 1 r
.006 w
.5 .04636 m
.5 .25649 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.402116 0.200176 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.214286 0.952381 [
[ 0 0 0 0 ]
[ 1 .52381 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .52381 L
0 .52381 L
closepath
clip
newpath
p
P
p
1 0 .6 r
.008 w
.38957 .03001 m
.38957 .20669 L
s
P
p
1 0 .6 r
.008 w
.03621 .20669 m
.38957 .20669 L
s
P
p
1 0 .6 r
.008 w
.38957 .4938 m
.38957 .20669 L
s
P
p
1 0 .6 r
.008 w
.03621 .31712 m
.5 .31712 L
s
P
p
1 0 .6 r
.008 w
.5 .4938 m
.5 .31712 L
s
P
p
1 0 .6 r
.008 w
.96379 .31712 m
.5 .31712 L
s
P
p
1 0 .6 r
.008 w
.61043 .4938 m
.61043 .20669 L
s
P
p
1 0 .6 r
.008 w
.96379 .20669 m
.61043 .20669 L
s
P
p
1 0 .6 r
.008 w
.61043 .03001 m
.61043 .20669 L
s
P
p
.2 1 0 r
.016 w
.5 .20669 m
.38957 .20669 L
s
P
p
.2 1 0 r
.016 w
.5 .20669 m
.5 .31712 L
s
P
p
.2 1 0 r
.016 w
.5 .20669 m
.61043 .20669 L
s
P
p
0 1 1 r
.014 w
.5 .03001 m
.5 .20669 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.402116 0.39418 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0262396 0.952381 [
[ 0 0 0 0 ]
[ 1 .8999 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8999 L
0 .8999 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.014 w
.20692 .24457 m
.17245 .46219 L
s
P
p
.2 0 1 r
.014 w
.20692 .24457 m
.30695 .04825 L
s
P
p
.2 0 1 r
.014 w
.20692 .24457 m
.05112 .40037 L
s
P
p
.2 0 1 r
.014 w
.20692 .24457 m
.40324 .14454 L
s
P
p
.2 0 1 r
.014 w
.27516 .67544 m
.49278 .7099 L
s
P
p
.2 0 1 r
.014 w
.27516 .67544 m
.07885 .57541 L
s
P
p
.2 0 1 r
.014 w
.27516 .67544 m
.43096 .83123 L
s
P
p
.2 0 1 r
.014 w
.27516 .67544 m
.17514 .47912 L
s
P
p
0 1 1 r
.002 w
.45648 .42588 m
.20692 .24457 L
s
P
p
0 1 1 r
.002 w
.45648 .42588 m
.27516 .67544 L
s
P
p
.2 0 1 r
.014 w
.18663 .55357 m
.34242 .70937 L
s
P
p
.2 0 1 r
.014 w
.18663 .55357 m
.0866 .35726 L
s
P
p
.2 0 1 r
.014 w
.18663 .55357 m
.22109 .77119 L
s
P
p
.2 0 1 r
.014 w
.18663 .55357 m
.22109 .33595 L
s
P
p
.2 0 1 r
.014 w
.57532 .75162 m
.73111 .59582 L
s
P
p
.2 0 1 r
.014 w
.57532 .75162 m
.379 .85165 L
s
P
p
.2 0 1 r
.014 w
.57532 .75162 m
.79294 .71715 L
s
P
p
.2 0 1 r
.014 w
.57532 .75162 m
.3577 .71715 L
s
P
p
0 1 1 r
.002 w
.47999 .45825 m
.18663 .55357 L
s
P
p
0 1 1 r
.002 w
.47999 .45825 m
.57532 .75162 L
s
P
p
.2 0 1 r
.014 w
.42468 .75162 m
.6423 .71715 L
s
P
p
.2 0 1 r
.014 w
.42468 .75162 m
.20706 .71715 L
s
P
p
.2 0 1 r
.014 w
.42468 .75162 m
.621 .85165 L
s
P
p
.2 0 1 r
.014 w
.42468 .75162 m
.26889 .59582 L
s
P
p
.2 0 1 r
.014 w
.81337 .55357 m
.77891 .33595 L
s
P
p
.2 0 1 r
.014 w
.81337 .55357 m
.77891 .77119 L
s
P
p
.2 0 1 r
.014 w
.81337 .55357 m
.9134 .35726 L
s
P
p
.2 0 1 r
.014 w
.81337 .55357 m
.65758 .70937 L
s
P
p
0 1 1 r
.002 w
.52001 .45825 m
.42468 .75162 L
s
P
p
0 1 1 r
.002 w
.52001 .45825 m
.81337 .55357 L
s
P
p
.2 0 1 r
.014 w
.72484 .67544 m
.82486 .47912 L
s
P
p
.2 0 1 r
.014 w
.72484 .67544 m
.56904 .83123 L
s
P
p
.2 0 1 r
.014 w
.72484 .67544 m
.92115 .57541 L
s
P
p
.2 0 1 r
.014 w
.72484 .67544 m
.50722 .7099 L
s
P
p
.2 0 1 r
.014 w
.79308 .24457 m
.59676 .14454 L
s
P
p
.2 0 1 r
.014 w
.79308 .24457 m
.94888 .40037 L
s
P
p
.2 0 1 r
.014 w
.79308 .24457 m
.69305 .04825 L
s
P
p
.2 0 1 r
.014 w
.79308 .24457 m
.82755 .46219 L
s
P
p
0 1 1 r
.002 w
.54352 .42588 m
.72484 .67544 L
s
P
p
0 1 1 r
.002 w
.54352 .42588 m
.79308 .24457 L
s
P
p
0 1 1 r
.008 w
.5 .41899 m
.45648 .42588 L
s
P
p
0 1 1 r
.008 w
.5 .41899 m
.47999 .45825 L
s
P
p
0 1 1 r
.008 w
.5 .41899 m
.52001 .45825 L
s
P
p
0 1 1 r
.008 w
.5 .41899 m
.54352 .42588 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.402116 0.588183 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.154708 0.952381 [
[ 0 0 0 0 ]
[ 1 .64296 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .64296 L
0 .64296 L
closepath
clip
newpath
p
P
p
0 1 .4 r
.012 w
.25404 .18638 m
.10701 .03934 L
s
P
p
0 1 .4 r
.012 w
.25404 .18638 m
.06877 .09198 L
s
P
p
0 1 .4 r
.012 w
.25404 .18638 m
.04866 .15385 L
s
P
p
0 1 .4 r
.012 w
.25404 .18638 m
.04866 .21891 L
s
P
p
0 1 .4 r
.012 w
.25404 .18638 m
.06877 .28079 L
s
P
p
0 1 .4 r
.012 w
.25404 .23192 m
.06877 .13752 L
s
P
p
0 1 .4 r
.012 w
.25404 .23192 m
.04866 .19939 L
s
P
p
0 1 .4 r
.012 w
.25404 .23192 m
.04866 .26445 L
s
P
p
0 1 .4 r
.012 w
.25404 .23192 m
.06877 .32633 L
s
P
p
0 1 .4 r
.012 w
.25404 .23192 m
.10701 .37896 L
s
P
p
0 1 .4 r
.012 w
.26812 .27524 m
.06273 .24271 L
s
P
p
0 1 .4 r
.012 w
.26812 .27524 m
.06273 .30776 L
s
P
p
0 1 .4 r
.012 w
.26812 .27524 m
.08284 .36964 L
s
P
p
0 1 .4 r
.012 w
.26812 .27524 m
.12108 .42227 L
s
P
p
0 1 .4 r
.012 w
.26812 .27524 m
.17371 .46051 L
s
P
p
0 1 .4 r
.018 w
.39781 .20915 m
.25404 .18638 L
s
P
p
0 1 .4 r
.018 w
.39781 .20915 m
.25404 .23192 L
s
P
p
0 1 .4 r
.018 w
.39781 .20915 m
.26812 .27524 L
s
P
p
0 1 .4 r
.012 w
.42262 .38749 m
.27559 .53453 L
s
P
p
0 1 .4 r
.012 w
.42262 .38749 m
.32822 .57277 L
s
P
p
0 1 .4 r
.012 w
.42262 .38749 m
.39009 .59287 L
s
P
p
0 1 .4 r
.012 w
.42262 .38749 m
.45515 .59287 L
s
P
p
0 1 .4 r
.012 w
.42262 .38749 m
.51703 .57277 L
s
P
p
0 1 .4 r
.012 w
.46816 .38749 m
.37376 .57277 L
s
P
p
0 1 .4 r
.012 w
.46816 .38749 m
.43563 .59287 L
s
P
p
0 1 .4 r
.012 w
.46816 .38749 m
.50069 .59287 L
s
P
p
0 1 .4 r
.012 w
.46816 .38749 m
.56257 .57277 L
s
P
p
0 1 .4 r
.012 w
.46816 .38749 m
.6152 .53453 L
s
P
p
0 1 .4 r
.012 w
.51148 .37342 m
.47895 .5788 L
s
P
p
0 1 .4 r
.012 w
.51148 .37342 m
.54401 .5788 L
s
P
p
0 1 .4 r
.012 w
.51148 .37342 m
.60588 .5587 L
s
P
p
0 1 .4 r
.012 w
.51148 .37342 m
.65851 .52045 L
s
P
p
0 1 .4 r
.012 w
.51148 .37342 m
.69675 .46782 L
s
P
p
0 1 .4 r
.018 w
.44539 .24372 m
.42262 .38749 L
s
P
p
0 1 .4 r
.018 w
.44539 .24372 m
.46816 .38749 L
s
P
p
0 1 .4 r
.018 w
.44539 .24372 m
.51148 .37342 L
s
P
p
.8 0 1 r
.008 w
.43889 .20265 m
.39781 .20915 L
s
P
p
.8 0 1 r
.008 w
.43889 .20265 m
.44539 .24372 L
s
P
p
0 1 .4 r
.012 w
.28705 .25907 m
.10177 .16466 L
s
P
p
0 1 .4 r
.012 w
.28705 .25907 m
.08167 .22654 L
s
P
p
0 1 .4 r
.012 w
.28705 .25907 m
.08167 .2916 L
s
P
p
0 1 .4 r
.012 w
.28705 .25907 m
.10177 .35347 L
s
P
p
0 1 .4 r
.012 w
.28705 .25907 m
.14001 .4061 L
s
P
p
0 1 .4 r
.012 w
.30112 .30238 m
.09574 .26985 L
s
P
p
0 1 .4 r
.012 w
.30112 .30238 m
.09574 .33491 L
s
P
p
0 1 .4 r
.012 w
.30112 .30238 m
.11584 .39678 L
s
P
p
0 1 .4 r
.012 w
.30112 .30238 m
.15408 .44942 L
s
P
p
0 1 .4 r
.012 w
.30112 .30238 m
.20672 .48766 L
s
P
p
0 1 .4 r
.012 w
.32789 .33922 m
.12251 .37175 L
s
P
p
0 1 .4 r
.012 w
.32789 .33922 m
.14261 .43363 L
s
P
p
0 1 .4 r
.012 w
.32789 .33922 m
.18085 .48626 L
s
P
p
0 1 .4 r
.012 w
.32789 .33922 m
.23349 .5245 L
s
P
p
0 1 .4 r
.012 w
.32789 .33922 m
.29536 .5446 L
s
P
p
0 1 .4 r
.018 w
.43082 .2363 m
.28705 .25907 L
s
P
p
0 1 .4 r
.018 w
.43082 .2363 m
.30112 .30238 L
s
P
p
0 1 .4 r
.018 w
.43082 .2363 m
.32789 .33922 L
s
P
p
0 1 .4 r
.012 w
.50952 .39824 m
.41512 .58352 L
s
P
p
0 1 .4 r
.012 w
.50952 .39824 m
.47699 .60362 L
s
P
p
0 1 .4 r
.012 w
.50952 .39824 m
.54205 .60362 L
s
P
p
0 1 .4 r
.012 w
.50952 .39824 m
.60393 .58352 L
s
P
p
0 1 .4 r
.012 w
.50952 .39824 m
.65656 .54527 L
s
P
p
0 1 .4 r
.012 w
.55283 .38416 m
.52031 .58955 L
s
P
p
0 1 .4 r
.012 w
.55283 .38416 m
.58536 .58955 L
s
P
p
0 1 .4 r
.012 w
.55283 .38416 m
.64724 .56944 L
s
P
p
0 1 .4 r
.012 w
.55283 .38416 m
.69987 .5312 L
s
P
p
0 1 .4 r
.012 w
.55283 .38416 m
.73811 .47857 L
s
P
p
0 1 .4 r
.012 w
.58968 .3574 m
.62221 .56278 L
s
P
p
0 1 .4 r
.012 w
.58968 .3574 m
.68408 .54267 L
s
P
p
0 1 .4 r
.012 w
.58968 .3574 m
.73672 .50443 L
s
P
p
0 1 .4 r
.012 w
.58968 .3574 m
.77496 .4518 L
s
P
p
0 1 .4 r
.012 w
.58968 .3574 m
.79506 .38993 L
s
P
p
0 1 .4 r
.018 w
.48675 .25447 m
.50952 .39824 L
s
P
p
0 1 .4 r
.018 w
.48675 .25447 m
.55283 .38416 L
s
P
p
0 1 .4 r
.018 w
.48675 .25447 m
.58968 .3574 L
s
P
p
.8 0 1 r
.008 w
.46787 .21741 m
.43082 .2363 L
s
P
p
.8 0 1 r
.008 w
.46787 .21741 m
.48675 .25447 L
s
P
p
0 1 .4 r
.012 w
.3409 .31799 m
.13552 .28546 L
s
P
p
0 1 .4 r
.012 w
.3409 .31799 m
.13552 .35052 L
s
P
p
0 1 .4 r
.012 w
.3409 .31799 m
.15562 .4124 L
s
P
p
0 1 .4 r
.012 w
.3409 .31799 m
.19386 .46503 L
s
P
p
0 1 .4 r
.012 w
.3409 .31799 m
.24649 .50327 L
s
P
p
0 1 .4 r
.012 w
.36767 .35484 m
.16228 .38737 L
s
P
p
0 1 .4 r
.012 w
.36767 .35484 m
.18239 .44924 L
s
P
p
0 1 .4 r
.012 w
.36767 .35484 m
.22063 .50187 L
s
P
p
0 1 .4 r
.012 w
.36767 .35484 m
.27326 .54011 L
s
P
p
0 1 .4 r
.012 w
.36767 .35484 m
.33514 .56022 L
s
P
p
0 1 .4 r
.012 w
.40451 .38161 m
.21923 .47601 L
s
P
p
0 1 .4 r
.012 w
.40451 .38161 m
.25747 .52864 L
s
P
p
0 1 .4 r
.012 w
.40451 .38161 m
.31011 .56688 L
s
P
p
0 1 .4 r
.012 w
.40451 .38161 m
.37198 .58699 L
s
P
p
0 1 .4 r
.012 w
.40451 .38161 m
.43704 .58699 L
s
P
p
0 1 .4 r
.018 w
.47059 .25191 m
.3409 .31799 L
s
P
p
0 1 .4 r
.018 w
.47059 .25191 m
.36767 .35484 L
s
P
p
0 1 .4 r
.018 w
.47059 .25191 m
.40451 .38161 L
s
P
p
0 1 .4 r
.012 w
.59549 .38161 m
.56296 .58699 L
s
P
p
0 1 .4 r
.012 w
.59549 .38161 m
.62802 .58699 L
s
P
p
0 1 .4 r
.012 w
.59549 .38161 m
.68989 .56688 L
s
P
p
0 1 .4 r
.012 w
.59549 .38161 m
.74253 .52864 L
s
P
p
0 1 .4 r
.012 w
.59549 .38161 m
.78077 .47601 L
s
P
p
0 1 .4 r
.012 w
.63233 .35484 m
.66486 .56022 L
s
P
p
0 1 .4 r
.012 w
.63233 .35484 m
.72674 .54011 L
s
P
p
0 1 .4 r
.012 w
.63233 .35484 m
.77937 .50187 L
s
P
p
0 1 .4 r
.012 w
.63233 .35484 m
.81761 .44924 L
s
P
p
0 1 .4 r
.012 w
.63233 .35484 m
.83772 .38737 L
s
P
p
0 1 .4 r
.012 w
.6591 .31799 m
.75351 .50327 L
s
P
p
0 1 .4 r
.012 w
.6591 .31799 m
.80614 .46503 L
s
P
p
0 1 .4 r
.012 w
.6591 .31799 m
.84438 .4124 L
s
P
p
0 1 .4 r
.012 w
.6591 .31799 m
.86448 .35052 L
s
P
p
0 1 .4 r
.012 w
.6591 .31799 m
.86448 .28546 L
s
P
p
0 1 .4 r
.018 w
.52941 .25191 m
.59549 .38161 L
s
P
p
0 1 .4 r
.018 w
.52941 .25191 m
.63233 .35484 L
s
P
p
0 1 .4 r
.018 w
.52941 .25191 m
.6591 .31799 L
s
P
p
.8 0 1 r
.008 w
.5 .2225 m
.47059 .25191 L
s
P
p
.8 0 1 r
.008 w
.5 .2225 m
.52941 .25191 L
s
P
p
0 1 .4 r
.012 w
.41032 .3574 m
.20494 .38993 L
s
P
p
0 1 .4 r
.012 w
.41032 .3574 m
.22504 .4518 L
s
P
p
0 1 .4 r
.012 w
.41032 .3574 m
.26328 .50443 L
s
P
p
0 1 .4 r
.012 w
.41032 .3574 m
.31592 .54267 L
s
P
p
0 1 .4 r
.012 w
.41032 .3574 m
.37779 .56278 L
s
P
p
0 1 .4 r
.012 w
.44717 .38416 m
.26189 .47857 L
s
P
p
0 1 .4 r
.012 w
.44717 .38416 m
.30013 .5312 L
s
P
p
0 1 .4 r
.012 w
.44717 .38416 m
.35276 .56944 L
s
P
p
0 1 .4 r
.012 w
.44717 .38416 m
.41464 .58955 L
s
P
p
0 1 .4 r
.012 w
.44717 .38416 m
.47969 .58955 L
s
P
p
0 1 .4 r
.012 w
.49048 .39824 m
.34344 .54527 L
s
P
p
0 1 .4 r
.012 w
.49048 .39824 m
.39607 .58352 L
s
P
p
0 1 .4 r
.012 w
.49048 .39824 m
.45795 .60362 L
s
P
p
0 1 .4 r
.012 w
.49048 .39824 m
.52301 .60362 L
s
P
p
0 1 .4 r
.012 w
.49048 .39824 m
.58488 .58352 L
s
P
p
0 1 .4 r
.018 w
.51325 .25447 m
.41032 .3574 L
s
P
p
0 1 .4 r
.018 w
.51325 .25447 m
.44717 .38416 L
s
P
p
0 1 .4 r
.018 w
.51325 .25447 m
.49048 .39824 L
s
P
p
0 1 .4 r
.012 w
.67211 .33922 m
.70464 .5446 L
s
P
p
0 1 .4 r
.012 w
.67211 .33922 m
.76651 .5245 L
s
P
p
0 1 .4 r
.012 w
.67211 .33922 m
.81915 .48626 L
s
P
p
0 1 .4 r
.012 w
.67211 .33922 m
.85739 .43363 L
s
P
p
0 1 .4 r
.012 w
.67211 .33922 m
.87749 .37175 L
s
P
p
0 1 .4 r
.012 w
.69888 .30238 m
.79328 .48766 L
s
P
p
0 1 .4 r
.012 w
.69888 .30238 m
.84592 .44942 L
s
P
p
0 1 .4 r
.012 w
.69888 .30238 m
.88416 .39678 L
s
P
p
0 1 .4 r
.012 w
.69888 .30238 m
.90426 .33491 L
s
P
p
0 1 .4 r
.012 w
.69888 .30238 m
.90426 .26985 L
s
P
p
0 1 .4 r
.012 w
.71295 .25907 m
.85999 .4061 L
s
P
p
0 1 .4 r
.012 w
.71295 .25907 m
.89823 .35347 L
s
P
p
0 1 .4 r
.012 w
.71295 .25907 m
.91833 .2916 L
s
P
p
0 1 .4 r
.012 w
.71295 .25907 m
.91833 .22654 L
s
P
p
0 1 .4 r
.012 w
.71295 .25907 m
.89823 .16466 L
s
P
p
0 1 .4 r
.018 w
.56918 .2363 m
.67211 .33922 L
s
P
p
0 1 .4 r
.018 w
.56918 .2363 m
.69888 .30238 L
s
P
p
0 1 .4 r
.018 w
.56918 .2363 m
.71295 .25907 L
s
P
p
.8 0 1 r
.008 w
.53213 .21741 m
.51325 .25447 L
s
P
p
.8 0 1 r
.008 w
.53213 .21741 m
.56918 .2363 L
s
P
p
0 1 .4 r
.012 w
.48852 .37342 m
.30325 .46782 L
s
P
p
0 1 .4 r
.012 w
.48852 .37342 m
.34149 .52045 L
s
P
p
0 1 .4 r
.012 w
.48852 .37342 m
.39412 .5587 L
s
P
p
0 1 .4 r
.012 w
.48852 .37342 m
.45599 .5788 L
s
P
p
0 1 .4 r
.012 w
.48852 .37342 m
.52105 .5788 L
s
P
p
0 1 .4 r
.012 w
.53184 .38749 m
.3848 .53453 L
s
P
p
0 1 .4 r
.012 w
.53184 .38749 m
.43743 .57277 L
s
P
p
0 1 .4 r
.012 w
.53184 .38749 m
.49931 .59287 L
s
P
p
0 1 .4 r
.012 w
.53184 .38749 m
.56437 .59287 L
s
P
p
0 1 .4 r
.012 w
.53184 .38749 m
.62624 .57277 L
s
P
p
0 1 .4 r
.012 w
.57738 .38749 m
.48297 .57277 L
s
P
p
0 1 .4 r
.012 w
.57738 .38749 m
.54485 .59287 L
s
P
p
0 1 .4 r
.012 w
.57738 .38749 m
.60991 .59287 L
s
P
p
0 1 .4 r
.012 w
.57738 .38749 m
.67178 .57277 L
s
P
p
0 1 .4 r
.012 w
.57738 .38749 m
.72441 .53453 L
s
P
p
0 1 .4 r
.018 w
.55461 .24372 m
.48852 .37342 L
s
P
p
0 1 .4 r
.018 w
.55461 .24372 m
.53184 .38749 L
s
P
p
0 1 .4 r
.018 w
.55461 .24372 m
.57738 .38749 L
s
P
p
0 1 .4 r
.012 w
.73188 .27524 m
.82629 .46051 L
s
P
p
0 1 .4 r
.012 w
.73188 .27524 m
.87892 .42227 L
s
P
p
0 1 .4 r
.012 w
.73188 .27524 m
.91716 .36964 L
s
P
p
0 1 .4 r
.012 w
.73188 .27524 m
.93727 .30776 L
s
P
p
0 1 .4 r
.012 w
.73188 .27524 m
.93727 .24271 L
s
P
p
0 1 .4 r
.012 w
.74596 .23192 m
.89299 .37896 L
s
P
p
0 1 .4 r
.012 w
.74596 .23192 m
.93123 .32633 L
s
P
p
0 1 .4 r
.012 w
.74596 .23192 m
.95134 .26445 L
s
P
p
0 1 .4 r
.012 w
.74596 .23192 m
.95134 .19939 L
s
P
p
0 1 .4 r
.012 w
.74596 .23192 m
.93123 .13752 L
s
P
p
0 1 .4 r
.012 w
.74596 .18638 m
.93123 .28079 L
s
P
p
0 1 .4 r
.012 w
.74596 .18638 m
.95134 .21891 L
s
P
p
0 1 .4 r
.012 w
.74596 .18638 m
.95134 .15385 L
s
P
p
0 1 .4 r
.012 w
.74596 .18638 m
.93123 .09198 L
s
P
p
0 1 .4 r
.012 w
.74596 .18638 m
.89299 .03934 L
s
P
p
0 1 .4 r
.018 w
.60219 .20915 m
.73188 .27524 L
s
P
p
0 1 .4 r
.018 w
.60219 .20915 m
.74596 .23192 L
s
P
p
0 1 .4 r
.018 w
.60219 .20915 m
.74596 .18638 L
s
P
p
.8 0 1 r
.008 w
.56111 .20265 m
.55461 .24372 L
s
P
p
.8 0 1 r
.008 w
.56111 .20265 m
.60219 .20915 L
s
P
p
1 0 0 r
.002 w
.5 .11853 m
.43889 .20265 L
s
P
p
1 0 0 r
.002 w
.5 .11853 m
.46787 .21741 L
s
P
p
1 0 0 r
.002 w
.5 .11853 m
.5 .2225 L
s
P
p
1 0 0 r
.002 w
.5 .11853 m
.53213 .21741 L
s
P
p
1 0 0 r
.002 w
.5 .11853 m
.56111 .20265 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.402116 0.782187 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.225751 0.952381 [
[ 0 0 0 0 ]
[ 1 .50088 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .50088 L
0 .50088 L
closepath
clip
newpath
p
P
p
.8 1 0 r
.002 w
.7016 .43289 m
.74394 .46365 L
s
P
p
.8 1 0 r
.002 w
.7016 .43289 m
.75393 .43289 L
s
P
p
.8 1 0 r
.002 w
.10434 .23883 m
.062 .20807 L
s
P
p
.8 1 0 r
.002 w
.10434 .23883 m
.052 .23883 L
s
P
p
.2 0 1 r
.016 w
.40297 .33586 m
.7016 .43289 L
s
P
p
.2 0 1 r
.016 w
.40297 .33586 m
.10434 .23883 L
s
P
p
.8 1 0 r
.002 w
.814 .35123 m
.86377 .3674 L
s
P
p
.8 1 0 r
.002 w
.814 .35123 m
.86377 .33506 L
s
P
p
.8 1 0 r
.002 w
.186 .35123 m
.13623 .33506 L
s
P
p
.8 1 0 r
.002 w
.186 .35123 m
.13623 .3674 L
s
P
p
.2 0 1 r
.016 w
.5 .35123 m
.814 .35123 L
s
P
p
.2 0 1 r
.016 w
.5 .35123 m
.186 .35123 L
s
P
p
.8 1 0 r
.002 w
.89566 .23883 m
.948 .23883 L
s
P
p
.8 1 0 r
.002 w
.89566 .23883 m
.938 .20807 L
s
P
p
.8 1 0 r
.002 w
.2984 .43289 m
.24607 .43289 L
s
P
p
.8 1 0 r
.002 w
.2984 .43289 m
.25606 .46365 L
s
P
p
.2 0 1 r
.016 w
.59703 .33586 m
.89566 .23883 L
s
P
p
.2 0 1 r
.016 w
.59703 .33586 m
.2984 .43289 L
s
P
p
0 .4 1 r
.004 w
.5 .03723 m
.40297 .33586 L
s
P
p
0 .4 1 r
.004 w
.5 .03723 m
.5 .35123 L
s
P
p
0 .4 1 r
.004 w
.5 .03723 m
.59703 .33586 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.402116 0.97619 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0126952 0.952381 [
[ 0 0 0 0 ]
[ 1 .97777 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .97777 L
0 .97777 L
closepath
clip
newpath
p
P
p
0 1 .4 r
.012 w
.56818 .56761 m
.53013 .68471 L
s
P
p
0 1 .4 r
.012 w
.76766 .36813 m
.88476 .33008 L
s
P
p
0 1 .4 r
.012 w
.48903 .324 m
.38942 .25163 L
s
P
p
1 0 0 r
.02 w
.6171 .41705 m
.56818 .56761 L
s
P
p
1 0 0 r
.02 w
.6171 .41705 m
.76766 .36813 L
s
P
p
1 0 0 r
.02 w
.6171 .41705 m
.48903 .324 L
s
P
p
0 1 .4 r
.012 w
.56818 .36433 m
.68528 .40238 L
s
P
p
0 1 .4 r
.012 w
.3687 .16485 m
.33066 .04775 L
s
P
p
0 1 .4 r
.012 w
.32457 .44348 m
.2522 .5431 L
s
P
p
1 0 0 r
.02 w
.41762 .31541 m
.56818 .36433 L
s
P
p
1 0 0 r
.02 w
.41762 .31541 m
.3687 .16485 L
s
P
p
1 0 0 r
.02 w
.41762 .31541 m
.32457 .44348 L
s
P
p
0 1 .4 r
.012 w
.3649 .36433 m
.40295 .24723 L
s
P
p
0 1 .4 r
.012 w
.16543 .56381 m
.04832 .60186 L
s
P
p
0 1 .4 r
.012 w
.44406 .60794 m
.54367 .68031 L
s
P
p
1 0 0 r
.02 w
.31598 .51489 m
.3649 .36433 L
s
P
p
1 0 0 r
.02 w
.31598 .51489 m
.16543 .56381 L
s
P
p
1 0 0 r
.02 w
.31598 .51489 m
.44406 .60794 L
s
P
p
0 1 .4 r
.012 w
.3649 .56761 m
.2478 .52956 L
s
P
p
0 1 .4 r
.012 w
.56438 .76709 m
.60243 .88419 L
s
P
p
0 1 .4 r
.012 w
.60851 .48846 m
.68088 .38884 L
s
P
p
1 0 0 r
.02 w
.51546 .61653 m
.3649 .56761 L
s
P
p
1 0 0 r
.02 w
.51546 .61653 m
.56438 .76709 L
s
P
p
1 0 0 r
.02 w
.51546 .61653 m
.60851 .48846 L
s
P
p
0 .4 1 r
.004 w
.46654 .46597 m
.6171 .41705 L
s
P
p
0 .4 1 r
.004 w
.46654 .46597 m
.41762 .31541 L
s
P
p
0 .4 1 r
.004 w
.46654 .46597 m
.31598 .51489 L
s
P
p
0 .4 1 r
.004 w
.46654 .46597 m
.51546 .61653 L
s
P
p
0 1 .4 r
.012 w
.62129 .50605 m
.65934 .62315 L
s
P
p
0 1 .4 r
.012 w
.66542 .22741 m
.73779 .1278 L
s
P
p
0 1 .4 r
.012 w
.41407 .35549 m
.29094 .35549 L
s
P
p
1 0 0 r
.02 w
.57237 .35549 m
.62129 .50605 L
s
P
p
1 0 0 r
.02 w
.57237 .35549 m
.66542 .22741 L
s
P
p
1 0 0 r
.02 w
.57237 .35549 m
.41407 .35549 L
s
P
p
0 1 .4 r
.012 w
.50181 .34159 m
.61891 .30354 L
s
P
p
0 1 .4 r
.012 w
.22318 .29746 m
.12357 .22509 L
s
P
p
0 1 .4 r
.012 w
.35125 .54882 m
.35125 .67194 L
s
P
p
1 0 0 r
.02 w
.35125 .39051 m
.50181 .34159 L
s
P
p
1 0 0 r
.02 w
.35125 .39051 m
.22318 .29746 L
s
P
p
1 0 0 r
.02 w
.35125 .39051 m
.35125 .54882 L
s
P
p
0 1 .4 r
.012 w
.33735 .46107 m
.2993 .34397 L
s
P
p
0 1 .4 r
.012 w
.29322 .73971 m
.22085 .83932 L
s
P
p
0 1 .4 r
.012 w
.54458 .61163 m
.66771 .61163 L
s
P
p
1 0 0 r
.02 w
.38627 .61163 m
.33735 .46107 L
s
P
p
1 0 0 r
.02 w
.38627 .61163 m
.29322 .73971 L
s
P
p
1 0 0 r
.02 w
.38627 .61163 m
.54458 .61163 L
s
P
p
0 1 .4 r
.012 w
.45684 .62553 m
.33974 .66358 L
s
P
p
0 1 .4 r
.012 w
.73547 .66966 m
.83508 .74203 L
s
P
p
0 1 .4 r
.012 w
.60739 .4183 m
.60739 .29518 L
s
P
p
1 0 0 r
.02 w
.60739 .57661 m
.45684 .62553 L
s
P
p
1 0 0 r
.02 w
.60739 .57661 m
.73547 .66966 L
s
P
p
1 0 0 r
.02 w
.60739 .57661 m
.60739 .4183 L
s
P
p
0 .4 1 r
.004 w
.47932 .48356 m
.57237 .35549 L
s
P
p
0 .4 1 r
.004 w
.47932 .48356 m
.35125 .39051 L
s
P
p
0 .4 1 r
.004 w
.47932 .48356 m
.38627 .61163 L
s
P
p
0 .4 1 r
.004 w
.47932 .48356 m
.60739 .57661 L
s
P
p
0 1 .4 r
.012 w
.62807 .42502 m
.72768 .49739 L
s
P
p
0 1 .4 r
.012 w
.5 .17367 m
.5 .05054 L
s
P
p
0 1 .4 r
.012 w
.37193 .42502 m
.27232 .49739 L
s
P
p
1 0 0 r
.02 w
.5 .33197 m
.62807 .42502 L
s
P
p
1 0 0 r
.02 w
.5 .33197 m
.5 .17367 L
s
P
p
1 0 0 r
.02 w
.5 .33197 m
.37193 .42502 L
s
P
p
0 1 .4 r
.012 w
.43474 .36221 m
.50712 .26259 L
s
P
p
0 1 .4 r
.012 w
.18339 .49028 m
.06026 .49028 L
s
P
p
0 1 .4 r
.012 w
.43474 .61835 m
.50712 .71796 L
s
P
p
1 0 0 r
.02 w
.34169 .49028 m
.43474 .36221 L
s
P
p
1 0 0 r
.02 w
.34169 .49028 m
.18339 .49028 L
s
P
p
1 0 0 r
.02 w
.34169 .49028 m
.43474 .61835 L
s
P
p
0 1 .4 r
.012 w
.37193 .55553 m
.27232 .48316 L
s
P
p
0 1 .4 r
.012 w
.5 .80689 m
.5 .93002 L
s
P
p
0 1 .4 r
.012 w
.62807 .55553 m
.72768 .48316 L
s
P
p
1 0 0 r
.02 w
.5 .64859 m
.37193 .55553 L
s
P
p
1 0 0 r
.02 w
.5 .64859 m
.5 .80689 L
s
P
p
1 0 0 r
.02 w
.5 .64859 m
.62807 .55553 L
s
P
p
0 1 .4 r
.012 w
.56526 .61835 m
.49288 .71796 L
s
P
p
0 1 .4 r
.012 w
.81661 .49028 m
.93974 .49028 L
s
P
p
0 1 .4 r
.012 w
.56526 .36221 m
.49288 .26259 L
s
P
p
1 0 0 r
.02 w
.65831 .49028 m
.56526 .61835 L
s
P
p
1 0 0 r
.02 w
.65831 .49028 m
.81661 .49028 L
s
P
p
1 0 0 r
.02 w
.65831 .49028 m
.56526 .36221 L
s
P
p
0 .4 1 r
.004 w
.5 .49028 m
.5 .33197 L
s
P
p
0 .4 1 r
.004 w
.5 .49028 m
.34169 .49028 L
s
P
p
0 .4 1 r
.004 w
.5 .49028 m
.5 .64859 L
s
P
p
0 .4 1 r
.004 w
.5 .49028 m
.65831 .49028 L
s
P
p
0 1 .4 r
.012 w
.58593 .35549 m
.70906 .35549 L
s
P
p
0 1 .4 r
.012 w
.33458 .22741 m
.26221 .1278 L
s
P
p
0 1 .4 r
.012 w
.37871 .50605 m
.34066 .62315 L
s
P
p
1 0 0 r
.02 w
.42763 .35549 m
.58593 .35549 L
s
P
p
1 0 0 r
.02 w
.42763 .35549 m
.33458 .22741 L
s
P
p
1 0 0 r
.02 w
.42763 .35549 m
.37871 .50605 L
s
P
p
0 1 .4 r
.012 w
.39261 .4183 m
.39261 .29518 L
s
P
p
0 1 .4 r
.012 w
.26453 .66966 m
.16492 .74203 L
s
P
p
0 1 .4 r
.012 w
.54316 .62553 m
.66026 .66358 L
s
P
p
1 0 0 r
.02 w
.39261 .57661 m
.39261 .4183 L
s
P
p
1 0 0 r
.02 w
.39261 .57661 m
.26453 .66966 L
s
P
p
1 0 0 r
.02 w
.39261 .57661 m
.54316 .62553 L
s
P
p
0 1 .4 r
.012 w
.45542 .61163 m
.33229 .61163 L
s
P
p
0 1 .4 r
.012 w
.70678 .73971 m
.77915 .83932 L
s
P
p
0 1 .4 r
.012 w
.66265 .46107 m
.7007 .34397 L
s
P
p
1 0 0 r
.02 w
.61373 .61163 m
.45542 .61163 L
s
P
p
1 0 0 r
.02 w
.61373 .61163 m
.70678 .73971 L
s
P
p
1 0 0 r
.02 w
.61373 .61163 m
.66265 .46107 L
s
P
p
0 1 .4 r
.012 w
.64875 .54882 m
.64875 .67194 L
s
P
p
0 1 .4 r
.012 w
.77682 .29746 m
.87643 .22509 L
s
P
p
0 1 .4 r
.012 w
.49819 .34159 m
.38109 .30354 L
s
P
p
1 0 0 r
.02 w
.64875 .39051 m
.64875 .54882 L
s
P
p
1 0 0 r
.02 w
.64875 .39051 m
.77682 .29746 L
s
P
p
1 0 0 r
.02 w
.64875 .39051 m
.49819 .34159 L
s
P
p
0 .4 1 r
.004 w
.52068 .48356 m
.42763 .35549 L
s
P
p
0 .4 1 r
.004 w
.52068 .48356 m
.39261 .57661 L
s
P
p
0 .4 1 r
.004 w
.52068 .48356 m
.61373 .61163 L
s
P
p
0 .4 1 r
.004 w
.52068 .48356 m
.64875 .39051 L
s
P
p
0 1 .4 r
.012 w
.51097 .324 m
.61058 .25163 L
s
P
p
0 1 .4 r
.012 w
.23234 .36813 m
.11524 .33008 L
s
P
p
0 1 .4 r
.012 w
.43182 .56761 m
.46987 .68471 L
s
P
p
1 0 0 r
.02 w
.3829 .41705 m
.51097 .324 L
s
P
p
1 0 0 r
.02 w
.3829 .41705 m
.23234 .36813 L
s
P
p
1 0 0 r
.02 w
.3829 .41705 m
.43182 .56761 L
s
P
p
0 1 .4 r
.012 w
.39149 .48846 m
.31912 .38884 L
s
P
p
0 1 .4 r
.012 w
.43562 .76709 m
.39757 .88419 L
s
P
p
0 1 .4 r
.012 w
.6351 .56761 m
.7522 .52956 L
s
P
p
1 0 0 r
.02 w
.48454 .61653 m
.39149 .48846 L
s
P
p
1 0 0 r
.02 w
.48454 .61653 m
.43562 .76709 L
s
P
p
1 0 0 r
.02 w
.48454 .61653 m
.6351 .56761 L
s
P
p
0 1 .4 r
.012 w
.55594 .60794 m
.45633 .68031 L
s
P
p
0 1 .4 r
.012 w
.83457 .56381 m
.95168 .60186 L
s
P
p
0 1 .4 r
.012 w
.6351 .36433 m
.59705 .24723 L
s
P
p
1 0 0 r
.02 w
.68402 .51489 m
.55594 .60794 L
s
P
p
1 0 0 r
.02 w
.68402 .51489 m
.83457 .56381 L
s
P
p
1 0 0 r
.02 w
.68402 .51489 m
.6351 .36433 L
s
P
p
0 1 .4 r
.012 w
.67543 .44348 m
.7478 .5431 L
s
P
p
0 1 .4 r
.012 w
.6313 .16485 m
.66934 .04775 L
s
P
p
0 1 .4 r
.012 w
.43182 .36433 m
.31472 .40238 L
s
P
p
1 0 0 r
.02 w
.58238 .31541 m
.67543 .44348 L
s
P
p
1 0 0 r
.02 w
.58238 .31541 m
.6313 .16485 L
s
P
p
1 0 0 r
.02 w
.58238 .31541 m
.43182 .36433 L
s
P
p
0 .4 1 r
.004 w
.53346 .46597 m
.3829 .41705 L
s
P
p
0 .4 1 r
.004 w
.53346 .46597 m
.48454 .61653 L
s
P
p
0 .4 1 r
.004 w
.53346 .46597 m
.68402 .51489 L
s
P
p
0 .4 1 r
.004 w
.53346 .46597 m
.58238 .31541 L
s
P
p
0 1 .4 r
.004 w
.5 .4551 m
.46654 .46597 L
s
P
p
0 1 .4 r
.004 w
.5 .4551 m
.47932 .48356 L
s
P
p
0 1 .4 r
.004 w
.5 .4551 m
.5 .49028 L
s
P
p
0 1 .4 r
.004 w
.5 .4551 m
.52068 .48356 L
s
P
p
0 1 .4 r
.004 w
.5 .4551 m
.53346 .46597 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{438, 258},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006f00010PP10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0]`000?l0]`000?l0]`000?l0]`000?l0
]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`00034000=<04`0o`230000<002C@0304e=0?T0
00<P0000Q@0003400da:00;O00=2gml00]l300CO00=2gml0W`000b0000250000<P000b<0001700;N
0P000d8000090003@P0000;NW@000b00002500007002C1@000<S00004@02C3P000=200002@000d80
002O0003800008D0000L00==4P000b<08`0B009=>0000d8000090003@P0009l000<P0000Q@0001d0
0T`28`l000DS00008`0>009<00<SC000>@000d8000070003@P000:0000<P0000Q@0001h000@SCDdS
3@000b<0000300038`0000/00Td00`0S000i0003@P0000L000=20000X0000b00002500007P001B<0
C00S00`000<S00000`000b<0000:00058`1<02<0>P000d8000070003@P000:0000<P0000Q@0001h0
00<S02<00P028`T000<S00001@000b<00007008S0P000b<08`0j0003@P0000;N00<0g]h00P000d80
002P0003800008D0000O008S10000b<0000500038`0000L000<S00001@000b<00002008S>`000d80
00020003g`00008000=20000X0000b00002500007`028`D00R<500038`0000L000<S00000`028`D0
0R<_0003gP0000<00mh30007@P000480@P030004@P0000?N10000mh0000O00=2?`03@S4000<P0000
Q@0001l00R<700058`0002<02`001B<0000S00L00R<_0003g`0000D00]l01T;O0480g`9200L0g`12
0=m200;O1P000ml0000R00=2>@03@S@000<P0000Q@00020000<S00001P000b<08`0=00038`0S00P0
00<S0000;@000mh000060008gP120=i2gP02@P800mh010120=h70003gP0002@00d8c00=2=`000b00
0025000080000b<000070003@R<000<01D`400038d8000P000<S0000;@000ml000060006gd80048A
0d801P12@]lA@P8000=2g`001P000ml0000W00=2;@03@SX000<P0000Q@00020000<S00001`001480
8`028`E=0R<0100S048900038`0002`00T8900A200<A@T802D800mh000060092:`03@RL00d8m0003
800003T000<S0000;P000b<0000H000080028`L000<S@R<00R<900<S00=28`001P028bh000CO0=m2
1P05@P034Mm200<00T800a52@P03@PD00T800`3O000]00=28@03@T0000<P0000>@000b<0000^0003
8`0001P0000P008S1P028`04@P00008S1@028`<000=28b<01P028bT000GN0000gP020003gP120092
0P02@P0<gP00gQ7N0480@P3N0T820004gT9200=200D0gP00gP040003gP0002T00d8K00=2@`000b00
000j00038`0002`000<S00006@0002000R<4008S0P000d80000300058`0002<010001T80001<8`@0
0R<Y0005g`000=l00`001=l00003@P030=l000=200<A@P000d801a52@T80g`000d830005g`000=l0
0`000ml0000/00=25@03@TH000<P0000>P000b<0000/00038`0001T0000P00038`0S00<S00E=8`00
@P0600<S1@001T80001=00@S00<08`00:0000mh000050005gP12@P000d801mi2@]i24Mh024801]i2
@P12009200?N00001P000mh0000_00=23`03@TT000<P0000>`000b<0000Z00038`0001X0000P008S
0T800`1<8`040003@P0000<000<S02<01@000d8000020003C00000920R<X0003g`0000L000M20000
@P3O00=200_O0152g`3O@Q7O@P024@04g`00@P<000=200001`000ml0000a00=22@03@T`000<P0000
>`000b<0000Z00038`0001X0000M00@S00<08`000T850003@P00008000DS00008`040003@P0000<0
00DS@P0S00048bD014860005gP00@P000d801MhAgT8A00GN00I24A40@P02gP0504800=h01P04@SH0
0d8300=2C`000b00000l00038`0002P000<S00006`0000l00d`>8`03@R<S00<S0T838`03@R<S00=<
0P02C0038d`S00`S00=28b<02b<3C1P000CO00001T800`3O0002@P8000=2gml00]l00a400002008A
00A2gd920`001D;O0=l000I20`000ml0000g00=2DP000b00000l00038`0002L000<S000070000100
0Td500<S1P000d8000028`<000A200120dd0101=0003C@0304e200800T83008S00<0@R<01P038`D0
0TdH0003gP0000L000=2gQ400a4014;N@P02@P08gQ4A017N@P05@P034D8A00;N00=200001`000mh0
000f0005@P120480D@000b00000l00038`0002L000<S0000700001800d`28`T000@S@P0S1@03@P03
04`000L000=<04800T8600048d808`T00R<00d`S8`0I0003g`0000P00ml00d;O@P054@03@P0A008A
00E24D;O@P024@04@Q52g`920]l90003g`0003D000A200120P000d80001>0003800003d000<S0000
9@000b<0000M00004P02C@038`0000T000DS02<08`0600038`0000X000<S00001@001B=28`0S00/0
00<SC@006@000mh000080004gP1200=20P02@P8A00I=g]i2CMh2@P80148010120=h90003gP0003<0
0T830004@P000092CP000b00000m00038`0002D000<S00007@0001D000<S000020001B=<8d8S00H0
00<S00002P000b<000050005@P0SC2<02P000b<0000I0003g`0000P000A200120P02@P;O00D0@P12
C00200044D`0@P8000CO@T920P00148004890003g`00034000=200000`000d8000030003@P0004/0
00<P0000?P000b<0000S00038`0001h0000F008S20001DdS000S00L000<S000020000b<000050004
@R<0008S20028a/000?N000020000mh0@P020003@P00009200H0gT924Dd24@0704dA@P3N0002@P80
00E20012gP0:0003gP0002l000=2000010000d8000040003@P0004X000<P0000?P000b<0000S0003
8`0001h0000H00038`0000D000<S00000P000b<0000500038`0000H000<S00001@000d8S00030003
8`0000D000<S00006P000d8000080009g`000480@]l0009200H0gd924D`24@0804cO@P3O04820004
gd80@P8000?O000020000d80000/00921`000d8000050092BP000b00000o00038`0000h00kL@0003
8`0001l0000I008S1@000b<0000200038d8000H000<S000010000b<000050003@P0S00@000<S0000
0`028a`000?N048020000mh00003009200?N04800T802Mi24D;NCMi=0002@P040=i2@P8000?N@T80
10000mh000070003@]h002/000=200001`000d8000070003@P0004L000<P0000?`000b<0000<00:g
0`02]`h000<S00007`0001/000@S00000R<400038d8S008S1@000b<0000300038`0000800b<3@P@0
0R<300038`0001/000GO0000@P070003g`0000@000I20=l0@]l2@P8A00SOC=m<4D;O00A200?O0480
1@000ml000060004@P00gbX000=2000020000d8000080003@P0004H000<P0000@0000b<0000900:g
1`02]`/000<S0000800001`000@S02<01D800`0S000200@S0P001B<0000S00800b<400038`1200A2
00@08`0S7@000mh000030003@P0000@000?N00001007@P0=4D;N@Te2CD8A@]i20005@PD000?N0000
1@000d8000020003gP0002D00T8;0003@P0000T00T9600038000044000<S00001P02]`/00kL70003
8`000240000M00=200<S00000`000b<0000500@S00<08b<00R<700038`0000<000@S@T929@000d80
00030003g`0000800]l3@P05gd;O@Q400d8024a2C4804Mm20]l00d;Og`02g`D000?O00000`000d80
000Z0003@P0000/000=200002`000d80001300038000044000<S00001002]a000[L500038`000240
000M00048`0S8`D000==000020038`X000==00000`028`0302<002D000=200000P04@P0;04920480
@]i24Mh00T801@1=04d0009200PAgT;N@P12009200<0@T800T840003@P0002X000=2000030000d80
000<0003@P00048000<P0000@P001=h00002]a@00[L20003gP000280000L00058`0002<01@02C0X0
00<S000020000d`0000400058`0002<09P001D80003O00<01T802`12@Q52gd;OC=m<00920]l2@P03
g`1200E20`001Ml0001202`000=200003@000d80000=0003@P00044000<P0000@P001=l0]kLH00:g
00?O00008P0001/000<S00000P038`<00Td:00038`0000L00Td400<S10000b<0000T0005@P00gP00
0T8200;N00E2g]kN4@05@P04CD9=00920]h01A52@]i200;N0P02@P050=h00480:`02@Q0000=20000
3P02@T4000<P0000@P000mjg000K0003]`000280000J00038`0000<000@S000S3P000b<0000<0004
8`008`D000<S0000900014;O@T8200;O0`02@P05gd80g`000d802Da2@T80gd8Ag`02@P<00]l20092
00?O@P00:P000d80000@0003@P00010000=20000?P000b00001000058ml00=l06P001=l0gb<R0000
6P000b<000030004C@00008S30000b<0000:008S0`000dd0000300038`0002<00]h01152@T8400=2
00CN@]kN0d820003C@0000=200CN@Q7N0d84009200CN4MkN:@000d80000A0003@P00014000=20000
?@000b00000n008S10000b<0000H00048`00008S800001T000<S00000`02C0D000<SC4`02@000b<0
0006009<00<08`000`02C0H000<S00007004g`06@]l0048A0]l7@P030492009200<0@P000d`01d80
@]l0@Q402482g`064Ml00=m21=lQ009250000d80000B0092?@000b00000m00038`0000D000<S0000
5P000b<00004008S7P0001P000<S00003002C@T000<S00001P02C@038`0000`000<S00007`000d80
0002@P09gQ7N@]i204;N00=200@0g]i20Td3009=00X0gT80@Q52gT800T82gP044Mi2@P8000=20000
8P000d80000D0003@P0001@000=20000>P000b00000k008S20000b<0000F00038`0000H00R<L0000
60000b<0000=009<20000b<000060003C2<000h000<S00007`000d800002@P04g`0A@P;O00]2g`00
@]l0@]m<@P040004@P1<009200KO4@00gd82g`04@Q40g`920P000d80000Q0003@P0001D000=20000
5@000d80000i0003800003T00R<;00038`0001@000<S00002@028aX0000G00038`0000l000<SC@00
1P000b<00004009=00<S00003`000b<0000N0003@P1200800d801140@]h20004@P3N@P9=0P000d80
0002@P090=i=C@3N014000;N00=201400d820003@P1202400T8H0003@P0001H00T8i0003800003L0
0R<=00038`0001@000<S00002`028aP0000F00038`00010000<S00001P000b<0000600038`000100
00<S00007P02@P8000I2gd804Ml20003@Q7O009<00A20=l00d801012g`02@P9<00/04@00g`0A04;O
@P0200928@000d80000H0003@P0001P000=20000=P000b00000d00<S40000b<0000B00038`0000h0
0b<E000050000ddS000B00038`0000H000<S00001P000b<0000A00038dd001d000A200000T802mh0
017N0480CMh0009200<0gT800T801P120480@P;N00I=@Q7N01420003gT9200<000=200007P000d80
000I0003@P0001T000=20000=@000b00000b008S4`000b<0000B00038`0001400R<C00004`000d`0
C00D00038`0000D000<S00001@000b<0000B0003C01<01`00T83009200H0gml04D82C08000KO@P12
04820003@P12008000CO00000T`00`0A0002g`03049200<000=200007@000d80000J0003@P0001X0
00=20000=0000b00000`008S5P000b<0000@00038`0001@00R<A000050000dd0000C00038`0000D0
00=200001@000b<0000C0003C@0001/00T830003@P3N008000?N4Dd01A400`12gP02@P;N0T82gP03
@P0A00@A00==4Mh00P000mh0@P030003@P0003X000=20000D@000b00000_00038`0001H000<S0000
40000b<0000F00038`0000h0000Z00038`0000@000=204801P000b<0000/00;O0P000d80@P020092
00?O00000Q400d;O000400@A0T800mlA4@044@@000?O4@000Q420003gd9200800T8300;O=P000d80
001A0003800004T000<S00003P000b<0000X0000:`000b<000030003@P1200D000<S0000;`001Mh0
@P1200800d824@<000@Ag]kN1d820004gT92gP9200?N@]h00]h0114000024@=20P02@P030=kN03P0
00=20000D@000b00001900038`0000h000<S0000:00002L00T`200038`00008000E20000@P040004
8`00C2l000A2g`000T801=lA4@03g`040152@P;O0T820006@P3Og`120P02@P050=oO@Q400P03g`04
@Q4Ag`9200<0gd80>P000d80001A0003800004X000<S000030000b<0000Y00009`03C@0302<000<0
00E20000@P0400048`1=CC400]h01T8A4Mi2gP8000KN017N0=h2@P<000I20=kN04840005@P3N0140
0P001]h0@]i2gP8A0]hl0003@P00054000<P0000BP000b<0000;00038`0002X0000Z00<S0P000d80
00030003@P0000<S=0000d8Ag`02@P8000I2003O4Ml3@P<000=200000T820004@P0000=200KO4@3O
048300=200<A@P00>`000d80001A0003800004X000<S00002`000b<0000Z0000;0038`03@P0000<0
00A28b<S=002@P050=h0@P001D801]h04Mh0@P<00d82gP=210001D80gQ4000I200D0@P3N0002@SX0
00=20000D@000b00001;00038`0000T000<S0000:`0002`000@S04801B<0101202<Z0003g`0000@0
0d820005g`00048010001T80@Q7O@P800d801P3O003O00=20P001480@Q42@PD000A2003O0`03@PD0
00?O0000;`000d80001A0003800004/000<S00002@000b<0000[0000;@000b=28`028`0602<S8d8S
:`000mh0000200921@04@P03048000<000E2gQ7N0002@P040480gP@000?N00000d801@124@1200D0
1D8600920`000mh0000_0003@P00054000<P0000C0000b<0000700038`0002`0000[008S00=28`00
1P0012=28b<Z0004g`12@PL000CO00001T801@3O4Mm200<000=200001`000d800002@P034D8000I2
0`000ml00006009200?O0000<0000d80001A0003800004`000<S00001`000b<0000/0000:0038`80
00<S00001`000b<000038bP000=200001`000mh000040003@P00009200<AgP000P000d8000090005
@P00gQ400T830003@P0000<000?N000020000d80000`0003@P00054000<P0000C@000b<000050003
8`0002d0000U00<S1@000b<0000600038`0000@00b<U0003g`0000L000?O00001@001T80003O00;O
00<0@P002P001T80g`12g`<000=200001@000ml000070003g`00030000=20000D@000b0000250000
8P038`T000<S00001@000b<0000700<S8`000mh000060003gP0000H000A20=i20`000d;N000:0009
gT800480gP1200P000?N00001P000mh0000a0003@P00054000<P0000Q@0001d00d`28``000<S0000
1@000b<0000:00048da<C1l000?O00001P000ml000070003@P1200D00]l700;O1000148004890003
g`0000H000?O0000<@000d80001A0003800008D0000M009=3`000b<0000400038`0000h000==0000
7P000mh0000>0005gP0004801P000mh000030003gP0000<000=200000P000mh0000>0003gP0008H0
00<P0000Q@0002l000<S00000`000b<0000o0003g`00008000=2000040000d8000030003g`0009H0
00<P0000Q@0002l000<S00000P000b<0000o0003gP0000<000=2000040000d8000040003gP0009D0
00<P0000Q@0002l000<S00000P000b<000150003@P00010000=20000W0000b0000250000<0001B<0
000S04L000=2000040000d80002L0003800008D0000`00048`008dP000=2000040000d80002L0003
800008D0000`00048`008dT000=200003P000d80002M0003800008D0000a00038`0S04T000=20000
3P000d80002M0003800008D0000a008SB002gP03@]kN00;N2004gP03@]kN09d000<P0000Q@000340
0Ta600;O5P02gi/000<P0000Q@0003400Tgk0003800008D0003o0;L0003o0;L0003o0;L0003o0;L0
003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0
003o0;L0000@0003aP00044000?60000o`1P000040000lH000110003aP00078000=<00001@02C0L0
00=<00001@02C0L000=<0000b000010000?60000@@000lH0001b0003C@0000D00Td70003C@0000D0
0Td70003C@000<P0000@0003aP00044000?60000LP000d`00005009<1`000d`000050003C00000D0
00=<0000b@00010000?60000@@000lH0001c0003C@0000@00Td60003C@1=00H00Td60003C@000<T0
000@0003aP00044000?60000L`000d`0C004009<0P02C08000M<04`0C01<00800T`40003C01<04<0
00>d0000Q@00010000?60000@@000lH0001[009=1P03C@<000==000014d2000;C@1=04d0C@1=04d0
1003C@H00Tdk0003]00008D0000@0003aP00044000?60000K@000d`0000400=<0P06C00604a<04`0
0T`00`1<0004C0800d`60003C00003X00kB6000040000lH000110003aP0006h000==00000`03C@80
2Dd01@1=04d000M=0P000dd0C@050003C@0003X000Fd0;@0]025000040000lH000110003aP0006l0
00=<00000P000d`0C002C08000=<04`014`00`1<0003C00504`0C0001D`4009<?0001;@00;@20003
]0000880000@0003aP00044000?60000K`03C@8000==04d00dd00`1=C@06C@0304e=009=00D0CDe=
0005C@<00Tdm0004]000]08000>d0000<0000b00000j000380000180000@0003aP00044000?60000
KP03C00404`000i<00<0C4`034`20003C01<009<>P001K@0002d00<000>d0000;`000b00000K0003
@P0001`000<P00004P00010000?60000@@000lH0001`0003C@0000==00<0CDd014d00`1=C@07C@03
04e=00Y=00<0CDd0>`000k@000020003]000008000>d0000;P000b00000K0003@P0001`000<P0000
4P00010000?60000@@000lH0001`00m<00D0C4a<0003C00304a<00Q<00@0C4a<?0000k@000020003
]00000<000>d0000;@000b00000K0003@P0001`000<P00004P00010000?60000@@000lH0001X009=
1`03C@0304e=009=0P08C@0304e=00I=0P03C@8000==04d01`02CC8000>d00000`000k@000030003
]00002d000<P00006`000d80000L000380000180000@0003aP00044000?60000;P03UCL05d`00kA<
C00MC34000>d000010000k@000040003]00002`000<P00000P0281L000=200005P0380<000<P0000
4P00010000?60000@@000lH0000]0005U@2E09D0>@000dd00002C@0304e=00U=00<0CDd02dd00`1=
C@02C@03]4d000==0P02C@8000==0000<@000k@000050003]00000D000>d0000:`000b00800281T0
00=200006@0481@0000@0003aP00044000?60000;0001iD0U@2E09D0>@02C08000I<04`0C00KC006
04`0C01<0P02C3@000>d00001@000k@000060003]00002X00b<K0003@P0001X00b<D000040000lH0
00110003aP0002X00YD20003U@2E00800YDi0003C@0000A=00<0CDd01Dd00`1=C@09C@0304e=00E=
00<0CDd00Td20003C@0003<000>d00001P000k@000060003]00002X000<P00000b<H0003@P0001L0
0b<2000380000180000@0003aP00044000?60000:@000iD000020003U@2E00@000>E0000<`0GC0:d
1d`2]0m<<@000k@000070003]00000L000>d0000:0000b00800400<S5@000d80000D00<S10000b00
800C000040000lH000110003aP0002P000>E00000P001ID0002E00@000>E0000<P04C@0304e=00A=
00<0CDd02Dd00kA=]002]09=0[@014fdCDd200I=00<0CDd00Td`0003]00000P000>d000020000k@0
000V0005800002001P038a8000=200004@038`H000DP0000800B000040000lH000110003aP0002H0
0YD50005U@0009D01@02UC@05D`2]004C;Bd]19<<P000k@000080003]00000T000>d000090000b00
00020003800000L00b<?0003@P0000h00b<80003800000<000<P00003`00010000?60000@@000lH0
000U0003U@0000D000FE0000U@070003U@0002X00Td600A=00<0CDd03Dd02kA=]kA=]4fd]dfd00M=
00<0CDd00Td6009=:P000k@000090003]00000X000>d00008P000b0000040003800000T00b<<0003
@P0000/00b<:0003800000D000<P00003P00010000?60000@@000lH0000S00:E1`000iD000030003
U@0000D00YDZ01a<00BdC;M<0k@014bgC;@DC2T000>d00002P000k@0000:0003]00003P00b<90003
@P0000P00b<V000040000lH000110003aP00028000>E00001`000iD000030003U@0000L000>E0000
:P000dd0C@0FC@>d00FgCDe=]`03]0m=00<0C@00:`000k@0000:0003]00000/000>d0000>P038`H0
00=200001@038bT0000@0003aP00044000?600003`02C10000>E000020000iD000030003U@0000P0
00>E00003P02C1X064`02kA<]4bgC;M<]4bd011<;0000k@0000;0003]00000`000>d0000?0038`<0
00=200000P038b`0000@0003aP00044000?600004@000dd0000;00:E2P000iD000050003U@0000P0
0YD=0003C@0001/00Td0101=CDd200a=00<PCK@00k@01Dfg8;M=00:d00==]4d01Dd200==00<0CDd0
;0000k@0000<0003]00000d000>d0000?P038`03@P0S008S;`00010000?60000@@000lH0000B0003
C00000T000>E00002P000iD000050003U@0000X000>E00002@000d`0000J01I<00@PC;Bd0kL00k@P
C003]`03]4bd00m<:@000k@0000=0003]00000d000>d0000@@000d8S000a000040000lH000110003
aP0001<00Td80003U@0000/000>E00001@000iD0000;0003U@0000H00TdL009=0P0DC@038;Bg00>d
00<P]k@00k@01;M=CK@;C@800TdX0003]00000d000>d00003P000k@0001000038`000340000@0003
aP00044000?600005@000d`0000300:E3@000iD000070003U@0000/00YD50003C00001`05T`3]007
8;A<]22d]`05]003C;Bd00m<9`000k@0000>0003]00000l000>d0000?P000b<08`0b000040000lH0
00110003aP0001H000E=0000U@0?0003U@0000L000>E00003@001ID0001=01X00Td60005C@1=C@00
2dd3]0==00LP];Bd8;Bg00Bd00==]4d00dd2]0==00D0CDd0C@06009=8@000k@0000?0003]0000100
00>d0000?0001B<0000S0340000@0003aP00044000?600005`000d`0U@0@0003U@0000L000>E0000
3P000iD0C00K01M<00>dC4`01D`0221<84bd]kA<0[@HC24000>d00003`000k@0000@0003]00003/0
00<S00000`000b<0000^000040000lH000110003aP0000`034d00iD0000>0003U@0000T000>E0000
3P000iE=C@09CA@000==000064d58004CKM=]1A=0P000dd0000Q0003]000010000>d00004@000k@0
000j00038`0000<000<S0000;P00010000?60000@@000lH0000F0003C01<010000>E00002@000iD0
000>0003C01<01h05d`3809<00<PC;@00b000kA<C00DC2<000>d00004@000k@0000B0003]00003P0
00<S00001@000b<0000]00004015@QL000A=04e=40000iD000090003U@0000d00Td20003C@0001d0
00==00001Td00`1=0007C@8P1Dd00b2dC@03]08P0Td00kA=C@02C@0304d000I=0P000dd0000R0003
]000018000>d00004`000k@0000f00038`0000L000<S0000;000010000?60000@@000lH0000C009<
0P000d`0C00>0003U@0000/000>E000030000d`0C002009<7P02C00404`000M<00>dC4`02D`01B1<
C4bd00m<00@0C4`00T`U0003]000018000>d00004`000k@0000f00038`0000L000<S0000;0000100
00?60000@@000lH0000B0003C@00008000==04d03P000iD0000;0003U@0000`000==04d010000dd0
000J00A=0`000dd0C@08C@0304e=00E=00TP]4fdCKA=]`000Td00kBgC@04C@0304d0008014dS0003
]00001<000>d000050000k@0000d00038`0000T000<S0000:`00010000?60000@@000lH0000A0003
C000008000A<001<3P000iD0000;0003U@0000/000A<001<1@000d`0000F01e<00<PC;@00d`00kA<
C003C003]4bd00m<7`000k@0000D0003]00001D000>d0000<P000b<0000;00038`0002X0000@0003
aP00044000?6000040000dd000030005C@0004d030000iD0000=0003U@0000X000E=0000C@050003
C@0001H000==0000100@C@03]4e=009=00TP]4e=]4fd]k@00Td00kA=C@05C@03]4e=00H000==0000
7@000k@0000E0003]00001D000>d0000<@000b<0000=00038`0002T0000@0003aP00044000?60000
3`000d`000040005C00004`030000iD0000=0003U@0000X000E<0000C0060003C00000h08d`02B1<
C4bdC;Bg]00JC1T000>d00005@000k@0000F0003]000030000<S00003@000b<0000Y000040000lH0
00110003aP0001D000==00000P000dd0000:0003U@0000d000>E00002@000dd000020003C@000240
14d01`1=CDd0C@001dd00kA=C@02C@03]de=00A=00>gCDd00dd00`1=0002C@8014dS0003]00001H0
00>d00005`000k@0000^00038`0000l000<S0000:000010000?60000@@000lH0000E0003C0000080
00=<00002@000iD0000?0003U@0000P000=<00000P000d`0000P00A<10001D`0C4`000M<00>dC4`0
1T`00kA<C004C00304a<009<1004C24000>d00005`000k@0000G0003]00002d000<S00004@000b<0
000W000040000lH000110003aP0001D000==00000`0;C@03UDd000h000==UDd02Td50003C@0001h0
00==04d04Dd00kA=C@0JC@0304d001l000>d00005`000k@0000H0003]00002/000<S00004`000b<0
000V000040000lH000110003aP0001@000=<000010000d`000060005C01<04`03@001D`0C01<00L0
00=<000010000d`0000K03U<70000k@0000H0003]00001T000>d0000:P000b<0000C00038`0002H0
000@0003aP00044000?600008`000dd00002C@0304d000T00Td00`1=C@020003C@0002T000==04d0
0`0014d0000CC@03]4e=00a=00<0CDd00`001dd0001=04d06`000k@0000I0003]00001T000>d0000
:@000b<0000E00038`0002D0000@0003aP00044000?600008@02C08000=<04`00P02C0L000M<0000
C01<00800T`W009<00<0C0000`000d`0C004C00304a<00Y<00>dC4`03T`0101<C002C00304`000<0
00A<04a<60000k@0000J0003]00001X000>d00009`000b<0000G00038`0002@0000@0003aP000440
00?6000080000dd000020003C@1=00@000==00000`000dd000020003C@1=00@000==00008`000dd0
00050005C@1=C@0024d00`1=C@02C@0404e=]0I=00<0CDd00Td00`1=C@06C@0504e=04d01`000dd0
000E0003]00001X000>d00006`000k@0000P00038000008000<S00006@000b<000020003800001h0
000@0003aP00044000?600007`000d`000030004C000C0@000=<00000T`40004C000C0D000=<0000
8@000d`0000600I<00<0C4`00d`00`1<C005C00304a<00=<00<0C4`01D`00`1<C003C00404a<00=<
20000d`0000C0003]00001/000>d00006`000k@0000P00038000008000<S00006@000b<000020003
800001h0000@0003aP00044000?600007P000dd000030005C@0004d01@02C@H000E=0000C@050003
C@0002T000A=04d00dd00`1=C@0MC@0504e=04d00P000dd0000K0003]00001`000>d000070000k@0
000O0005800002<07@001B<0000P0200000@0003aP00044000?600007@000d`000040005C00004`0
1@02C0H000E<0000C0060003C00002L000=<04`00P001D`004`000e<00<0C00034`0101<C002C005
04a<04`070000k@0000L0003]00001d000>d00007P00120002<O00048`008200000@0003aP000440
00?6000090000dd000020003C@0000T000==00000P000dd0000^009=0P02C@0404e=00I=00<0CDd0
3Dd00`1=C@03C@0504d0C@000Td2009=6`000k@0000M0003]00001d000>d00007P00120002<O0004
8`008200000@0003aP00044000?6000090000d`000020003C00000T000=<00000P000d`0000^000;
C00004`0C01<04`00P0GC08000A<04`00T`40003C00001P000>d00007P000k@0000N0003]00001L0
0b030003800S00800R0I00<P00@08`0P100281X0000@0003aP00044000?600008`000dd000030003
C@0000T000==00000`000dd0000/0003C@0000H01Td00`1=C@04C@8000==]4d00P06C@0304e=00A=
20000dd0000F0003]00001l000>d00007`000k@0000I00@P00@S820P7P0280038b0000<P70000100
00?60000@@000lH0000S0003C00000@000=<00001`000d`000040003C00003@000]<001<04`0C01<
0003C00304a<00=<00h0C4a<04`0C01<04`0C4<000>d0000?P000b<P000S00038b0001h0000@0003
aP00044000?60000LP000dd0C@020007C@1=C@1=000=C@0504e=04d00P000dd0C@120003]00003h0
00<P00008`000b00000N000040000lH000110003aP0007800T`20003C01<009<00<0C00014`00`1<
0006C00604a<C01<0P02C48000>d0000?`000b00000Q0003800001l0000@0003aP00044000?60000
L@02C@@00Td01@1=04d000E=00<0CDd00Td20004C@1=009=10000dd000100003]000040000<P0000
7`000b00000P000040000lH000110003aP00074000=<000010001D`0C4`000I<00<0C4`01d`00`1<
00050003C00003l000>d0000@@000b00000M000380000240000@0003aP00044000?60000N@0014d0
04d2009=00D0C@1=0002C@8000A=001=B@000k@000120003800001/000<P00008P00010000?60000
@@000lH0001i00=<0`03C0<00d`30003C01<04T000>d0000Q@00010000?60000@@000lH0001i0003
C@0000<00dd300==1002CDT000>d0000Q@00010000?60000@@000lH0001h0003C00000<014`300A<
1002C4P000>d0000Q@00010000?60000@@000lH0001g009=20001Dd0001=00P000==0000AP000k@0
0025000040000lH000110003aP00080000=<00000`000d`0001>0003]00008D0000@0003aP000440
00?60000P0000dd000030003C@000=H0000@0003aP00044000?60000P0000d`000030003C0000=H0
000@0003aP00044000?60000O`000dd000050003C@000=D0000@0003aP00044000?60000O`000d`0
00050003C0000=D0000@0003aP00044000?60000o`1P0000o`2g0000o`2g0000o`2g0000o`2g0000
o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000
o`2g0000o`1f0003]`0001L000>g000090000?l0MP000kL0000:0003]`0000X000>g000090000?l0
M`000kL000090003]`0000T000>g00009@0007L000=<00006`000d`0003N0003]`0000T000>g0000
2@000kL0000U0000M`000dd0000K0003C@000=h000>g00002@000kL000090003]`0002D0001f0003
C00001d000=<0000gP000kL000080003]`0000P000>g00009P0007H000==00007@000dd0003N0003
]`0000P000>g000020000kL0000V0000M@000d`0000O0003C0000=H000>g000010000kL000080003
]`0000P000>g000010000kL0000O0000M@000dd0000O0003C@000=H000>g00001@000kL000070003
]`0000L000>g00001@000kL0000O0000M0000d`0000Q0003C0000=H000>g000010000b<000070003
]`0000L000<S000010000kL0000P0000M0000dd0000Q0003C@000=L000>g00000`000b<000070003
8`0000L000<S00000`000kL0000Q0000L`000d`00007009<3P02C0X000=<0000e`000kL000030003
8`0000H000<S00001`000b<000020003]`000280001b0003C@0000H00TdB009=20000dd0003H0003
]`00008000<S00001P000b<0000600038`0000<000>g00008P00078000=<00001002C1H00T`60003
C000020000>g0000>@000kL0001j0005]`0002<020000b<0000600038`00008000>g00008`000740
00==00000P03CAX00dd40003C@00020000>g0000=`000kL0001[00:g3`001B<0000S00L000<S0000
1P001B<0000S00h00[LF0000L@000d`00002C2000T`20003C000024000>g0000=@000kL0001^0003
]`0000`000DS00008`0700038`0000H000DS00008`0=0003]`0001H0000Y0003800000H000>d0000
1@000b00000c0004C@1=CB@00Td00`1=000R0003]`0003<000>g0000L0000kL0000<00058`008kL0
1P000b<0000500058kL002<03@000kL0000G0000:@000b0000060003]00000D000<P0000<`02C2P0
0T`M00:g1@000kL0000a0003]`0000<00[M]00:g3@000b<00002]`D00[L50005]b<002<03002]aX0
000Y0003800000H000>d00001@000b00000b00:d:P02]1h00[L40003]`0002l000>g00000P02]c@0
00?60000>P000kL0000:00068`2g8`2g1002]`@000Jg02>g02<;0003]`0001X0000Y0003800000H0
00>d00001@000b00000a009<00<0]0009`001;@0C4`O00:g0`000kL0000E00038`0001D000Bg0000
0[Lf0003aP0003/000>g00002P000b>g8`020004]`0000:g0P02]`8000<S]b<02`000kL0000K0000
:@000b0000060003]00000D000<P0000<0000dd0C@020003]00002@000Jd001=04dJ00:g1002]`80
00>g000050000b<0000D0003]`0000:g1002]c800/Hm008S2P03]`088`00]`2g8`02]`<000<S]kL0
2P028ah0000Y0003800000H000>d00001@000b00000_0004C000C0<00[@R00:d0`0014`004`G00Jg
1002]`030;L001<00b<D0004]`2g]`@01KL`00?6?`000b<0000700:g00TS]kNg0;L08`000[L01`2g
8lJg0;L020000b<0000N0000:@000b0000060003]00000D000<P0000;P001Dd0001=00D000>d0000
7P000k@000040004C@00CAX01KL300>g4P058a800kL300Fg<`03aSD00kL8008S1`02]`048lH08`>g
0R<02KLS8b<0a[L0]`0700038`0000P00[LE0000:@000b0000060003]00000D000<P0000;@001D`0
001<00L000>d000070000k@000050005C00004`07009]a0000<S02<00R<00`0S000?00Vg=P02aP03
0<H003H00kL700038kL000@00[L28`03a[L000DS00@0]`360R<00`2g0004008S2003]aL0000Y0003
800000H000>d00001@000b00000/0003C@00008000==00001P02]1X00[@80003C@00008000==0000
6`0;]`/000<S00000b<200038`0000T02kLg0005aP360<H0>P03]`@02[L00b?68`098`04aR>g8`Fg
00<S]`001@03]aX0000Y0003800000H000>d00001@000b00000[0003C00000<000=<04`020000k@0
000F0003]00000H000=<04`01@000d`0000A00ng1@05]`@000U28`008`0S02<00P000b=2@P0300Fg
1@0>]bl000G60<H0aP0m008S10002KLS000S0;LS]`028`<000C600000R<01/HS8b<08`8000<S]`00
0`028`03]`0001/0000Y0003800000H000>d00001@000b00000Z0003C@0000@000==04d02@02]1@0
0[@90003C@1=00H000==00004004]`030;Ng00Vg1P05]`9200`0@P128`0S02=204820003@[Ng00Bg
1@0:]`030;Ng00:g;`000lH0aP020003aP0003`00b<01P2g02<08`>g0R<01LH0003600@000C68b>g
0b<01@0S0;L000<S800002T000<P00001P000k@000050003800002T000=<00001@000d`0C00;0003
]000010000>d00002@0014`004`60003C00001801KL00`2g]`0200Vg0P02]`D000U204808`120480
1@02]`<02;L200:g00<0]kL00kL`0004aP00aP8000?60000?`000b>g8`03]`050;LS8`000/H20004
aP0000;60b<200038lJg00:g00<S00008@0002T000<P00001P000k@000050003800002P00Td70003
C@1=00`000>d00003P000k@0000:0004C@00C@H00TdB00Bg00<0]kL02[L300:g00<0]kL00kL2@P80
00=204800P02@PRg0`0<]`800kL_0004aP00aP8000?60000@002]`LS00<0a/H00P001<H00002aP05
02>g8lH00b<00kL0000S0000:@000b0000060003]00000D000<P00009`0014`004`60003C01<00d0
0[@<00:d3P000d`0C0050004C000C1802;L0102g000:]`800kL00`2g]`02@P03049200:g00@0]kNg
0`09]`8000>g00001kL`0004aP00aP<000?60000@0001;L0]b<3aP<00/H010360002aP800lH00b>g
8`02]bD0000>01/P2ID00kBEU@06UA/P3@001Dd0001=00H00Td@0003]00000P000>d00003P000dd0
C@050005C@0004d03P08]`802[L500:g00<0]`002kL00`2g0002]`D02[L200Ng;@001LH0003600<0
00?60000@002]`038`0S008S1<H01036aP06aP8S0P028`03]`0002<0000Y0003800000H000>E0000
1@000b00000[0003C00000<00T`A0003]00000H000>d00003`000d`0C0040003C00001<000Bg0000
3;L500:g0P03]`040;Ng00>g00@0]kL00kL200:g100=]`<000>g00003`02ga/000G60000aP030003
aP0001X00]lT00>g00LS02<S0<H000K600T0aP3602<08kL00b<U0000:@000b0000060003U@0000D0
00<P0000:`000dd000020003C@1=01802;@B0003C@1=00@000==0000500?]`<00[L300:g0P000kL0
]`06]`040;L000:g0`02]`<03kLD0003gP0001P000G60000aP040003aP0001L00]hU00:g0R<00kL0
8`0300;61[L2aP800b<00kLS8`02]b@0000Y0003800000H000>E00001@000b00000/0007C00004`0
C00B0005]0000;@00P000k@0000@0004C000C08000=<00005004]`D00kL00`2g]`04]`<00[L300fg
0`02]`<01[L0102g]kL500Bg4004g`9<60001LH0003600@000?600005@02C0CO8P02]`<S00@0]b<0
0lH00`360002]`030<H000?60R<01KLS8b<000:g8`0002T000<P00001P000iD000050003800002`0
00M=0000C@1=014000Nd0000]02d008000>d000040000dd0C@020003C@0001D00[L3016g0`000kL0
]`02]`050;Ng]`000kL00`2g0002016g0`02]aL00ddD0003aP00008000?600000P000lH0000B00==
5P09]`LS0[L38`C60R<5aP:g00?6]lH02<H48`03]b<S00HS2[LA0000:@000b0000060003U@0000D0
00<P0000;@001T`004`0C10000>d0;@00[@200>d00<0]00040001D`0C01<01L000>g0;L01KL00`2g
]`0;]`<000Fg002g0007]`050;L00;L00`0=]`030;Ng00Bg00<0]`006003C14000?600000P000lH0
00030003aP0000h00d`Y00>g00D08b<SaP038`D01<H400@S0lH00b<0]`02]b40000Y0003800000H0
00>E00001@000b00000^0005C@1=04d03`03]08000Bd002d0P03]10000E=04d0C@0K00Fg00<0]kL0
0[L00`2g]`04]`<000>g00000[L01P2g]`2g00:g00<0]kL00P001;L00006]`030;Ng00:g00<0]kL0
0kLP00==3P000lH000020003aP0000<000?600002`03CB`000>g02<00[L0100S0;L28`@00lH00`36
aP03008S00<0]b<00R<01<HS8kLR0000:@000b0000060003U@0000D000<P0000;P001D`0C01<00`0
1;@50003]02d00@01;@=0005C01<04`06@02]`040;L001Bg0P02]`030;L000:g0P0D]`8000Bg0;Ng
8@03C0X000?600000`000lH000030003aP0000T00T`]00>g00/S0000]b>g02<08`020003aP3600;6
00@0a/H00b<01@0S8b>g00<000@S]b>g7`0000h092000iDP800Q81H000A=04e=2@03]08000>d0000
1002]0H000>d00001;@9009=00<0C@0060000kL00005]`804KL200>g00@0]kNg0P0A]`030;Ng00Bg
0P000kL0000Q00==1`000lH000030003aP0000@000?600001@03CBd00b<200>g0P02]`0502<08`00
0/H01036a/H200;600@S02<00b<300Bg0b<M0000:@000b0000060003800000D000<P0000;`000d`0
C00700>d1@000k@0000400:d1`000k@0000300>d1P02C00304`001X000>g0;L03[L00`2g]`0:]`03
0;Ng00Zg00<0]kL03KL00`2g000W00=<10000lH000030003aP0000@000?600000P03C2d00b<800:g
00DS]b<S00028`04aP0000;60`02aP0302<S00<S0kL700<S6P0002T000<P00001P000b0000050003
800003000dd300>d1`000k@000060003]00000H000>d00001@03]0<00ddM0004]`2g00:g00<0]kL0
0P06]`030;Ng00Vg00<0]kL02KL00`2g]`04]`800[L00`2g]`02]`030;L002/00dd00lH000040003
aP0000@000?604d00Td^0003]b<000`000Jg8b<SaP028`<000?600000P001B?6aR<0008S00>g0000
2`000b>g]`0G0000:@000b0000060003800000D000<P0000<003C0>d2@000k@0000600:d20000k@0
000800>d0d`N0004]`2g00:g0`02]`050;Ng]`006KL01@2g]kL000:g0`02]`040;Ng]a/00mlB0003
aTa<00@000?600000`02C003aP0000l00mlJ00>g3`001;L08lH28`03]`0S008000K600008kL58`:g
4003]a@0000Y0003800000H000<P00001@000b00000a00:d00==000020000k@0000700:d2@000k@0
00090003CKBd01h000>g00001;L00`2g]`0Y]`030;Ng00:g0P000kL0000J00;N64d00lI=C@0FC@;N
6@03]a8000Vg8b<08lHS]b<00P000lH000048`04aP008`:g4`03]a40000Y0003800000H000<P0000
1@000b00000a00=<2P000k@000070003]02d00T000>d00002003C20000>g0;L01[L2026g0P07]`03
0;L001/00]lI00A<6002gaD00[LD008S0P0012?68`02]`038lHS00<S00Vg8b<0aR<08kL05P000kL0
000>0000:@000b0000060003800000D000<P0000:@02C@H000A=04e=20000k@000070004]000]0T0
00>d00001`02C@0304d000D00TdI0004]`2g00>g00@0]kL00kL00`2g]`0E]`050;Ng]`000[L0202g
]kL0]`2g=@04C@8014e100Zg0R<01LHS8b>g00DS00G6]kNg8`0V0000:@000b0000060003800000D0
00<P0000:`02C0@000=<00000T`00`1<00030003]00000P000Bd002d2P000k@000020003C000009<
0P000d`00002009<70000kL0]`09]`030;Ng01Ng00<0]kL02;L00`2g000b00=<2P03C3d000@S002g
0P000b<00003]`0702?68kL08`02]`8000HS002g02<U0000:@000b0000060003800000D000<P0000
;@02C@8000E=0000C@020005C@000;@02P001K@0002d00X000Fd0000C@020004C@00C@<00TdP0004
]`2g00:g00<0]kL01;L00`2g]`0H]`070;Ng0;L0]`0b00==4003CCP00R<30004]`0S00Fg00LS0;Ng
8`2g00800kL00b<0]`02008S8`0002T000<P00001P000b0000050003800002l014`30006C000C02d
2P000k@000020003]00000T000>d04`00P0014`00004C24000Jg0;L0]`05]`030;Ng01Ng00<0]kL0
0kL01P2g0;L0]bh00d`F00=<=0000b<0000300Bg10001[LS]b<08`:g1@000kLS]`0400038`000200
000Y0003800000H000<P00001@000b00000b009=0P02C@8000==00002@000k@000030003]00000P0
00BdC@000Td2009=9`000kL0]`02]`030;L001^g00<0]`000kL00`2g000Z00CN0TdL009=1=h/0003
]b<000@00[L80006]`0S02>g2002]`@000<S]`007`0002T000<P00001P000b000005000380000380
00E<04a<0002C0030;A<00X000>d00000`000k@000080003C;@0009<00D0C4`0C00Y00:g00<0]`00
3[L00`2g]`0<]`030;L000:g;P02gb8000?O0000:`000kL0000500038`0000H00[L01P0S0;LS]`P0
00<S000010000kL0000M0000:@000b0000060003800000D000<P0000<P0014d00002C@0504d004d0
20000k@000040003]00000L000E=002d0002C@<000==00009P02]`090;Ng]`2g0;L000Bg00<0]kL0
0[L00`2g]`07]`050;Ng]`000kL00`2g]`0/0003gP0002<000?N0000:@000kL0000500038`0000L0
00LS0;LS0;LS00T000<S00001@000kL0000L0000:@000b0000060003800000D000<P0000<P000d`0
00030006]4a<C01<1`000k@000050003]00000D000=<04`00T`00k@000020003C00002X00[L01@2g
]kL000:g00<0]kL03KL0102g]`03]`030;Ng080000>g00001@000b<0000800078`008kL08`0:0003
8`0000D00[LL0000:@000b0000060003800000D000<P0000<P000dd000040003C@1=00E=10000k@0
00050004]00000M=00<0C@0010000dd0000]00>g00<0]kL04kL00`2g]`230003]`0000D000<S0000
200012<00002]`8000<S000020000b<000060003]`0001T0001_0003C00000D000=<04`00P000d`0
C002C003]4`000D01D`20006C000C01<1P000d`0000/0004]`2g00Ng00<0]kL01KL00`2g]`05]`03
0;Ng084000>g00001@000b<0000900058`0002<00`000b<0000900038`0000H000>g0000600006l0
00==00001P000dd0C@020006C@000;@01Td20005]00004d00P000dd0C@070003C@00034000Ng0;Ng
0;L000:g00<0]`000[L01`2g]`2g0;L0Q0000kL000060003]`0000T000DS00008`0300038`0000T0
00>g00001`000kL0000G0000K`05C0D000=<04`014`00`2d00080003]01<00A<00<0C0000`05C3D0
0[L00`2g0002]`030;L000:g00D0]kL0]`2>0003]`0000T000<S00000P000b<0000200038`0000T0
00>g00008000070000A=00002Dd20003CKA=00a=0P08C@@000==0000>002]`<00[NB0003]`0000X0
00>g00000P000b<000020003]`0000X000>g00007`00070000=<000020000d`0C002C004]4a<C0D0
0d`01[A<C4`0C0T000=<0000dP000kL000090003]`0000<000<S00000`000kL0000:0003]`0001h0
001`0003C@0000T000==00000`02C@D00Td50003C@0000P000==0000d@000kL0000:0003]`0000<0
00<S00000`000kL0000:0003]`0001h0001`0003C00000X000=<00001002C00304a<00H000=<0000
2@000d`0003A0003]`0000X000>g00000`000b<000030003]`0000/000>g00007@0007h000==0000
1003C@H000==0000g@000kL0000:0003]`0000@000>g000010000kL0000;0003]`0001`0001o0003
C000008000E<0000C0040003C0000=d000>g00002`000kL000040003]`0000@000>g000030000kL0
000K0000P00014d0CDd5009=00<0C@00k@000kL000040003]`0000@000>g0000:P0008000T`9009<
k@000kL000050003]`0000D000>g0000:@0007h00Td=009=j`000kL000050003]`0000D000>g0000
:@0007d000=<00003`000d`0003`0003]`000340003o08<000>g0000<@000?l0P`000kL0000a0000
o`230003]`000340003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0003o0;L0
003o0;L0003o0;L00000\
\>"],
  ImageRangeCache->{{{0, 437}, {257, 0}} -> {-0.145065, -0.0740895, 0.0121056,
   0.0121056}, {{11.9375, 88.4375}, {250.875, 174.375}} -> {-0.188853,
   -0.109075, 0.0137256, 0.0137256}, {{96.0625, 172.562}, {250.875, 174.375}}
   -> {-1.34352, -0.109074, 0.0137256, 0.0137256}, {{180.25, 256.688}, {
  250.875, 174.375}} -> {-2.50107, -0.109572, 0.0137368, 0.0137368}, {{
  264.375, 340.875}, {250.875, 174.375}} -> {-3.65372, -0.109075, 0.0137256, 
  0.0137256}, {{348.5, 425}, {250.875, 174.375}} -> {-4.80839, -0.109077, 
  0.0137256, 0.0137256}, {{11.9375, 88.4375}, {166.688, 90.25}} -> {-0.189418,
   -1.26561, 0.0137368, 0.0137368}, {{96.0625, 172.562}, {166.688, 90.25}} ->
   {-1.34352, -1.26417, 0.0137256, 0.0137256}, {{180.25, 256.688}, {166.688, 
  90.25}} -> {-2.50107, -1.26561, 0.0137368, 0.0137368}, {{264.375, 340.875},
   {166.688, 90.25}} -> {-3.65372, -1.26417, 0.0137256, 0.0137256}, {{348.5, 
  425}, {166.688, 90.25}} -> {-4.80839, -1.26417, 0.0137256, 0.0137256}, {{
  11.9375, 88.4375}, {82.5625, 6.0625}} -> {-0.188855, -2.41927, 0.0137256, 
  0.0137256}, {{96.0625, 172.562}, {82.5625, 6.0625}} -> {-1.34352, -2.41927, 
  0.0137256, 0.0137256}, {{180.25, 256.688}, {82.5625, 6.0625}} -> {-2.50107,
   -2.42166, 0.0137368, 0.0137368}, {{264.375, 340.875}, {82.5625, 6.0625}} ->
   {-3.65372, -2.41927, 0.0137256, 0.0137256}, {{348.5, 425}, {82.5625, 
  6.0625}} -> {-4.80839, -2.41927, 0.0137256, 0.0137256}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples (5)", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(bioTable = Table[randBio, {3}, {5}]\), 
    \(\(biomorph[bioTable]; \)\)}], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({{{1, 2, 9, 5, 10, 8, 3, 8, 10, 9, 10, 4, 8, 3, 3, 2, 4, 10, 6, 4, 9}, {
          3, 5, 8, 8, 6, 5, 3, 7, 1, 8, 8, 2, 5, 7, 7, 7, 3, 9, 10, 1, 6}, {
          2, 2, 5, 6, 3, 7, 1, 2, 3, 5, 4, 3, 8, 7, 7, 9, 1, 3, 6, 8, 4}, {1, 
          1, 3, 3, 2, 9, 4, 4, 8, 10, 6, 3, 8, 5, 10, 1, 5, 6, 8, 7, 6}, {2, 
          5, 2, 3, 4, 2, 5, 6, 10, 2, 9, 2, 7, 9, 3, 4, 5, 8, 1, 9, 7}}, {{2, 
          4, 10, 4, 1, 4, 2, 5, 10, 1, 8, 5, 10, 4, 3, 8, 5, 1, 9, 7, 7}, {4, 
          1, 7, 6, 3, 8, 5, 10, 4, 2, 7, 1, 1, 9, 5, 9, 1, 10, 4, 1, 6}, {4, 
          3, 6, 3, 8, 3, 3, 6, 7, 7, 1, 4, 9, 8, 7, 1, 5, 7, 9, 9, 9}, {3, 4, 
          5, 7, 8, 9, 2, 5, 9, 1, 9, 3, 2, 9, 9, 2, 4, 4, 7, 8, 1}, {4, 2, 2, 
          3, 4, 9, 4, 5, 7, 6, 3, 3, 10, 9, 4, 7, 4, 10, 7, 4, 10}}, {{4, 3, 
          9, 8, 8, 5, 2, 5, 10, 10, 1, 1, 10, 8, 1, 5, 5, 10, 3, 9, 9}, {2, 
          2, 1, 9, 8, 7, 5, 3, 1, 7, 8, 4, 10, 8, 2, 4, 2, 1, 8, 10, 3}, {2, 
          4, 2, 9, 6, 10, 4, 2, 2, 1, 6, 3, 8, 5, 8, 10, 3, 2, 7, 2, 4}, {2, 
          4, 8, 3, 4, 4, 4, 3, 8, 2, 7, 3, 3, 8, 2, 5, 4, 4, 10, 5, 9}, {1, 
          3, 2, 3, 5, 5, 4, 1, 5, 1, 7, 2, 7, 5, 5, 7, 5, 1, 4, 3, 9}}}\)], 
  "Output",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .59259 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.0141093 0.190476 [
[ 0 0 0 0 ]
[ 1 .59259 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .59259 L
0 .59259 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0141093 0.200176 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0484534 1.09691 0.0274227 1.09691 [
[ 0 0 0 0 ]
[ 1 1.15175 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.15175 L
0 1.15175 L
closepath
clip
newpath
p
P
p
1 0 .6 r
.018 w
.62059 .1123 m
.6494 .05575 L
s
P
p
1 0 .6 r
.018 w
.62059 .1123 m
.59177 .16886 L
s
P
p
0 1 1 r
.002 w
.54375 .26311 m
.62059 .1123 L
s
P
p
1 0 .6 r
.018 w
.10839 .27873 m
.05183 .24991 L
s
P
p
1 0 .6 r
.018 w
.10839 .27873 m
.16494 .30754 L
s
P
p
0 1 1 r
.002 w
.25919 .35557 m
.10839 .27873 L
s
P
p
1 .6 0 r
.02 w
.4477 .45162 m
.54375 .26311 L
s
P
p
1 .6 0 r
.02 w
.4477 .45162 m
.25919 .35557 L
s
P
p
1 0 .6 r
.018 w
.23072 1.05112 m
.18584 1.096 L
s
P
p
1 0 .6 r
.018 w
.23072 1.05112 m
.2756 1.00624 L
s
P
p
0 1 1 r
.002 w
.3504 .93144 m
.23072 1.05112 L
s
P
p
1 0 .6 r
.018 w
.76928 1.05112 m
.81416 1.096 L
s
P
p
1 0 .6 r
.018 w
.76928 1.05112 m
.7244 1.00624 L
s
P
p
0 1 1 r
.002 w
.6496 .93144 m
.76928 1.05112 L
s
P
p
1 .6 0 r
.02 w
.5 .78184 m
.3504 .93144 L
s
P
p
1 .6 0 r
.02 w
.5 .78184 m
.6496 .93144 L
s
P
p
1 0 .6 r
.018 w
.89161 .27873 m
.94817 .24991 L
s
P
p
1 0 .6 r
.018 w
.89161 .27873 m
.83506 .30754 L
s
P
p
0 1 1 r
.002 w
.74081 .35557 m
.89161 .27873 L
s
P
p
1 0 .6 r
.018 w
.37941 .1123 m
.3506 .05575 L
s
P
p
1 0 .6 r
.018 w
.37941 .1123 m
.40823 .16886 L
s
P
p
0 1 1 r
.002 w
.45625 .26311 m
.37941 .1123 L
s
P
p
1 .6 0 r
.02 w
.5523 .45162 m
.74081 .35557 L
s
P
p
1 .6 0 r
.02 w
.5523 .45162 m
.45625 .26311 L
s
P
p
0 1 1 r
.016 w
.5 .61259 m
.4477 .45162 L
s
P
p
0 1 1 r
.016 w
.5 .61259 m
.5 .78184 L
s
P
p
0 1 1 r
.016 w
.5 .61259 m
.5523 .45162 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.0141093 0.39418 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.239055 0.952381 [
[ 0 0 0 0 ]
[ 1 .47427 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .47427 L
0 .47427 L
closepath
clip
newpath
p
P
p
.8 0 1 r
.014 w
.23484 .24508 m
.06703 .15958 L
s
P
p
.8 0 1 r
.014 w
.23484 .24508 m
.06703 .33058 L
s
P
p
.8 0 1 r
.014 w
.23484 .24508 m
.20538 .4311 L
s
P
p
.8 0 1 r
.014 w
.23484 .24508 m
.36801 .37825 L
s
P
p
.8 0 1 r
.014 w
.23484 .24508 m
.42086 .21562 L
s
P
p
.8 0 1 r
.014 w
.76516 .24508 m
.57914 .21562 L
s
P
p
.8 0 1 r
.014 w
.76516 .24508 m
.63199 .37825 L
s
P
p
.8 0 1 r
.014 w
.76516 .24508 m
.79462 .4311 L
s
P
p
.8 0 1 r
.014 w
.76516 .24508 m
.93297 .33058 L
s
P
p
.8 0 1 r
.014 w
.76516 .24508 m
.93297 .15958 L
s
P
p
.2 0 1 r
.016 w
.26836 .03348 m
.23484 .24508 L
s
P
p
.2 0 1 r
.016 w
.73164 .03348 m
.76516 .24508 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.0141093 0.588183 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.178604 0.952381 [
[ 0 0 0 0 ]
[ 1 .59517 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .59517 L
0 .59517 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.002 w
.1445 .29809 m
.05163 .26791 L
s
P
p
0 .4 1 r
.002 w
.1445 .29809 m
.05163 .32827 L
s
P
p
0 .4 1 r
.002 w
.1445 .29809 m
.0871 .37709 L
s
P
p
0 .4 1 r
.002 w
.1445 .29809 m
.1445 .39574 L
s
P
p
0 .4 1 r
.002 w
.36421 .45772 m
.27134 .4879 L
s
P
p
0 .4 1 r
.002 w
.36421 .45772 m
.30681 .53672 L
s
P
p
0 .4 1 r
.002 w
.36421 .45772 m
.36421 .55537 L
s
P
p
0 .4 1 r
.002 w
.36421 .45772 m
.42161 .53672 L
s
P
p
0 .4 1 r
.002 w
.63579 .45772 m
.57839 .53672 L
s
P
p
0 .4 1 r
.002 w
.63579 .45772 m
.63579 .55537 L
s
P
p
0 .4 1 r
.002 w
.63579 .45772 m
.69319 .53672 L
s
P
p
0 .4 1 r
.002 w
.63579 .45772 m
.72866 .4879 L
s
P
p
0 .4 1 r
.002 w
.8555 .29809 m
.8555 .39574 L
s
P
p
0 .4 1 r
.002 w
.8555 .29809 m
.9129 .37709 L
s
P
p
0 .4 1 r
.002 w
.8555 .29809 m
.94837 .32827 L
s
P
p
0 .4 1 r
.002 w
.8555 .29809 m
.94837 .26791 L
s
P
p
1 0 0 r
.012 w
.5 .0398 m
.1445 .29809 L
s
P
p
1 0 0 r
.012 w
.5 .0398 m
.36421 .45772 L
s
P
p
1 0 0 r
.012 w
.5 .0398 m
.63579 .45772 L
s
P
p
1 0 0 r
.012 w
.5 .0398 m
.8555 .29809 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.0141093 0.782187 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0282661 0.952381 [
[ 0 0 0 0 ]
[ 1 .89585 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .89585 L
0 .89585 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.004 w
.57364 .37789 m
.87131 .52956 L
s
P
p
.2 0 1 r
.004 w
.57364 .37789 m
.87131 .22622 L
s
P
p
.2 0 1 r
.004 w
.57364 .37789 m
.6259 .04792 L
s
P
p
.2 0 1 r
.004 w
.57364 .37789 m
.33741 .14166 L
s
P
p
.2 0 1 r
.004 w
.38085 .51796 m
.22918 .22029 L
s
P
p
.2 0 1 r
.004 w
.38085 .51796 m
.05088 .4657 L
s
P
p
.2 0 1 r
.004 w
.38085 .51796 m
.14462 .75419 L
s
P
p
.2 0 1 r
.004 w
.38085 .51796 m
.43311 .84793 L
s
P
p
.2 0 1 r
.004 w
.61915 .51796 m
.56689 .84793 L
s
P
p
.2 0 1 r
.004 w
.61915 .51796 m
.85538 .75419 L
s
P
p
.2 0 1 r
.004 w
.61915 .51796 m
.94912 .4657 L
s
P
p
.2 0 1 r
.004 w
.61915 .51796 m
.77082 .22029 L
s
P
p
.2 0 1 r
.004 w
.42636 .37789 m
.66259 .14166 L
s
P
p
.2 0 1 r
.004 w
.42636 .37789 m
.3741 .04792 L
s
P
p
.2 0 1 r
.004 w
.42636 .37789 m
.12869 .22622 L
s
P
p
.2 0 1 r
.004 w
.42636 .37789 m
.12869 .52956 L
s
P
p
0 1 .4 r
.008 w
.5 .47924 m
.57364 .37789 L
s
P
p
0 1 .4 r
.008 w
.5 .47924 m
.38085 .51796 L
s
P
p
0 1 .4 r
.008 w
.5 .47924 m
.61915 .51796 L
s
P
p
0 1 .4 r
.008 w
.5 .47924 m
.42636 .37789 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.0141093 0.97619 0.190476 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0473091 0.952381 [
[ 0 0 0 0 ]
[ 1 .85776 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85776 L
0 .85776 L
closepath
clip
newpath
p
P
p
0 1 1 r
.01 w
.5 .06589 m
.07328 .65322 L
s
P
p
0 1 1 r
.01 w
.5 .06589 m
.5 .79187 L
s
P
p
0 1 1 r
.01 w
.5 .06589 m
.92672 .65322 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.208113 0.200176 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.430875 0.952381 [
[ 0 0 0 0 ]
[ 1 .09063 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .09063 L
0 .09063 L
closepath
clip
newpath
p
P
p
.8 0 1 r
.002 w
.68362 .06662 m
.66231 .04532 L
s
P
p
.8 0 1 r
.002 w
.68362 .02401 m
.66231 .04532 L
s
P
p
.8 0 1 r
.002 w
.31638 .02401 m
.33769 .04532 L
s
P
p
.8 0 1 r
.002 w
.31638 .06662 m
.33769 .04532 L
s
P
p
0 1 .4 r
.002 w
.5 .04532 m
.66231 .04532 L
s
P
p
0 1 .4 r
.002 w
.5 .04532 m
.33769 .04532 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.208113 0.39418 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-5.7963 12.5926 0.314815 12.5926 [
[ 0 0 0 0 ]
[ 1 13.2222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 13.2222 L
0 13.2222 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.002 w
.5 11.1686 m
.5 12.5708 L
s
P
p
1 0 .6 r
.01 w
.5 8.0134 m
.5 11.1686 L
s
P
p
0 .4 1 r
.002 w
.5 2.05367 m
.5 .65138 L
s
P
p
1 0 .6 r
.01 w
.5 5.20882 m
.5 2.05367 L
s
P
p
.2 0 1 r
.004 w
.5 6.61111 m
.5 8.0134 L
s
P
p
.2 0 1 r
.004 w
.5 6.61111 m
.5 5.20882 L
s
P
p
.8 0 1 r
.006 w
.5 4.50768 m
.5 6.61111 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.208113 0.588183 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.022157 0.952381 [
[ 0 0 0 0 ]
[ 1 .9967 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .9967 L
0 .9967 L
closepath
clip
newpath
p
P
p
1 0 .6 r
.018 w
.34751 .32528 m
.37984 .52941 L
s
P
p
1 0 .6 r
.018 w
.34751 .32528 m
.49366 .17913 L
s
P
p
1 0 .6 r
.018 w
.34751 .32528 m
.14338 .29294 L
s
P
p
1 0 .6 r
.018 w
.34751 .32528 m
.44134 .50943 L
s
P
p
1 0 .6 r
.018 w
.34751 .32528 m
.44134 .14112 L
s
P
p
1 0 .6 r
.018 w
.69266 .43742 m
.72499 .23329 L
s
P
p
1 0 .6 r
.018 w
.69266 .43742 m
.5085 .53125 L
s
P
p
1 0 .6 r
.018 w
.69266 .43742 m
.87681 .53125 L
s
P
p
1 0 .6 r
.018 w
.69266 .43742 m
.66033 .23329 L
s
P
p
1 0 .6 r
.018 w
.69266 .43742 m
.54651 .58357 L
s
P
p
1 0 .6 r
.018 w
.39906 .22411 m
.30523 .40826 L
s
P
p
1 0 .6 r
.018 w
.39906 .22411 m
.60319 .19178 L
s
P
p
1 0 .6 r
.018 w
.39906 .22411 m
.25291 .07797 L
s
P
p
1 0 .6 r
.018 w
.39906 .22411 m
.36673 .42824 L
s
P
p
1 0 .6 r
.018 w
.39906 .22411 m
.58321 .13028 L
s
P
p
1 0 .6 r
.018 w
.61237 .51771 m
.75852 .37156 L
s
P
p
1 0 .6 r
.018 w
.61237 .51771 m
.40824 .48538 L
s
P
p
1 0 .6 r
.018 w
.61237 .51771 m
.7062 .70186 L
s
P
p
1 0 .6 r
.018 w
.61237 .51771 m
.7062 .33355 L
s
P
p
1 0 .6 r
.018 w
.61237 .51771 m
.40824 .55004 L
s
P
p
1 .6 0 r
.014 w
.52897 .35402 m
.34751 .32528 L
s
P
p
1 .6 0 r
.014 w
.52897 .35402 m
.69266 .43742 L
s
P
p
1 .6 0 r
.014 w
.52897 .35402 m
.39906 .22411 L
s
P
p
1 .6 0 r
.014 w
.52897 .35402 m
.61237 .51771 L
s
P
p
1 0 .6 r
.018 w
.31033 .61585 m
.49449 .52201 L
s
P
p
1 0 .6 r
.018 w
.31033 .61585 m
.12618 .52201 L
s
P
p
1 0 .6 r
.018 w
.31033 .61585 m
.34267 .81998 L
s
P
p
1 0 .6 r
.018 w
.31033 .61585 m
.45648 .4697 L
s
P
p
1 0 .6 r
.018 w
.31033 .61585 m
.1062 .58351 L
s
P
p
1 0 .6 r
.018 w
.31033 .25294 m
.1062 .28527 L
s
P
p
1 0 .6 r
.018 w
.31033 .25294 m
.45648 .39908 L
s
P
p
1 0 .6 r
.018 w
.31033 .25294 m
.34267 .0488 L
s
P
p
1 0 .6 r
.018 w
.31033 .25294 m
.12618 .34677 L
s
P
p
1 0 .6 r
.018 w
.31033 .25294 m
.49449 .34677 L
s
P
p
1 0 .6 r
.018 w
.19819 .59808 m
.40233 .63041 L
s
P
p
1 0 .6 r
.018 w
.19819 .59808 m
.10436 .41393 L
s
P
p
1 0 .6 r
.018 w
.19819 .59808 m
.10436 .78224 L
s
P
p
1 0 .6 r
.018 w
.19819 .59808 m
.40233 .56575 L
s
P
p
1 0 .6 r
.018 w
.19819 .59808 m
.05205 .45194 L
s
P
p
1 0 .6 r
.018 w
.4115 .30449 m
.22735 .21065 L
s
P
p
1 0 .6 r
.018 w
.4115 .30449 m
.44383 .50862 L
s
P
p
1 0 .6 r
.018 w
.4115 .30449 m
.55765 .15834 L
s
P
p
1 0 .6 r
.018 w
.4115 .30449 m
.20737 .27215 L
s
P
p
1 0 .6 r
.018 w
.4115 .30449 m
.50533 .48864 L
s
P
p
1 .6 0 r
.014 w
.2816 .43439 m
.31033 .61585 L
s
P
p
1 .6 0 r
.014 w
.2816 .43439 m
.31033 .25294 L
s
P
p
1 .6 0 r
.014 w
.2816 .43439 m
.19819 .59808 L
s
P
p
1 .6 0 r
.014 w
.2816 .43439 m
.4115 .30449 L
s
P
p
1 0 .6 r
.018 w
.59817 .56141 m
.45203 .41527 L
s
P
p
1 0 .6 r
.018 w
.59817 .56141 m
.56584 .76555 L
s
P
p
1 0 .6 r
.018 w
.59817 .56141 m
.78232 .46758 L
s
P
p
1 0 .6 r
.018 w
.59817 .56141 m
.41402 .46758 L
s
P
p
1 0 .6 r
.018 w
.59817 .56141 m
.6305 .76555 L
s
P
p
1 0 .6 r
.018 w
.25303 .67356 m
.34686 .85771 L
s
P
p
1 0 .6 r
.018 w
.25303 .67356 m
.34686 .4894 L
s
P
p
1 0 .6 r
.018 w
.25303 .67356 m
.04889 .70589 L
s
P
p
1 0 .6 r
.018 w
.25303 .67356 m
.39917 .8197 L
s
P
p
1 0 .6 r
.018 w
.25303 .67356 m
.28536 .46942 L
s
P
p
1 0 .6 r
.018 w
.61593 .67356 m
.5836 .46942 L
s
P
p
1 0 .6 r
.018 w
.61593 .67356 m
.46979 .8197 L
s
P
p
1 0 .6 r
.018 w
.61593 .67356 m
.82007 .70589 L
s
P
p
1 0 .6 r
.018 w
.61593 .67356 m
.5221 .4894 L
s
P
p
1 0 .6 r
.018 w
.61593 .67356 m
.5221 .85771 L
s
P
p
1 0 .6 r
.018 w
.27079 .56141 m
.23846 .76555 L
s
P
p
1 0 .6 r
.018 w
.27079 .56141 m
.45494 .46758 L
s
P
p
1 0 .6 r
.018 w
.27079 .56141 m
.08663 .46758 L
s
P
p
1 0 .6 r
.018 w
.27079 .56141 m
.30312 .76555 L
s
P
p
1 0 .6 r
.018 w
.27079 .56141 m
.41693 .41527 L
s
P
p
1 .6 0 r
.014 w
.43448 .64482 m
.59817 .56141 L
s
P
p
1 .6 0 r
.014 w
.43448 .64482 m
.25303 .67356 L
s
P
p
1 .6 0 r
.014 w
.43448 .64482 m
.61593 .67356 L
s
P
p
1 .6 0 r
.014 w
.43448 .64482 m
.27079 .56141 L
s
P
p
1 .6 0 r
.014 w
.43448 .48407 m
.52897 .35402 L
s
P
p
1 .6 0 r
.014 w
.43448 .48407 m
.2816 .43439 L
s
P
p
1 .6 0 r
.014 w
.43448 .48407 m
.43448 .64482 L
s
P
p
1 0 .6 r
.018 w
.37586 .70603 m
.56001 .6122 L
s
P
p
1 0 .6 r
.018 w
.37586 .70603 m
.1917 .6122 L
s
P
p
1 0 .6 r
.018 w
.37586 .70603 m
.40819 .91016 L
s
P
p
1 0 .6 r
.018 w
.37586 .70603 m
.522 .55988 L
s
P
p
1 0 .6 r
.018 w
.37586 .70603 m
.17172 .6737 L
s
P
p
1 0 .6 r
.018 w
.37586 .34312 m
.17172 .37545 L
s
P
p
1 0 .6 r
.018 w
.37586 .34312 m
.522 .48927 L
s
P
p
1 0 .6 r
.018 w
.37586 .34312 m
.40819 .13899 L
s
P
p
1 0 .6 r
.018 w
.37586 .34312 m
.1917 .43695 L
s
P
p
1 0 .6 r
.018 w
.37586 .34312 m
.56001 .43695 L
s
P
p
1 0 .6 r
.018 w
.26371 .68827 m
.46785 .7206 L
s
P
p
1 0 .6 r
.018 w
.26371 .68827 m
.16988 .50411 L
s
P
p
1 0 .6 r
.018 w
.26371 .68827 m
.16988 .87242 L
s
P
p
1 0 .6 r
.018 w
.26371 .68827 m
.46785 .65593 L
s
P
p
1 0 .6 r
.018 w
.26371 .68827 m
.11757 .54212 L
s
P
p
1 0 .6 r
.018 w
.47702 .39467 m
.29287 .30084 L
s
P
p
1 0 .6 r
.018 w
.47702 .39467 m
.50935 .5988 L
s
P
p
1 0 .6 r
.018 w
.47702 .39467 m
.62317 .24852 L
s
P
p
1 0 .6 r
.018 w
.47702 .39467 m
.27289 .36234 L
s
P
p
1 0 .6 r
.018 w
.47702 .39467 m
.57085 .57882 L
s
P
p
1 .6 0 r
.014 w
.34712 .52457 m
.37586 .70603 L
s
P
p
1 .6 0 r
.014 w
.34712 .52457 m
.37586 .34312 L
s
P
p
1 .6 0 r
.014 w
.34712 .52457 m
.26371 .68827 L
s
P
p
1 .6 0 r
.014 w
.34712 .52457 m
.47702 .39467 L
s
P
p
1 0 .6 r
.018 w
.66369 .65159 m
.51755 .50545 L
s
P
p
1 0 .6 r
.018 w
.66369 .65159 m
.63136 .85573 L
s
P
p
1 0 .6 r
.018 w
.66369 .65159 m
.84784 .55776 L
s
P
p
1 0 .6 r
.018 w
.66369 .65159 m
.47954 .55776 L
s
P
p
1 0 .6 r
.018 w
.66369 .65159 m
.69602 .85573 L
s
P
p
1 0 .6 r
.018 w
.31855 .76374 m
.41238 .94789 L
s
P
p
1 0 .6 r
.018 w
.31855 .76374 m
.41238 .57959 L
s
P
p
1 0 .6 r
.018 w
.31855 .76374 m
.11441 .79607 L
s
P
p
1 0 .6 r
.018 w
.31855 .76374 m
.46469 .90988 L
s
P
p
1 0 .6 r
.018 w
.31855 .76374 m
.35088 .5596 L
s
P
p
1 0 .6 r
.018 w
.68145 .76374 m
.64912 .5596 L
s
P
p
1 0 .6 r
.018 w
.68145 .76374 m
.53531 .90988 L
s
P
p
1 0 .6 r
.018 w
.68145 .76374 m
.88559 .79607 L
s
P
p
1 0 .6 r
.018 w
.68145 .76374 m
.58762 .57959 L
s
P
p
1 0 .6 r
.018 w
.68145 .76374 m
.58762 .94789 L
s
P
p
1 0 .6 r
.018 w
.33631 .65159 m
.30398 .85573 L
s
P
p
1 0 .6 r
.018 w
.33631 .65159 m
.52046 .55776 L
s
P
p
1 0 .6 r
.018 w
.33631 .65159 m
.15216 .55776 L
s
P
p
1 0 .6 r
.018 w
.33631 .65159 m
.36864 .85573 L
s
P
p
1 0 .6 r
.018 w
.33631 .65159 m
.48245 .50545 L
s
P
p
1 .6 0 r
.014 w
.5 .735 m
.66369 .65159 L
s
P
p
1 .6 0 r
.014 w
.5 .735 m
.31855 .76374 L
s
P
p
1 .6 0 r
.014 w
.5 .735 m
.68145 .76374 L
s
P
p
1 .6 0 r
.014 w
.5 .735 m
.33631 .65159 L
s
P
p
1 0 .6 r
.018 w
.52298 .39467 m
.42915 .57882 L
s
P
p
1 0 .6 r
.018 w
.52298 .39467 m
.72711 .36234 L
s
P
p
1 0 .6 r
.018 w
.52298 .39467 m
.37683 .24852 L
s
P
p
1 0 .6 r
.018 w
.52298 .39467 m
.49065 .5988 L
s
P
p
1 0 .6 r
.018 w
.52298 .39467 m
.70713 .30084 L
s
P
p
1 0 .6 r
.018 w
.73629 .68827 m
.88243 .54212 L
s
P
p
1 0 .6 r
.018 w
.73629 .68827 m
.53215 .65593 L
s
P
p
1 0 .6 r
.018 w
.73629 .68827 m
.83012 .87242 L
s
P
p
1 0 .6 r
.018 w
.73629 .68827 m
.83012 .50411 L
s
P
p
1 0 .6 r
.018 w
.73629 .68827 m
.53215 .7206 L
s
P
p
1 0 .6 r
.018 w
.62414 .34312 m
.43999 .43695 L
s
P
p
1 0 .6 r
.018 w
.62414 .34312 m
.8083 .43695 L
s
P
p
1 0 .6 r
.018 w
.62414 .34312 m
.59181 .13899 L
s
P
p
1 0 .6 r
.018 w
.62414 .34312 m
.478 .48927 L
s
P
p
1 0 .6 r
.018 w
.62414 .34312 m
.82828 .37545 L
s
P
p
1 0 .6 r
.018 w
.62414 .70603 m
.82828 .6737 L
s
P
p
1 0 .6 r
.018 w
.62414 .70603 m
.478 .55988 L
s
P
p
1 0 .6 r
.018 w
.62414 .70603 m
.59181 .91016 L
s
P
p
1 0 .6 r
.018 w
.62414 .70603 m
.8083 .6122 L
s
P
p
1 0 .6 r
.018 w
.62414 .70603 m
.43999 .6122 L
s
P
p
1 .6 0 r
.014 w
.65288 .52457 m
.52298 .39467 L
s
P
p
1 .6 0 r
.014 w
.65288 .52457 m
.73629 .68827 L
s
P
p
1 .6 0 r
.014 w
.65288 .52457 m
.62414 .34312 L
s
P
p
1 .6 0 r
.014 w
.65288 .52457 m
.62414 .70603 L
s
P
p
1 .6 0 r
.014 w
.5 .57425 m
.34712 .52457 L
s
P
p
1 .6 0 r
.014 w
.5 .57425 m
.5 .735 L
s
P
p
1 .6 0 r
.014 w
.5 .57425 m
.65288 .52457 L
s
P
p
1 0 .6 r
.018 w
.72921 .56141 m
.58307 .41527 L
s
P
p
1 0 .6 r
.018 w
.72921 .56141 m
.69688 .76555 L
s
P
p
1 0 .6 r
.018 w
.72921 .56141 m
.91337 .46758 L
s
P
p
1 0 .6 r
.018 w
.72921 .56141 m
.54506 .46758 L
s
P
p
1 0 .6 r
.018 w
.72921 .56141 m
.76154 .76555 L
s
P
p
1 0 .6 r
.018 w
.38407 .67356 m
.4779 .85771 L
s
P
p
1 0 .6 r
.018 w
.38407 .67356 m
.4779 .4894 L
s
P
p
1 0 .6 r
.018 w
.38407 .67356 m
.17993 .70589 L
s
P
p
1 0 .6 r
.018 w
.38407 .67356 m
.53021 .8197 L
s
P
p
1 0 .6 r
.018 w
.38407 .67356 m
.4164 .46942 L
s
P
p
1 0 .6 r
.018 w
.74697 .67356 m
.71464 .46942 L
s
P
p
1 0 .6 r
.018 w
.74697 .67356 m
.60083 .8197 L
s
P
p
1 0 .6 r
.018 w
.74697 .67356 m
.95111 .70589 L
s
P
p
1 0 .6 r
.018 w
.74697 .67356 m
.65314 .4894 L
s
P
p
1 0 .6 r
.018 w
.74697 .67356 m
.65314 .85771 L
s
P
p
1 0 .6 r
.018 w
.40183 .56141 m
.3695 .76555 L
s
P
p
1 0 .6 r
.018 w
.40183 .56141 m
.58598 .46758 L
s
P
p
1 0 .6 r
.018 w
.40183 .56141 m
.21768 .46758 L
s
P
p
1 0 .6 r
.018 w
.40183 .56141 m
.43416 .76555 L
s
P
p
1 0 .6 r
.018 w
.40183 .56141 m
.54797 .41527 L
s
P
p
1 .6 0 r
.014 w
.56552 .64482 m
.72921 .56141 L
s
P
p
1 .6 0 r
.014 w
.56552 .64482 m
.38407 .67356 L
s
P
p
1 .6 0 r
.014 w
.56552 .64482 m
.74697 .67356 L
s
P
p
1 .6 0 r
.014 w
.56552 .64482 m
.40183 .56141 L
s
P
p
1 0 .6 r
.018 w
.5885 .30449 m
.49467 .48864 L
s
P
p
1 0 .6 r
.018 w
.5885 .30449 m
.79263 .27215 L
s
P
p
1 0 .6 r
.018 w
.5885 .30449 m
.44235 .15834 L
s
P
p
1 0 .6 r
.018 w
.5885 .30449 m
.55617 .50862 L
s
P
p
1 0 .6 r
.018 w
.5885 .30449 m
.77265 .21065 L
s
P
p
1 0 .6 r
.018 w
.80181 .59808 m
.94795 .45194 L
s
P
p
1 0 .6 r
.018 w
.80181 .59808 m
.59767 .56575 L
s
P
p
1 0 .6 r
.018 w
.80181 .59808 m
.89564 .78224 L
s
P
p
1 0 .6 r
.018 w
.80181 .59808 m
.89564 .41393 L
s
P
p
1 0 .6 r
.018 w
.80181 .59808 m
.59767 .63041 L
s
P
p
1 0 .6 r
.018 w
.68967 .25294 m
.50551 .34677 L
s
P
p
1 0 .6 r
.018 w
.68967 .25294 m
.87382 .34677 L
s
P
p
1 0 .6 r
.018 w
.68967 .25294 m
.65733 .0488 L
s
P
p
1 0 .6 r
.018 w
.68967 .25294 m
.54352 .39908 L
s
P
p
1 0 .6 r
.018 w
.68967 .25294 m
.8938 .28527 L
s
P
p
1 0 .6 r
.018 w
.68967 .61585 m
.8938 .58351 L
s
P
p
1 0 .6 r
.018 w
.68967 .61585 m
.54352 .4697 L
s
P
p
1 0 .6 r
.018 w
.68967 .61585 m
.65733 .81998 L
s
P
p
1 0 .6 r
.018 w
.68967 .61585 m
.87382 .52201 L
s
P
p
1 0 .6 r
.018 w
.68967 .61585 m
.50551 .52201 L
s
P
p
1 .6 0 r
.014 w
.7184 .43439 m
.5885 .30449 L
s
P
p
1 .6 0 r
.014 w
.7184 .43439 m
.80181 .59808 L
s
P
p
1 .6 0 r
.014 w
.7184 .43439 m
.68967 .25294 L
s
P
p
1 .6 0 r
.014 w
.7184 .43439 m
.68967 .61585 L
s
P
p
1 0 .6 r
.018 w
.38763 .51771 m
.59176 .55004 L
s
P
p
1 0 .6 r
.018 w
.38763 .51771 m
.2938 .33355 L
s
P
p
1 0 .6 r
.018 w
.38763 .51771 m
.2938 .70186 L
s
P
p
1 0 .6 r
.018 w
.38763 .51771 m
.59176 .48538 L
s
P
p
1 0 .6 r
.018 w
.38763 .51771 m
.24148 .37156 L
s
P
p
1 0 .6 r
.018 w
.60094 .22411 m
.41679 .13028 L
s
P
p
1 0 .6 r
.018 w
.60094 .22411 m
.63327 .42824 L
s
P
p
1 0 .6 r
.018 w
.60094 .22411 m
.74709 .07797 L
s
P
p
1 0 .6 r
.018 w
.60094 .22411 m
.39681 .19178 L
s
P
p
1 0 .6 r
.018 w
.60094 .22411 m
.69477 .40826 L
s
P
p
1 0 .6 r
.018 w
.30734 .43742 m
.45349 .58357 L
s
P
p
1 0 .6 r
.018 w
.30734 .43742 m
.33967 .23329 L
s
P
p
1 0 .6 r
.018 w
.30734 .43742 m
.12319 .53125 L
s
P
p
1 0 .6 r
.018 w
.30734 .43742 m
.4915 .53125 L
s
P
p
1 0 .6 r
.018 w
.30734 .43742 m
.27501 .23329 L
s
P
p
1 0 .6 r
.018 w
.65249 .32528 m
.55866 .14112 L
s
P
p
1 0 .6 r
.018 w
.65249 .32528 m
.55866 .50943 L
s
P
p
1 0 .6 r
.018 w
.65249 .32528 m
.85662 .29294 L
s
P
p
1 0 .6 r
.018 w
.65249 .32528 m
.50634 .17913 L
s
P
p
1 0 .6 r
.018 w
.65249 .32528 m
.62016 .52941 L
s
P
p
1 .6 0 r
.014 w
.47103 .35402 m
.38763 .51771 L
s
P
p
1 .6 0 r
.014 w
.47103 .35402 m
.60094 .22411 L
s
P
p
1 .6 0 r
.014 w
.47103 .35402 m
.30734 .43742 L
s
P
p
1 .6 0 r
.014 w
.47103 .35402 m
.65249 .32528 L
s
P
p
1 .6 0 r
.014 w
.56552 .48407 m
.56552 .64482 L
s
P
p
1 .6 0 r
.014 w
.56552 .48407 m
.7184 .43439 L
s
P
p
1 .6 0 r
.014 w
.56552 .48407 m
.47103 .35402 L
s
P
p
.2 1 0 r
.016 w
.5 .50536 m
.43448 .48407 L
s
P
p
.2 1 0 r
.016 w
.5 .50536 m
.5 .57425 L
s
P
p
.2 1 0 r
.016 w
.5 .50536 m
.56552 .48407 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.208113 0.782187 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
P
p
.8 1 0 r
.018 w
.40263 .22559 m
.50669 .08236 L
s
P
p
.8 1 0 r
.018 w
.40263 .22559 m
.40263 .04854 L
s
P
p
.8 1 0 r
.018 w
.40263 .22559 m
.29857 .08236 L
s
P
p
.8 1 0 r
.018 w
.22559 .40263 m
.08236 .29857 L
s
P
p
.8 1 0 r
.018 w
.22559 .40263 m
.04854 .40263 L
s
P
p
.8 1 0 r
.018 w
.22559 .40263 m
.08236 .50669 L
s
P
p
1 0 .6 r
.002 w
.40263 .40263 m
.40263 .22559 L
s
P
p
1 0 .6 r
.002 w
.40263 .40263 m
.22559 .40263 L
s
P
p
.8 1 0 r
.018 w
.22559 .59737 m
.08236 .49331 L
s
P
p
.8 1 0 r
.018 w
.22559 .59737 m
.04854 .59737 L
s
P
p
.8 1 0 r
.018 w
.22559 .59737 m
.08236 .70143 L
s
P
p
.8 1 0 r
.018 w
.40263 .77441 m
.29857 .91764 L
s
P
p
.8 1 0 r
.018 w
.40263 .77441 m
.40263 .95146 L
s
P
p
.8 1 0 r
.018 w
.40263 .77441 m
.50669 .91764 L
s
P
p
1 0 .6 r
.002 w
.40263 .59737 m
.22559 .59737 L
s
P
p
1 0 .6 r
.002 w
.40263 .59737 m
.40263 .77441 L
s
P
p
.8 1 0 r
.018 w
.59737 .77441 m
.49331 .91764 L
s
P
p
.8 1 0 r
.018 w
.59737 .77441 m
.59737 .95146 L
s
P
p
.8 1 0 r
.018 w
.59737 .77441 m
.70143 .91764 L
s
P
p
.8 1 0 r
.018 w
.77441 .59737 m
.91764 .70143 L
s
P
p
.8 1 0 r
.018 w
.77441 .59737 m
.95146 .59737 L
s
P
p
.8 1 0 r
.018 w
.77441 .59737 m
.91764 .49331 L
s
P
p
1 0 .6 r
.002 w
.59737 .59737 m
.59737 .77441 L
s
P
p
1 0 .6 r
.002 w
.59737 .59737 m
.77441 .59737 L
s
P
p
.8 1 0 r
.018 w
.77441 .40263 m
.91764 .50669 L
s
P
p
.8 1 0 r
.018 w
.77441 .40263 m
.95146 .40263 L
s
P
p
.8 1 0 r
.018 w
.77441 .40263 m
.91764 .29857 L
s
P
p
.8 1 0 r
.018 w
.59737 .22559 m
.70143 .08236 L
s
P
p
.8 1 0 r
.018 w
.59737 .22559 m
.59737 .04854 L
s
P
p
.8 1 0 r
.018 w
.59737 .22559 m
.49331 .08236 L
s
P
p
1 0 .6 r
.002 w
.59737 .40263 m
.77441 .40263 L
s
P
p
1 0 .6 r
.002 w
.59737 .40263 m
.59737 .22559 L
s
P
p
1 0 .6 r
.016 w
.5 .5 m
.40263 .40263 L
s
P
p
1 0 .6 r
.016 w
.5 .5 m
.40263 .59737 L
s
P
p
1 0 .6 r
.016 w
.5 .5 m
.59737 .59737 L
s
P
p
1 0 .6 r
.016 w
.5 .5 m
.59737 .40263 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.208113 0.97619 0.38448 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000233323 0.952381 [
[ 0 0 0 0 ]
[ 1 .95191 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95191 L
0 .95191 L
closepath
clip
newpath
p
P
p
1 0 0 r
.008 w
.49953 .51972 m
.65271 .44167 L
s
P
p
1 0 0 r
.008 w
.49953 .51972 m
.34635 .59777 L
s
P
p
1 0 0 r
.008 w
.29883 .12583 m
.14565 .20388 L
s
P
p
1 0 0 r
.008 w
.29883 .12583 m
.45201 .04778 L
s
P
p
.2 0 1 r
.008 w
.39918 .32278 m
.49953 .51972 L
s
P
p
.2 0 1 r
.008 w
.39918 .32278 m
.29883 .12583 L
s
P
p
1 0 0 r
.008 w
.521 .45366 m
.44295 .30048 L
s
P
p
1 0 0 r
.008 w
.521 .45366 m
.59905 .60684 L
s
P
p
1 0 0 r
.008 w
.12711 .65435 m
.20516 .80753 L
s
P
p
1 0 0 r
.008 w
.12711 .65435 m
.04906 .50118 L
s
P
p
.2 0 1 r
.008 w
.32405 .55401 m
.521 .45366 L
s
P
p
.2 0 1 r
.008 w
.32405 .55401 m
.12711 .65435 L
s
P
p
1 0 0 r
.008 w
.45493 .43219 m
.30175 .51024 L
s
P
p
1 0 0 r
.008 w
.45493 .43219 m
.60811 .35414 L
s
P
p
1 0 0 r
.008 w
.65563 .82608 m
.80881 .74803 L
s
P
p
1 0 0 r
.008 w
.65563 .82608 m
.50245 .90413 L
s
P
p
.2 0 1 r
.008 w
.55528 .62914 m
.45493 .43219 L
s
P
p
.2 0 1 r
.008 w
.55528 .62914 m
.65563 .82608 L
s
P
p
1 0 0 r
.008 w
.43347 .49826 m
.51152 .65144 L
s
P
p
1 0 0 r
.008 w
.43347 .49826 m
.35542 .34508 L
s
P
p
1 0 0 r
.008 w
.82736 .29756 m
.74931 .14438 L
s
P
p
1 0 0 r
.008 w
.82736 .29756 m
.90541 .45074 L
s
P
p
.2 0 1 r
.008 w
.63041 .39791 m
.43347 .49826 L
s
P
p
.2 0 1 r
.008 w
.63041 .39791 m
.82736 .29756 L
s
P
p
.2 1 0 r
.012 w
.47723 .47596 m
.39918 .32278 L
s
P
p
.2 1 0 r
.012 w
.47723 .47596 m
.32405 .55401 L
s
P
p
.2 1 0 r
.012 w
.47723 .47596 m
.55528 .62914 L
s
P
p
.2 1 0 r
.012 w
.47723 .47596 m
.63041 .39791 L
s
P
p
1 0 0 r
.008 w
.56653 .49826 m
.64458 .34508 L
s
P
p
1 0 0 r
.008 w
.56653 .49826 m
.48848 .65144 L
s
P
p
1 0 0 r
.008 w
.17264 .29756 m
.09459 .45074 L
s
P
p
1 0 0 r
.008 w
.17264 .29756 m
.25069 .14438 L
s
P
p
.2 0 1 r
.008 w
.36959 .39791 m
.56653 .49826 L
s
P
p
.2 0 1 r
.008 w
.36959 .39791 m
.17264 .29756 L
s
P
p
1 0 0 r
.008 w
.54507 .43219 m
.39189 .35414 L
s
P
p
1 0 0 r
.008 w
.54507 .43219 m
.69825 .51024 L
s
P
p
1 0 0 r
.008 w
.34437 .82608 m
.49755 .90413 L
s
P
p
1 0 0 r
.008 w
.34437 .82608 m
.19119 .74803 L
s
P
p
.2 0 1 r
.008 w
.44472 .62914 m
.54507 .43219 L
s
P
p
.2 0 1 r
.008 w
.44472 .62914 m
.34437 .82608 L
s
P
p
1 0 0 r
.008 w
.479 .45366 m
.40095 .60684 L
s
P
p
1 0 0 r
.008 w
.479 .45366 m
.55705 .30048 L
s
P
p
1 0 0 r
.008 w
.87289 .65435 m
.95094 .50118 L
s
P
p
1 0 0 r
.008 w
.87289 .65435 m
.79484 .80753 L
s
P
p
.2 0 1 r
.008 w
.67595 .55401 m
.479 .45366 L
s
P
p
.2 0 1 r
.008 w
.67595 .55401 m
.87289 .65435 L
s
P
p
1 0 0 r
.008 w
.50047 .51972 m
.65365 .59777 L
s
P
p
1 0 0 r
.008 w
.50047 .51972 m
.34729 .44167 L
s
P
p
1 0 0 r
.008 w
.70117 .12583 m
.54799 .04778 L
s
P
p
1 0 0 r
.008 w
.70117 .12583 m
.85435 .20388 L
s
P
p
.2 0 1 r
.008 w
.60082 .32278 m
.50047 .51972 L
s
P
p
.2 0 1 r
.008 w
.60082 .32278 m
.70117 .12583 L
s
P
p
.2 1 0 r
.012 w
.52277 .47596 m
.36959 .39791 L
s
P
p
.2 1 0 r
.012 w
.52277 .47596 m
.44472 .62914 L
s
P
p
.2 1 0 r
.012 w
.52277 .47596 m
.67595 .55401 L
s
P
p
.2 1 0 r
.012 w
.52277 .47596 m
.60082 .32278 L
s
P
p
1 0 .6 r
.008 w
.5 .40588 m
.47723 .47596 L
s
P
p
1 0 .6 r
.008 w
.5 .40588 m
.52277 .47596 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.402116 0.200176 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.41467 0.952381 [
[ 0 0 0 0 ]
[ 1 .12304 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .12304 L
0 .12304 L
closepath
clip
newpath
p
P
p
.8 0 1 r
.02 w
.5 .02636 m
.05605 .09668 L
s
P
p
.8 0 1 r
.02 w
.5 .02636 m
.94395 .09668 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.217813 0.402116 0.39418 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.000503103 0.952381 [
[ 0 0 0 0 ]
[ 1 .95339 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95339 L
0 .95339 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.014 w
.70694 .57355 m
.49652 .54022 L
s
P
p
.2 0 1 r
.014 w
.70694 .57355 m
.67361 .78397 L
s
P
p
.2 0 1 r
.014 w
.7605 .56507 m
.85722 .75489 L
s
P
p
.2 0 1 r
.014 w
.7605 .56507 m
.95032 .46835 L
s
P
p
.2 0 1 r
.014 w
.72215 .52672 m
.81887 .3369 L
s
P
p
.2 0 1 r
.014 w
.72215 .52672 m
.53233 .43 L
s
P
p
.8 0 1 r
.016 w
.73156 .55566 m
.70694 .57355 L
s
P
p
.8 0 1 r
.016 w
.73156 .55566 m
.7605 .56507 L
s
P
p
.8 0 1 r
.016 w
.73156 .55566 m
.72215 .52672 L
s
P
p
.2 0 1 r
.014 w
.38732 .28345 m
.53797 .43409 L
s
P
p
.2 0 1 r
.014 w
.38732 .28345 m
.53797 .13281 L
s
P
p
.2 0 1 r
.014 w
.339 .25883 m
.37233 .04841 L
s
P
p
.2 0 1 r
.014 w
.339 .25883 m
.12858 .2255 L
s
P
p
.2 0 1 r
.014 w
.34748 .3124 m
.15767 .40911 L
s
P
p
.2 0 1 r
.014 w
.34748 .3124 m
.4442 .50222 L
s
P
p
.8 0 1 r
.016 w
.35689 .28345 m
.38732 .28345 L
s
P
p
.8 0 1 r
.016 w
.35689 .28345 m
.339 .25883 L
s
P
p
.8 0 1 r
.016 w
.35689 .28345 m
.34748 .3124 L
s
P
p
.2 0 1 r
.014 w
.47538 .70601 m
.44205 .49559 L
s
P
p
.2 0 1 r
.014 w
.47538 .70601 m
.26496 .73934 L
s
P
p
.2 0 1 r
.014 w
.5 .75433 m
.34936 .90498 L
s
P
p
.2 0 1 r
.014 w
.5 .75433 m
.65064 .90498 L
s
P
p
.2 0 1 r
.014 w
.52462 .70601 m
.73504 .73934 L
s
P
p
.2 0 1 r
.014 w
.52462 .70601 m
.55795 .49559 L
s
P
p
.8 0 1 r
.016 w
.5 .7239 m
.47538 .70601 L
s
P
p
.8 0 1 r
.016 w
.5 .7239 m
.5 .75433 L
s
P
p
.8 0 1 r
.016 w
.5 .7239 m
.52462 .70601 L
s
P
p
.2 0 1 r
.014 w
.65252 .3124 m
.5558 .50222 L
s
P
p
.2 0 1 r
.014 w
.65252 .3124 m
.84233 .40911 L
s
P
p
.2 0 1 r
.014 w
.661 .25883 m
.87142 .2255 L
s
P
p
.2 0 1 r
.014 w
.661 .25883 m
.62767 .04841 L
s
P
p
.2 0 1 r
.014 w
.61268 .28345 m
.46203 .13281 L
s
P
p
.2 0 1 r
.014 w
.61268 .28345 m
.46203 .43409 L
s
P
p
.8 0 1 r
.016 w
.64311 .28345 m
.65252 .3124 L
s
P
p
.8 0 1 r
.016 w
.64311 .28345 m
.661 .25883 L
s
P
p
.8 0 1 r
.016 w
.64311 .28345 m
.61268 .28345 L
s
P
p
.2 0 1 r
.014 w
.27785 .52672 m
.46767 .43 L
s
P
p
.2 0 1 r
.014 w
.27785 .52672 m
.18113 .3369 L
s
P
p
.2 0 1 r
.014 w
.2395 .56507 m
.04968 .46835 L
s
P
p
.2 0 1 r
.014 w
.2395 .56507 m
.14278 .75489 L
s
P
p
.2 0 1 r
.014 w
.29306 .57355 m
.32639 .78397 L
s
P
p
.2 0 1 r
.014 w
.29306 .57355 m
.50348 .54022 L
s
P
p
.8 0 1 r
.016 w
.26844 .55566 m
.27785 .52672 L
s
P
p
.8 0 1 r
.016 w
.26844 .55566 m
.2395 .56507 L
s
P
p
.8 0 1 r
.016 w
.26844 .55566 m
.29306 .57355 L
s
P
p
0 1 1 r
.012 w
.5 .48043 m
.73156 .55566 L
s
P
p
0 1 1 r
.012 w
.5 .48043 m
.35689 .28345 L
s
P
p
0 1 1 r
.012 w
.5 .48043 m
.5 .7239 L
s
P
p
0 1 1 r
.012 w
.5 .48043 m
.64311 .28345 L
s
P
p
0 1 1 r
.012 w
.5 .48043 m
.26844 .55566 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.411817 0.402116 0.588183 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.214286 0.952381 [
[ 0 0 0 0 ]
[ 1 .52381 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .52381 L
0 .52381 L
closepath
clip
newpath
p
P
p
0 1 .4 r
.01 w
.20261 .33625 m
.05391 .48495 L
s
P
p
0 1 .4 r
.01 w
.79739 .33625 m
.94609 .48495 L
s
P
p
.2 0 1 r
.006 w
.5 .03886 m
.20261 .33625 L
s
P
p
.2 0 1 r
.006 w
.5 .03886 m
.79739 .33625 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.60582 0.402116 0.782187 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.804348 2.6087 0.0652174 2.6087 [
[ 0 0 0 0 ]
[ 1 2.73913 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 2.73913 L
0 2.73913 L
closepath
clip
newpath
p
P
p
1 0 .6 r
.004 w
.5 .2136 m
.5 2.52553 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.799824 0.402116 0.97619 0.578483 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.02731 0.952381 [
[ 0 0 0 0 ]
[ 1 .89776 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .89776 L
0 .89776 L
closepath
clip
newpath
p
P
p
1 0 .6 r
.004 w
.39622 .41118 m
.74214 .52358 L
s
P
p
1 0 .6 r
.004 w
.39622 .41118 m
.39622 .04746 L
s
P
p
1 0 .6 r
.004 w
.39622 .41118 m
.05031 .52358 L
s
P
p
1 0 .6 r
.004 w
.39622 .41118 m
.61001 .70544 L
s
P
p
1 0 .6 r
.004 w
.39622 .41118 m
.61001 .11693 L
s
P
p
1 0 .6 r
.004 w
.43586 .46574 m
.78178 .35334 L
s
P
p
1 0 .6 r
.004 w
.43586 .46574 m
.22207 .17148 L
s
P
p
1 0 .6 r
.004 w
.43586 .46574 m
.22207 .76 L
s
P
p
1 0 .6 r
.004 w
.43586 .46574 m
.78178 .57814 L
s
P
p
1 0 .6 r
.004 w
.43586 .46574 m
.43586 .10202 L
s
P
p
1 0 .6 r
.004 w
.5 .48658 m
.71379 .19232 L
s
P
p
1 0 .6 r
.004 w
.5 .48658 m
.15408 .37418 L
s
P
p
1 0 .6 r
.004 w
.5 .48658 m
.5 .8503 L
s
P
p
1 0 .6 r
.004 w
.5 .48658 m
.84592 .37418 L
s
P
p
1 0 .6 r
.004 w
.5 .48658 m
.28621 .19232 L
s
P
p
1 0 .6 r
.004 w
.56414 .46574 m
.56414 .10202 L
s
P
p
1 0 .6 r
.004 w
.56414 .46574 m
.21822 .57814 L
s
P
p
1 0 .6 r
.004 w
.56414 .46574 m
.77793 .76 L
s
P
p
1 0 .6 r
.004 w
.56414 .46574 m
.77793 .17148 L
s
P
p
1 0 .6 r
.004 w
.56414 .46574 m
.21822 .35334 L
s
P
p
1 0 .6 r
.004 w
.60378 .41118 m
.38999 .11693 L
s
P
p
1 0 .6 r
.004 w
.60378 .41118 m
.38999 .70544 L
s
P
p
1 0 .6 r
.004 w
.60378 .41118 m
.94969 .52358 L
s
P
p
1 0 .6 r
.004 w
.60378 .41118 m
.60378 .04746 L
s
P
p
1 0 .6 r
.004 w
.60378 .41118 m
.25786 .52358 L
s
P
p
.8 1 0 r
.008 w
.5 .37746 m
.39622 .41118 L
s
P
p
.8 1 0 r
.008 w
.5 .37746 m
.43586 .46574 L
s
P
p
.8 1 0 r
.008 w
.5 .37746 m
.5 .48658 L
s
P
p
.8 1 0 r
.008 w
.5 .37746 m
.56414 .46574 L
s
P
p
.8 1 0 r
.008 w
.5 .37746 m
.60378 .41118 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{438, 258},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006f00010PP10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0]`000?l0]`000?l0]`000?l0]`000?l0
]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`0002P000<P00004@000b00003o07P0000X0003
8000014000<P0000o`1h0000:@000b00000?000380000?l0N@0002T000<P00003`000b00003o07T0
000Z0003]00000d000>d0000i`000d`0000A0003C00007/0000Z0003]00000d000>d0000i`000dd0
000A0003C@0007/0000[0003]00000/000>d0000j0000d`0000A0003C00007/0000[0003]00000/0
00>d0000j0000dd0000A0003C@0004L000>d0000<@0002`000>d00002@000k@0003Z0003C00000l0
00=<0000B0000k@0000a0000;0000k@000090003]0000>X000==00003`000dd0001700>d<P0002d0
00>d00001`000k@0003[0003C00000l000=<0000AP001K@0]02d0340000]0003]00000L000>d0000
j00014d004dA0005C@0004d0A0000k@0]0020003]00002h0000^0003]00000D000>d0000j@0014`0
04`A0004C000C4@000Bd002d0P000k@0000^0000500281P000>d00001@000k@0000E008Pd`000dd0
C@0A0003C@1=04@000Fd0000]0030003]00002d0000F008P5`000a40000300034@0001D000<P0000
e002C1400Ta40003]000008000>d00000P000k@0000/00006002]1D000<A00000`000a40000C00:d
S0038dT00Td?009=A@000k@000020003]00000<000>d0000:`0001X00[@D00054@0001405002]8d0
00DS02<08`190003C00000d000=<0000@`000k@000030003]00000<000>d0000:`0001/000<P];@0
4P001A40000A01800[B>00048`008`8000<S0000>@000dd0000:009=3@02C@`000==0000=@000k@0
00040003]00000@000>d0000:P0001h00[@A00034@0A01400[B>008S0P000b<08`02008S<P02C0D0
00=<00002P000d`0C00;0003C01<00`000=<00001002C2l000>d000010000k@000050003]00002T0
000P00:d3`000a404@0?00:d;`000dd0000Q0003C@0003T000<S00000P000b<08`0400038`000340
0Td40003C@0000T000A=001=2@0014d004d;0003C@0000<00Td`0003]00000D000>d00001@000k@0
000Y00008P024@h000<A000030024C4000=<00008@000d`0000h00038`0000<000<S02<01@000b<0
000b009<0P000d`000090005C00004`01`001D`0001<00/000A<00000T`a0003]00000H000>d0000
1P000k@0000X000090024@/00Q4<008A<`000dd0000Q0003C@0003H00R<500058`0002<01@028c@0
00A=001=2`001Dd0001=00D000E=0000C@0;0003C@00009=<P000k@000070003]00000L000>d0000
9`0002H000<A000020024@X00Q4e0003C000024000=<0000=@000b<0000500058`0002<01`000b<0
000b00=<2`000d`000020005C00004`010000d`0000900=<=0000k@000070003]00000P000>d0000
9P0002L00Q4700044@004@L00Q4g0003C@00024000==0000=0000b<0000600058`0002<020000b<0
000c009=2P000dd000030003C@1=00D000==00002002CCD000>d000020000k@000080003]00002H0
000Y008A1@001140014600034@0003H000=<00008`000d`0000a008S20000b<0000300038`0000H0
0R<d00=<20000d`000040003C00000@000=<00001`02C3D000>d00002@000k@000090003]00002D0
000[00054@0001401000114000024CT000==00008`000dd0000`00038`0000P000<S00000`000b<0
000800038`00038000A=04e=1P000dd000030003C@1=00D000==00001@03CCH000>d00002@000k@0
000:0003]00002@0000/008A00<04@000`0011404A4k0003C00002<000=<0000;P028`/000<S0000
0`000b<00009008S<P0014`00002C0@000=<00000P001D`0001<00@000=<00000`02C08000=<0000
<`000k@0000:0003]00000/000>d00008`0002h000>d000010000k@0000k0003C@0002<000==0000
;@000b<0000:00038`0000D000<S00002P000b<0000`0003C@00008000E=0000C@030003C@0000<0
00E=0000C@03009=0`000dd0000c0003]00000/000>d00002`000k@0000S0000;P000k@000040003
]00003/000=<00008`000d`0000/00038`0000/000<S00001@000b<0000;00038`0002l000=<0000
0`02C08000=<04`01`000d`0C002009<1@000d`0000b0003]00000`000>d000030000k@0000R0000
;`000k@000030003]00002d00T8<0003C@0002<000==00002P02@Qh00R<>00038`0000D000<S0000
30028c0000==00001004C@T014d60003C@0003<000>d000030000k@0000=0003]0000240000_0003
]000008000>d0000<002@PX000=<00008`000d`0000800927`000b<0000=00038`0000L000<S0000
3@000b<0000^0003C00000@000=<]`002P000kM<00050003C00003<000>d00003@000k@0000>0003
]0000200000_0003]000008000>d0000<P02@PP000==00008`000dd00006009280000b<0000>0003
8`0000L000<S00003P000b<0000]0003C@0000800Td00`2g000:0004]`1=C@@000==0000<P000k@0
000>0003]00000h000>d00008000030000Fd0000]00f00=210000d`0000U0003C00000800d8P008S
4@000b<0000700038`0000l00R<^0004C01<C0@000>g00001`000kL00002009<00<0C000=0000k@0
000>0003]00000l000>d00007`00030000Bd002d>P02@P8000==00002004@P/01D890003C@000092
6@03aPH000<S00004@000b<0000700038`00014000<S00001003aR@00Td70003]`0000D000>g0000
1@02CC@000>d00003`000k@0000@0003]00001h0000a0003]02d03`00T8014`00007@Q@01d820003
C49201h00lH200038`00014000<S00002@000b<0000A00038`0000?69@02C00304`000L000>g0000
0`000kL000060004C01<C34000>d000040000k@0000@0003]00001h0000a0003]02d03d000=2CD80
0T8R009200==@P008002aP038`00018000<S00002@000b<0000B00038lK602D00Td30003C@0000L0
00Fg0000]`090004C@0000==;@000k@0000A0003]000014000>d00007@0003400[@l009200<0@P00
9P001480@T8L00?60P000lH0000B00038`0000T000<S00004P000lH00003aQ4014`;009<1P000d`0
00070003]`2g00T000=<00001@02C0X014`M0003]000014000>d00004P000k@0000L0000<P000k@0
000h00920`02@RD00T8300926002aP@00/HC00038`0000/000<S00004@02aP@00/HC00I=0`02C@P0
00==00001`04]`P000==00001`02C@801TdP0003]000018000>d00004`000k@0000K0000<P000k@0
000f009210001480048S0003@P1200D00T8K0003aP3601<000<S00002`000b<0000A0003aP3601h0
1d`70003C00000<00kL400>g10000d`0000500M<9@000k@0000C0003]00001<000>d00006`000380
00>d0000=@000d8000040005@P0004808@00148004870003@P0001L000C600364`000b<0000;0003
8`00014000C600367002C@H01Td0101=0003]`X00kL00`1=0006C@L00TdS0003]00001<000>d0000
50000k@0000J0000<P000k@0000c00921`000d8000020003@P0001d000=200000P000d8000050092
5P001LH00036018000<S00003@000b<0000@0005aP000<H06@02C0h00T`2]a0000>gC4`03`02C200
00>d000050000k@0000E0003]00001T0000b0003]00003400T890003@P0000<000=200006`000d80
00030003@P0000L00T8C0003aP00008000?6000040000b<0000=00038`00010000?600000P000lH0
000E0003C@0000l00TdA009=4P000dd0000L0003]00001D000>d00005P000k@0000H0000<P000k@0
000`0003@P0000T000=2000010000d80000I0003@P0000@000=200002@000d80000E0003aP000100
00<S00003@000b<0000@0003aP0002/000=<04`04@000d`0C00_0003]00001H000>d00005P000k@0
000H0000<P000k@0000k0003@P0000H000=200005`000d8000050003@P0003<000<S00003`000b<0
000l0004C@00CA4000A=001=;P000k@0000F0003]00001L000>d00005`00038000>d0000>`000d80
00070003@P0001D000=200001P000d80000c00038`0000l000<S0000>`000d`000020003C00000d0
00=<00000P000d`0000Z0003]00001L000>d000060000k@0000F0000<P000k@0000k0003@P0000P0
00=200004`000d8000070003@P0003<000<S00003`000b<0000j0003C@0000<000==00003@000dd0
00030003C@0002P000>d000060000k@0000I0003]00001D0000b0003]00003/000=200002@000d80
000A0003@P0000P000=20000<P000b<0000A00038`0003P000=<000010000d`0000=0003C00000@0
00=<00009`000k@0000H0003]00001T000>d00005@00038000>d0000>`000d80000Y0003@P0002l0
0/H00b<0000A00038lK603L000==00001@000dd0000=0003C@0000D000==00009@000k@0000I0003
]00001X000>d00005000038000>d0000>P000d80000Z0003@P0002/01<H20003aP00014000?60000
0lHc0003C00000H000=<00003@000d`000060003C00002<000>d00006P000k@0000K0003]00001<0
000a00034K@A03/000=20000:P000d80000Y00;61@03aQ400lH400;6<0000dd000070003C@0000d0
00==00001`000dd0000Q0003]00001/000>d00006`000k@0000C0000<0001A40000A03X000=20000
:P000d80000_0005aP360<H03`001LH0aP3603@000=<00002@000d`0000;0003C00000T000=<0000
80000k@0000K0003]00001`000>d00004P0002l000<A00000`000a40002E0006aP00aP363`000lH0
aP020003aP00030000==00002P000dd0000;0003C@0000X000==00007P000k@0000L0003]00001d0
00>d00004@0002h000<A00001@000a40002C0005aP000<H00P000lH0000;0004aP00aP<000?60000
;P000d`0000;0003C00000/000=<00002`000d`0000L0003]00001d000>d00007P000k@0000@0000
;@000a40000700034@00094000?600000P001LH0003600/000G60000aP040003aP0002`000==0000
30000dd0000;0003C@0000`000==0000>`000k@0000a0000;0000a40000900034@0009D000?60000
4@000lH0000`0003C00000d000=<00002`000d`0000=0003C00003X000>d0000<@0002/000<A0000
2`000a40002D0003aP00014000?60000;`000dd0000>0003C@0000/000==00003P000dd0000i0003
]0000340000Z00034@0000d000<A0000f0000d`0000?0003C00000/000=<00003`000d`0000h0003
]0000340000Y00034@0000l000<A0000eP000dd0000A0003C@0000T000==00004@000dd0000g0003
]0000340000X00034@00014000<A0000e0000d`0000B0003C00000T000=<00004P000d`0000f0003
]0000340000W0003]00001<000>d0000j0000dd000090003C@0004/000>d0000<@0002H000>d0000
5@000k@0003W0003C00000T000=<0000B`000k@0000a00009@000k@0000G0003]0000>H000==0000
2@000dd0001;0003]0000340000T0003]00001T000>d0000i@000d`000090003C00004/000>d0000
<@0002<000>d00006`000k@0003U0003C@0000L000==0000C0000k@0000a00008P000k@0000M0003
]0000>@000=<00001`000d`0002000008@000k@0000O0003]0000><000==00001`000dd000200000
80000k@0000Q0003]0000?l0L00001l000<P00008`000b00003o06l0000N0003800002D000<P0000
o`1^00007@000b00000W000380000?l0K@000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0
]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`000?l0]`0008H0
00?60000A@000b00000E0003800003h000?N000030000mh0001m0000QP000lH000150003800001D0
00<P0000?P000ml0000<0003g`0004D00R<6008S;P0008H000?60000?P000b0000040003800001D0
00<P000010000b00000_0003gP0000D000?N00001002gPH000?N00001@000mh0000k008S2P028b`0
00260003aP0003l000<P00000P000b00000F0003800000<000<P0000<0000ml000050003g`0000@0
0]l60003g`0000D000?O0000>@028`h00R<Z0000QP000lH0001000058000020060000b0000020003
8000038000?N000010000mh0000400;N1P000mh000040003gP0003P00R<B008S:00008H000?60000
@@001200020I0004800083H000?O00000`000ml000030004g`00g`D000?O00000`000ml0000g008S
5P028bH000260003aP00048000<P02001P0280T00R060003800P03P000?N00000P000mh000020003
gP00008000?N00000P000mh000020003gP0003H00R<J008S900008H000?60000@`0280D000<P0200
0R05008P0P000b000003008P>@000ml000020003g`00008000?O00000P000ml000020003g`000080
00?O0000=0000b=<000M0003C2<0024000260003800004<00R050005800P80000R001@0P800P0080
00<P00000`000b00000i0005gP000=h00`000mh000040005gP000=h00`000mh0000c008S00<0C@00
7@0014d08b<P0000QP000b0000130003800P00@00R020003800P008P00H0800P0204008P?0001=l0
0=l20003g`0000H000CO003O0P000ml0000b008S10000d`0000J0004C00000<S7P0008H000<P0000
@`00120002020003800P00801b00100P02030003800P03`000CN003N0P000mh000060004gP00gP80
00?N0000<0028`0302<000<000==00006P001Dd0000S008000<S00006`0008H000<P0000@`001R00
000P00DP00@082000R000`0P8003800502000200?@001Ml0g`3O00X000GO0=l0g`0a008S0P000b<0
00040003C00001P000=<00000`000b<000028a/000260003800003`00R0500038000008012000`0P
80078003020P008P10000b000003008P=P03gP`00mh`008S10000b<000040003C@0001P000==0000
0`000b<00002008S6@0008H000<P0000?P02808000<P00001005808000<P02000P0480034@0000<0
00@P00000R0i0003800000`000<P0000;P000b<0000300038`0000H000=<00005P000d`000050003
8`0000<000<S00005P0008H000<P0000@003808000PP00008140808000DP000080020004800A80<0
00@P02000R0k0003800000`000<P0000=0000b<000060003C@0001H000==00001@000b<0000L0000
QP000b000010008P00@A800P0P028005014002001@001B000140008P0P0280044B0P83/000<P0000
30000b00000c00038`0000P000=<000050000d`0000700038`0001/000260003800003/01R000`0A
000280800b000`0A80070003814000<P00H0820P4@0783H000<P000030000b00000b00038`0000X0
00==00004P000dd0000900038`0001X000260003800003H02b000`0A00078003020A00L000<A8000
1b000a40000;834000<P000030000b00000b00038`0000X000=<00004P000d`0000900038`0001X0
00260003800003<01b000`0P8003008P00<A82001b0200034@0000<000<A00002B000a4P800200<P
0P0682h000<P000030000b00000a00038`0000`000==000040000dd0000;00038`0001T000260003
800003T01R02008P00<0800012000a4P800200054@0001400P0280034B0P008P00D0800A800300DP
6`02gaL000<P000030000b00000D00;O6`000b<0000<0003C000010000=<00002`000b<0000I0000
QP000b00000g008P1P068006020P814P0P02800501404@000R020006814P02001b05008P6`000mh0
000D0003800000`000<P00004`000mh0000J009=3`000dd0000>0003C@0000`00TdJ0000QP000b00
000e008P2P000b00000480044B0P80800b00114P820200<P114280034B0000T00R0J0003g`0001<0
00<P000030000b00000B0003g`0001/000@S04a<3@001D`0000S00P000DS0000C00<009<00<08`00
6@0008H000=20000=0000b00000:0004800P008P00<A80000R034@03814P00PA00PP4B0P020A80`0
00<P00006002gQ<000<P000030000b00000@00;N7@000b<00002009=300019D002<800048`00U@/0
0Td400038`0001L000260003@P0004001R024@DP00<04A401A400`0P80038003020P00<P00<A8000
9`000ml0000@0003800000`000<P00003`000ml0000M00038`0000@00T`:0005U@0002<01P001B<0
002E00T00T`600038`0001L000260003@P0003/02R001A4P4B00008P0Q401`0A02004@0012001@0P
020A00<P00<A8200120T00;N40000b00000<0003800000d00]hO00038`0000L000==00000`000b<0
00020004U@008`H000@S002E0`000b<000030003C@0000L000<S00005P0008H000=20000>0038080
00<P00000R000`0P4@0280034B0P008A00H0814P4@048003020P00DP00DA820A80020003800000<P
8`000ml0000=0003800000`000<P000030000ml0000O00038`0000P00T`300038`00008S00FE0000
8`0400058`0009D00R<00`0S0002009<2P000b<0000F0000QP000d80000n008P00@A020P0P044@04
020P808A00@P4B0A12000`0A800280800R001140820Z0003gP0000`000<P000030000b00000;0003
gP0001l000<S00002`02C@8000@S00000R<200038`00008000DS002E8`0200038`00009=3@000b<0
000E0000QP000d80000l008P00L08140800P008A0R020004800A4@8P00<A82000R00100P00038008
4B008140800281`03Ml?80d03b0>ga@000<S00003@02C0038`00008000FE8b<08`0200058`0S8iD0
0`000b=<C00?00038`0001D000260003@P0003<000<P0000100280@000<P4B000Q401@0A820000<P
00HA820P014580030200008P00@04A4P0Q44008P1P000b00000L0003gP0000h000<P00002@000b00
000>0003gP0001d000<S00004002U@@000>E02<01B<00`2E000200038iD0014000<S0000500008H0
00=20000<`000b0000030003800000@000XA814P020A800P0P000a4080028003020A008000XP020P
0200800P0a460003800000<000<P00006`000ml0000@0003800000L000<P000040000ml0000L0003
8`00014000<SUID00P001YD0000P8`<000FE09FE8`0C00038`0001@000260003@P0002l000<P0000
0P000b000008008P00<081400R002A4P82004B004@0580044@0P4@8P00@0814P0a400`0A800:0003
8000008000<P00005@02gQ@000<P00001@000b00000B00;N6`000b<0000C00068`2EU@2E0R<0120S
8b<3U@0302<001@000<S00004`0008H000=20000;`000b0000020003800000L000<P4A400P001200
82024@07014A800A000380080140814P02034@040200008A00<P00001`000b0000020003800001@0
00?O00005@000b0000030003800001D000?O000060000b<0000@008S00<08`000P02U@800R00101<
UB<200038`00008S4@000b<0000C000090000d80000I0003@P0004<000=20000<003808000<P0000
0`038004014A808000<P02000R024@8P00<A80000b000`0P4@0280<A00@P4@0P0P0011404@0380D0
00<P00000b0E00;N6@001B00000P01T00]hG00038`0001<01B<01P1=UB1=80:E00E=02<S00028a@0
00<S00004P0002@000=2000060000d8000140003@P00034000<P02000R04008P00<082000P001200
000380044B0A80:E00<082000b00102EUA4280044B0P80<000HA000A800280@00b000`0P000D0003
g`0001X000<P020070000ml0000[00<S0`001YDPUB1<U@<00b<Z00009@0J]dL000=20000<P000b00
00028003020P00@000@A820P0P000b0A800280034B0P008P0iD01R2EUIDP4@@P0Q401B00000A008P
00<A00000P028003020P008000<P00004P02gQh00R0M00;N:@028`800R<02@1=8b00CB2EC@028`<0
00<S00009`0002D000=200005`000d8000140003C00003<000<P00000b0400034@0000DP0Q428003
4B0P00DP00>E82000R00114P8142808A0b001A4P000A00<012020003800001<000?O0=l070001200
020K0003g`3O02L00R<400038d`S008S00FE04bEC002U@03C00000800R<W000090000d80000I0003
@P0004<000==0000=0048003020P008000DA000P4@0380@A12001@0P822E00@P00<A82000R000`0P
80028003014P008000<A02000R000`0P800281T00]hI00038000008000<P00005P02gQ@000<S0000
4@028`H00YD0100S8b<2U@04C@0SC@:E1@028a@000<S00003P0008H000=<0000=00480030200008P
00<A00001200100P80098003UB0P008P00@A020P0Q401b0A820A02000P001Q4P000P00@P6`02gaH0
00<P000010000b00000C00;O5P000b<0000@00038`0000@00YD0200S02<08dbE0P028`800YD50003
8`00014000<S00003P0008H000==0000=000120080038005014P80000R001@0P4A40008P00D0820A
80030006U@00020A1B001@0A4B0A00@P00<04@000b00100P020M0003gP00018000<P00001P000b00
000A0003gP0001L000<S00005002U@@00b<00`2EC@048`@00YDF00038`0000l000260003C00003D0
1200100P814200<A00@P014A0b024@<P0a400iDP4@034@DP00@A01400a4300044B0P00@P7`02ga40
00<P000020000b00000>00;O6P000b<0000B00:E1@028`<00YD2008S1P02UA@000<S00003`0008H0
00==0000=P001B00820000<P00<080000a4780034B00008000<PUA400P024@@P00<082000R000a40
800380030140008P00<080008@000mh0000=0003800000X000<P000030000mh0000K00038`0000l0
00==U@0010038`0802<0U@2E02<2008S1P000iE=000@00038`00010000260003C00003<01B001@0P
820000DP0a4280800b000a4P4@0280034B0P008P00DA820P000380<A1B001@0A820000DP4`0=g`lP
3P0>80kO40000b<0000=009<1@028`8000TS02<0U@1<UB<00P0012<08b<6009<3`000b<0000@0000
QP000dd0000h008P00<A82001B00114P82024@HP00D04A4A80020003814P008P00<04A400R000a4P
800680034B0P02<000?N00003@000b00000<0003800000`000?N00006`000b<0000:009=1@028`<0
00DS0000U@0300038`00008000<S00000R<6009=30000b<0000A0000QP000b00000i008P00<08000
12001a4P820A81400R00100P82054@03020A008P0Q401@0P820A00@P0P001200820S0003g`0000h0
00<P000030000b00000=0003g`0001X000<S00002002C0H000<S00000`002R<0002E8`0SC9D30003
8`00008000<S00001@02C0X000<S00004@0008H000<P0000>@048003020P008P00<A02001R024@<P
00@04@0P11448005020P81400b0200@P8@02gQ4000<P000030000b00000>00;N6`000b<000060003
C@0000/000/S0000U@0S02<0U@0400038`0000/000==00001P000b<0000B0000QP000b00000i0004
800P00@P00<A82000b001P0P820A80<A00<P4B002A448003020000<P00@0800P80000ml0000A0003
800000`000<P000040000ml0000H00038`0000@00T`B0004U@008`8000>E00004@02C0H000<S0000
4P0008H000<P0000>00012000005808A00@P4A4A1B074@@P00@A020P11400b0A4@0580<000<P0000
6`02gQ@000<P000030000b00000A00;N6@0012<00002CA<000FE00008`030003U@0001800Td30003
8`0001<000260003800003P01b024@@P00<08200114280<000<A00000R000`0P800280034B0P00@P
0a4681`000?O000050000b00000<0003800001<000?O00005P0012<0C4`E0006C0008`0S0P000d`0
000D009<00<08`00500008H000<P0000=P058003020P008P00<A820012000a4P4@0280D000<A0000
0P0380034B0A00HP00<A82000R000`0P800381T000?N00005@000b00000<0003800001@000?N0000
5P000dd0000D0003C@0000L000==00005@000dd0000D0000QP000b00000a00DP00<080000`0;8006
4B0P4B0A10000a400002008A0R000a4P800;80<000<P0200120C0003g`0001H000<P000030000b00
000E0003g`0001D000<S000050000d`000070003C00001D000<S0000500008H000<P0000;P0380D0
00<P00000b0200@P00<082000R000a4P80028003014A008000<A00000Q401@0P820A00@P0P0480<0
0R020003800000<00R0Z0003800000`000<P0000;P000b<0000B0003C@0000T000==00004`000b<0
000E0000QP000b00000f0003800000@00R00100P80038004020000DP11468003020000<P00H0820P
02070003800002l000<P000030000b00000^00038`00018000=<00002@000d`0000C00038`0001D0
00260003800003D000<P00001@028003020000@P00P08000800P00PA00@P02000b001`0P82008000
0R070003800002h000<P000030000b00000_00038`00010000==00002`000dd0000A00038`0001H0
00260003800003D000<P00001@00120000058003020A008A0b070003814A008A00@P4A4012030003
800000D000<P0000;P000b00000<0003800002l000<S000040000d`0000;0003C000014000<S0000
5P0008H000<P0000=0000b0000060003800000<P114280800R000`0P00040004800P80800b000a4P
4@03808000<P00001P000b00000]0003800000`000<P0000<0000b<0000>0003C@0000d000==0000
3`000b<0000G0000QP000b00000d0003800000@01B0200DP00<080000P0012000203000480008080
00<P00001B0200DP1P000b00000]0003800000`000<P0000<@038``000=<00003`000d`0000;00<S
6P0008H000<P0000<`000b0000058003020000@01B000`0P00020007800002008003000480008080
1B050003800P00@P0P000b00000/0003gP0000`000?N0000<@000b<000028`X000==00003`000dd0
0009008S0P000b<0000H0000QP000b00000c00<P1@000b00000500HP10001B00000P00<000HP0000
800580L000<P00000`0282h00ml<00?O<`0012<000028`L000=<00004@000d`00006008S0`000b<0
000I0000QP000b00000k0003800000@00R000`0P800280@000HP000P02020004800000<P00@0800P
1`000b00000b0005gP3N0=h02P001Mh0gP3N038000<S00000`000b<000040003C@00014000==0000
10028`D000<S00006@0008H000<P0000>P000b0000050005800P80000b04008P0`0280@00b001@0P
800P00L000<P0000<0001=l00=l20003g`0000H000CO003O0P000ml0000`00038`0000<00R<30003
C00001<000A<00000R<600038`0001X000260003800003X000<P00001@00120080028003020000<0
00<P00000`000b0000020008800P800P020700038000030000CN003N0P000mh000060004gP00gP80
00?N0000>0028`0304d001@000A=02<S9@0008H000?60000>@000b0000060003800000<P00<08200
10001B00000P00@00R00100P82020003800000H000<P0000;P001Ml0003O00<000?O000010001Ml0
003O00<000?O0000>@000d`S000D00038d`002H000260003aP0003T000<P00002`001B00800P00/0
00DP0200800=0003800002d000?N00000P000mh000020003gP00008000?N00000P000mh000020003
gP0003X00R<A008S:@0008H000?60000>0000b00000<0003800P008000<P00001`000b0080020003
800000`000<P0000;0000ml000020003g`00008000?O00000P000ml000020003g`00008000?O0000
?0028`d00R<[0000QP000lH000180003800P008000<P00001@001R00020083d000?N00000`000mh0
00030004gP00gPD000?N00000`000mh0000m008S2@028bd000260003aP0004P000<P02000`000b00
0003000780000200800l0003g`0000@000?O00001002g`H000?O000010000ml0000n008S1@028bl0
00260003aP0004T00R0=008P?0000mh000050003gP0000@00]h60003gP0000D000?N0000?`028`03
02<S034000260003aP0004T000<P00003@000b0000120003g`0000`000?O0000B@000b<0000a0000
QP000lH0001:0003800000/000<P0000@`000mh0000<0003gP0007d0003o02P000?O000030000ml0
001m0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000
o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000O0000d`0000A0003C0000?l0900007`0
00==00004@000dd0002K0003800008D0001l0003C000014000=<0000V`000b0000190003800000d0
00<P0000:@0007`000==00004@000dd0002K0003800004T000<P00003@000b00000Y0000N`000d`0
000B0003C00009/000<P0000B@000b00000=0003800002T0001k0003C@0001<000==0000VP000b00
00190003800000d000<P0000:@0007/000=<00004`000d`0002J0003800004T000<P00003@000b00
000Y0000N`000dd000050003C@0000800Td70003C@0009X000<P0000B@00120002090004800082/0
001k0003C00000H000A<001<2@000d`0002J0003800004T000@P000P2@000b00000282X0001j0003
C@0000P00Td:0003C@0009X000<P0000B@001200020900038000008P:P0007X000=<00002002C0X0
00=<0000VP000b000019008P00<0800020001200020[0000NP000dd000070004C@00C@T000==0000
VP000b0000190004800P80T000@P020P:`0007X000=<00001P000d`000020003C00000H000=<0000
VP000b00000l0003800000X000@P000P2@028003020000`000<P00006`0007X000==00001@000dd0
00040003C@0000D000==0000VP000b00000l0003800000X000@P000P2@028003020000`000<P0000
6`0006T014`=0003C00000@000=<00001P000d`000050003C00000X014b;0003800003d000DP0000
800700038000008P2000120002080005800002007P0006d01Dd70003C@0000@000==000020000dd0
00040003C@0000D01Df?0003800003h000@P000P1`001R00020080H00R020003800000H000@P000P
7`0007801D`20003C00000<000=<00002P000d`000030003C00000E<@0000d`0001A0003800003l0
00@P000P1P001R00020080D000<P02000P000b000005000480008200001g009=0T830003C@0000`0
00==00000P000d9=C@140003C@1=058000<P0000?`001B00000P00D000@P000P0P001B00000P0080
00@P000P1P001B00000P0200001k0003]49201000d800k@000140005C00004`0D@000b0000100005
8000020010001200020300048000808000@P000P1@001B00000P0240001k0004]000C@l000A=002d
A@000dd000030003C@0004h000<P0000@@00120002040004800080@00R030004800080D000@P000P
8P0007X000=20;@00P000d`0000;0005C000]480A0000d`000050003C00004d000<P0000@@001B00
000P00<000@P000P10000b0000020004800080@000@P000P8`0007T000E=@P00]0020003C@0000T0
00M=002d049=048000==00001`000dd0001<00038000048000DP000080020004800080<000<P0200
0`00120002030004800082@0001]0003C00000L00T`00`1<00020004]000C0T000A<002d0P0014`0
C4`90003C00003<000=<00002@000d`0001;0003800004<000@P000P0P0012000203000480008080
00@P000P0P001B00000P02@0001]0003C@0000D00Td40004C@00]0<000==00001@001dd0002d04d0
1002C@L000==0000<P000dd0000;0003C@0004X000<P0000A0001R000200808000@P000P10000b00
80020003800P00<000<P00008`0006h000=<00000P02C0H000E<0000]0030003C00000<000E<0000
]0020003C00000@00d`30003C000038000=<00003@000d`000190003800004@000@P00000R020003
800P00D000<P02000P000b0080020003800002@0001^0003C@00009=2@001Dd0002d00<000E=0000
C@030004]000C@X00Td00`1=000b0003C@0000l000==0000B0000b0000150005800002000P0280L0
0R02008P0P000b00000U0000K`02C0`000E<0000]0030003C01<00<000Fd0000C00<009<<P000d`0
000A0003C00004L000<P0000?00380L000@P000P0P000b0000070004800080<000<P00001@0381d0
001]00==3@001Dd0002d00@000==00000P001;@004d=0004C@1=CBl000==00004`000dd000160003
800003L00R0600<P1@001R00820080T000@P020P0P000b00000300<P1P0281P0001/0005C00004`0
3@001D`0002d008000=<04`00P001K@0001<00`000=<00000P000d`0000[0003C00001D000=<0000
A@000b00000i00<P1P03808000@P02000R0200GO0P048003020000800b0600<P6P00070000==0000
2`000dd000020003]4d0008000==]0000P000dd0000;0003C@0002l000==00005`000dd000140003
800003`00b0600HP1=h20003gP0000CN1b0600<P7@0002l01d8k0003C00000/000E<001<]0040003
C;@0008000=<00002P000d`0000_0003C00001T000=<0000@`000b00000o00<P1P000b3Og`0280<0
0ml30004803Og`8P1P038200000Y00I21`06@SH000==00002P03C@8000Jd0000]003C@d000==0000
;P000dd0000K0003C@00048000<P0000@P068004020000<P00GN0=h0gP048004020000HP8`0002@0
1D8C00E2<@000d`0000900=<10000k@0]004009<30000d`0000]0003C00001d000=<0000@@000b00
001200HP0P001B00803O008P00SO823O020080<01R0S00007P06@Qd01T8L009=3P000dd00006009=
0`0014d00004]08000==00000dd80003C@0000/00TdP0003C@0001l000==0000@0000b00000o00<P
1P058005gR0P8=h00b001=hP800380H00b0P00006006@RT01T8H009<30000d`00004009<1@001Tbd
];@0]0800k@5009<1P000d`00009009<8@000d`0000Q0003C00003l000<P0000?00380`000<Pgb00
0R001`3O02008=l00R0<00<P7@0001<01D8e00E25@02C@/000A=00000Td500>d00E=0000]0030003
C@2d00:d1002C@<000==00002002CB8000==00008`000dd0000n0003800003T00b0=00@P00D0820P
gP058004020P80d00b0J00004003@Sl00d8D00=<200014`0C4`400>d0P000d`000020005]00004`0
1003]0<00T`00`1<0007009<8`000d`0000U0003C00003d000<P0000=P0380d00b020004800P008P
00?O82000R000`0P000200<P3@0381L0001/009=1`0014800003]0D000==00000P001K@0001=00L0
0k@20003@P0000D00TdT0003C@0002L000==0000?0000b00000c00<P3@0380@000<P02000R020003
800000DP1@0380d00b0D0000KP02C0D000A2];Bd20000d`0C002C003]4a<009<2P03]0D00T`U0003
C00002T000=<0000>`000b00000`00<P3@0380H00b030003800P008000@P00000b0600<P3@038140
001`009=00@0@[Bd2005C@<000Bd00001Dd90003]480009=9P000dd0000[0003C@0003X000<P0000
;`000b00000=0003800000@012050005800P02001@000b00800280H000<P00003@000b00000>0000
LP001480048300E<10001D`0002d008000=<00000`05C0<000A200129`000kL0000]0003]`0003T0
00<P0000@`03808000<P00001@0380L000@P00000b0T0000LP001Dd00012009=2@001Dd0002d0080
00==00002002C@05@P0004d09P000kL0000_0003]`0003P000<P0000@00380@000<P00001`0280P0
00<P00000`038240001a0003C000008000=<00002@001D`0002d008000=<00002P000d`000020003
C000028000>g0000<@000kL0000g0003800003d00b070003800000L00R090003800000D00b0N0000
L@000dd000020003C@0000T000E=0000]0020003C@0000X000==00000P000dd0000Q0003]`0003<0
00>g0000=P000b00000l0003800000L000<P00001`0380T000<P000020000b00000K0000L0000d`0
00030003C00000X000A<002d0P000d`0000:0003C00000<000=<00007`000kL0000e0003]`0003D0
00<P0000A@000b000008008P00<0800020000b00000U0000K`000dd000050003C@0000T000A=002d
0P000dd000090003C@0000@000==00007P000kL0000g0003]`0003@000<P0000A@000b0000070003
800P008000<P00001`000b00000T0000K`000d`000050003C00000T000A<002d0P000d`000090003
C00000D000=<000070000kL0000i0003]`0003<000<P0000A0000b00000700048000808000<P0000
20000b00000S0000KP000dd000060003C@0000T000A=002d0P000dd000090003C@0000D000==0000
6`000kL0000k0003]`00038000<P0000@`000b0000080004800080<000<P00001`000b00000S0000
KP000d`000060003C00000T000I<002d04`<0003C00000H000=<00006@000kL0000m0003]`000340
00<P0000@`000b00000700058000020010000b000007000380000280001]0003C@0000L000==0000
2P001Dd0]01=00`000==00001P000dd0000H0003]`0003l000>g0000<0000b0000120003800000L0
00<P00000P000b0000030003800000L000<P00008@0006d000=<000020000d`000090005C02d04`0
2`000d`000080003C00001H000>g0000@@000kL0000_00038000044000<P00001`000b0000030003
800000<000<P00001`000b00000Q0000K0000dd000090003C@0000D014d2@P03]49200A=1`000dd0
00080003C@0008`000<P0000@@000b0000070003800000<000<P000010000b000007000380000200
001[0003C00000X024`60003]00000@024`;0003C00008/000<P0000@0000b0000070003800000@0
00<P00001@000b0000070003800001l0001[0003C@0000H01Dd=0003@P0000/01Dd70003C@0008/0
00<P0000?`000b0000070003800000D000<P00001P000b0000070003800001h0001Z0003C00000/0
00=<00002`000d80000;0003C00000X000=<0000RP000b00000n00038000010000<P000040000b00
000N0000N@000dd00009009=30000dd0002H0003800003h000<P000040000b00000A0003800001d0
001i0003C00000P000A<001<2`000d`0002H0003800003d000<P00004@000b00000B0003800001`0
001i0003C@0000L000==00000P000dd000080003C@0009P000<P0000?0000b00000B0003800001<0
00<P00006`00088000=<000010000d`0002R00038000054000<P0000<@00084000==00001P000dd0
002Q00038000054000<P0000<@00080000=<000020000d`0002P00038000054000<P0000<@0007l0
00==00002P000dd0002O00038000054000<P0000<@0007h000=<000030000d`0002N000380000540
00<P0000<@0007d000==00003P000dd0002M00038000054000<P0000<@0007`000=<000040000d`0
002L00038000054000<P0000<@0007/000==00004P000dd0002K0003800008D0001j0003C00001@0
00=<0000o`0S0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000o`2g0000
o`2g0000o`2g0000o`2g0000\
\>"],
  ImageRangeCache->{{{0, 437}, {257, 0}} -> {-0.145065, -0.0740895, 0.0121056,
   0.0121056}, {{11.9375, 88.4375}, {250.875, 174.375}} -> {-0.188853,
   -0.109074, 0.0137256, 0.0137256}, {{96.0625, 172.562}, {250.875, 174.375}}
   -> {-1.34352, -0.109075, 0.0137256, 0.0137256}, {{180.25, 256.688}, {
  250.875, 174.375}} -> {-2.50107, -0.109574, 0.0137368, 0.0137368}, {{
  264.375, 340.875}, {250.875, 174.375}} -> {-3.65372, -0.109074, 0.0137256, 
  0.0137256}, {{348.5, 425}, {250.875, 174.375}} -> {-4.80839, -0.109076, 
  0.0137256, 0.0137256}, {{11.9375, 88.4375}, {166.688, 90.25}} -> {-0.188855,
   -1.26417, 0.0137256, 0.0137256}, {{96.0625, 172.562}, {166.688, 90.25}} ->
   {-1.34503, -1.26561, 0.0137368, 0.0137368}, {{180.25, 256.688}, {166.688, 
  90.25}} -> {-2.50107, -1.26561, 0.0137368, 0.0137368}, {{264.375, 340.875},
   {166.688, 90.25}} -> {-3.65711, -1.26561, 0.0137368, 0.0137368}, {{348.5, 
  425}, {166.688, 90.25}} -> {-4.80839, -1.26417, 0.0137256, 0.0137256}, {{
  11.9375, 88.4375}, {82.5625, 6.0625}} -> {-0.188855, -2.41927, 0.0137256, 
  0.0137256}, {{96.0625, 172.562}, {82.5625, 6.0625}} -> {-1.34352, -2.41927, 
  0.0137256, 0.0137256}, {{180.25, 256.688}, {82.5625, 6.0625}} -> {-2.50107,
   -2.42166, 0.0137368, 0.0137368}, {{264.375, 340.875}, {82.5625, 6.0625}} ->
   {-3.65371, -2.41927, 0.0137256, 0.0137256}, {{348.5, 425}, {82.5625, 
  6.0625}} -> {-4.80839, -2.41927, 0.0137256, 0.0137256}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Biomorph Mutants", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(testBio = randomBiomorphParams[]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({2, 3, 6, 4, 2, 9, 2, 9, 7, 8, 5, 1, 2, 5, 8, 10, 4, 9, 3, 5, 10}\)], 
  "Output",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[biomorph[testBio]]\)], "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95094 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{267, 253},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004;0000o@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l030000?l030000?l030000?l030000?l0
30000?l030000?l030000?l030000?l030000?l030000?l030000?l030000?l0300005D01;AG00Bd
E`0005D01;AG00BdE`0005D01;AG00BdE`0005D01;AG00BdE`0005@01KAG00FdEP0005@01KAG00Fd
EP0005@01KAG00FdEP0005@01;AI00BdEP0005@01;AI00BdEP0005@01;AI00BdEP0005<01KAI00Fd
E@0005<01KAI00FdE@0005<01KAI00FdE@0005<01;AK00BdE@0005<01;AK00BdE@0005<01;AK00Bd
E@0005801KAK00FdE00005801KAK00FdE00005801KAK00FdE00005801;AM00BdE00005801;AM00Bd
E00005801;AM00BdE00005801;AM00BdE00005401KAM00FdD`0005401KAM00FdD`0005401KAM00Fd
D`0005401;AO00BdD`0005401;AO00BdD`0005401;AO00BdD`0005001KAO00FdDP0005001KAO00Fd
DP0005001KAO00FdDP0005001;AQ00BdDP0005001;AQ00BdDP0005001;AQ00BdDP0004l01KAQ00Fd
D@0004l01KAQ00FdD@0004l01KAQ00FdD@0004l01;AS00BdD@0004l01;AS00BdD@0004l01;AS00Bd
D@0004h01KAS00FdD00004h01KAS00FdD00004h01KAS00FdD00004h01;AU00BdD00004h01;AU00Bd
D00004h01;AU00BdD00004d01KAU00FdC`0004d01KAU00FdC`0004d01KAU00FdC`0004d01;AW00Bd
C`0004d01;AW00BdC`0004d01;AW00BdC`0004`01KAW00FdCP0004`01KAW00FdCP0004`01KAW00Fd
CP0004`01;AY00BdCP0004`01;AY00BdCP0004`01;AY00BdCP0004/01KAY00FdC@0004/01KAY00Fd
C@0004/01KAY00FdC@0004/01;A[00BdC@0004/01;A[00BdC@0004/01;A[00BdC@0004/01;A[00Bd
C@0004X01KA[00FdC00004X01KA[00FdC00004X01KA[00FdC00004X01;A]00BdC00004X01;A]00Bd
C00004X01;A]00BdC00004T01KA]00FdB`0004T01KA]00FdB`0004T01KA]00FdB`0004T01;A_00Bd
B`0004T01;A_00BdB`0004T01;A_00BdB`0004P01KA_00FdBP0004P01KA_00FdBP0004P01KA_00Fd
BP0004P01;Aa00BdBP0004P01;Aa00BdBP0004P01;Aa00BdBP0004L01KAa00FdB@0004L01KAa00Fd
B@0004L01KAa00FdB@0004L01;Ac00BdB@0004L01;Ac00BdB@0004L01;Ac00BdB@0004H01KAc00Fd
B00004H01KAc00FdB00004H01KAc00FdB00004H01;Ae00BdB00004H01;Ae00BdB00004H01;Ae00Bd
B00004D01KAe00FdA`0004D01KAe00FdA`0004D01KAe00FdA`0004D01;Ag00BdA`0004D01;Ag00Bd
A`0004D01;Ag00BdA`0004D01;Ag00BdA`0004@01KAg00FdAP0004@01KAg00FdAP0004@01KAg00Fd
AP0004@01;Ai00BdAP0004@01;Ai00BdAP0004@01;Ai00BdAP0004<01KAi00FdA@0004<01KAi00Fd
A@0004<01KAi00FdA@0004<01;Ak00BdA@0004<01;Ak00BdA@0004<01;Ak00BdA@0004801KAk00Fd
A00004801KAk00FdA00004801KAk00FdA00004800[@387`00b000k@000120000@@05]004020P87H0
0b05]4<0001100Fd100387000b0300Fd@`0004001[@700<PJP0380H01[A20000@005]0/00b1T00<P
2P05]480000o00Jd3P0385h00b0=00Jd@@0003l01K@B00<PF00381401KA10000?P06]1D00b1B00<P
5006]400000n00Fd6@0384`00b0H00Fd@00003d01[@L00<PAP0381/01[@o0000?@05]200120o00<P
7`05]3l0000l00Jd900383T00b0R00Jd?P0003`01K@X00<P<`0382H01K@n0000>`06]2/00b0]00<P
:@06]3d0000k00Fd;`0382L00b0]00Fd?@0003X01[@b00<P8@0383001[@l0000>P05]3H00b0K00<P
=005]3`0000i00Jd>@0381D00b0g00Jd>`0003T01K@m00<P3`0383/01K@k0000>006]4000b0900<P
?P06]3X0000h00FdA00380<00b1200Fd>P0003L01[A700<PA@06]3T0000g00FdB@000b00001500Fd
>@0003H01[A90003800004D01[@h0000=P05]4X000<P0000AP05]3P0000e00JdBP000b00001600Jd
=`0003@01[A;0003800004L01[@f0000=006]4/000<P0000A`06]3H0000c00JdC0000b00001800Jd
=@0003<01KA=0003800004T01K@e0000<P06]4d000<P0000B@06]3@0000b00FdCP000b00001:00Fd
=00003401[A>0003800004X01[@c0000<@05]4l000<P0000B`05]3<0000`00JdC`000b00001;00Jd
<P0003001KA@0003800004`01K@b0000;`06]50000<P0000C006]340000_00FdD@000b00001=00Fd
<@0002h01[AA0003800004d01[@`0000;P05]58000<P0000CP05]300000]00JdDP000b00001>00Jd
;`0002d01KAC0003800004l01K@_0000;006]5<000<P0000C`06]2h0000/00FdE0000b00001@00Fd
;P0002/01[AD0003800005001[@]0000:`05]5D000<P0000D@05]2d0000Z00JdE@000b00001A00Jd
;00002X01KAF0003800005801K@/0000:@06]5H000<P0000DP06]2/0000Y00FdE`000b00001C00Fd
:`0002P01[AG0003800005<01[@Z0000:005]5P000<P0000E005]2X0000W00JdF0000b00001D00Jd
:@0002L01KAI0003800005D01K@Y00009P06]5T000<P0000E@06]2P0000V00FdFP000b00001F00Fd
:00002D01[AJ0003800005H01[@W00009@05]5/000<P0000E`05]2L0000T00JdF`000b00001G00Jd
9P0002@01KAL0003800005P01K@V00008`06]5`000<P0000F006]2D0000S00FdG@000b00001I00Fd
9@0002801[AM0003800005T01[@T00008P05]5h000<P0000FP05]2@0000Q00JdGP000b00001J00Jd
8`0002401KAO0003800005/01K@S00008006]5l000<P0000F`06]280000P00FdH0000b00001L00Fd
8P0001l01[AP0003800005`01[@Q00007`05]64000<P0000G@05]240000N00JdH@000b00001M00Jd
800001h01KAR0003800005h01K@P00007@06]68000<P0000GP06]1l0000M00FdH`000b00001O00Fd
7`0001`01[AS0003800005l01[@N00007005]6@000<P0000H005]1h0000K00JdI0000b00001P00Jd
7@0001/01KAU0003800006401K@M00006P06]6D000<P0000H@06]1`0000I00JdIP000b00001R00Jd
6`0001T01[AV0003800006801[@K00006006]6L000<P0000H`06]1X0000H00FdJ0000b00001T00Fd
6P0001L01[AX0003800006@01[@I00005`05]6T000<P0000I@05]1T0000F00JdJ@000b00001U00Jd
600001H01KAZ0003800006H01K@H00005@06]6X000<P0000IP06]1L0000E00FdIP05]0038;Bd00:d
I@05]1L0000D00JdH00;]0038;Bd00RdG`06]1H0000D00FdFP0S]5X01K@F00004`06]5@0<;AC00Jd
5@0001<01KA?01bd100L]4h01K@E00004P06]4T07;@@01bdB006]1@0000B00FdA00K]1d07;A300Fd
500001401[@m01bd:P0K]3d01[@C00004@05]3P07;@f01^d>005]1<0000@00Jd<P0L]4807;@a00Jd
4P0001001K@]01bdCP0L]2`01K@B00003`06]2L06kAK01bd9P06]140000?00Fd8@0L]6L07;@Q00Fd
4@0000h01[@K01bdM00K]1/01[@@00003P05]1H07;B001^d5P05]100000=00Jd400L]8`06k@@00Jd
3`0000d01K@;01^dV@0L]0X01K@?00003006]0@07;BU01bd1006]0h0000<022d/@0P]0h0000<01Zd
_@0J]0h0000<01BdbP0C]0h0000=00bde`0<]0l0000=00Jdh`06]0l0003o00`0003o00`0003o00`0
003o00`0003o00`0003o00`0003o00`0003o00`0003o00`0003o00`0003o00`00000\
\>"],
  ImageRangeCache->{{{0, 266}, {252, 0}} -> {-0.0269845, 0.000753209, 
  0.00396229, 0.00396229}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(biomorphsMut = Table[PointMutation[testBio, i], {i, 1, 21}]\)], "Input",\

  AspectRatioFixed->True],

Cell[BoxData[
    \({{3, 3, 6, 4, 2, 9, 2, 9, 7, 8, 5, 1, 2, 5, 8, 10, 4, 9, 3, 5, 10}, {2, 
        4, 6, 4, 2, 9, 2, 9, 7, 8, 5, 1, 2, 5, 8, 10, 4, 9, 3, 5, 10}, {2, 3, 
        5, 4, 2, 9, 2, 9, 7, 8, 5, 1, 2, 5, 8, 10, 4, 9, 3, 5, 10}, {2, 3, 6, 
        3, 2, 9, 2, 9, 7, 8, 5, 1, 2, 5, 8, 10, 4, 9, 3, 5, 10}, {2, 3, 6, 4, 
        3, 9, 2, 9, 7, 8, 5, 1, 2, 5, 8, 10, 4, 9, 3, 5, 10}, {2, 3, 6, 4, 2, 
        10, 2, 9, 7, 8, 5, 1, 2, 5, 8, 10, 4, 9, 3, 5, 10}, {2, 3, 6, 4, 2, 
        9, 3, 9, 7, 8, 5, 1, 2, 5, 8, 10, 4, 9, 3, 5, 10}, {2, 3, 6, 4, 2, 9, 
        2, 8, 7, 8, 5, 1, 2, 5, 8, 10, 4, 9, 3, 5, 10}, {2, 3, 6, 4, 2, 9, 2, 
        9, 8, 8, 5, 1, 2, 5, 8, 10, 4, 9, 3, 5, 10}, {2, 3, 6, 4, 2, 9, 2, 9, 
        7, 7, 5, 1, 2, 5, 8, 10, 4, 9, 3, 5, 10}, {2, 3, 6, 4, 2, 9, 2, 9, 7, 
        8, 4, 1, 2, 5, 8, 10, 4, 9, 3, 5, 10}, {2, 3, 6, 4, 2, 9, 2, 9, 7, 8, 
        5, 6, 2, 5, 8, 10, 4, 9, 3, 5, 10}, {2, 3, 6, 4, 2, 9, 2, 9, 7, 8, 5, 
        1, 3, 5, 8, 10, 4, 9, 3, 5, 10}, {2, 3, 6, 4, 2, 9, 2, 9, 7, 8, 5, 1, 
        2, 6, 8, 10, 4, 9, 3, 5, 10}, {2, 3, 6, 4, 2, 9, 2, 9, 7, 8, 5, 1, 2, 
        5, 9, 10, 4, 9, 3, 5, 10}, {2, 3, 6, 4, 2, 9, 2, 9, 7, 8, 5, 1, 2, 5, 
        8, 1, 4, 9, 3, 5, 10}, {2, 3, 6, 4, 2, 9, 2, 9, 7, 8, 5, 1, 2, 5, 8, 
        10, 5, 9, 3, 5, 10}, {2, 3, 6, 4, 2, 9, 2, 9, 7, 8, 5, 1, 2, 5, 8, 
        10, 4, 8, 3, 5, 10}, {2, 3, 6, 4, 2, 9, 2, 9, 7, 8, 5, 1, 2, 5, 8, 
        10, 4, 9, 2, 5, 10}, {2, 3, 6, 4, 2, 9, 2, 9, 7, 8, 5, 1, 2, 5, 8, 
        10, 4, 9, 3, 4, 10}, {2, 3, 6, 4, 2, 9, 2, 9, 7, 8, 5, 1, 2, 5, 8, 
        10, 4, 9, 3, 5, 1}}\)], "Output",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[Partition[biomorph[biomorphsMut], 7]]]; \)\)], 
  "Input",
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0194351 0.952381 [
[ 0 0 0 0 ]
[ 1 .91351 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .91351 L
0 .91351 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.28499 .44547 m
.28499 .04985 L
s
P
p
0 1 1 r
.016 w
.28499 .44547 m
.05245 .76554 L
s
P
p
0 1 1 r
.016 w
.5 .74141 m
.12374 .86366 L
s
P
p
0 1 1 r
.016 w
.5 .74141 m
.87626 .86366 L
s
P
p
0 1 1 r
.016 w
.71501 .44547 m
.94755 .76554 L
s
P
p
0 1 1 r
.016 w
.71501 .44547 m
.71501 .04985 L
s
P
p
1 0 .6 r
.004 w
.5 .51533 m
.28499 .44547 L
s
P
p
1 0 .6 r
.004 w
.5 .51533 m
.5 .74141 L
s
P
p
1 0 .6 r
.004 w
.5 .51533 m
.71501 .44547 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.000503103 0.952381 [
[ 0 0 0 0 ]
[ 1 .95339 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95339 L
0 .95339 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.28453 .4986 m
.35541 .05106 L
s
P
p
0 1 1 r
.016 w
.28453 .4986 m
.07882 .90233 L
s
P
p
0 1 1 r
.016 w
.5 .79516 m
.05246 .86605 L
s
P
p
0 1 1 r
.016 w
.5 .79516 m
.94754 .86605 L
s
P
p
0 1 1 r
.016 w
.71547 .4986 m
.92118 .90233 L
s
P
p
0 1 1 r
.016 w
.71547 .4986 m
.64459 .05106 L
s
P
p
1 0 .6 r
.004 w
.5 .56861 m
.28453 .4986 L
s
P
p
1 0 .6 r
.004 w
.5 .56861 m
.5 .79516 L
s
P
p
1 0 .6 r
.004 w
.5 .56861 m
.71547 .4986 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.014 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.014 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.014 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.014 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.014 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.014 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 .4 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 .4 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 .4 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 .4 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 .4 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 .4 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.000503103 0.952381 [
[ 0 0 0 0 ]
[ 1 .95339 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95339 L
0 .95339 L
closepath
clip
newpath
p
P
p
1 0 0 r
.016 w
.39725 .23647 m
.42691 .04917 L
s
P
p
1 0 0 r
.016 w
.23518 .73525 m
.14909 .90422 L
s
P
p
0 1 1 r
.016 w
.35571 .4987 m
.39725 .23647 L
s
P
p
0 1 1 r
.016 w
.35571 .4987 m
.23518 .73525 L
s
P
p
1 0 0 r
.016 w
.23777 .73882 m
.05047 .76849 L
s
P
p
1 0 0 r
.016 w
.76223 .73882 m
.94953 .76849 L
s
P
p
0 1 1 r
.016 w
.5 .69729 m
.23777 .73882 L
s
P
p
0 1 1 r
.016 w
.5 .69729 m
.76223 .73882 L
s
P
p
1 0 0 r
.016 w
.76482 .73525 m
.85091 .90422 L
s
P
p
1 0 0 r
.016 w
.60275 .23647 m
.57309 .04917 L
s
P
p
0 1 1 r
.016 w
.64429 .4987 m
.76482 .73525 L
s
P
p
0 1 1 r
.016 w
.64429 .4987 m
.60275 .23647 L
s
P
p
1 0 .6 r
.004 w
.5 .54558 m
.35571 .4987 L
s
P
p
1 0 .6 r
.004 w
.5 .54558 m
.5 .69729 L
s
P
p
1 0 .6 r
.004 w
.5 .54558 m
.64429 .4987 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.000503103 0.952381 [
[ 0 0 0 0 ]
[ 1 .95339 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95339 L
0 .95339 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.43239 .22469 m
.77354 .05086 L
s
P
p
0 1 1 r
.016 w
.43239 .22469 m
.05422 .28459 L
s
P
p
0 1 1 r
.016 w
.323 .56137 m
.05226 .29063 L
s
P
p
0 1 1 r
.016 w
.323 .56137 m
.49682 .90252 L
s
P
p
0 1 1 r
.016 w
.677 .56137 m
.50318 .90252 L
s
P
p
0 1 1 r
.016 w
.677 .56137 m
.94774 .29063 L
s
P
p
0 1 1 r
.016 w
.56761 .22469 m
.94578 .28459 L
s
P
p
0 1 1 r
.016 w
.56761 .22469 m
.22646 .05086 L
s
P
p
1 0 .6 r
.004 w
.5 .43277 m
.43239 .22469 L
s
P
p
1 0 .6 r
.004 w
.5 .43277 m
.323 .56137 L
s
P
p
1 0 .6 r
.004 w
.5 .43277 m
.677 .56137 L
s
P
p
1 0 .6 r
.004 w
.5 .43277 m
.56761 .22469 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.24157 .5 m
.17082 .05332 L
s
P
p
0 1 1 r
.016 w
.24157 .5 m
.17082 .94668 L
s
P
p
0 1 1 r
.016 w
.5 .75843 m
.05332 .82918 L
s
P
p
0 1 1 r
.016 w
.5 .75843 m
.94668 .82918 L
s
P
p
0 1 1 r
.016 w
.75843 .5 m
.82918 .94668 L
s
P
p
0 1 1 r
.016 w
.75843 .5 m
.82918 .05332 L
s
P
p
1 0 .6 r
.004 w
.5 .5 m
.24157 .5 L
s
P
p
1 0 .6 r
.004 w
.5 .5 m
.5 .75843 L
s
P
p
1 0 .6 r
.004 w
.5 .5 m
.75843 .5 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.000503103 0.952381 [
[ 0 0 0 0 ]
[ 1 .95339 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95339 L
0 .95339 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.31566 .49856 m
.38641 .05187 L
s
P
p
0 1 1 r
.016 w
.31566 .49856 m
.11035 .90151 L
s
P
p
0 1 1 r
.016 w
.5 .75227 m
.05332 .82302 L
s
P
p
0 1 1 r
.016 w
.5 .75227 m
.94668 .82302 L
s
P
p
0 1 1 r
.016 w
.68434 .49856 m
.88965 .90151 L
s
P
p
0 1 1 r
.016 w
.68434 .49856 m
.61359 .05187 L
s
P
p
1 0 .6 r
.004 w
.5 .55845 m
.31566 .49856 L
s
P
p
1 0 .6 r
.004 w
.5 .55845 m
.5 .75227 L
s
P
p
1 0 .6 r
.004 w
.5 .55845 m
.68434 .49856 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 .6 r
.006 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 .6 r
.006 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 .6 r
.006 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.000722097 0.952381 [
[ 0 0 0 0 ]
[ 1 .95094 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95094 L
0 .95094 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.25659 .49411 m
.32665 .05173 L
s
P
p
0 1 1 r
.016 w
.25659 .49411 m
.05325 .89318 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.05762 .8992 L
s
P
p
0 1 1 r
.016 w
.5 .82914 m
.94238 .8992 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.94675 .89318 L
s
P
p
0 1 1 r
.016 w
.74341 .49411 m
.67335 .05173 L
s
P
p
1 0 0 r
.004 w
.5 .5732 m
.25659 .49411 L
s
P
p
1 0 0 r
.004 w
.5 .5732 m
.5 .82914 L
s
P
p
1 0 0 r
.004 w
.5 .5732 m
.74341 .49411 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.124671 0.952381 [
[ 0 0 0 0 ]
[ 1 .70304 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .70304 L
0 .70304 L
closepath
clip
newpath
p
P
p
0 1 1 r
.016 w
.33673 .13536 m
.63716 .13536 L
s
P
p
0 1 1 r
.016 w
.33673 .13536 m
.051 .04252 L
s
P
p
0 1 1 r
.016 w
.33673 .13536 m
.57978 .31195 L
s
P
p
0 1 1 r
.016 w
.5 .36009 m
.40716 .07436 L
s
P
p
0 1 1 r
.016 w
.5 .36009 m
.5 .66052 L
s
P
p
0 1 1 r
.016 w
.5 .36009 m
.59284 .07436 L
s
P
p
0 1 1 r
.016 w
.66327 .13536 m
.42022 .31195 L
s
P
p
0 1 1 r
.016 w
.66327 .13536 m
.949 .04252 L
s
P
p
0 1 1 r
.016 w
.66327 .13536 m
.36284 .13536 L
s
P
p
1 0 .6 r
.004 w
.5 .18841 m
.33673 .13536 L
s
P
p
1 0 .6 r
.004 w
.5 .18841 m
.5 .36009 L
s
P
p
1 0 .6 r
.004 w
.5 .18841 m
.66327 .13536 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{436, 183},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006d0000]`P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l0]@000?l0]@000?l0]@000?l0]@000?l0
]@000?l0]@000?l0]@000?l0]@000?l0]@0001d000>d000040000k@0000U0003]000010000>d0000
9P000k@0000@0003]00002H000>d00003`000k@0000V0003]000010000>d00009P000k@0000@0003
]00002D000>d000040000k@0000L00007@000k@0000@0003]00002D000>d000040000k@0000V0003
]000010000>d00009P000k@0000?0003]00002H000>d000040000k@0000V0003]000010000>d0000
9@000k@0000@0003]00001`0000M0003]000010000>d00009@000k@0000@0003]00002H000>d0000
40000k@0000V0003]00000l000>d00009P000k@0000@0003]00002H000>d000040000k@0000U0003
]000010000>d0000700001d000>d000040000k@0000U0003]000010000>d00009P000k@0000@0003
]00002H000>d00003`000k@0000V0003]000010000>d00009P000k@0000@0003]00002D000>d0000
40000k@0000L000070000k@0000A0003]00002D000>d00004@000k@0000T0003]000018000>d0000
90000k@0000A0003]00002@000>d00004P000k@0000T0003]000014000>d00009@000k@0000A0003
]00001/0000L0003]000018000>d00008`000k@0000B0003]00002@000>d00004P000k@0000T0003
]000014000>d000090000k@0000B0003]00002@000>d00004P000k@0000S0003]000018000>d0000
6`0001`000>d00004P000k@0000S0003]000018000>d000090000k@0000B0003]00002@000>d0000
4@000k@0000T0003]000018000>d000090000k@0000B0003]00002<000>d00004P000k@0000K0000
70000k@0000B0003]00002<000>d00004P000k@0000T0003]000018000>d000090000k@0000A0003
]00002@000>d00004P000k@0000T0003]000018000>d00008`000k@0000B0003]00001/0000L0003
]000018000>d00008`000k@0000B0003]00002@000>d00004P000k@0000T0003]000014000>d0000
90000k@0000B0003]00002@000>d00004P000k@0000S0003]000018000>d00006`0001`000>d0000
4P000k@0000S0003]000018000>d000090000k@0000B0003]00002@000>d00004@000k@0000T0003
]000018000>d000090000k@0000B0003]00002<000>d00004P000k@0000K00006`000k@0000C0003
]00002<000>d00004`000k@0000R0003]00001@000>d00008P000k@0000C0003]000028000>d0000
50000k@0000R0003]00001<000>d00008`000k@0000C0003]00001X0000K0003]00001<000>d0000
8`000k@0000C0003]000028000>d000050000k@0000R0003]00001<000>d00008P000k@0000D0003
]000028000>d00004`000k@0000S0003]00001<000>d00006P0001/000>d00004`000k@0000S0003
]00001<000>d00008P000k@0000D0003]000028000>d00004`000k@0000R0003]00001@000>d0000
8P000k@0000C0003]00002<000>d00004`000k@0000J00006`000k@0000D0003]000024000>d0000
50000k@0000R0003]00001@000>d00008P000k@0000C0003]000028000>d000050000k@0000R0003
]00001@000>d00008@000k@0000D0003]00001X0000K0003]00001@000>d00008@000k@0000D0003
]000028000>d000050000k@0000R0003]00001<000>d00008P000k@0000D0003]000028000>d0000
50000k@0000Q0003]00001@000>d00006P0001/000>d000050000k@0000Q0003]00001@000>d0000
8P000k@0000D0003]000028000>d00004`000k@0000R0003]00001@000>d00008P000k@0000D0003
]000024000>d000050000k@0000J00006P000k@0000E0003]000024000>d00005@000k@0000P0003
]00001H000>d000080000k@0000E0003]000020000>d00005P000k@0000P0003]00001D000>d0000
8@000k@0000E0003]00001T0000J0003]00001D000>d00008@000k@0000E0003]000020000>d0000
5P000k@0000P0003]00001D000>d000080000k@0000F0003]000020000>d00005@000k@0000Q0003
]00001D000>d00006@0001X000>d00005@000k@0000Q0003]00001D000>d000080000k@0000F0003
]000020000>d00005@000k@0000P0003]00001H000>d000080000k@0000E0003]000024000>d0000
5@000k@0000I00006P000k@0000E0003]000024000>d00005@000k@0000P0003]00001H000>d0000
80000k@0000E0003]000020000>d00005P000k@0000P0003]00001D000>d00008@000k@0000E0003
]00001T0000J0003]00001D000>d00008@000k@0000E0003]000020000>d00005P000k@0000P0003
]00001D000>d000080000k@0000F0003]000020000>d00005@000k@0000Q0003]00001D000>d0000
6@0001X000>d00005P000k@0000O0003]00001H000>d000080000k@0000F0003]000020000>d0000
5@000k@0000P0003]00001H000>d000080000k@0000F0003]00001l000>d00005P000k@0000I0000
6@000k@0000G0003]00001l000>d00005`000k@0000N0003]00001P000>d00007P000k@0000G0003
]00001h000>d000060000k@0000N0003]00001L000>d00007`000k@0000G0003]00001P0000I0003
]00001L000>d00007`000k@0000G0003]00001h000>d000060000k@0000N0003]00001L000>d0000
7P000k@0000H0003]00001h000>d00005`000k@0000O0003]00001L000>d0000600001T00b0E00<P
8@0381D00b0P00<P5P0382000b0E00<P800381H00b0P00<P5@0382400b0E00<P6P0001T000>d0000
0b0?00<P0P000k@0000O0003]00000<P3`03808000>d00007P000k@0000381000b020003]00001h0
00>d00000b0?00<P0P000k@0000N0003]00000<P4003808000>d00007P000k@0000380l00b020003
]00001l000>d00000b0?00<P0P000k@0000H000060000k@0000400<P2@0380H000>d00007@000k@0
000400<P2@0380H000>d000070000k@0000400<P2@0480H000>d000070000k@0000400<P2@0380H0
00>d000070000k@0000400@P2@0380H000>d000070000k@0000400<P2@0380H000>d00007@000k@0
000400<P2@0380H000>d00005`0001P000>d00001`0380<00b090003]00001d000>d00001`0380<0
0b090003]00001`000>d00001`0380<00b0:0003]00001`000>d00001`0380<00b090003]00001`0
00>d0000200380<00b090003]00001`000>d00001`0380<00b090003]00001d000>d00001`0380<0
0b090003]00001L0000G0003]00000/00b0=0003]00001/000>d00002`0380d000>d00006P000k@0
000;00<P3P000k@0000J0003]00000/00b0=0003]00001X000>d0000300380d000>d00006P000k@0
000;00<P3@000k@0000K0003]00000/00b0=0003]00001H0000G0003]00000`000<P000030000k@0
000K0003]00000`000<P000030000k@0000J0003]00000`000<P00003@000k@0000J0003]00000`0
00<P000030000k@0000J0003]00000d000<P000030000k@0000J0003]00000`000<P000030000k@0
000K0003]00000`000<P000030000k@0000F00005P000k@0000=0003800000d000>d00006@000k@0
000=0003800000d000>d000060000k@0000=0003800000h000>d000060000k@0000=0003800000d0
00>d000060000k@0000>0003800000d000>d000060000k@0000=0003800000d000>d00006@000k@0
000=0003800000d000>d00005@0001H000>d00003@000b00000=0003]00001T000>d00003@000b00
000=0003]00001P000>d00003@000b00000>0003]00001P000>d00003@000b00000=0003]00001P0
00>d00003P000b00000=0003]00001P000>d00003@000b00000=0003]00001T000>d00003@000b00
000=0003]00001D0000E0003]00000h000<P00003P000k@0000G0003]00000h000<P00003P000k@0
000F0003]00000h000<P00003`000k@0000F0003]00000h000<P00003P000k@0000F0003]00000l0
00<P00003P000k@0000F0003]00000h000<P00003P000k@0000G0003]00000h000<P00003P000k@0
000D00005@000k@0000>0003800000h000>d00005`000k@0000>0003800000h000>d00005P000k@0
000>0003800000l000>d00005P000k@0000>0003800000h000>d00005P000k@0000?0003800000h0
00>d00005P000k@0000>0003800000h000>d00005`000k@0000>0003800000h000>d0000500001@0
00>d00003`000b00000?0003]00001D000>d00003`000b00000?0003]00001@000>d00003`000b00
000@0003]00001@000>d00003`000b00000?0003]00001@000>d000040000b00000?0003]00001@0
00>d00003`000b00000?0003]00001D000>d00003`000b00000?0003]00001<0000D0003]00000l0
00<P00003`000k@0000E0003]00000l000<P00003`000k@0000D0003]00000l000<P000040000k@0
000D0003]00000l000<P00003`000k@0000D0003]000010000<P00003`000k@0000D0003]00000l0
00<P00003`000k@0000E0003]00000l000<P00003`000k@0000C00004`000k@0000@000380000100
00>d00004`000k@0000@00038000010000>d00004P000k@0000@00038000014000>d00004P000k@0
000@00038000010000>d00004P000k@0000A00038000010000>d00004P000k@0000@000380000100
00>d00004`000k@0000@00038000010000>d00004P0001<000>d000040000b00000@0003]00001<0
00>d000040000b00000@0003]000018000>d000040000b00000A0003]000018000>d000040000b00
000@0003]000018000>d00004@000b00000@0003]000018000>d000040000b00000@0003]00001<0
00>d000040000b00000@0003]0000180000B0003]000014000<P00004@000k@0000A0003]0000140
00<P00004@000k@0000@0003]000014000<P00004P000k@0000@0003]000014000<P00004@000k@0
000@0003]000018000<P00004@000k@0000@0003]000014000<P00004@000k@0000A0003]0000140
00<P00004@000k@0000A00004P000k@0000A00038000014000>d00004@000k@0000A000380000140
00>d000040000k@0000A00038000018000>d000040000k@0000A00038000014000>d000040000k@0
000B00038000014000>d000040000k@0000A00038000014000>d00004@000k@0000A000380000140
00>d00004@00014000>d00004P000b00000B0003]00000l000>d00004P000b00000B0003]00000h0
00>d00004P000b00000C0003]00000h000>d00004P000b00000B0003]00000h000>d00004`000b00
000B0003]00000h000>d00004P000b00000B0003]00000l000>d00004P000b00000B0003]0000100
000A0003]000018000<P00004P000k@0000?0003]000018000<P00004P000k@0000>0003]0000180
00<P00004`000k@0000>0003]000018000<P00004P000k@0000>0003]00001<000<P00004P000k@0
000>0003]000018000<P00004P000k@0000?0003]000018000<P00004P000k@0000@000040000k@0
000@00>d00@P];Bd4P000k@0000=0003]00001000k@0122d];@B0003]00000`000>d00004003]004
8;Bd]1<000>d000030000k@0000@00>d00@P];Bd4P000k@0000<0003]00001400k@0122d];@B0003
]00000`000>d00004003]0048;Bd]18000>d00003@000k@0000@00>d00@P];Bd4P000k@0000?0000
40000k@0000:00Jd1`06]0`000>d00003@000k@0000:00Jd1`06]0`000>d000030000k@0000:00Jd
1`06]0d000>d000030000k@0000:00Jd1`06]0`000>d000030000k@0000;00Jd1`06]0`000>d0000
30000k@0000:00Jd1`06]0`000>d00003@000k@0000:00Jd1`06]0`000>d00003`0000l000>d0000
1@06]1<01[@70003]00000/000>d00001@06]1<01[@70003]00000X000>d00001@06]1<01[@80003
]00000X000>d00001@06]1<01[@70003]00000X000>d00001P06]1<01[@70003]00000X000>d0000
1@06]1<01[@70003]00000/000>d00001@06]1<01[@70003]00000h0000?0003]02d00Fd7`06]003
0;@000`000>d0;@01K@O00Jd00<0]0002`000k@0]005]1l01[@20003]00000X000>d0;@01K@O00Jd
00<0]0002`000k@00006]1l01[@00`2d000;0003]02d00Fd7`06]0030;@000`000>d0;@01K@O00Jd
00<0]0003`0000h00k@[00>d2`03]2/00k@:00>d:`04]0X00k@[00>d2P04]2/00k@:00>d:`03]0/0
0k@[00>d3`000?l0]@000?l0]@000?l0]@000?l0]@000?l0]@000?l0]@000?l0]@000?l0]@000?l0
]@000?l0]@000?l0]@000?l0]@0005X000>d00003@000k@0003o04P0000K0003]00001@000>d0000
9@000k@0000=0003]00002L000>d000040000k@0000V0003]`0000l000>g00009P000k@0000@0003
]00002H000>d000040000k@0000U0003]000010000>d0000700001/000>d000050000k@0000U0003
]00000d000>d00009`000k@0000@0003]00002H000>g00003`000kL0000V0003]000010000>d0000
9P000k@0000@0003]00002D000>d000040000k@0000L00006`000k@0000D0003]00002D000>d0000
3@000k@0000W0003]000010000>d00009P000kL0000?0003]`0002H000>d000040000k@0000V0003
]000010000>d00009@000k@0000@0003]00001`0000K0003]00001@000>d000090000k@0000>0003
]00002L000>d000040000k@0000V0003]`0000l000>g00009P000k@0000@0003]00002H000>d0000
40000k@0000U0003]000010000>d0000700001/000>d000050000k@0000T0003]00000l000>d0000
9@000k@0000B0003]00002@000>g00004@000kL0000T0003]000018000>d000090000k@0000A0003
]00002D000>d00004@000k@0000K00006`000k@0000D0003]00002@000>d00003`000k@0000U0003
]000018000>d000090000kL0000A0003]`0002@000>d00004P000k@0000T0003]000018000>d0000
8`000k@0000B0003]00001/0000K0003]00001@000>d000090000k@0000?0003]00002D000>d0000
4P000k@0000T0003]`00014000>g000090000k@0000B0003]00002@000>d00004P000k@0000S0003
]000018000>d00006`0001/000>d000050000k@0000T0003]00000l000>d00009@000k@0000B0003
]00002@000>g00004@000kL0000T0003]000018000>d000090000k@0000B0003]00002<000>d0000
4P000k@0000K00006`000k@0000D0003]00002@000>d00003`000k@0000U0003]000018000>d0000
90000kL0000A0003]`0002@000>d00004P000k@0000T0003]000018000>d00008`000k@0000B0003
]00001/0000K0003]00001@000>d00008`000k@0000@0003]00002D000>d00004P000k@0000T0003
]`00014000>g000090000k@0000B0003]00002@000>d00004P000k@0000S0003]000018000>d0000
6`0001/000>d000050000k@0000S0003]000010000>d000090000k@0000D0003]000028000>g0000
4`000kL0000R0003]00001@000>d00008P000k@0000C0003]00002<000>d00004`000k@0000J0000
6`000k@0000D0003]00002<000>d000040000k@0000T0003]00001@000>d00008P000kL0000C0003
]`00028000>d000050000k@0000R0003]00001<000>d00008`000k@0000C0003]00001X0000K0003
]00001@000>d00008`000k@0000A0003]00002<000>d000050000k@0000R0003]`0001<000>g0000
8P000k@0000D0003]000028000>d00004`000k@0000S0003]00001<000>d00006P0001/000>d0000
50000k@0000S0003]000014000>d00008`000k@0000D0003]000028000>g00004`000kL0000R0003
]00001@000>d00008P000k@0000D0003]000024000>d000050000k@0000J00006`000k@0000D0003
]00002<000>d00004@000k@0000S0003]00001@000>d00008P000kL0000C0003]`00028000>d0000
50000k@0000R0003]00001@000>d00008@000k@0000D0003]00001X0000K0003]00001@000>d0000
8`000k@0000A0003]00002<000>d000050000k@0000R0003]`0001<000>g00008P000k@0000D0003
]000028000>d000050000k@0000Q0003]00001@000>d00006P0001/000>d000050000k@0000R0003
]000018000>d00008P000k@0000F0003]000020000>g00005@000kL0000P0003]00001H000>d0000
80000k@0000E0003]000024000>d00005@000k@0000I00006`000k@0000D0003]000028000>d0000
4P000k@0000R0003]00001H000>d000080000kL0000E0003]`00020000>d00005P000k@0000P0003
]00001D000>d00008@000k@0000E0003]00001T0000K0003]00001@000>d00008P000k@0000B0003
]000028000>d00005P000k@0000P0003]`0001D000>g000080000k@0000F0003]000020000>d0000
5@000k@0000Q0003]00001D000>d00006@0001/000>d000050000k@0000R0003]000018000>d0000
8P000k@0000F0003]000020000>g00005@000kL0000P0003]00001H000>d000080000k@0000E0003
]000024000>d00005@000k@0000I00006`000k@0000D0003]000028000>d00004P000k@0000R0003
]00001H000>d000080000kL0000E0003]`00020000>d00005P000k@0000P0003]00001D000>d0000
8@000k@0000E0003]00001T0000K0003]00001@000>d00008P000k@0000C0003]000024000>d0000
5P000k@0000P0003]`0001D000>g000080000k@0000F0003]000020000>d00005P000k@0000O0003
]00001H000>d00006@0001/00R0D008P8`000k@0000D0003]000020000>d000060000k@0000N0003
]`0001L000>g00007P000k@0000H0003]00001h000>d00005`000k@0000O0003]00001L000>d0000
600001/000>d02000R0>00<P00<0]0008P000k@0000D0003]000020000>d000060000k@0000N0003
]`0001L000>g00007P000k@0000H0003]00001h000>d00005`000k@0000O0003]00001L000>d0000
600001X000>d00000`0380P00b050003]00002000b0C008P8P0381H00b0P00<P5@0382000b0F00<P
800381D00b0Q00<P5@0381X0000I0003]00000L00b0200<P2@000k@0000O0003]00000<P3@038003
0;@0024000>d00000b0@00<P0P000k@0000N0003]`0000<P3`03808000>g00007P000k@000038100
0b020003]00001h000>d00000b0?00<P0P000k@0000O0003]00000<P3`03808000>d0000600001P0
00>d00002`0280`000>d00007P000k@0000400<P1`0380D000>d00007P000k@0000400<P2@0480H0
00>d000070000kL0000400<P2@0380H000>g000070000k@0000400@P2@0380H000>d000070000k@0
000400<P2@0380H000>d00007@000k@0000400<P2@0380H000>d00005`0001P000>d00002`000b00
000<0003]00001d000>d00001`038004020P80P000>d00007P000k@0000700<P0`0380X000>d0000
70000kL0000700<P0`0380T000>g000070000k@0000800<P0`0380T000>d000070000k@0000700<P
0`0380T000>d00007@000k@0000700<P0`0380T000>d00005`0001L000>d000030000b00000=0003
]00001/000>d00002`000b00000:0003]00001`000>d00002`0380h000>d00006P000kL0000;00<P
3@000kL0000J0003]00000`00b0=0003]00001X000>d00002`0380d000>d00006`000k@0000;00<P
3@000k@0000F00005P000k@0000=0003800000h000>d00006P000k@0000;0003800000X000>d0000
70000k@0000<0003800000d000>d00006P000kL0000<0003800000`000>g00006P000k@0000=0003
800000`000>d00006P000k@0000<0003800000`000>d00006`000k@0000<0003800000`000>d0000
5P0001D000>d00003P000b00000>0003]00001T000>d000030000b00000;0003]00001X000>d0000
3@000b00000>0003]00001P000>g00003@000b00000=0003]`0001P000>d00003P000b00000=0003
]00001P000>d00003@000b00000=0003]00001T000>d00003@000b00000=0003]00001D0000D0003
]00000l000<P00003`000k@0000H0003]00000`000<P000030000k@0000I0003]00000d000<P0000
3P000k@0000H0003]`0000d000<P00003@000kL0000H0003]00000h000<P00003@000k@0000H0003
]00000d000<P00003@000k@0000I0003]00000d000<P00003@000k@0000E000050000k@0000?0003
8000010000>d00005P000k@0000=0003800000`000>d000060000k@0000>0003800000l000>d0000
5P000kL0000>0003800000h000>g00005P000k@0000?0003800000h000>d00005P000k@0000>0003
800000h000>d00005`000k@0000>0003800000h000>d0000500001<000>d000040000b00000@0003
]00001H000>d00003@000b00000=0003]00001L000>d00003P000b00000?0003]00001H000>g0000
3P000b00000>0003]`0001H000>d00003`000b00000>0003]00001H000>d00003P000b00000>0003
]00001L000>d00003P000b00000>0003]00001@0000B0003]000014000<P00004@000k@0000D0003
]00000h000<P00003@000k@0000F0003]00000l000<P000040000k@0000D0003]`0000l000<P0000
3`000kL0000D0003]000010000<P00003`000k@0000D0003]00000l000<P00003`000k@0000E0003
]00000l000<P00003`000k@0000C00004@000k@0000B00038000018000>d00004`000k@0000>0003
800000h000>d000050000k@0000@00038000014000>d00004P000kL0000@00038000010000>g0000
4P000k@0000A00038000010000>d00004P000k@0000@00038000010000>d00004`000k@0000@0003
8000010000>d00004P00014000>d00004P000b00000C0003]000014000>d00003`000b00000>0003
]00001@000>d000040000b00000A0003]000018000>g000040000b00000@0003]`00018000>d0000
4@000b00000@0003]000018000>d000040000b00000@0003]00001<000>d000040000b00000@0003
]0000180000@0003]00001<000<P00004`000k@0000A0003]00000l000<P00003`000k@0000B0003
]000014000<P00004P000k@0000@0003]`00014000<P00004@000kL0000@0003]000018000<P0000
4@000k@0000@0003]000014000<P00004@000k@0000A0003]000014000<P00004@000k@0000A0000
3`000k@0000C0004]22d]1@000>d00003`000k@0000@0003800000l000>d00004P000k@0000A0003
8000018000>d000040000kL0000A00038000014000>g000040000k@0000B00038000014000>d0000
40000k@0000A00038000014000>d00004@000k@0000A00038000014000>d00004@0000h000>d0000
4@03]0@00k@B0003]00000h000>d000040000b00000@0003]000010000>d00004P000b00000C0003
]00000h000>g00004P000b00000B0003]`0000h000>d00004`000b00000B0003]00000h000>d0000
4P000b00000B0003]00000l000>d00004P000b00000B0003]0000100000O00>d2P03]1l000>d0000
3P03]0048;Bd]0l000>d000040000k@0000B0003800001<000>d00003P000kL0000B000380000180
00>g00003P000k@0000C00038000018000>d00003P000k@0000B00038000018000>d00003`000k@0
000B00038000018000>d0000400001`00k@@00>d70000k@0000800Jd1`06]0X000>d00003P000k@0
000C0003800001@000>d000030000kL0000C0003800001<000>g000030000k@0000D0003800001<0
00>d000030000k@0000C0003800001<000>d00003@000k@0000C0003800001<000>d00003`0001T0
0k@F00>d60000k@0000300Jd4`06]0D000>d00003@000k@0000?00Bd00<P];@00[@B0003]00000`0
00>g00003`04]`038;Ng00:g4@000kL0000<0003]00001001;@00b2d]002]14000>d000030000k@0
000?00Bd00<P];@00[@A0003]00000d000>d00003`04]0038;Bd00:d4@000k@0000?00005P03]1`0
0k@E00Jd7`06]0h000>d00002008]0T02;@;0003]00000X000>g00002008]`T02;L:0003]`0000X0
00>d00002@08]0T02;@:0003]00000X000>d00002008]0T02;@:0003]00000/000>d00002008]0T0
2;@:0003]00000h0000C00>d8P03]0l00k@[00>d2`000k@00008]1T02;@30003]00000X000>g0000
2;LI00Rg0P000kL0000:0004]00000Rd6@08]08000>d00002P000k@00008]1T02;@20003]00000/0
00>d00002;@I00Rd0P000k@0000>00004P000k@0000V0003]00000h000>d0000:@000k@0000:00Bd
:@05]0X01;LY00Bg2P05]2T01;@:00Bd:@04]0/01;@Y00Bd3`0004/000>d0000:`000k@0003o03T0
003o0;D0003o0;D0003o0;D0003o0;D0003o0;D0003o0;D0003o0;D0003o0;D0003o0;D0003o0;D0
003o0;D0002<0003]000020000>d0000o`0300008P000b<0000500038`0002H00[@K00:d6P000k@0
000P0003]000024000>d00002@000k@0000Y0003]000010000>d00009P000k@0000@0003]00005L0
000R00038`0000D000<S0000:002]1L00[@L0003]000020000>d00008@000k@000090003]00002T0
00>d000040000k@0000V0003]000010000>d0000E`00028000<S00001@000b<0000Z00:d4`02]1h0
00>d000080000k@0000Q0003]00000T000>d0000:@000k@0000@0003]00002H000>d000040000k@0
001G00008P000b<0000600038`0002/00[@?00:d80000k@0000O0003]000028000>d00002@000k@0
000Y0003]000010000>d00009P000k@0000@0003]00005L0000R00038`0000H000<S0000;@02]0X0
0k@S0003]00001h000>d00008@000k@0000;0003]00002L000>d00004P000k@0000T0003]0000140
00>d0000E`00028000<S00001P000b<0000_00:d1P02]2H000>d00007P000k@0000Q0003]00000/0
00>d00009`000k@0000B0003]00002@000>d00004P000k@0001F00008@000b<0000700038`000340
0[@200:d:0000k@0000N0003]000024000>d00002`000k@0000W0003]000018000>d000090000k@0
000B0003]00001D00k@]00:d3`00024000<S00001`000b<0000c00:d:P000k@0000N0003]0000240
00>d00002`000k@0000W0003]000018000>d000090000k@0000B0003]00001P00k@W00>d4@000240
00<S000020000b<0000`00:d0P02]2P000>d00007P000k@0000Q0003]00000/000>d00009`000k@0
000B0003]00002@000>d00004P000k@0000K00>d2`000k@000070003]00000T00k@D00008@000b<0
000800038`0002d00[@00b00000400048;Bd]2@000>d00007@000k@0000R0003]00000/000>d0000
9`000k@0000B0003]00002@000>d00004P000k@0000N00>d20000k@000070003]00000H00k@G0000
8@000k@000080003]00002P01K@20003800000@000@P00001K@O0003]00001d000>d00008@000k@0
000=0003]00002D000>d000050000k@0000R0003]00001<000>d00008@03]0D000>d00001`000k@0
000300>d6P00024000>d000020000k@0000S00Fd20000b0000030003800000H01K@J0003]00001d0
00>d00008@000k@0000=0003]00002D000>d000050000k@0000R0003]00001<000>d000090001;@P
820>]08P00>d00006`00024000>d000020000k@0000N00Fd3@000b0000020003800000`01K@F0003
]00001`000>d00008@000k@0000=0003]00002D000>d000050000k@0000R0003]00001<000>d0000
9`001;@P82070004]20P8200000P0003]00000T000>d00006`03]18000<P00000P000b00000A00>d
4`000k@0000L0003]000024000>d00003@000k@0000U0003]00001@000>d00008P000k@0000D0003
]00002L000>d0;@00b0200<P0[@Q000080000k@0000:0003]00001X000>d00004`001B00000P01@0
00>d00004P000k@0000L0003]000024000>d00003@000k@0000U0003]00001@000>d00008P000k@0
000D0003]00002P00k@2008P00<0];@08`00020000>d00002P000k@0000K0003]000018000DP0000
800C0003]00001<000>d00006`000k@0000R0003]00000d000>d00009@000k@0000D0003]0000280
00>d000050000k@0000Z0004]000808000>d00008P00020000>d00002P000k@0000L0003]0000140
00@P000P4`000k@0000D0003]00001/000>d00008@000k@0000?0003]00002<000>d00005P000k@0
000P0003]00001D000>d0000:P02]003022d00:d9000020000>d00002P000k@0000M0003]0000140
00<P02004P000k@0000E0003]00001/000>d00008@000k@0000?0003]00002<000>d00005P000k@0
000P0003]00001D000>d0000:`02]003802d02D0000O0003]00000/000>d00007P000k@0000@0003
800P014000>d00005P000k@0000K0003]000024000>d00003`000k@0000S0003]00001H000>d0000
80000k@0000E0003]00002/00[@00b2d]00U00007`000k@0000;0003]00001l000>d00003`000b00
800@0003]00001L000>d00006`000k@0000Q0003]00000l000>d00008`000k@0000F0003]0000200
00>d00005@000k@0000Z00:d00@0802d9@0001l000>d00002`000k@0000P0003]00000l000<P0000
3P000k@0000I0003]00001X000>d00008@000k@0000?0003]00002<000>d00005P000k@0000P0003
]00001D000>d0000:@002;@00;@P]02d900001l000>d000030000k@0000P0003]00000d00b0>0003
]00001X000>d00006@000k@0000R0003]00000l000>d00008`000k@0000F0003]000020000>d0000
5P000k@0000W0007]0000;@P]0020003]0000240000O0003]00000`000>d00008@000k@0000;0005
8000020030000k@0000K0003]00001T000>d00008@000k@0000A0003]000024000>d000060000k@0
000N0003]00001L000>d0000:`000k@P]00V00007P000k@0000=0003]000028000>d0000200280D0
00<P000020000k@0000L01dP8`000k@0000A0003]000024000>d000060000k@0000N0003]00001L0
00>d0000;0000b00000U00007P0280d00R0U0003]00000H000<P00001P0280L000>d00007@000k@0
000;0003800000/000>d00008@0281400R0S00<P5P0382000b<E00<S;P000b00000U00007P000k@0
800280L00b000`2d000U0003]00000@000<P00002@000b0000030003]00001h000>d00002`000b00
000;0003]000024000>d02000R0;00<P00<0]0008P000k@0000381000b020003]00001h000>d0000
0b<?00<S0P000k@0000/0003]00002D0000M0003]00000<00b00100P82050003]00002@000Bd0000
0R0=000580000;@08@000k@0000;0003800000/000>d000080000k@00003008P1`0280D000>d0000
7`000k@0000400@P2@0380H000>d000070000k@0000400<S2@038`H000>d0000:`000k@0000U0000
7@000k@000060003800000H000>d00009@000k@0800@0003802d028000>d00002`000b00000<0003
]00001l000>d00001@038004020P80L000>d00007`000k@0000800<P0`0380T000>d000070000k@0
000700<S0`038`T000>d0000:`000k@0000U000070000k@000070003800000L000>d00009@000b00
000@00038000020000>d000030000b00000<0003]00001h000>d00002@000b0000090003]00001d0
00>d0000300380d000>d00006P000k@0000;00<S3@000k@0000Z0003]00002D0000L0003]00000L0
00<P00001`000k@0000U0003]000010000>d000080000k@0000<0003800000`000>d00007P000k@0
00090003800000T000>d00007@000k@0000=0003800000`000>d00006P000k@0000<00038`0000`0
00>d0000:P000k@0000U00006`000k@000080003800000P000>d00009@000k@0000>0003]0000240
00>d000030000b00000<0003]00001d000>d00002P000b00000:0003]00001/000>d00003P000b00
000=0003]00001P000>d00003@000b<0000=0003]00002T000>d00009@0001/000>d000020000b00
00090003]00002@000>d00003P000k@0000Q0003]00000`000<P000030000k@0000M0003]00000X0
00<P00002P000k@0000K0003]00000h000<P00003@000k@0000H0003]00000d000<S00003@000k@0
000Y0003]00002D0000K0003]00000P000<P00002@000k@0000U0003]00000`000>d00008P000k@0
000<0003800000`000>d000070000k@0000;0003800000/000>d00006@000k@0000?0003800000h0
00>d00005P000k@0000>00038`0000h000>d0000:0000k@0000U00006P000k@000090003800000X0
00>d00009@000k@0000;0003]000028000>d000030000b00000=0003]00001/000>d00002`000b00
000;0003]00001T000>d00003`000b00000>0003]00001H000>d00003P000b<0000>0003]00002P0
00>d00009@0001X000>d00002@000b00000:0003]00002D000>d00002P000k@0000S0003]00000`0
00<P00003@000k@0000J0003]00000`000<P000030000k@0000G0003]000010000<P00003`000k@0
000D0003]00000l000<S00003`000k@0000W0003]00002D0000I0003]00000L00k@00b2d]002]0T0
00>d00009@000k@000090003]00002<000>d000030000b00000=0003]00001X000>d000030000b00
000<0003]00001L000>d000040000b00000?0003]00001@000>d00003`000b<0000?0003]00002L0
00>d00009@0001T000>d00001k@800Nd0P000k@0000U0003]00000P000>d00008`000k@0000=0003
800000d000>d00006@000k@0000=0003800000d000>d00005@000k@0000A00038000010000>d0000
4P000k@0000@00038`00010000>d00009P000k@0000U00005P028`Bd5P04]08S9@000k@000070003
]00002<000>d00002P03]0048;Bd]0`000>d00006@000k@0000=0003800000d000>d00005@000k@0
000A00038000010000>d00004P000k@0000@00038`00010000>d00009P000k@0000U00004@058`80
00<S00006P000b<000058b0000>d00001P000k@0000T0003]00000@01[@700Jd1P000k@0000H0003
]00000/00k@0122d];@=0003]00001<000>d00004P000b00000A0003]000010000>d00004@000b<0
000A0003]00002D000>d00009@0000h00b<600038`0001`000<S000010038ah000>d00001@000k@0
000T00Nd4`08]1T000>d00001@06]0L01[@70003]00001<000>d00004P000b00000A0003]0000100
00>d00004@000b<0000A0003]00002D000>d00009@0001L000<S000070000b<0000U0003]00000@0
00>d00008006]2001[@C0003]00000Jd4`06]08000>d00004@000k@0000C00038000018000>d0000
3P000k@0000B00038`00018000>d000090000k@0000U00005P000b<0000N00038`0002D000>d0000
0`000k@0000M00>d1@000k@0000N0003]00000<00k@=00Jd7`06]10000>d00004`000b00000B0003
]00000h000>d00004P000b<0000B0003]00004`0000E00038`0001l000<S00009P001K@0002d02P0
00>d00007P000k@0000@00>d0P000k@0000S0003]00000>d30000k@0000A00>d00@P];Bd4P000k@0
000<0003]00001000k@012>d];@B0003]00004/0000E00038`0001l000<S00009P001K@0002d02P0
00>d00007P000k@0000E0003]00002<000>d00003`000k@0000;00Jd1`06]0`000>d000030000k@0
000:00Jd1`06]0`000>d0000B`0001@000<S00008@000b<0000V0003]02d02P000>d00007`000k@0
000D0003]00002D000>d00003@000k@0000600Jd4`06]0L000>d00002P000k@0000500Jd4`06]0L0
00>d0000BP0001@000<S00008@000b<0000V0003]02d02P000>d000080000k@0000C0003]00002D0
00>d00003@000k@00006]1l01[@00`2d000;0003]02d00Fd7`06]0030;@004/0000C00038`0002<0
00<S00009P000k@0000W0003]000020000>d00004P000k@0000W0003]00000/01;@[00>d2P03]2/0
0kA;0000S0000k@0000P0003]0000?l00`000?l0]@000?l0]@000?l0]@000?l0]@000?l0]@000?l0
]@000?l0]@000001\
\>"],
  ImageRangeCache->{{{0, 435}, {182, 0}} -> {-0.198395, -0.0737002, 0.0170042,
   0.0170042}, {{11.625, 65.8125}, {177.625, 123.5}} -> {-0.250267, -0.109174,
   0.0193774, 0.0193774}, {{71.25, 125.375}, {177.625, 123.5}} -> {-1.40724,
   -0.109877, 0.0193997, 0.0193997}, {{130.812, 185}, {177.625, 123.5}} ->
   {-2.55981, -0.109174, 0.0193774, 0.0193774}, {{190.375, 244.562}, {177.625,
   123.5}} -> {-3.71397, -0.109174, 0.0193774, 0.0193774}, {{250, 304.125}, {
  177.625, 123.5}} -> {-4.87494, -0.109877, 0.0193997, 0.0193997}, {{309.562, 
  363.75}, {177.625, 123.5}} -> {-6.02351, -0.109174, 0.0193774, 0.0193774},
   {{369.125, 423.312}, {177.625, 123.5}} -> {-7.17767, -0.109174, 0.0193774, 
  0.0193774}, {{11.625, 65.8125}, {118.062, 63.875}} -> {-0.250267, -1.26395, 
  0.0193774, 0.0193774}, {{71.25, 125.375}, {118.062, 63.875}} -> {-1.40724,
   -1.26598, 0.0193997, 0.0193997}, {{130.812, 185}, {118.062, 63.875}} ->
   {-2.55981, -1.26394, 0.0193774, 0.0193774}, {{190.375, 244.562}, {118.062, 
  63.875}} -> {-3.71397, -1.26394, 0.0193774, 0.0193774}, {{250, 304.125}, {
  118.062, 63.875}} -> {-4.87494, -1.26598, 0.0193997, 0.0193997}, {{309.562, 
  363.75}, {118.062, 63.875}} -> {-6.02351, -1.26394, 0.0193774, 0.0193774},
   {{369.125, 423.312}, {118.062, 63.875}} -> {-7.17767, -1.26394, 0.0193774, 
  0.0193774}, {{11.625, 65.8125}, {58.5, 4.3125}} -> {-0.250267, -2.41811, 
  0.0193774, 0.0193774}, {{71.25, 125.375}, {58.5, 4.3125}} -> {-1.40724,
   -2.42148, 0.0193997, 0.0193997}, {{130.812, 185}, {58.5, 4.3125}} ->
   {-2.55981, -2.41811, 0.0193774, 0.0193774}, {{190.375, 244.562}, {58.5, 
  4.3125}} -> {-3.71397, -2.41811, 0.0193774, 0.0193774}, {{250, 304.125}, {
  58.5, 4.3125}} -> {-4.87494, -2.42148, 0.0193997, 0.0193997}, {{309.562, 
  363.75}, {58.5, 4.3125}} -> {-6.02351, -2.41811, 0.0193774, 0.0193774}, {{
  369.125, 423.312}, {58.5, 4.3125}} -> {-7.17767, -2.41811, 0.0193774, 
  0.0193774}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  GraphicsArray  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Breeding of Biomorphs", "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
We start our interactive evolution from a randomly generated \
biomorph vector.\
\>", "Text",
  CellTags->"breeding experiment"],

Cell[CellGroupData[{

Cell[BoxData[
    \(evolveBiomorphs[randomBiomorphParams[]]\)], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Gen 1\n{{4, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \
\n  {3, 3, 2, 5, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  \
{3, 2, 1, 5, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, \
2, 2, 6, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, \
2, 5, 9, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, \
5, 8, 2, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, \
8, 1, 1, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, \
1, 2, 9, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, \
2, 8, 9, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, \
8, 8, 9, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, \
8, 8, 8, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, \
8, 7, 6, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, 8, \
7, 1, 7, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, \
1, 6, 3, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 1, \
6, 2, 8, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 1, 6, \
2, 9, 7, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, \
9, 6, 6, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, \
6, 1, 1, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, \
1, 2, 7, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, \
2, 6, 9, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, \
10, 6}}\nGen. 1, selected bio: \n{3, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 6, 6, 2, \
9, 6, 1, 2, 6, 10, 7}\nGen 2\n{{2, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, \
6, 1, 2, 6, 10, 7}, \n \n  {3, 1, 2, 5, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, \
1, 2, 6, 10, 7}, \n \n  {3, 2, 3, 5, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, \
2, 6, 10, 7}, \n \n  {3, 2, 2, 4, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, \
6, 10, 7}, \n \n  {3, 2, 2, 5, 7, 1, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, \
10, 7}, \n \n  {3, 2, 2, 5, 8, 11, 2, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, \
7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \
\n \n  {3, 2, 2, 5, 8, 1, 2, 9, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n\
  {3, 2, 2, 5, 8, 1, 2, 8, 7, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  \
{3, 2, 2, 5, 8, 1, 2, 8, 8, 7, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, \
2, 2, 5, 8, 1, 2, 8, 8, 8, 6, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, \
2, 5, 8, 1, 2, 8, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, \
5, 8, 1, 2, 8, 8, 8, 7, 1, 7, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, \
8, 1, 2, 8, 8, 8, 7, 1, 6, 1, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, \
1, 2, 8, 8, 8, 7, 1, 6, 2, 10, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, \
2, 8, 8, 8, 7, 1, 6, 2, 9, 5, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, \
8, 8, 8, 7, 1, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, \
8, 8, 7, 1, 6, 2, 9, 6, 1, 3, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, \
8, 7, 1, 6, 2, 9, 6, 1, 2, 7, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, 8, \
7, 1, 6, 2, 9, 6, 1, 2, 6, 9, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 1, \
6, 2, 9, 6, 1, 2, 6, 10, 6}}\nGen. 2, selected bio: \n{3, 2, 2, 5, 8, 1, 3, \
8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}\nGen 3\n{{2, 2, 2, 5, 8, 1, 3, 8, \
8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 3, 2, 5, 8, 1, 3, 8, 8, \
8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 1, 5, 8, 1, 3, 8, 8, 8, \
7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 6, 8, 1, 3, 8, 8, 8, 7, \
1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 9, 1, 3, 8, 8, 8, 7, 1, \
6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 2, 3, 8, 8, 8, 7, 1, 6, \
2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 1, 6, 2, \
9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 7, 8, 8, 7, 1, 6, 2, 9, \
6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 7, 8, 7, 1, 6, 2, 9, 6, \
1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 7, 7, 1, 6, 2, 9, 6, 1, \
2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 8, 1, 6, 2, 9, 6, 1, 2, \
6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 6, 6, 2, 9, 6, 1, 2, 6, \
10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 7, 2, 9, 6, 1, 2, 6, 10, \
7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 3, 9, 6, 1, 2, 6, 10, 7}, \
\n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 10, 6, 1, 2, 6, 10, 7}, \n \
\n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 7, 1, 2, 6, 10, 7}, \n \n  \
{3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {3, \
2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 1, 6, 10, 7}, \n \n  {3, 2, \
2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 7, 10, 7}, \n \n  {3, 2, 2, \
5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 9, 7}, \n \n  {3, 2, 2, 5, 8, \
1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 6}}\nGen. 3, selected bio: \n\
{3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 6, 6, 2, 9, 6, 1, 2, 6, 10, 7}\nGen 4\n{{4, \
2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 1, \
2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 1, \
5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 6, \
8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 7, \
1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 2, \
3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 4, \
8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 9, \
8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 7, \
8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 9, \
7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 8, \
1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, \
6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 5, \
2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 3, \
9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 10, \
6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 7, \
1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 2, \
2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 1, \
6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 7, \
10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 9, \
7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 6}}\n\
Gen. 4, selected bio: \n{3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 1, \
2, 6, 10, 7}\nGen 5\n{{4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, \
6, 10, 7}, \n \n  {3, 1, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, \
10, 7}, \n \n  {3, 2, 3, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, \
7}, \n \n  {3, 2, 2, 4, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \
\n \n  {3, 2, 2, 5, 7, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n\
  {3, 2, 2, 5, 8, 11, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  \
{3, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, \
2, 2, 5, 8, 1, 3, 9, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, \
2, 5, 8, 1, 3, 8, 7, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, \
5, 8, 1, 3, 8, 8, 7, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, \
8, 1, 3, 8, 8, 8, 8, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, \
1, 3, 8, 8, 8, 7, 1, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, \
3, 8, 8, 8, 7, 2, 7, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, \
8, 8, 8, 7, 2, 6, 1, 9, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, \
8, 8, 7, 2, 6, 2, 10, 6, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, \
8, 7, 2, 6, 2, 9, 5, 1, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, \
7, 2, 6, 2, 9, 6, 6, 2, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, \
2, 6, 2, 9, 6, 1, 1, 6, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, \
6, 2, 9, 6, 1, 2, 7, 10, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, \
2, 9, 6, 1, 2, 6, 1, 7}, \n \n  {3, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, \
6, 1, 2, 6, 10, 8}}\nGen. 5, selected bio: \n{4, 2, 2, 5, 8, 1, 3, 8, 8, 8, \
7, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}\nGen 6\n{{1, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, \
2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {4, 1, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, \
6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {4, 2, 3, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, \
2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {4, 2, 2, 4, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, \
9, 6, 1, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 9, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, \
6, 1, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 2, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, \
1, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 2, 8, 8, 8, 7, 2, 6, 2, 9, 6, 1, \
2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 9, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, \
6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, 9, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, \
10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, 8, 9, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, \
7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 6, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \
\n \n  {4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 3, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n\
  {4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 5, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  \
{4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 3, 9, 6, 1, 2, 6, 10, 7}, \n \n  {4, \
2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 10, 6, 1, 2, 6, 10, 7}, \n \n  {4, 2, \
2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 7, 1, 2, 6, 10, 7}, \n \n  {4, 2, 2, \
5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, \
8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 1, 3, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, \
1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 5, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, \
3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, 9, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, \
8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, 8}}\nGen. 6, selected bio: \n{4, 2, 2, \
5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}\nGen 7\n{{1, 2, 2, 5, \
8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, \
1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 3, 5, 8, 1, \
3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 6, 8, 1, 3, \
8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 7, 1, 3, 8, \
8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 2, 3, 8, 8, \
8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 8, 8, 8, \
7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 7, 8, 8, 7, \
2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, 7, 8, 7, 2, \
6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, 8, 7, 7, 2, 6, \
2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 8, 2, 6, 2, \
9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 3, 6, 2, 9, \
6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 7, 2, 9, 6, \
2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 1, 9, 6, 2, \
2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 8, 6, 2, 2, \
6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 5, 2, 2, 6, \
10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 3, 2, 6, 10, \
7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 1, 6, 10, 7}, \
\n \n  {4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 5, 10, 7}, \n \n\
  {4, 2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 9, 7}, \n \n  {4, \
2, 2, 5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 8}}\nGen. 7, \
selected bio: \n{4, 2, 2, 5, 8, 1, 4, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, \
7}\nGen 8\n{{1, 2, 2, 5, 8, 1, 4, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \
\n \n  {4, 3, 2, 5, 8, 1, 4, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n\
  {4, 2, 1, 5, 8, 1, 4, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  \
{4, 2, 2, 4, 8, 1, 4, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, \
2, 2, 5, 7, 1, 4, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, \
2, 5, 8, 2, 4, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, \
5, 8, 1, 3, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, \
8, 1, 4, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, \
1, 4, 8, 9, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, \
4, 8, 8, 9, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, \
8, 8, 8, 8, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 8, \
8, 8, 7, 3, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 8, 8, \
8, 7, 2, 5, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 8, 8, 8, \
7, 2, 6, 3, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 8, 8, 8, 7, \
2, 6, 2, 8, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 8, 8, 8, 7, 2, \
6, 2, 9, 5, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 8, 8, 8, 7, 2, 6, \
2, 9, 6, 3, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 8, 8, 8, 7, 2, 6, 2, \
9, 6, 2, 1, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 8, 8, 8, 7, 2, 6, 2, 9, \
6, 2, 2, 5, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 8, 8, 8, 7, 2, 6, 2, 9, 6, \
2, 2, 6, 9, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, \
6, 10, 6}}\nGen. 8, selected bio: \n{4, 2, 2, 5, 8, 1, 4, 9, 8, 8, 7, 2, 6, \
2, 9, 6, 2, 2, 6, 10, 7}\nGen 9\n{{3, 2, 2, 5, 8, 1, 4, 9, 8, 8, 7, 2, 6, 2, \
9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 4, 9, 8, 8, 7, 2, 6, 2, 9, \
6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 1, 5, 8, 1, 4, 9, 8, 8, 7, 2, 6, 2, 9, 6, \
2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 6, 8, 1, 4, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, \
2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 9, 1, 4, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, \
6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 11, 4, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, \
10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 3, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, \
7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 10, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \
\n \n  {4, 2, 2, 5, 8, 1, 4, 9, 7, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n\
  {4, 2, 2, 5, 8, 1, 4, 9, 8, 7, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  \
{4, 2, 2, 5, 8, 1, 4, 9, 8, 8, 6, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, \
2, 2, 5, 8, 1, 4, 9, 8, 8, 7, 1, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, \
2, 5, 8, 1, 4, 9, 8, 8, 7, 2, 7, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, \
5, 8, 1, 4, 9, 8, 8, 7, 2, 6, 1, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, \
8, 1, 4, 9, 8, 8, 7, 2, 6, 2, 8, 6, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, \
1, 4, 9, 8, 8, 7, 2, 6, 2, 9, 7, 2, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, \
4, 9, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, \
9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 3, 6, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 9, \
8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 7, 10, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 9, 8, \
8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 2, 2, 5, 8, 1, 4, 9, 8, 8, 7, \
2, 6, 2, 9, 6, 2, 2, 6, 10, 6}}\nGen. 9, selected bio: \n{4, 3, 2, 5, 8, 1, \
4, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}\nGen 10\n{{1, 3, 2, 5, 8, 1, 4, \
9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 2, 5, 8, 1, 4, 9, \
8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 1, 5, 8, 1, 4, 9, 8, \
8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 6, 8, 1, 4, 9, 8, 8, \
7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 7, 1, 4, 9, 8, 8, 7, \
2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 11, 4, 9, 8, 8, 7, 2, \
6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, \
2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 4, 10, 8, 8, 7, 2, 6, 2, \
9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 4, 9, 7, 8, 7, 2, 6, 2, 9, \
6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 4, 9, 8, 7, 7, 2, 6, 2, 9, 6, \
2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 4, 9, 8, 8, 8, 2, 6, 2, 9, 6, 2, \
2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 4, 9, 8, 8, 7, 1, 6, 2, 9, 6, 2, 2, \
6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 4, 9, 8, 8, 7, 2, 7, 2, 9, 6, 2, 2, 6, \
10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 4, 9, 8, 8, 7, 2, 6, 1, 9, 6, 2, 2, 6, 10, \
7}, \n \n  {4, 3, 2, 5, 8, 1, 4, 9, 8, 8, 7, 2, 6, 2, 8, 6, 2, 2, 6, 10, 7}, \
\n \n  {4, 3, 2, 5, 8, 1, 4, 9, 8, 8, 7, 2, 6, 2, 9, 7, 2, 2, 6, 10, 7}, \n \n\
  {4, 3, 2, 5, 8, 1, 4, 9, 8, 8, 7, 2, 6, 2, 9, 6, 3, 2, 6, 10, 7}, \n \n  \
{4, 3, 2, 5, 8, 1, 4, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 3, 6, 10, 7}, \n \n  {4, \
3, 2, 5, 8, 1, 4, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 7, 10, 7}, \n \n  {4, 3, \
2, 5, 8, 1, 4, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 9, 7}, \n \n  {4, 3, 2, 5, \
8, 1, 4, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 6}}\nGen. 10, selected bio: \
\n{4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}\nGen 11\n\
{{3, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, \
4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, \
1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, \
6, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, \
7, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, \
11, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, \
4, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, \
8, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, \
7, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, \
7, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, \
8, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, \
3, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, \
5, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, \
1, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, \
10, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, \
7, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, \
3, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, \
1, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, \
7, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, \
9, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, \
6}}\nGen. 11, selected bio: \n{4, 3, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, \
6, 2, 2, 6, 10, 7}\nGen 12\n{{3, 3, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, \
2, 2, 6, 10, 7}, \n \n  {4, 2, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, \
2, 6, 10, 7}, \n \n  {4, 3, 11, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, \
6, 10, 7}, \n \n  {4, 3, 1, 4, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, \
10, 7}, \n \n  {4, 3, 1, 5, 7, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, \
7}, \n \n  {4, 3, 1, 5, 8, 2, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \
\n \n  {4, 3, 1, 5, 8, 1, 1, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n\
  {4, 3, 1, 5, 8, 1, 5, 10, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  \
{4, 3, 1, 5, 8, 1, 5, 9, 7, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, \
3, 1, 5, 8, 1, 5, 9, 8, 9, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, \
1, 5, 8, 1, 5, 9, 8, 8, 6, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 1, \
5, 8, 1, 5, 9, 8, 8, 7, 1, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 1, 5, \
8, 1, 5, 9, 8, 8, 7, 2, 5, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 1, 5, 8, \
1, 5, 9, 8, 8, 7, 2, 6, 3, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 1, 5, 8, 1, \
5, 9, 8, 8, 7, 2, 6, 2, 8, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 1, 5, 8, 1, 5, \
9, 8, 8, 7, 2, 6, 2, 9, 5, 2, 2, 6, 10, 7}, \n \n  {4, 3, 1, 5, 8, 1, 5, 9, \
8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {4, 3, 1, 5, 8, 1, 5, 9, 8, \
8, 7, 2, 6, 2, 9, 6, 2, 1, 6, 10, 7}, \n \n  {4, 3, 1, 5, 8, 1, 5, 9, 8, 8, \
7, 2, 6, 2, 9, 6, 2, 2, 5, 10, 7}, \n \n  {4, 3, 1, 5, 8, 1, 5, 9, 8, 8, 7, \
2, 6, 2, 9, 6, 2, 2, 6, 9, 7}, \n \n  {4, 3, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, \
2, 9, 6, 2, 2, 6, 10, 6}}\nGen. 12, selected bio: \n{4, 3, 11, 5, 8, 1, 5, 9, \
8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}\nGen 13\n{{1, 3, 1, 5, 8, 1, 5, 9, 8, \
8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, \
7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, \
2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 1, 4, 8, 1, 5, 9, 8, 8, 7, 2, \
6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 1, 5, 9, 1, 5, 9, 8, 8, 7, 2, 6, \
2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 1, 5, 8, 11, 5, 9, 8, 8, 7, 2, 6, 2, \
9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 1, 5, 8, 1, 1, 9, 8, 8, 7, 2, 6, 2, 9, \
6, 2, 2, 6, 10, 7}, \n \n  {4, 3, 1, 5, 8, 1, 5, 10, 8, 8, 7, 2, 6, 2, 9, 6, \
2, 2, 6, 10, 7}, \n \n  {4, 3, 1, 5, 8, 1, 5, 9, 9, 8, 7, 2, 6, 2, 9, 6, 2, \
2, 6, 10, 7}, \n \n  {4, 3, 1, 5, 8, 1, 5, 9, 8, 7, 7, 2, 6, 2, 9, 6, 2, 2, \
6, 10, 7}, \n \n  {4, 3, 1, 5, 8, 1, 5, 9, 8, 8, 6, 2, 6, 2, 9, 6, 2, 2, 6, \
10, 7}, \n \n  {4, 3, 1, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 2, 2, 6, 10, \
7}, \n \n  {4, 3, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 7, 2, 9, 6, 2, 2, 6, 10, 7}, \
\n \n  {4, 3, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 3, 9, 6, 2, 2, 6, 10, 7}, \n \n\
  {4, 3, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 8, 6, 2, 2, 6, 10, 7}, \n \n  \
{4, 3, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 5, 2, 2, 6, 10, 7}, \n \n  {4, \
3, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, 6, 10, 7}, \n \n  {4, 3, \
1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 1, 6, 10, 7}, \n \n  {4, 3, 1, \
5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 7, 10, 7}, \n \n  {4, 3, 1, 5, \
8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 9, 7}, \n \n  {4, 3, 1, 5, 8, 1, \
5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 6}}\nGen. 13, selected bio: \n{4, \
4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}\nGen 14\n{{1, 4, \
1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 5, 1, \
5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 2, 5, \
8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 6, 8, \
1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 9, 1, \
5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 2, 5, \
9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 1, 9, \
8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 10, 8, \
8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 9, 8, \
7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 7, 7, \
2, 6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 6, 2, \
6, 2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 1, 6, \
2, 9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 7, 2, \
9, 6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 3, 9, \
6, 2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 8, 6, \
2, 2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 7, 2, \
2, 6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 1, 2, \
6, 10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 3, 6, \
10, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 5, 10, \
7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n\
 \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 10, 6}}\nGen. \
14, selected bio: \n{4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, \
1, 7}\nGen 15\n{{1, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, \
7}, \n \n  {4, 3, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n\
 \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  \
{4, 4, 1, 4, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, \
4, 1, 5, 7, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 1, \
5, 8, 11, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 1, 5, \
8, 1, 1, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 1, 5, 8, 1, \
5, 10, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, \
9, 9, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, \
7, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 6, \
2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 1, 6, \
2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 5, 2, 9, \
6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 1, 9, 6, 2, \
2, 6, 1, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 10, 6, 2, 2, \
6, 1, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 7, 2, 2, 6, 1, \
7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n\
 \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 1, 6, 1, 7}, \n \n  \
{4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 7, 1, 7}, \n \n  {4, \
4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 2, 7}, \n \n  {4, 4, 1, \
5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 6}}\nGen. 15, selected \
bio: \n{4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}\nGen \
16\n{{1, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  \
{4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, \
4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 2, \
6, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 7, \
1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 2, 5, \
9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 1, 9, 8, \
8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 10, 8, 8, \
7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 9, 8, 7, 2, \
6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 9, 7, 2, 6, 2, \
9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 6, 2, 6, 2, 9, 6, \
2, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 1, 6, 2, 9, 6, 2, 2, \
6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 7, 2, 9, 6, 2, 2, 6, 1, \
7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 3, 9, 6, 2, 2, 6, 1, 7}, \n\
 \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 10, 6, 2, 2, 6, 1, 7}, \n \n  \
{4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 7, 2, 2, 6, 1, 7}, \n \n  {4, \
4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, \
5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, \
1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 5, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, \
9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 11, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, \
8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 6}}\nGen. 16, selected bio: \n{4, 4, 2, \
5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 3, 2, 6, 1, 7}\nGen 17\n{{3, 4, 2, 5, \
8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 3, 2, 5, 8, 1, \
5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 3, 5, 8, 1, 5, 9, \
8, 8, 7, 2, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 4, 8, 1, 5, 9, 8, 8, \
7, 2, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 7, 1, 5, 9, 8, 8, 7, 2, \
6, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 11, 5, 9, 8, 8, 7, 2, 6, \
2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 4, 9, 8, 8, 7, 2, 6, 2, 9, \
6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 8, 8, 8, 7, 2, 6, 2, 9, 6, 3, \
2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 7, 8, 7, 2, 6, 2, 9, 6, 3, 2, 6, \
1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 7, 7, 2, 6, 2, 9, 6, 3, 2, 6, 1, \
7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 6, 2, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n\
 \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  \
{4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 5, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, \
4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 3, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, \
5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 8, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, \
1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 5, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, \
9, 8, 8, 7, 2, 6, 2, 9, 6, 2, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, \
8, 7, 2, 6, 2, 9, 6, 3, 3, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, \
2, 6, 2, 9, 6, 3, 2, 5, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, \
2, 9, 6, 3, 2, 6, 2, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 2, 6, 2, 9, \
6, 3, 2, 6, 1, 8}}\nGen. 17, selected bio: \n{4, 4, 2, 5, 8, 1, 5, 9, 8, 8, \
7, 3, 6, 2, 9, 6, 3, 2, 6, 1, 7}\nGen 18\n{{3, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, \
3, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 3, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, \
2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 1, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, \
6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 6, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, \
2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 9, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 2, 6, \
1, 7}, \n \n  {4, 4, 2, 5, 8, 2, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 2, 6, 1, \
7}, \n \n  {4, 4, 2, 5, 8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n\
 \n  {4, 4, 2, 5, 8, 1, 5, 8, 8, 8, 7, 3, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  \
{4, 4, 2, 5, 8, 1, 5, 9, 9, 8, 7, 3, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, \
4, 2, 5, 8, 1, 5, 9, 8, 9, 7, 3, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, \
5, 8, 1, 5, 9, 8, 8, 8, 3, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, \
1, 5, 9, 8, 8, 7, 2, 6, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, \
9, 8, 8, 7, 3, 5, 2, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, \
8, 7, 3, 6, 1, 9, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, \
3, 6, 2, 8, 6, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, \
2, 9, 7, 3, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, \
6, 4, 2, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, \
1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 2, 7, \
1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 2, 6, 2, \
7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 2, 6, 1, 6}}\n\
Gen. 18, selected bio: \n{4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, \
1, 6, 1, 7}\nGen 19\n{{1, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, \
6, 1, 7}, \n \n  {4, 5, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, \
7}, \n \n  {4, 4, 3, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n\
 \n  {4, 4, 2, 6, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  \
{4, 4, 2, 5, 7, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, \
4, 2, 5, 8, 11, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, \
2, 5, 8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, \
8, 1, 5, 10, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, \
1, 5, 9, 7, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, \
9, 8, 7, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, \
8, 6, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, \
2, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 7, \
2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 1, 9, \
6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 10, 6, \
3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 5, 3, 1, \
6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 2, 1, 6, 1, \
7}, \n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 11, 6, 1, 7}, \
\n \n  {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 5, 1, 7}, \n \n \
 {4, 4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 11, 7}, \n \n  {4, \
4, 2, 5, 8, 1, 5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 8}}\nGen. 19, \
selected bio: \n{4, 4, 2, 5, 8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, \
7}\nGen 20\n{{3, 4, 2, 5, 8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \
\n \n  {4, 5, 2, 5, 8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n \
 {4, 4, 1, 5, 8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, \
4, 2, 4, 8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, \
5, 7, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, \
11, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, \
5, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 4, \
10, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 4, 9, \
9, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 4, 9, 8, 7, \
7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 4, 9, 8, 8, 6, 3, \
6, 2, 9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 4, 9, 8, 8, 7, 4, 6, 2, \
9, 6, 3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 4, 9, 8, 8, 7, 3, 7, 2, 9, 6, \
3, 1, 6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 4, 9, 8, 8, 7, 3, 6, 3, 9, 6, 3, 1, \
6, 1, 7}, \n \n  {4, 4, 2, 5, 8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 8, 6, 3, 1, 6, 1, \
7}, \n \n  {4, 4, 2, 5, 8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 7, 3, 1, 6, 1, 7}, \n\
 \n  {4, 4, 2, 5, 8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 2, 1, 6, 1, 7}, \n \n  \
{4, 4, 2, 5, 8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 11, 6, 1, 7}, \n \n  {4, \
4, 2, 5, 8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 5, 1, 7}, \n \n  {4, 4, 2, \
5, 8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 11, 7}, \n \n  {4, 4, 2, 5, \
8, 1, 4, 9, 8, 8, 7, 3, 6, 2, 9, 6, 3, 1, 6, 1, 6}}"], "Print",
  Evaluatable->False,
  CellOpen->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .4862 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{241, 117},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003a0000M@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?40003a0000l@000?40003a0000l@000?40
003a0000M`034GL0001g00<AM`0007H0115g0000MP054GH0001f00DAMP0007D01Q5f0000M@074GD0
001e00LAM@0007@01140100A4A5e0000M0044@03014A008AM00007@00a4200@AM00007<0114300<A
M00007<0114300@AL`0007<00a4400@AL`000780114500<AL`000780114500@ALP0007800a4600@A
LP000740114700<ALP000740114700@AL@0007400a4800@AL@000700114900<AL@000700114900@A
L00007000a4:00@AL00006l0114;00<AL00006l0114;00<AL00006l00a4<00@AK`0006h0114<00@A
K`0006h0114=00<AK`0006h00a4>00@AKP0006d0114>00@AKP0006d0114?00<AKP0006d00a4@00@A
K@0006`0114@00@AK@0006`0114A00<AK@0006`00a4B00@AK00006/0114B00@AK00006/0114C00<A
K00006/00a4D00@AJ`0006X0114D00@AJ`0006X0114E00<AJ`0006X00a4F00@AJP0006T0114F00@A
JP0006T0114G00<AJP0006T00a4H00@AJ@0000X05<I:C@@A60044DY=4lH<00002P0DaTY<11400d`0
000D009<0a5:C1?6300000X05<I:C@<A0ddD00==0a5:CA?6300000X05lI900I<4006C4P05lH<0000
J`06C@h01Te/0000K007C0X01da]0000KP06C@P01Te_0000K`06C0H01Ta`0000L@06C@801Teb0000
LP0<C7<0001c00Y=M00007D01Taf0000M008CGD0001c00Y<M00007401Td200I=LP0007001T`400I<
L@0006h01dd600M=K`0006d01T`:00I<KP0006`01Td<00I=K@0006X01T`@00I<J`0006T01TdB00I=
JP0006P01T`D00I<J@0006H01TdH00I=I`0006D01T`J00I<IP0006@01TdL00I=I@0006801T`P00I<
H`0006401TdR00I=HP0005l01d`T00M<H00005h01TdX00I=G`0005d01T`Z00I<GP0005/01Td^00I=
G00005X01T``00I<F`0005T01Tdb00I=FP0005L01T`f00I<F00005H01Tdh00I=E`0005D01T`j00I<
EP0005<01Tdn00I=E00005801Ta000I<D`0005001de200M=D@0004l01Ta600I<D00004h01Te800I=
C`0004`01Ta<00I<C@0004/01Te>00I=C00004X01Ta@00I<B`0004L00/H5CE@01Dd00lH000170000
AP03aPA<EP04C0;6B00004D01<H3CEL000C6CDe=0lI70000@`09aUL02LI50000@P08aU/02<I40000
@009aUd02LI20000?`09aUl02LI10000?P08aV<02<I00000?009aVD02LHn0000>`08aVT02<Hm0000
>P08aV/02<Hl0000>@08aVd02<Hk0000>@06aW401/Hk0000>@05aW<01LHk0000>@04aWD01<Hk0000
l@000?40003a0000l@000?40003a0000\
\>"],
  ImageRangeCache->{{{0, 240}, {116, 0}} -> {-0.028119, 0.244745, 0.00440099, 
  0.00440099}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.016 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.016 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.016 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.016 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
.2 0 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
.2 0 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
.2 0 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.258619 0.952381 [
[ 0 0 0 0 ]
[ 1 .43514 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .43514 L
0 .43514 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12834 .17257 m
.05062 .16026 L
s
P
p
0 .4 1 r
.018 w
.71965 .3647 m
.78976 .40042 L
s
P
p
.2 0 1 r
.016 w
.43921 .22181 m
.12834 .17257 L
s
P
p
.2 0 1 r
.016 w
.43921 .22181 m
.71965 .3647 L
s
P
p
0 .4 1 r
.018 w
.28035 .3647 m
.21024 .40042 L
s
P
p
0 .4 1 r
.018 w
.87166 .17257 m
.94938 .16026 L
s
P
p
.2 0 1 r
.016 w
.56079 .22181 m
.28035 .3647 L
s
P
p
.2 0 1 r
.016 w
.56079 .22181 m
.87166 .17257 L
s
P
p
1 .6 0 r
.016 w
.5 .03472 m
.43921 .22181 L
s
P
p
1 .6 0 r
.016 w
.5 .03472 m
.56079 .22181 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.239417 0.952381 [
[ 0 0 0 0 ]
[ 1 .47355 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .47355 L
0 .47355 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12195 .20611 m
.05025 .20611 L
s
P
p
0 .4 1 r
.018 w
.70564 .39577 m
.76365 .43791 L
s
P
p
.2 0 1 r
.016 w
.44461 .20611 m
.12195 .20611 L
s
P
p
.2 0 1 r
.016 w
.44461 .20611 m
.70564 .39577 L
s
P
p
0 .4 1 r
.018 w
.29436 .39577 m
.23635 .43791 L
s
P
p
0 .4 1 r
.018 w
.87805 .20611 m
.94975 .20611 L
s
P
p
.2 0 1 r
.016 w
.55539 .20611 m
.29436 .39577 L
s
P
p
.2 0 1 r
.016 w
.55539 .20611 m
.87805 .20611 L
s
P
p
1 .6 0 r
.016 w
.5 .03563 m
.44461 .20611 L
s
P
p
1 .6 0 r
.016 w
.5 .03563 m
.55539 .20611 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.018 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.018 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.018 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.018 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.8 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.8 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.8 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.8 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.19792 0.952381 [
[ 0 0 0 0 ]
[ 1 .55654 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .55654 L
0 .55654 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.10014 .32127 L
s
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.17982 .2116 L
s
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.05089 .16971 L
s
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.05089 .30527 L
s
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.17982 .26338 L
s
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.10014 .15371 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.75565 .36669 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.62672 .40859 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.7064 .51826 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.78609 .40859 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.65716 .36669 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.65716 .50226 L
s
P
p
.2 0 1 r
.016 w
.43527 .23749 m
.10014 .23749 L
s
P
p
.2 0 1 r
.016 w
.43527 .23749 m
.7064 .43448 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.34284 .50226 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.34284 .36669 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.21391 .40859 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.2936 .51826 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.37328 .40859 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.24435 .36669 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.89986 .15371 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.82018 .26338 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.94911 .30527 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.94911 .16971 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.82018 .2116 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.89986 .32127 L
s
P
p
.2 0 1 r
.016 w
.56473 .23749 m
.2936 .43448 L
s
P
p
.2 0 1 r
.016 w
.56473 .23749 m
.89986 .23749 L
s
P
p
1 .6 0 r
.016 w
.5 .03828 m
.43527 .23749 L
s
P
p
1 .6 0 r
.016 w
.5 .03828 m
.56473 .23749 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.239417 0.952381 [
[ 0 0 0 0 ]
[ 1 .47355 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .47355 L
0 .47355 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.1578 .20611 m
.05025 .20611 L
s
P
p
0 .4 1 r
.018 w
.67664 .37469 m
.76365 .43791 L
s
P
p
.2 0 1 r
.016 w
.44461 .20611 m
.1578 .20611 L
s
P
p
.2 0 1 r
.016 w
.44461 .20611 m
.67664 .37469 L
s
P
p
0 .4 1 r
.018 w
.32336 .37469 m
.23635 .43791 L
s
P
p
0 .4 1 r
.018 w
.8422 .20611 m
.94975 .20611 L
s
P
p
.2 0 1 r
.016 w
.55539 .20611 m
.32336 .37469 L
s
P
p
.2 0 1 r
.016 w
.55539 .20611 m
.8422 .20611 L
s
P
p
1 .6 0 r
.016 w
.5 .03563 m
.44461 .20611 L
s
P
p
1 .6 0 r
.016 w
.5 .03563 m
.55539 .20611 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.260225 0.952381 [
[ 0 0 0 0 ]
[ 1 .43193 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .43193 L
0 .43193 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.20335 .15623 m
.04918 .15623 L
s
P
p
0 .4 1 r
.018 w
.25474 .15623 m
.20335 .15623 L
s
P
p
.2 0 1 r
.02 w
.66818 .30727 m
.7929 .39788 L
s
P
p
0 .4 1 r
.018 w
.6266 .27706 m
.66818 .30727 L
s
P
p
.2 0 1 r
.016 w
.4603 .15623 m
.25474 .15623 L
s
P
p
.2 0 1 r
.016 w
.4603 .15623 m
.6266 .27706 L
s
P
p
.2 0 1 r
.02 w
.33182 .30727 m
.2071 .39788 L
s
P
p
0 .4 1 r
.018 w
.3734 .27706 m
.33182 .30727 L
s
P
p
.2 0 1 r
.02 w
.79665 .15623 m
.95082 .15623 L
s
P
p
0 .4 1 r
.018 w
.74526 .15623 m
.79665 .15623 L
s
P
p
.2 0 1 r
.016 w
.5397 .15623 m
.3734 .27706 L
s
P
p
.2 0 1 r
.016 w
.5397 .15623 m
.74526 .15623 L
s
P
p
1 .6 0 r
.016 w
.5 .03405 m
.4603 .15623 L
s
P
p
1 .6 0 r
.016 w
.5 .03405 m
.5397 .15623 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.220295 0.952381 [
[ 0 0 0 0 ]
[ 1 .51179 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .51179 L
0 .51179 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.11899 .09353 m
.05028 .07121 L
s
P
p
0 .4 1 r
.018 w
.5637 .41663 m
.60616 .47508 L
s
P
p
.2 0 1 r
.016 w
.39384 .18283 m
.11899 .09353 L
s
P
p
.2 0 1 r
.016 w
.39384 .18283 m
.5637 .41663 L
s
P
p
0 .4 1 r
.018 w
.22516 .30663 m
.15644 .32896 L
s
P
p
0 .4 1 r
.018 w
.77484 .30663 m
.84356 .32896 L
s
P
p
.2 0 1 r
.016 w
.5 .21733 m
.22516 .30663 L
s
P
p
.2 0 1 r
.016 w
.5 .21733 m
.77484 .30663 L
s
P
p
0 .4 1 r
.018 w
.4363 .41663 m
.39384 .47508 L
s
P
p
0 .4 1 r
.018 w
.88101 .09353 m
.94972 .07121 L
s
P
p
.2 0 1 r
.016 w
.60616 .18283 m
.4363 .41663 L
s
P
p
.2 0 1 r
.016 w
.60616 .18283 m
.88101 .09353 L
s
P
p
1 .6 0 r
.016 w
.5 .03671 m
.39384 .18283 L
s
P
p
1 .6 0 r
.016 w
.5 .03671 m
.5 .21733 L
s
P
p
1 .6 0 r
.016 w
.5 .03671 m
.60616 .18283 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.24066 0.952381 [
[ 0 0 0 0 ]
[ 1 .47106 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .47106 L
0 .47106 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.13414 .29665 m
.05092 .30983 L
s
P
p
0 .4 1 r
.018 w
.76736 .39694 m
.84244 .4352 L
s
P
p
.2 0 1 r
.016 w
.46705 .24393 m
.13414 .29665 L
s
P
p
.2 0 1 r
.016 w
.46705 .24393 m
.76736 .39694 L
s
P
p
0 .4 1 r
.018 w
.23264 .39694 m
.15756 .4352 L
s
P
p
0 .4 1 r
.018 w
.86586 .29665 m
.94908 .30983 L
s
P
p
.2 0 1 r
.016 w
.53295 .24393 m
.23264 .39694 L
s
P
p
.2 0 1 r
.016 w
.53295 .24393 m
.86586 .29665 L
s
P
p
1 .6 0 r
.016 w
.5 .03586 m
.46705 .24393 L
s
P
p
1 .6 0 r
.016 w
.5 .03586 m
.53295 .24393 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.219707 0.952381 [
[ 0 0 0 0 ]
[ 1 .51297 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .51297 L
0 .51297 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12631 .25323 m
.05047 .25323 L
s
P
p
0 .4 1 r
.018 w
.67512 .43155 m
.73648 .47613 L
s
P
p
.2 0 1 r
.016 w
.42969 .25323 m
.12631 .25323 L
s
P
p
.2 0 1 r
.016 w
.42969 .25323 m
.67512 .43155 L
s
P
p
0 .4 1 r
.018 w
.32488 .43155 m
.26352 .47613 L
s
P
p
0 .4 1 r
.018 w
.87369 .25323 m
.94953 .25323 L
s
P
p
.2 0 1 r
.016 w
.57031 .25323 m
.32488 .43155 L
s
P
p
.2 0 1 r
.016 w
.57031 .25323 m
.87369 .25323 L
s
P
p
1 .6 0 r
.016 w
.5 .03684 m
.42969 .25323 L
s
P
p
1 .6 0 r
.016 w
.5 .03684 m
.57031 .25323 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.018 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.018 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
.8 1 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
.8 1 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.21445 1.4289 0.0357225 1.4289 [
[ 0 0 0 0 ]
[ 1 1.50034 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.50034 L
0 1.50034 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12238 1.24187 m
.06429 1.42066 L
s
P
p
.2 0 1 r
.016 w
.35476 .52667 m
.12238 1.24187 L
s
P
p
0 .4 1 r
.018 w
.87762 1.24187 m
.93571 1.42066 L
s
P
p
.2 0 1 r
.016 w
.64524 .52667 m
.87762 1.24187 L
s
P
p
1 .6 0 r
.016 w
.5 .07968 m
.35476 .52667 L
s
P
p
1 .6 0 r
.016 w
.5 .07968 m
.64524 .52667 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`0001L000<A000080000a40
000P00034@00020000<A000080000a40000P00034@00020000<A00005P0001L000<A000080000a40
000P00034@00020000<A000080000a40000P00034@00020000<A00005P0001H000<A014080000a40
4@0P00034@0A020000<A014080000a404@0P00034@0A020000<A01405`0001H000<A014080000a40
4@0P00034@0A020000<A014080000a404@0P00034@0A020000<A01405`0001H000<A014080000a40
4@0P00034@0A020000<A014080000a404@0P00034@0A020000<A01405`0001D000DA00004@0N0005
4@0001407P001A40000A01h000DA00004@0N00054@0001407P001A40000A01h000DA00004@0F0000
2@02aPY<00DAC01<4@0:C0;61P0<C0054D`0C14034`600;62T`01A5<04`A00Y<0/H600;62T`01A5<
04`A00Y<0/H600;62T`01A5<04`A00Y<0/H600;62T`01A5<04`A00Y<0/H600;62T`01A5<04`A00Y<
0/H:00005`000dd0000P0003C@00020000==000080000dd0000P0003C@00020000==000080000dd0
000F00005P000d`0C00P0003C01<020000=<04`080000d`0C00P0003C01<020000=<04`080000d`0
C00G00005002C@<00TdL009=0`02CA`00Td3009=7002C@<00TdL009=0`02CA`00Td3009=7002C@<0
0TdE00004`000d`000050003C00001P000=<00001@000d`0000H0003C00000D000=<000060000d`0
00050003C00001P000=<00001@000d`0000H0003C00000D000=<000060000d`000050003C0000180
000B0003C@0000L000==00005P000dd000070003C@0001H000==00001`000dd0000F0003C@0000L0
00==00005P000dd000070003C@0001H000==00001`000dd0000F0003C@0000L000==00004@000140
00=<00002@000d`0000D0003C00000T000=<000050000d`000090003C00001@000=<00002@000d`0
000D0003C00000T000=<000050000d`000090003C00001@000=<00002@000d`0000@000040000lH0
000;0003aP00018000==00002`000dd0000B0003aP0000/000?600004P000lH0000;0003aP000180
00?600002`000lH0000B0003aP0000/000?600004P000lH0000;0003aP0000l0000?0003aP0000d0
00?6000040000d`0000=0003C000010000?600003@000lH0000@0003aP0000d000?6000040000lH0
000=0003aP00010000?600003@000lH0000@0003aP0000d000?600003P000?l00`000?l00`000?l0
0`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000:<000<A0000G00005d000<A0000
80000a40000P00034@00020000<A0000>@0001L000<A000080000a40000P00034@00020000<A0000
80000a40000P00034@00020000<A00005P0001L000<A000080000a40000O00034@0A020000<A0140
80000a404@0P00034@0A024000<A00005P0001H000<A014080000a404@0P00034@0A020000<A0140
50000lH0000900034@0A00/000?600004P000a404@0P00034@0A01L0000F00034@0A020000<A0140
80000a404@0P00034@0A01<00/H;00034@0A00/00/HC00034@0A020000<A01405`0000T00/H;0003
4@0A00/00/HC00034@0A01l000DA00004@0N00054@0001404P02aP030<K600L000DA00004@0700G6
4P001A40000A01l000<A01405`0000/01Td400054@0001401006C@P00/H:C@054Dd0CA402Td2aPH0
0/H:C@054Dd0CA402Td2aPH00/H:@P054D80@Q402T82aPL02dd01A5=04dA00]=1`02aPY=00DAC@1=
4@0:C@;61P03aPU=00DAC@1=4@09C@?62P00014014`01A5<04`A00A<70000d`0000P0003C0000200
00=200004`001<H00<H90003C00000L00/H00`36000D0003C000020000=<00005P0001H00ddO009=
00<0C@007`000dd0C@0P0003@P1201<00/H:009=00<0CDd02P02aQ<000==04d07`02C@0304e=01H0
000D009<0`02C1`000=<00000P02C1`00T`3009<7002@P<00T8L0003C00000<000=<00006P02C0<0
0T`K009<1@02C1@0000C0003C@0000D000==00005`02C@L000==000060000dd000050003C@0001P0
00=200001@000d80000D0003aP00009=1`02C@8000?6000050000dd000050003C@0001L000==0000
1`000dd0000A00004@02C0T00T`F0003C00000P000=<00005P000d`000070003C00001H000=20000
1`000d80000B00;600@0C<K61`02aP04C036aQ@000=<00001`000d`0000E0003C00000T000=<0000
400000l000?6C@0030000dg6000B0003C@0000X000==aP0050000dd000090003C@0001@000=20000
2@000d80000C0003CLH000/000==00004`000dd000090003C@0001<000?600002`000lH0000?0000
3P000lH0000?0003aP0000l000?600003@000lH0000A0003aP0000/000?600004P000lH0000;0003
aP0001800/H;00;650000lH0000;0003aP00014000?600003@000lH0000>0000E@000lH0000=0003
aP00010000?600003@000lH0000A0003aP3600T000?60<H04`000lH0000=0003aP000340002L0003
aP0000/000?60000E@000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`000?l00`000?l00`000>T000<A00005P000>T000<A00005P000>P000<A0140
5`000>P000<A01405`000>P000<A01405`000>L000DA00004@0F0000i`001A40000A01H0000j0003
4@0004<000<A000080000a40000P0003g`0001h000DA00004@0F00005`000a40000B00;630000a40
000:00;650000a40000P00034@00020000<A000080000mh0000M00034@0000<000<A00004`0001L0
00<A00005003C0P00a49009<5P000a40000P00034@0001l000<A014080000ml0g`0N00034@0000<0
00<A00004`0001L000<A00005`03C@@000DA01404@0500==60000a40000O00034@0A020000<A0140
80000mh0gP0N0003C@0000<000==00004`0001H000<A01406`03C00601404@0A0P03C1/000<A0000
7`000a404@0P00034@0A020000?O0=l07P000d`000030003C00001<0000900A=0/H7C@034DdA00M=
00?6CDd00ddA00044@004@8000<AC@0070000a404@0P00034@0A01l000DA00004@0N0005gP000=h0
70000dd000050003C@000180000F0003C01<01h000A<04`A0d`N00034@0A01l000DA00004@0B00;6
2T`01A5<04`A00Y<0/H600;62T`01Mm<04cO00Y<0/H@0003C00000D000=<00004P0001D000E=0000
C@0L00==0`04CAT00dd00a5=4@03CA000/H:C@054Dd0CA402Td2aQ@000==000080000dd0000L0003
C@0000D000==00004P0001@000=<00000`000d`0000F00=<0`000d`0C00400=<4@05C0800T`00`1<
C00200E<6@000d`0000O0003C01<020000=<04`070000d`000070003C0000140000C0003C@0000D0
00==00004@02aP9=1`000dd000060003CLK600T00/H3C@D00Td5009=1@03C@;64`000dd0C@0N009=
0`02CA`00Td3009=6P000dd000070003C@000140000A0003C<H000P000?6C0006`000d`0000J009<
2@000d`0000H009<0`02C1/000=<00001@000d`0000H0003C00000D000=<00005`000d`000070003
C0000140000@0003C@0000/000==000060000dd0C@0I009=3002CAL000==00001@000dd0000G0003
C@0000L000==00005P000dd000070003C@0001D000==00002@000dd0000@00003`000d`0000=0003
C00001H000E<0000C00F0003aT`000l000=<a/H04`000d`000070003C00001D000=<00002@000d`0
000D0003C00000T000=<000050000d`000090003C0000100000>0003C@0000l000==00005@001LH0
003601D000?600004`000lH0000>0003aTd000X000==00004`000lH0000;0003aP00018000?60000
2`000lH0000C0003C@0000T000==0000400003L000?600000`000lH0000h0003aP0000`000?60000
4@000lH0000=0003aP00010000?600003@000lH0000A0003C00000/000=<00003`000>8000==0000
2`000dd0000?0000hP000d`0000;0003C00000l0003Q0003C@0000d000==00003P000>4000=<0000
3@000d`0000>0000h@000lH0000=0003aP0000h0003P0003aP0000l000?600003@000>0000?60000
3`000lH0000=0000o`030000o`030000o`030000o`030000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.109415,
   0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110612, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.109415, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.74027, -0.110612, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.109415, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277,
   -0.110612, 0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.1939, -0.109415, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.270008, -1.2634, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  69.375, 37.5625}} -> {-1.42777, -1.26686, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26686, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.88594, -1.2634, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277,
   -1.26686, 0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.1939, -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.270008, -2.41738, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.74027, -2.42311, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277,
   -2.42311, 0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1938, -2.41735, 0.0329411, 0.0329411}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .55654 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.19792 0.952381 [
[ 0 0 0 0 ]
[ 1 .55654 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .55654 L
0 .55654 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.10014 .32127 L
s
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.17982 .2116 L
s
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.05089 .16971 L
s
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.05089 .30527 L
s
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.17982 .26338 L
s
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.10014 .15371 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.75565 .36669 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.62672 .40859 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.7064 .51826 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.78609 .40859 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.65716 .36669 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.65716 .50226 L
s
P
p
.2 0 1 r
.016 w
.43527 .23749 m
.10014 .23749 L
s
P
p
.2 0 1 r
.016 w
.43527 .23749 m
.7064 .43448 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.34284 .50226 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.34284 .36669 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.21391 .40859 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.2936 .51826 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.37328 .40859 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.24435 .36669 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.89986 .15371 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.82018 .26338 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.94911 .30527 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.94911 .16971 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.82018 .2116 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.89986 .32127 L
s
P
p
.2 0 1 r
.016 w
.56473 .23749 m
.2936 .43448 L
s
P
p
.2 0 1 r
.016 w
.56473 .23749 m
.89986 .23749 L
s
P
p
1 .6 0 r
.016 w
.5 .03828 m
.43527 .23749 L
s
P
p
1 .6 0 r
.016 w
.5 .03828 m
.56473 .23749 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{225, 125},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Q0000O@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000>40003Q0000h@000>40003Q0000h@000>40
003Q0000K`034Fl0001_00<AK`0006h0115_0000KP054Fh0001^00DAKP0006d01Q5^0000K@074Fd0
001]00LAK@0006`01140100A4A5]0000K0044@03014A008AK00006`00a4200@AK00006/0114300<A
K00006/0114300@AJ`0006/00a4400@AJ`0006X0114500<AJ`0006X0114500@AJP0006X00a4600@A
JP0006T0114700<AJP0006T0114700@AJ@0006T00a4800@AJ@0006P0114900<AJ@0006P0114900@A
J00006P00a4:00@AJ00006L0114;00<AJ00006L0114;00<AJ00006L00a4<00@AI`0001@01<I>00@A
30044Dd01<HF00005004aTh0114=00<AC@04aQH0000D00C6CP034@h0115<00C65P0000T01<H700C6
C@044@h0115<00C61`04aP/0000900C61`04aTd0114?00<AC004aPL01<H;00002@05aPH01<I=00<A
40044D/01<H600G62`0000T01/H500C6C0044A00115;00C61@06aP/0000900O61004aT`0114A00<A
B`04aP@01lH;00002P06aP@01<I<00<A4P044DX01<H400K6300000/01/H300C6B`044A80115:00C6
0`06aPd0000<00K60P04aT/0114C00<ABP04aP801/H>00003007aP030<K600;6B`034A@0115900C6
00<0a/H01LH>00003@06aP030<K600;6BP044A@0115900C600<0a/H01<H?00003P0:aP`01/Hh00@A
5@034CL01/H<00[6400000l02LH900W6>0034AH0114f00W62@09aQ40000?00W61@0=aSL0114F00@A
=P0=aPD02LHA00004008aP030<K600o6=`044AL00a4f017600<0a/H01/HB00004@0FaSX00a4H00@A
>00FaQ<0000A00C6Bdd44AP0115;C@?64`0001800lI;C0@A00=<00005002C0<ABd`2aQ@0000C00;6
Bdd34@==5003C@<ABdd00lH0000C00004P0AaSl01T`@00I<?`0@aQ@0000B01C6?@06C@h01Tdm01?6
500001401lH200o6>`07C0X01d`k00o600<0a/H01LHC00004008aPD03LHl00I=2006CC/03/H400S6
4P0001002<H800[6?@06C0H01T`l00_61`08aQ80000?00W62`07aSl01Td200I=?P08aPX02LHA0000
3P0:aPh01<I000a<?`05aPd02/H@00003@0;aU<02TeB00_63`0000d01/H00`36aP02aUD01TaD00C6
00<0a/H01<H?00003006aP801<ID00Q=D`04aP801/H>00002`06aP<01<IC00Y<DP04aP<01/H=0000
2`06aP<01<IA00I=0P06CE001<H300K63@0000X01/H400C6D006C0@01Ta?00C61006aP`0000900K6
1@04aTh01dd600M=C@04aPD01/H;00002@06aPD01<I=00I<2P06C4`01<H500K62`0000T01LH600C6
C006C@`01Te;00C61P05aP/0000900C61`04aTX01T`@00I<B@04aPL01<H;00005004aTT01TdB00I=
B004aQH0000D00C6B006C1@01Ta700C65P0001@01<I600I=6006CDD01<HF0000G@06C1X01TaN0000
G006CA`01TeM0000FP06C2001TaK0000F@06CB801TeJ0000E`07C2@01daH0000EP06CBP01TeG0000
=@04aQ401<H700I<:P06C0H01<HA00C6=`0003D01<HA00C61@06CBh01Td400C64@04aSL0000e00G6
3`05aP@01T``00I<0`05aPl01LHg0000=@06aPd01/H300I=<P06C@801/H=00K6=`0003D01lH<00K6
00<0C4`014`f00I<1/H<00O6=`0003H01/H;00K600<0CDd014dh00I=1/H;00K6>00003L01/H900K6
00<0C4`014`j00I<1/H900K6>@0003P01/H800G61Tdn00I=1<H800K6>P0003P01lH600G61Ta000I<
1<H600O6>P0003T01/H500C61de200M=0lH500K6>`0002h01/H600K61003aPI<0P06aSD01/H300I<
0/H400K61P06aS00000^00W61006aP800lH6C@W6=@09aP0304e=00A=0/H200K61009aS00000^01?6
00<0a/H01T`;aSD03<H6C003aP3601;6<00002h05LH6C@c6=@0=aPI=5<H`0000<@0AaPI<2/Hk00_6
1T`@aS<0000d00g61Dd9aT402/H5C@c6=P0003P02LH4C0K6B@07aPA<2<Hj0000?005aP==1<I?00G6
0dd4aSh0000o00O6D`07aT40001000K6D`06aT80001000O6D@07aT80001000S6C`08aT80001000S6
C`08aT80001000W6C@09aT80001000[6B`0:aT80001000[6B`0:aT80001000C600<0a/H01<I900K6
00<0a/H00/I20000@004aP801/I700K60P04aT80001000C60P06aTL01/H200C6@P0004001<H300K6
A@06aP<01<I20000@004aP@01/I300K61004aT80001000C61006aT<01/H400C6@P0004001<H500G6
@`05aPD01<I20000@004aPH01<I300C61P04aT80001000C6E`04aT80001000C6E`04aT80001000C6
E`04aT80001000C6E`04aT80003Q0000h@000>40003Q0000h@000>400000\
\>"],
  ImageRangeCache->{{{0, 224}, {124, 0}} -> {-0.0278206, 0.207813, 0.00471268,
   0.00471268}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.02 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.02 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.02 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.02 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 1 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 1 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 1 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 1 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.258619 0.952381 [
[ 0 0 0 0 ]
[ 1 .43514 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .43514 L
0 .43514 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12834 .17257 m
.05062 .16026 L
s
P
p
0 .4 1 r
.018 w
.71965 .3647 m
.78976 .40042 L
s
P
p
.2 0 1 r
.016 w
.43921 .22181 m
.12834 .17257 L
s
P
p
.2 0 1 r
.016 w
.43921 .22181 m
.71965 .3647 L
s
P
p
0 .4 1 r
.018 w
.28035 .3647 m
.21024 .40042 L
s
P
p
0 .4 1 r
.018 w
.87166 .17257 m
.94938 .16026 L
s
P
p
.2 0 1 r
.016 w
.56079 .22181 m
.28035 .3647 L
s
P
p
.2 0 1 r
.016 w
.56079 .22181 m
.87166 .17257 L
s
P
p
1 .6 0 r
.016 w
.5 .03472 m
.43921 .22181 L
s
P
p
1 .6 0 r
.016 w
.5 .03472 m
.56079 .22181 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.225569 0.952381 [
[ 0 0 0 0 ]
[ 1 .50124 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .50124 L
0 .50124 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.13613 .23924 m
.05097 .23924 L
s
P
p
0 .4 1 r
.018 w
.67536 .41444 m
.74426 .4645 L
s
P
p
.2 0 1 r
.016 w
.43421 .23924 m
.13613 .23924 L
s
P
p
.2 0 1 r
.016 w
.43421 .23924 m
.67536 .41444 L
s
P
p
0 .4 1 r
.018 w
.32464 .41444 m
.25574 .4645 L
s
P
p
0 .4 1 r
.018 w
.86387 .23924 m
.94903 .23924 L
s
P
p
.2 0 1 r
.016 w
.56579 .23924 m
.32464 .41444 L
s
P
p
.2 0 1 r
.016 w
.56579 .23924 m
.86387 .23924 L
s
P
p
1 .6 0 r
.016 w
.5 .03674 m
.43421 .23924 L
s
P
p
1 .6 0 r
.016 w
.5 .03674 m
.56579 .23924 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.014 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.014 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.014 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.014 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
0 .4 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
0 .4 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
0 .4 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
0 .4 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.19792 0.952381 [
[ 0 0 0 0 ]
[ 1 .55654 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .55654 L
0 .55654 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.05089 .16971 L
s
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.05089 .30527 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.7064 .51826 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.78609 .40859 L
s
P
p
.2 0 1 r
.016 w
.43527 .23749 m
.10014 .23749 L
s
P
p
.2 0 1 r
.016 w
.43527 .23749 m
.7064 .43448 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.21391 .40859 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.2936 .51826 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.94911 .30527 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.94911 .16971 L
s
P
p
.2 0 1 r
.016 w
.56473 .23749 m
.2936 .43448 L
s
P
p
.2 0 1 r
.016 w
.56473 .23749 m
.89986 .23749 L
s
P
p
1 .6 0 r
.016 w
.5 .03828 m
.43527 .23749 L
s
P
p
1 .6 0 r
.016 w
.5 .03828 m
.56473 .23749 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.225569 0.952381 [
[ 0 0 0 0 ]
[ 1 .50124 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .50124 L
0 .50124 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.09355 .23924 m
.05097 .23924 L
s
P
p
0 .4 1 r
.018 w
.70981 .43947 m
.74426 .4645 L
s
P
p
.2 0 1 r
.016 w
.43421 .23924 m
.09355 .23924 L
s
P
p
.2 0 1 r
.016 w
.43421 .23924 m
.70981 .43947 L
s
P
p
0 .4 1 r
.018 w
.29019 .43947 m
.25574 .4645 L
s
P
p
0 .4 1 r
.018 w
.90645 .23924 m
.94903 .23924 L
s
P
p
.2 0 1 r
.016 w
.56579 .23924 m
.29019 .43947 L
s
P
p
.2 0 1 r
.016 w
.56579 .23924 m
.90645 .23924 L
s
P
p
1 .6 0 r
.016 w
.5 .03674 m
.43421 .23924 L
s
P
p
1 .6 0 r
.016 w
.5 .03674 m
.56579 .23924 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0880319 0.952381 [
[ 0 0 0 0 ]
[ 1 .77632 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .77632 L
0 .77632 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.016 w
.03184 .39007 m
.38853 .39007 L
s
P
p
.2 0 1 r
.016 w
.38853 .39007 m
.85545 .72931 L
s
P
p
.2 0 1 r
.016 w
.61147 .39007 m
.14455 .72931 L
s
P
p
.2 0 1 r
.016 w
.96816 .39007 m
.61147 .39007 L
s
P
p
1 .6 0 r
.016 w
.5 .04701 m
.38853 .39007 L
s
P
p
1 .6 0 r
.016 w
.5 .04701 m
.61147 .39007 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.249845 0.952381 [
[ 0 0 0 0 ]
[ 1 .45269 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .45269 L
0 .45269 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.14116 .38798 m
.05145 .41712 L
s
P
p
0 .4 1 r
.018 w
.85884 .38798 m
.94855 .41712 L
s
P
p
.2 0 1 r
.016 w
.5 .27138 m
.14116 .38798 L
s
P
p
.2 0 1 r
.016 w
.5 .27138 m
.85884 .38798 L
s
P
p
1 .6 0 r
.016 w
.5 .03557 m
.5 .27138 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.226453 0.952381 [
[ 0 0 0 0 ]
[ 1 .49947 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .49947 L
0 .49947 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12349 .155 m
.05037 .14341 L
s
P
p
0 .4 1 r
.018 w
.62537 .41071 m
.67772 .46306 L
s
P
p
.2 0 1 r
.016 w
.41598 .20132 m
.12349 .155 L
s
P
p
.2 0 1 r
.016 w
.41598 .20132 m
.62537 .41071 L
s
P
p
0 .4 1 r
.018 w
.37463 .41071 m
.32228 .46306 L
s
P
p
0 .4 1 r
.018 w
.87651 .155 m
.94963 .14341 L
s
P
p
.2 0 1 r
.016 w
.58402 .20132 m
.37463 .41071 L
s
P
p
.2 0 1 r
.016 w
.58402 .20132 m
.87651 .155 L
s
P
p
1 .6 0 r
.016 w
.5 .03641 m
.41598 .20132 L
s
P
p
1 .6 0 r
.016 w
.5 .03641 m
.58402 .20132 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.247215 0.952381 [
[ 0 0 0 0 ]
[ 1 .45795 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .45795 L
0 .45795 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.13067 .18752 m
.05069 .18752 L
s
P
p
0 .4 1 r
.018 w
.70938 .37555 m
.77408 .42256 L
s
P
p
.2 0 1 r
.016 w
.45057 .18752 m
.13067 .18752 L
s
P
p
.2 0 1 r
.016 w
.45057 .18752 m
.70938 .37555 L
s
P
p
0 .4 1 r
.018 w
.29062 .37555 m
.22592 .42256 L
s
P
p
0 .4 1 r
.018 w
.86933 .18752 m
.94931 .18752 L
s
P
p
.2 0 1 r
.016 w
.54943 .18752 m
.29062 .37555 L
s
P
p
.2 0 1 r
.016 w
.54943 .18752 m
.86933 .18752 L
s
P
p
1 .6 0 r
.016 w
.5 .03539 m
.45057 .18752 L
s
P
p
1 .6 0 r
.016 w
.5 .03539 m
.54943 .18752 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.014 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.014 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`0001L000<A000080000a40
000P00034@00020000<A000080000a40000P00034@00020000<A00005P0001L000<A000080000a40
000P00034@00020000<A000080000a40000P00034@00020000<A00005P0001H000<A014080000a40
4@0P00034@0A020000<A014080000a404@0P00034@0A020000<A01405`0001H000<A014080000a40
4@0P00034@0A020000<A014080000a404@0P00034@0A020000<A01405`0001H000<A014080000a40
4@0P00034@0A020000<A014080000a404@0P00034@0A020000<A01405`0001D000DA00004@0N0005
4@0001407P001A40000A01h000DA00004@0N00054@0001407P001A40000A01h000DA00004@0F0000
2@02aPY<00DAC01<4@0:C0;61P02]0Y<00DAC01<4@0:C0:d1P02aPY<00DAC01<4@0:C0;61P02aPY<
00DAC01<4@0:C0;61P02aPY<00DAC01<4@0:C0;61P02aPY<00DAC01<4@0:C0;61P02aPY<00DAC01<
4@0:C0;62P0001L000==000080000dd0000P0003C@00020000==000080000dd0000P0003C@000200
00==00005P0001H000=<04`080000d`0C00P0003C01<020000=<04`080000d`0C00P0003C01<0200
00=<04`05`0001@00Td3009=7002C@<00TdL009=0`02CA`00Td3009=7002C@<00TdL009=0`02CA`0
0Td3009=5@0001<000=<00001@000d`0000H0003C00000D000=<000060000d`000050003C00001P0
00=<00001@000d`0000H0003C00000D000=<000060000d`000050003C00001P000=<00001@000d`0
000B00004P000dd000070003C@0001H000==00001`000dd0000F0003C@0000L000==00005P000dd0
00070003C@0001H000==00001`000dd0000F0003C@0000L000==00005P000dd000070003C@000140
000A0003C00000T000=<000050000d`000090003C00001@000=<00002@000d`0000D0003C00000T0
00=<000050000d`000090003C00001@000=<00002@000d`0000D0003C00000T000=<000040000100
00?600002`000lH0000B0003]00000/000>d00004P000lH0000;0003aP00018000?600002`000lH0
000B0003aP0000/000?600004P000lH0000;0003aP00018000?600002`000lH0000?00003`000lH0
000=0003aP00010000>d00003@000k@0000@0003aP0000d000?6000040000lH0000=0003aP000100
00?600003@000lH0000@0003aP0000d000?6000040000lH0000=0003aP0000h0003o00<0003o00<0
003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0
003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0002S00034@0005`0000j0003
4@00020000<A000080000a40000P00034@00020000<A000080000a40000F00005`000a40000P0003
4@00020000<A000080000a40000P00034@00020000<A000080000a40000F00005`000a40000P0003
4@0001l000<A014080000a404@0P00034@0A020000<A01408@000a40000F00005P000a404@0P0003
4@0A020000<A014080000a404@0P00034@0A020000<A014080000a404@0G00005P000a404@0P0003
4@0A020000<A014080000a404@0C0003aP0000X000<A014030000lH0000A00034@0A020000<A0140
5`0000T00/H;00034@0A00/00/HC00034@0A01l000DA00004@0N00054@0001404P000lH000090005
4@0001402`000lH0000@00054@0001407`000a404@0G00002`06C@@000DA00004@0400I=50001A40
000A01800/H:C@054Dd0CA402Td2aPH03<H01A760<HA00c61`0;C@054Dd0CA402dd700;62Td01A5=
04dA00Y=0/HB00054@0001405P00014014`01A5<04`A00A<3P02aPY<00DAC01<4@09C0?650000d`0
000P0003aP0001<000?600002P000d`0000:0003aP0001<000=<00004P000lI<C009C0054D`0C140
2d`00lH0000800005P03CB4000==00007`000dd0C@0P0003aP3601<000?600002@02C@0304e=00/0
00?600004@000dd0C@0Q0003C@0001H0000D009<0`02C1d00T`00`1<C00M009<0`02C1`00/H300;6
70000d`000030003C00001X00T`3009<7@02C00304a<01H0000C0003C@0000D000==00006002C@D0
00==00006@000dd000050003C@0001P000?600001@000lH0000G009=1`02CAT000==00001@000dd0
000I0003C@0000<000==00004`0001400T`9009<5`000d`000060003C00001L000=<00001`000d`0
000F0003aP0000L000?600004P02aP0304`000X000A<0<K650000d`000070003C00001H00T`7009<
4`0000l000?6C@0030000dg6000C0003C@0000P000==aP005@000dd000090003C@0001@000?60000
2@000lH0000C0003C@0000/000==00004`000dd000090003C@0001@000==00002@000dd0000@0000
3P000lH0000?0003aP00010000?600002`000lH0000B0003aP0000/000?600004P000lH0000;0003
aP00018000?600002`000lH0000B0003aP0000/000?600004P000d`0000;0003C00000l0000b0003
aP0000d000?6000040000lH0000=0003aP00010000?600003@000lH0000A0003aP0000/000?60000
4@000lH0000=0003aP00010000?600003@000lH0000>0000W0000lH0000;0003aP0005D0003o00<0
003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0
003o00<0003R0003aP0000/000?600003`000>8000?600002`000lH0000?0000h`000lH000090003
aP000100000G00034@000<T000=<00002@000d`0000@00005`000a4000390003C@0000T000==0000
400001H00Q7700;60`000d`000070004C00000;63P0001H000<A0140b0001<H004d90004C@00aQ00
000F00034@0A04@000<A0000@`000a40000P00034@0001T00d`400034@0000800d`A00005@001140
014Q00034@00020000<A000080000a40000P00034@00020000<A00006`02C@<000@A00000TdC0000
5@001A40000A020000<A00007`000a404@0Q00034@0001l000<A014080000a404@0M0005C0000140
0`000d`0000B00005@001A40000A020000<A00007`000a404@0P00034@0A020000<A014080000a40
4@0M00==00<A01400ddD000050000a40000200034@0001h000<A00004P02aP=<1`001A40000A00L0
0d`2aQ<000<A014080000a404@0P00034@0A01h000M<01404@1<01D0000D00034@00008000<A0000
7P000a40000G00E=0P001A40000A00801DdH00034@0A01l000DA00004@0N00054@0001407@001dd0
4DdA04d05@0001@000<A00000`000a40000M00034@0001`000=<4D`00`000d`AC00@00;62T`01A5<
04`A00Y<0/H600;62T`01A5<04`A00Y<0/H600;62T`01A5<04`A00Y<0/HA0007C15<04`AC00E0000
200;C@034Dd000<000==4Dd02ddC00034@0001l000==04d08@000dd0000P0003C@00020000==0000
7P001A40000A01H0000E0004C000C20000=<4D`08@000d`0000N009<00<0C4`07`000d`0C00P0003
C01<01l000E<0000C00F00005P02CAh00dd300==7@000dd0C@0N0003C@0000<000==00006P02C@<0
0TdL009=0`02CA`000==00000`000dd0000C00005P03C1X00d`900=<6@001D`0001<01/00T`7009<
6@000d`000050003C00001P000=<00001@000d`0000I0003C00000<000=<00004`0001@00Td30003
C@0001@00dd?00==5@000dd000030003C@0001L000==00002@000dd0000E0003C@0000L000==0000
5P000dd000070003C@0001P000==00000`000dd0000C00004`000d`00004009<4@000lI<C00E0003
C<K6014000=<00001@000d`0000D0003aT`000`000=<aP004`000d`000090003C00001@000=<0000
2@000d`0000F0003C00000D000=<00004P00018000==00001`000dd0000=0003aP0001T000?60000
3@000lH000070003aP00018000?600003`000lH0000@0003aP0000/000?600004P000lH0000;0003
aP0001D000==00001@000dd0000B00004002C0/000=<0000=`000lH000090003aP0003D000?60000
3@000lH0000@0003aP0000d000?6000050000d`000050003C0000180000?0003C@0000`00Tg40003
C@0000L000==00004@0000h000=<00003`000d`000310003C00000L000=<00004@0000d000==0000
4@000dd000300003C@0000L000==00004@0000`000=<00004`000d`0002n0003C00000T000=<0000
40000><000?600002@000lH0000@0000hP000lH0000;0003aP0000l0003R0003aP0000/000?60000
3`000?l00`000?l00`000?l00`000?l00`000001\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.109415,
   0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110612, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.109415, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.74027, -0.110612, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.109415, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277,
   -0.110612, 0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.1939, -0.109415, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.270008, -1.2634, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  69.375, 37.5625}} -> {-1.42777, -1.26687, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26686, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.88594, -1.2634, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277,
   -1.26686, 0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.1939, -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.270008, -2.41738, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.74027, -2.42311, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277,
   -2.42311, 0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.19394, -2.41739, 0.0329417, 0.0329417}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.4224 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{141, 200},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002=0000b0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP0008d0002=0000S@0008d0002=0000S@0008d0
002=0000S@0008d0002=00006@02aUD00/HK00006@02aUD00/HK00006@03aU<00lHK00006P02aU<0
0/HL00006P02aU<00/HL00006P03aU400lHL00006`02aU400/HM00006`02aU400/HM00006`03aTl0
0lHM00007002aTl00/HN00007002aTl00/HN00007003aTd00lHN00007@02aTd00/HO00007@02aTd0
0/HO00007@03aT/00lHO00007P02aT/00/HP00007P02aT/00/HP00007P03aTT00lHP00007`02CDT0
0TdQ00007`02C4T00T`Q00007`02CDT00TdQ00007`03C4L00d`Q00008002CDL00TdR00008002C4L0
0T`R00008003CDD00ddR00008@02C4D00T`S00008@02CDD00TdS00008@03C4<00d`S00008P02CD<0
0TdT00008P02C4<00T`T00008P03CD400ddT00008`02C4400T`U00008`02CD400TdU00008`03C3l0
0d`U00001`03aQX00Tdo009=6P03aPT0000700C66@02C3l00T`I00C62@0000T00lHH00==?@03CAP0
0lH;00002P04aQL00T`m009<5`04aP`0000;00C65P02CCd00TdF00C63@0000d01<HD00=<>`03C1@0
1<H?00003P04aQ@00Tdk009=5004aQ00000@00?64`02C3/00T`C00?64P0001401<HA00==>@03CA40
1<HC00004P04aQ400T`i009<4@04aQ@0000D00?64002CA`00Q4K009=4003aQH0000E0004aTa<C0h0
0d`K008A6P03C0h00d`00lH0000E00005P04C@h00TdJ00<A6P02C@h014dH00006003C0d00T`J00@A
6@02C0d00d`J00006@04C@/00ddI00@A6003C@/014dK00006P04C0/00T`H00DA6002C0/014`L0000
7004C@T00TdH008A00@04A4A5`02C@T014dN00007@04C0P00d`G008A0P024AH00d`800A<7`0001l0
0dd8009=5P034@800Q4F009=2003CB40000P00A<1P02C1H00Q4300<A5@02C0H014`R00008@04C@D0
0ddE008A10024A@00dd500A=8`0002<014`4009<50034@@00Q4D009<1004C2D0000T00A=0`02CA@0
0Q4500<A4`02C@<014dV00009P03C0800T`D008A1P024A<00T`200=<:00002L01ddB00<A1P024A80
1ddY0000:006C1800Q4700<A4@06C2X0000Z00A=4P024@P00Q4A00A=;00002/014`@00<A20024A00
14`]0000;004C@l00Q49008A3`04CBh0000]00E<3@024@T00a4<00E<;`0002d01Td;00<A2P024@/0
1Td_0000;P02C00404a<C0X00Q4;008A2P03C00304a<0300000^009=0P04C@P00Q4;00<A1`04C@80
0Td`0000;P03C08014`600<A30024@H014`200=<<00002l00Td400A=10024@d00Q4400A=1002CC40
000_009<1@04C0<00Q4=00<A0P04C0D00T`a0000;`03C@H00dd0100A4A4>008A00@0CDe=1P03CC40
000`009<1`03C08A3`024@=<1`02C380000`009=2002C@8A3`034@03C@0000H00Tdb0000<003C0P0
0a42C0/00d`24@P00d`b0000<@02C@P00Q44C@T014d24@P00Tdc0000<@02C0P00Q4200=<1`03C080
0Q48009<<`0003400dd600<A0`04C@<014d300<A1P03CC<0000b009<1P024@D014`00`1<C002C0D0
0Q46009<=00003800Td6008A1`05C@L00Q46009==00003800d`400<A1`05C0L00a4400=<=00003<0
0Td4008A1`07C@L00Q44009==@0003<00T`4008A1@04C0<014`5008A1002C3D0000c00==0P034@@0
14d500A=10034@800dde0000=002C0800Q4400=<2@03C0@00Q42009<=P0003@00Td2008A0P04C@/0
14d2008A0P02CCH0000d00=<0a400`1<C002C0d014`0100A4A43C3H0000e009=0Q44CA4014d24@9=
=`0003D00T`24@=<4`03C08A0T`g0000=@001DdA4A5=01L000E=4A4AC@0g0000=P024@03C00001L0
00=<4A40>00003H00Q4K008A>00003H00T`K009<>00003D00ddK00===`0003D00T`M009<=`0003D0
0TdM009==`0003@00d`M00=<=P0003@00TdO009==P0003@00T`O009<=P0003<00ddO00===@0003<0
0T`Q009<=@0003<00TdQ009==@0003800d`Q00=<=00003800TdS009==00003800T`S009<=0000340
0ddS00==<`0003400T`U009<<`0003400TdU009=<`0003000d`U00=<<P0003000TdW009=<P000300
0T`W009<<P0002l00ddW00==<@0002l00T`Y009<<@0002l00TdY009=<@0002h00d`Y00=<<00002h0
0Td[009=<00002h00T`[009<<00002d00dd[00==;`0002d00T`]009<;`0002d00Td]009=;`0002`0
0d`]00=<;P0002`00Td_009=;P0002`00T`_009<;P0002/00dd_00==;@0002/00T`a009<;@0002/0
0Tda009=;@0002X00d`a00=<;00002X00Tdc009=;00002X00T`c009<;00002X00Tdc009=;00002T0
0d`c00=<:`0002T00Tde009=:`0002T00T`e009<:`0002P00dde00==:P0002P00T`g009<:P0002P0
0Tdg009=:P0002L00d`g00=<:@0002L00Tdi009=:@0002L00T`i009<:@0002H00ddi00==:00002H0
0T`k009<:00002H00Tdk009=:00002D00d`k00=<9`0002D00Tdm009=9`0002D00T`m009<9`0002@0
0ddm00==9P0002@00T`o009<9P0002@00Tdo009=9P0002<00d`o00=<9@0002<00Te1009=9@0002<0
0Ta1009<9@0002800de100==900002800Ta3009<900002800Te3009=900002400da300=<8`000240
0Te5009=8`0002400Ta5009<8`0002000de500==8P0002000Ta7009<8P0002000Te7009=8P0001l0
0da700=<8@0001l00Te9009=8@0001l00Ta9009<8@0001h00lI900?6800001h00/I;00;6800001h0
0/I;00;6800001d00lI;00?67`0001d00/I=00;67`0001d00/I=00;67`0001`00lI=00?67P0001`0
0/I?00;67P0001`00/I?00;67P0001/00lI?00?67@0001/00/IA00;67@0001/00/IA00;67@0001X0
0lIA00?6700001X00/IC00;6700001X00/IC00;6700001T00lIC00?66`0001T00/IE00;66`0001T0
0/IE00;66`0008d0002=0000S@0008d0002=0000S@0008d0002=0000S@000001\
\>"],
  ImageRangeCache->{{{0, 140}, {199, 0}} -> {0.130649, -0.0250053, 0.00527646,
   0.00527646}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.02 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.02 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.02 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.02 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.02 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.02 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
.2 0 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
.2 0 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
.2 0 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
.2 0 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
.2 0 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0234887 1.04698 0.0261744 1.04698 [
[ 0 0 0 0 ]
[ 1 1.09933 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.09933 L
0 1.09933 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.15026 .14758 m
.08445 .057 L
s
P
p
0 .4 1 r
.018 w
.27511 .93584 m
.24051 1.04232 L
s
P
p
0 .4 1 r
.018 w
.83944 .37151 m
.94592 .33691 L
s
P
p
.2 0 1 r
.016 w
.4135 .50991 m
.15026 .14758 L
s
P
p
.2 0 1 r
.016 w
.4135 .50991 m
.27511 .93584 L
s
P
p
.2 0 1 r
.016 w
.4135 .50991 m
.83944 .37151 L
s
P
p
0 .4 1 r
.018 w
.16056 .37151 m
.05408 .33691 L
s
P
p
0 .4 1 r
.018 w
.72489 .93584 m
.75949 1.04232 L
s
P
p
0 .4 1 r
.018 w
.84974 .14758 m
.91555 .057 L
s
P
p
.2 0 1 r
.016 w
.5865 .50991 m
.16056 .37151 L
s
P
p
.2 0 1 r
.016 w
.5865 .50991 m
.72489 .93584 L
s
P
p
.2 0 1 r
.016 w
.5865 .50991 m
.84974 .14758 L
s
P
p
1 .6 0 r
.016 w
.5 .2437 m
.4135 .50991 L
s
P
p
1 .6 0 r
.016 w
.5 .2437 m
.5865 .50991 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.19431 1.38862 0.0347155 1.38862 [
[ 0 0 0 0 ]
[ 1 1.45805 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.45805 L
0 1.45805 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.21702 .22098 m
.16985 .07583 L
s
P
p
0 .4 1 r
.018 w
.21702 1.23707 m
.16985 1.38223 L
s
P
p
0 .4 1 r
.018 w
.81426 .41504 m
.93774 .32533 L
s
P
p
.2 0 1 r
.016 w
.38209 .72903 m
.21702 .22098 L
s
P
p
.2 0 1 r
.016 w
.38209 .72903 m
.21702 1.23707 L
s
P
p
.2 0 1 r
.016 w
.38209 .72903 m
.81426 .41504 L
s
P
p
0 .4 1 r
.018 w
.18574 .41504 m
.06226 .32533 L
s
P
p
0 .4 1 r
.018 w
.78298 1.23707 m
.83015 1.38223 L
s
P
p
0 .4 1 r
.018 w
.78298 .22098 m
.83015 .07583 L
s
P
p
.2 0 1 r
.016 w
.61791 .72903 m
.18574 .41504 L
s
P
p
.2 0 1 r
.016 w
.61791 .72903 m
.78298 1.23707 L
s
P
p
.2 0 1 r
.016 w
.61791 .72903 m
.78298 .22098 L
s
P
p
1 .6 0 r
.016 w
.5 .36614 m
.38209 .72903 L
s
P
p
1 .6 0 r
.016 w
.5 .36614 m
.61791 .72903 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.014 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.014 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.014 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.014 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.014 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.014 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.8 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.8 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.8 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.8 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.8 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.8 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .21298 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .27756 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.24057 .30222 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.36341 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.36341 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.24057 1.0266 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.05127 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.11585 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.74227 .25625 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.74227 .46524 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.69535 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.8941 .46524 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.1059 .46524 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.30465 .40066 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.25773 .46524 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.25773 .25625 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.11585 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.05127 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.75943 1.0266 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.63659 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.63659 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.75943 .30222 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .27756 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .21298 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.164046 1.32809 0.0332023 1.32809 [
[ 0 0 0 0 ]
[ 1 1.3945 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.3945 L
0 1.3945 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.25957 .24188 m
.20409 .07112 L
s
P
p
0 .4 1 r
.018 w
.25957 1.15261 m
.20409 1.32338 L
s
P
p
0 .4 1 r
.018 w
.79488 .41582 m
.94014 .31028 L
s
P
p
.2 0 1 r
.016 w
.40753 .69725 m
.25957 .24188 L
s
P
p
.2 0 1 r
.016 w
.40753 .69725 m
.25957 1.15261 L
s
P
p
.2 0 1 r
.016 w
.40753 .69725 m
.79488 .41582 L
s
P
p
0 .4 1 r
.018 w
.20512 .41582 m
.05986 .31028 L
s
P
p
0 .4 1 r
.018 w
.74043 1.15261 m
.79591 1.32338 L
s
P
p
0 .4 1 r
.018 w
.74043 .24188 m
.79591 .07112 L
s
P
p
.2 0 1 r
.016 w
.59247 .69725 m
.20512 .41582 L
s
P
p
.2 0 1 r
.016 w
.59247 .69725 m
.74043 1.15261 L
s
P
p
.2 0 1 r
.016 w
.59247 .69725 m
.74043 .24188 L
s
P
p
1 .6 0 r
.016 w
.5 .41264 m
.40753 .69725 L
s
P
p
1 .6 0 r
.016 w
.5 .41264 m
.59247 .69725 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.216768 1.43354 0.0358384 1.43354 [
[ 0 0 0 0 ]
[ 1 1.50521 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.50521 L
0 1.50521 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.016 w
.36327 .75261 m
.14451 .07932 L
s
P
p
.2 0 1 r
.016 w
.36327 .75261 m
.14451 1.4259 L
s
P
p
.2 0 1 r
.016 w
.36327 .75261 m
.93601 .33649 L
s
P
p
.2 0 1 r
.016 w
.63673 .75261 m
.06399 .33649 L
s
P
p
.2 0 1 r
.016 w
.63673 .75261 m
.85549 1.4259 L
s
P
p
.2 0 1 r
.016 w
.63673 .75261 m
.85549 .07932 L
s
P
p
1 .6 0 r
.016 w
.5 .3318 m
.36327 .75261 L
s
P
p
1 .6 0 r
.016 w
.5 .3318 m
.63673 .75261 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0608526 1.12171 0.0280426 1.12171 [
[ 0 0 0 0 ]
[ 1 1.17779 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.17779 L
0 1.17779 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.35166 .16101 m
.35166 .06006 L
s
P
p
0 .4 1 r
.018 w
.11432 .89147 m
.05499 .97314 L
s
P
p
0 .4 1 r
.018 w
.73569 .44002 m
.83169 .40882 L
s
P
p
.2 0 1 r
.016 w
.35166 .5648 m
.35166 .16101 L
s
P
p
.2 0 1 r
.016 w
.35166 .5648 m
.11432 .89147 L
s
P
p
.2 0 1 r
.016 w
.35166 .5648 m
.73569 .44002 L
s
P
p
0 .4 1 r
.018 w
.26266 .28632 m
.20332 .20465 L
s
P
p
0 .4 1 r
.018 w
.5 1.01678 m
.5 1.11773 L
s
P
p
0 .4 1 r
.018 w
.73734 .28632 m
.79668 .20465 L
s
P
p
.2 0 1 r
.016 w
.5 .61299 m
.26266 .28632 L
s
P
p
.2 0 1 r
.016 w
.5 .61299 m
.5 1.01678 L
s
P
p
.2 0 1 r
.016 w
.5 .61299 m
.73734 .28632 L
s
P
p
0 .4 1 r
.018 w
.26431 .44002 m
.16831 .40882 L
s
P
p
0 .4 1 r
.018 w
.88568 .89147 m
.94501 .97314 L
s
P
p
0 .4 1 r
.018 w
.64834 .16101 m
.64834 .06006 L
s
P
p
.2 0 1 r
.016 w
.64834 .5648 m
.26431 .44002 L
s
P
p
.2 0 1 r
.016 w
.64834 .5648 m
.88568 .89147 L
s
P
p
.2 0 1 r
.016 w
.64834 .5648 m
.64834 .16101 L
s
P
p
1 .6 0 r
.016 w
.5 .36063 m
.35166 .5648 L
s
P
p
1 .6 0 r
.016 w
.5 .36063 m
.5 .61299 L
s
P
p
1 .6 0 r
.016 w
.5 .36063 m
.64834 .5648 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.194931 1.38986 0.0347465 1.38986 [
[ 0 0 0 0 ]
[ 1 1.45935 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.45935 L
0 1.45935 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.19244 .19934 m
.12918 .07518 L
s
P
p
0 .4 1 r
.018 w
.3583 1.24654 m
.3365 1.38418 L
s
P
p
0 .4 1 r
.018 w
.83965 .30185 m
.93818 .20331 L
s
P
p
.2 0 1 r
.016 w
.4455 .696 m
.19244 .19934 L
s
P
p
.2 0 1 r
.016 w
.4455 .696 m
.3583 1.24654 L
s
P
p
.2 0 1 r
.016 w
.4455 .696 m
.83965 .30185 L
s
P
p
0 .4 1 r
.018 w
.16035 .30185 m
.06182 .20331 L
s
P
p
0 .4 1 r
.018 w
.6417 1.24654 m
.6635 1.38418 L
s
P
p
0 .4 1 r
.018 w
.80756 .19934 m
.87082 .07518 L
s
P
p
.2 0 1 r
.016 w
.5545 .696 m
.16035 .30185 L
s
P
p
.2 0 1 r
.016 w
.5545 .696 m
.6417 1.24654 L
s
P
p
.2 0 1 r
.016 w
.5545 .696 m
.80756 .19934 L
s
P
p
1 .6 0 r
.016 w
.5 .3519 m
.4455 .696 L
s
P
p
1 .6 0 r
.016 w
.5 .3519 m
.5545 .696 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.208517 1.41703 0.0354259 1.41703 [
[ 0 0 0 0 ]
[ 1 1.48789 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.48789 L
0 1.48789 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.19641 .21003 m
.15304 .07656 L
s
P
p
0 .4 1 r
.018 w
.19641 1.27785 m
.15304 1.41133 L
s
P
p
0 .4 1 r
.018 w
.82406 .41397 m
.93761 .33147 L
s
P
p
.2 0 1 r
.016 w
.36989 .74394 m
.19641 .21003 L
s
P
p
.2 0 1 r
.016 w
.36989 .74394 m
.19641 1.27785 L
s
P
p
.2 0 1 r
.016 w
.36989 .74394 m
.82406 .41397 L
s
P
p
0 .4 1 r
.018 w
.17594 .41397 m
.06239 .33147 L
s
P
p
0 .4 1 r
.018 w
.80359 1.27785 m
.84696 1.41133 L
s
P
p
0 .4 1 r
.018 w
.80359 .21003 m
.84696 .07656 L
s
P
p
.2 0 1 r
.016 w
.63011 .74394 m
.17594 .41397 L
s
P
p
.2 0 1 r
.016 w
.63011 .74394 m
.80359 1.27785 L
s
P
p
.2 0 1 r
.016 w
.63011 .74394 m
.80359 .21003 L
s
P
p
1 .6 0 r
.016 w
.5 .34351 m
.36989 .74394 L
s
P
p
1 .6 0 r
.016 w
.5 .34351 m
.63011 .74394 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.018 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.018 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
.8 1 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
.8 1 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.233093 0.952381 [
[ 0 0 0 0 ]
[ 1 .4862 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .4862 L
0 .4862 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.12843 .22125 m
.05058 .22125 L
s
P
p
0 .4 1 r
.018 w
.6918 .4043 m
.75478 .45006 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.12843 .22125 L
s
P
p
.2 0 1 r
.016 w
.43985 .22125 m
.6918 .4043 L
s
P
p
0 .4 1 r
.018 w
.3082 .4043 m
.24522 .45006 L
s
P
p
0 .4 1 r
.018 w
.87157 .22125 m
.94942 .22125 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.3082 .4043 L
s
P
p
.2 0 1 r
.016 w
.56015 .22125 m
.87157 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.43985 .22125 L
s
P
p
1 .6 0 r
.016 w
.5 .03614 m
.56015 .22125 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`00010000?600002`000lH0000B0003C@0000/000==00004P000lH0000;0003aP00018000?60000
2`000lH0000B0003aP0000/000?600004P000lH0000;0003aP00018000?600002`000lH0000?0000
40000lH0000;0003aP00018000=<00002`000d`0000B0003aP0000/000?600004P000lH0000;0003
aP00018000?600002`000lH0000B0003aP0000/000?600004P000lH0000;0003aP0000l0000A0003
aP0000T000?6000050000dd000090003C@0001@000?600002@000lH0000D0003aP0000T000?60000
50000lH000090003aP0001@000?600002@000lH0000D0003aP0000T000?600004000014000=<0000
2@000d`0000D0003C00000T000=<000050000d`000090003C00001@000=<00002@000d`0000D0003
C00000T000=<000050000d`000090003C00001@000=<00002@000d`0000@00004@000dd000090003
C@0001@000==00002@000dd0000D0003C@0000T000==000050000dd000090003C@0001@000==0000
2@000dd0000D0003C@0000T000==000050000dd000090003C@000100000=0003aP00008000=<0000
1`0014`00002aPh00T`30003C00000L000A<00000T`>00;60`000d`000070004C00000;63P02aP<0
00=<00001`0014`00002aPh00/H30003C00000L000A<00000/H>00;60`000d`000070004C00000;6
3P02aP<000=<00001`0014`00002aPh0000>0005aP0004d02@0014d00<HB0004C@00C@T000A=001=
4P001<H004d90004C@00aQ8000C6001=2@0014d00<HB0004aP00C@T000A=00364P001<H004d90004
C@00aQ8000C6001=2@0014d00<H@00003`02C00304`000<000<A00000P03C1@00d`400034@000080
0d`D00=<10000a40000200=<5003C0@000<A00000P03C1@00d`400034@0000800d`D00=<10000a40
000200=<5003C0@000<A00000P03C140000A0003C@1=00<000@A00000TdH009=0`0011400002CAP0
0Td300044@00009=6002C@<000@A00000TdH009=0`0011400002CAP00Td300044@00009=6002C@<0
00@A00000TdC00004P02C0<000DA0000C00J0005C00001400`000d`0000H0005C00001400`000d`0
000H0005C00001400`000d`0000H0005C00001400`000d`0000H0005C00001400`000d`0000H0005
C00001400`000d`0000B00004`02C@0401404@==6P03C@034@0A00==6P03C@034@0A00==6P03C@03
4@0A00==6P03C@034@0A00==6P03C@034@0A00==6P03C@034@0A00==500001@00T`01A404@1<01`0
00M<01404@1<01`000M<01404@1<01`000M<01404@1<01`000M<01404@1<01`000M<01404@1<01`0
00M<01404@1<01D0000D0007C@0ACA40C@0L0007C@0ACA40C@0L0007C@0ACA40C@0L0007C@0ACA40
C@0L0007C@0ACA40C@0L0007C@0ACA40C@0L0007C@0ACA40C@0E000050001d`AC01<4D`070001d`A
C01<4D`070001d`AC01<4D`070001d`AC01<4D`070001d`AC01<4D`070001d`AC01<4D`070001d`A
C01<4D`05@0001D000DA00004@0N00054@0001407P001A40000A01h000DA00004@0N00054@000140
7P001A40000A01h000DA00004@0F00005@001D`0001<01h000E<0000C00N0005C00004`07P001D`0
001<01h000E<0000C00N0005C00004`07P001D`0001<01H0000D0003C@0000<000==00006P000dd0
00030003C@0001X000==00000`000dd0000J0003C@0000<000==00006P000dd000030003C@0001X0
00==00000`000dd0000J0003C@0000<000==00004`0001@000=<00000`000d`0000J0003C00000<0
00=<00006P000d`000030003C00001X000=<00000`000d`0000J0003C00000<000=<00006P000d`0
00030003C00001X000=<00000`000d`0000C000050000dd000030003C@0001X000==00000`000dd0
000J0003C@0000<000==00006P000dd000030003C@0001X000==00000`000dd0000J0003C@0000<0
00==00006P000dd000030003C@0001<0000C0003C00000D000=<000060000d`000050003C00001P0
00=<00001@000d`0000H0003C00000D000=<000060000d`000050003C00001P000=<00001@000d`0
000H0003C00000D000=<00004P0001<000==00001@000dd0000H0003C@0000D000==000060000dd0
00050003C@0001P000==00001@000dd0000H0003C@0000D000==000060000dd000050003C@0001P0
00==00001@000dd0000B00004`000d`000050003C00001P000=<00001@000d`0000H0003C00000D0
00=<000060000d`000050003C00001P000=<00001@000d`0000H0003C00000D000=<000060000d`0
00050003C0000180000B0003C@0000L000==00005P000dd000070003C@0001H000==00001`000dd0
000F0003C@0000L000==00005P000dd000070003C@0001H000==00001`000dd0000F0003C@0000L0
00==00004@00018000=<00001`000d`0000F0003C00000L000=<00005P000d`000070003C00001H0
00=<00001`000d`0000F0003C00000L000=<00005P000d`000070003C00001H000=<00001`000d`0
000A00004P000dd000070003C@0001H000==00001`000dd0000F0003C@0000L000==00005P000dd0
00070003C@0001H000==00001`000dd0000F0003C@0000L000==00005P000dd000070003C@000140
000A0003C00000T000=<000050000d`000090003C00001@000=<00002@000d`0000D0003C00000T0
00=<000050000d`000090003C00001@000=<00002@000d`0000D0003C00000T000=<000040000140
00?600002@000lH0000D0003C@0000T000==000050000lH000090003aP0001@000?600002@000lH0
000D0003aP0000T000?6000050000lH000090003aP0001@000?600002@000lH0000@000040000lH0
000;0003aP00018000=<00002`000d`0000B0003aP0000/000?600004P000lH0000;0003aP000180
00?600002`000lH0000B0003aP0000/000?600004P000lH0000;0003aP0000l0000@0003aP0000/0
00?600004P000dd0000;0003C@00018000?600002`000lH0000B0003aP0000/000?600004P000lH0
000;0003aP00018000?600002`000lH0000B0003aP0000/000?600003`000?l00`000?l00`000?l0
0`000?l00`000?l00`000?l00`0000/000?600005@000lH0000=0003aP0000/000?600004P000lH0
000;0003aP00018000?600002`000lH0000E0003aP0000D000?600005@000lH0000;0003aP000180
00?600002`000lH0000?000030000lH0000C0003aP0000h000?600002`000lH0000B0003aP0000/0
00?600004P000lH0000;0003aP0001000lH01036a/H500?60P02aQ8000?600002`000lH0000B0003
aP0000/000?600003`0000d000=<00004@000d`0000@0003aP0000T000?6000050000lH000090003
aP0001@000?600002@000lH0000C0003aTc600X000=<a/H050000lH000090003aP0001@000?60000
2P000lH0000?00003@000dd0000A0003C@00010000==00002@000dd0000D0003C@0000T000==0000
50000d8000090003@P0001400/H00`1=000:0004C@00aQ<000==00002@000dd0000D0003aP0000T0
00?60000400000h000=<00003`000d`0000A0003C00000T000=<000050000d`000090003C00001@0
00=200002@000d80000B0004aP36C0T000A<aP3650000d`000090003C00001D000=<000020000d`0
000@00003`000dd0000500034@0000D000==00003P02aP8000==000020001Dd0003600l00/H30003
C@0000L000A=00000/H>00;60`000d8000070004@P0000;640001LH0aTg600L000G6CLH0aP0@00;6
0`000dd000070004C@0000;63P000lH000020003C@0000P000E=0000aP0>00003`000d`000050003
4@0000@000=<00004@001<H004`400034@00008000A<00364P001<H004`90004C000aQ8000C60012
2@0014800<HB00;600<0C000200014`0a/HB0004aP00C0T000A<00364@001LH0001<00T000E<0000
aP0?000040000dd00003008A1P000dd0000B00==10000a40000200==5003C@@000<A00000P03CA@0
0d8400034@0000800d8B0006aTe=aP1=0`001A40001=00800Td2aQ400dd400034@0000800ddC0005
aP0004d0200014d00<H@00002P03aP@000=<00000P000a404@040003C00000<00/H@0004C000008A
0`02C1P00T`300044@00009<6002@P<000@A00000T8B00;600H0a/I<aT`300074@0004c6C002aP80
00?600004002C0<000@A00000T`F009<00<0C0000P000a40000200=<4@0000d00dd00`1=00030003
4@0A00<000==00000dd00lH0000A0007C@004@0A0002CAX000E=00004@030003C@0001P000E20000
4@030003@P0001<000C600360Td300044@00009=00C600365@001Dd0000A00<000==00005`02C@<0
00@A00000TdC00004003C08000@A000A0`03C1L00d`01Q404D`0C1X00d`00a404@03C1X00d800a40
4@03@Q/000M<01404@1<01/00d`00a404@03C1X00T`01@0A0140009<500001800dd011400143CAX0
00Q=015=0140CA`000M=01404@1=01`000M201404@1201`00Td00a404@02CA`000M=01404@1=01`0
0Td00a404@02CAD0000C0003C00A00=<00<AC0006P000d`04@02C0034@1<01`000M<015<4@1<01`0
00M201524@1201`000M<015<4@1<01`000M<015<4@1<01`000M<015<4@1<01D0000D00034Dd00080
00<A00006`001ddA001=4Dd070001ddAC@1=4Dd070001d8A@P124D807@001A5=04dA01d000M=4Dd0
CA5=01d000HAC@1=4DdE000050000d`000020003C00001/000<A00000P000a40000L00054@000140
7P001A40000A01h000DA00004@0N00054@0001407P001A40000A01H0000C0003C@0000@000==0000
6P000dd000020003C@0001`000E=0000C@0N0005@P0004807P001Dd0001=01h000E=0000C@0N0005
C@0004d05P0001<000=<000010000d`0000J0003C00000<000=<00006P000d`000030003C00001X0
00=200000`000d80000J0003C00000<000=<00006P000d`000030003C00001/000=<00000P000d`0
000C00004`000dd000040003C@0001T000==000010000dd0000J0003C@0000<000==00006P000d80
00030003@P0001X000==00000`000dd0000J0003C@0000<000==00006P000dd000030003C@0001<0
000B0003C00000H000=<000060000d`000040003C00001X000=<00000`000d`0000J0003@P0000<0
00=200006P000d`000030003C00001X000=<00000`000d`0000J0003C00000<000=<00004`000180
00==00001P000dd0000H0003C@0000D000==000060000dd000050003C@0001P000=200001@000d80
000H0003C@0000D000==000060000dd000050003C@0001T000==000010000dd0000B00004P000d`0
00060003C00001L000=<00001P000d`0000H0003C00000D000=<000060000d8000050003@P0001P0
00=<00001@000d`0000H0003C00000D000=<000060000d`000050003C0000180000A0003C@0000P0
00==00005P000dd000060003C@0001P000==00001@000dd0000H0003@P0000D000=2000060000dd0
00050003C@0001P000==00001@000dd0000H0003C@0000H000==00004@00014000=<000020000d`0
000F0003C00000L000=<00005P000d`000070003C00001H000=200001`000d80000F0003C00000L0
00=<00005P000d`000070003C00001L000=<00001P000d`0000A00004@000dd000080003C@0001H0
00==00001`000dd0000F0003C@0000L000==00005P000d8000070003@P0001D000?6CLH01`000lI=
aP0G0003C@0000L000==00005P000dd000070003C@000140000@0003C00000X000=<000050000d`0
00080003C00001H000=<00001`000d`0000F0003@P0000L000=200005@000lI<aP070003aTc601L0
00=<00001`000d`0000F0003C00000P000=<00004000010000==00002P000dd0000D0003C@0000T0
00==000050000dd000090003C@0001@000=200002@000d80000A00?600==aP0020000lI=0002aQ<0
00==00002@000dd0000E0003aP0000P000?600004000010000?600002P000lH0000D0003aP0000T0
00?6000050000lH000090003aP0001@000?600002@000lH0000C0004aTc6aPP000C6C<K650000lH0
00090003aP0001@000?600002@000lH0000@00003`000lH0000<0003aP00018000?600002`000lH0
000B0003aP0000/000?600004P000lH0000;0003aP0001000/H20003aP3600D00lH30003aP000100
00?600002`000lH0000C0003aP0000X000?600003`0000l000?6000030000lH0000B0003aP0000/0
00?600004P000lH0000;0003aP00018000?600002`000lH0000E0003aP0000D000?600005@000lH0
000;0003aP00018000?600002`000lH0000?0000o`030000o`030000o`030000o`030000o`030000
o`0300003`000dd0000<0003C@0001D000?600001@000lH0000D0003aP0000d000?600004@000lH0
000;0003aP00018000?600002`000lH0000B0003aP0000/000?60000<P0000l000=<000030000d`0
000E0003aP0000D000?6000050000lH0000=0003aP00014000?600002`000lH0000B0003aP0000/0
00?600004P000lH0000;0003aP000380000@0003C@0000/000==00005@000dd000050003C@0001D0
00==00002`000dd0000B0003aP0000X000?6000050000lH000090003aP0001@000?600002@000lH0
000c000040000d`0000:0003C00001H000=<00001@000d`0000B00;600<0C000300014`0a/HA0003
C00000X000=<000050000d`000090003C00001@000=<00002@000d`0000c000040000dd0000:0003
C@00018000G60000C@070005C@000<H04P000lH0C@0;0003C@3601<000==00002P000dd0000D0003
C@0000T000==000050000dd000090003C@0003<0000>009<00<0C00010000a4000030004C01<C140
00G60000C0070004C000aQ@00T`;009<4P001<H004`500034@0000<000A<00363`02aP<000=<0000
1`0014`00002aPh00/H30003C00000L000A<00000/Ha00004002C@D000<A00000P000dd0C@0D0004
C@00C@L000==04d05P02C@@000<A00000P02CA@000?604d01@000a4000020004C@00aQ8000C6001=
2@0014d00<HB0004aP00C@T000A=0036<`00014000=<00000P000a404@03009<5@0014`004`70003
C01<01L000=<00000P000a4000020003C00001@00T`400034@0A00<00d`D00=<10000a40000200=<
5003C0@000?O00000P03C1/000<A00005P0001800Td200034@0A00800TdG0003C@1=00<000@A0000
0TdI0005C@0001400`000dd0000G0007C@0001404@030003C@0001H00Td300044@00009=6002C@<0
00CN00000TdM00034@0001H0000B000;C01<01404@1<04`05003aP0304a<00<000DA0000C00300;6
5P0014`001420003C00001P00d`01@0A0140009<6P001D`0000A00<000=<000060001D`0003O00<0
00=<00006`000a404@0G00004P0014d0014300034@1=01P00dd200<A0P03C@03aP0001H00Td00a40
4@02CAX000A=000A0`000a40C@0J00==00<A01400ddJ00==00?N0=h00ddM00034@0A01L0000C0003
C00A00=<00<A04`06P02C0054D`AC1400T`L0005C1404D`070002D`04D`0C140C00K0007C00A0140
C00L0007C03O0=l0C00N00034@0A01L0000C0009C@0AC@1=4@1=01X000E=4De=4@02C@034Dd001/0
00E=4DdAC@0L0003C@0A00==00<A04d06`001dd04DdA04d070001dd0gTgN04d07@001A40000A01H0
000C0003C15<00<000=<4@006P001Q5<C00A009<00<A00006`000a404@0M0003C15<00<000=<4@00
6`001d`AC01<4D`070001dcOC01<gd`04@02aPY<00DAC01<4@0:C0;62P0001@000<A00000`000a40
000I0006C@00CA5=0P000dd0000K0003C@1=01h000<A00000`000a40000K00054@0001407P001Mh0
003N020000==00005P0001@000=<00000`000d`0000H0003C000008000<A00000P000d`0000J0003
C01<01h000=<00000`000d`0000K0005C00004`07P001D`0001<01l000=<04`05`0001<000==0000
10000dd0000G0003C@0000<000==00000`000dd0000I0003C@1=01d000==000010000dd0000J0003
C@0000<000==00006P000dd000030003C@0001X00Td3009=5@0001<000=<00001@000d`0000E0003
C00000@000=<00000`000d`0000H0005C00004`070000d`000050003C00001T000=<00000`000d`0
000J0003C00000<000=<00006@000d`000050003C0000180000C0003C@0000D000==000050000dd0
00050003C@0000@000==00005`001Dd0001=01`000==00001@000dd0000I0003C@0000<000==0000
6P000dd000030003C@0001P000==00001`000dd0000A00004P000d`000060003C00001@000=<0000
1@000d`000050003C00001H000E<0000C00K0003C00000H000=<000060000d`000050003C00001P0
00=<00001@000d`0000F0003C00000T000=<00004000018000==00001`000dd0000B0003C@0000H0
00==00001@000dd0000F0005C@0004d06`000dd000070003C@0001L000==00001@000dd0000H0003
C@0000D000==00005@000lH0000;0003aP0000l0000B0003C00000L000=<00004@000d`000070003
C00000H000=<00005@001D`0001<01/000=<00001`000d`0000G0003C00000D000=<000060000d`0
00050003C00001@000?600003@000lH0000>00004@000dd000080003C@00010000==000020000dd0
00070003C@0001@000E=0000C@0J0003C@0000P000==00005P000dd000070003C@0001H000==0000
1`000dd0000d00004@000d`000080003C000010000?6000020000d`000080003aP00018000=<0000
0`000d`0000G0003C00000P000=<00005P000d`000070003C00001H000=<00001`000d`0000d0000
4@000dd000090003C@0000h000?600002@000dd000090003aP00014000==00000`000dd0000G0003
C@0000T000==00005@000dd000070003C@0001H000==00001`000dd0000d000040000d`0000:0003
C00001X000=<00007@000d`000030003C00001H000=<00002P000d`0000D0003C00000T000=<0000
50000d`000090003C00003<0000@0003C@0000X000==00006P000dd0000M0003aP0000<000?60000
5P000lH0000:0003aP0001@000?600002@000lH0000D0003aP0000T000?60000<`00010000=<0000
2`000d`0000I0003aP0001`000?600001@000lH0000E0003aP0000/000?600004P000lH0000;0003
aP00018000?600002`000lH0000b00003`000dd0000<0003C@0001T000?6000070000lH000050003
aP0001D000?600002`000lH0000B0003aP0000/000?600004P000lH0000;0003aP000380003o00<0
003o00<0003o00<0003o00<00000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.27001, -0.109418, 
  0.0329417, 0.0329417}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.424,
   -0.109418, 0.0329417, 0.0329417}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57799, -0.109418, 0.0329417, 0.0329417}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.73197, -0.109418, 0.0329417, 0.0329417}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88596, -0.109418, 0.0329417, 
  0.0329417}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.03995,
   -0.109418, 0.0329417, 0.0329417}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.19394, -0.109418, 0.0329417, 0.0329417}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.271522, -1.26687, 0.0330063, 0.0330063}, {{42.5, 74.3125},
   {69.375, 37.5625}} -> {-1.42777, -1.26686, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.58403, -1.26687, 0.0330064, 0.0330064},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74029, -1.26687, 0.0330064, 
  0.0330064}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.89653, -1.26687, 
  0.0330063, 0.0330063}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.0528,
   -1.26687, 0.0330064, 0.0330064}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.20905, -1.26687, 0.0330064, 0.0330064}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.270006, -2.41737, 0.0329414, 0.0329414}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42398, -2.41737, 0.0329414, 0.0329414}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57796, -2.41738, 0.0329414, 0.0329414}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.73198, -2.4174, 0.0329417, 
  0.0329417}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88596, -2.41739, 
  0.0329417, 0.0329417}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.03995,
   -2.41739, 0.0329417, 0.0329417}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1939, -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.32883 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .21298 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .27756 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.24057 .30222 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.36341 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.36341 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.24057 1.0266 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.05127 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.11585 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.74227 .25625 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.74227 .46524 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.69535 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.8941 .46524 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.1059 .46524 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.30465 .40066 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.25773 .46524 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.25773 .25625 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.11585 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.05127 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.75943 1.0266 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.63659 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.63659 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.75943 .30222 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .27756 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .21298 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{145, 192},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A0000`0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000940002A0000T@000940002A0000T@000940
002A0000T@000940000/00;6<`02aRh0000/00;6<`02aRh0000[00?6<`03aRd0000Z00?6=@03aR`0
000Y00?6=`03aR/0000Y00;6>@02aR/0000X00?6>@03aRX0000W00?6>`03aRT0000V00?6?@03aRP0
000V00;6?`02aRP0000@00C64@03aPT01<HU00C62@03aQ401<HB00004007aPd00lH700O69@07aPL0
0lH=00O64P0001<02<H900;61008aR/02<H400;62@08aQD0000F00S61@0<aS403<H500S6600001X0
1lH00`36aP07aST02LH00`36aP05aQ`0000M00C60Td4aT401<H2C@C67`0001d01<H2C003aP0004D0
00?6C4`01<HO00006P07aP9=00?60000A@000lI=C@07aQ`0000G00O60`03C003aP0004<000C6C4a<
0`07aQT0000D00O61P000lI=C@02aT<00/H2C@03aP0000@01lHF00004@07aPT000?6C4`00/I300;6
0T`00lH0000700O64`0001001LH<0004aTe=C@;6@@02aP==00?600002P05aQ80000@00;63`02aP9<
0lHo00?60T`2aPl00/HB00008@02aP9=00@0a/K6?@03aP0304e=00;68`0001T00/H600;60d`00`36
aP0m00;600@0C4a<0/H600;66`0001T00/H600;600@0CDd00lHk00?600@0CDd00/H600;66`0001T0
0/H600;600<0C4`00P03aST00lH2009<00<0a/H01P02aQ/0000I00;61P02aP040<K6C@800/Hi00;6
0P03C@030<K600H00/HK00006@02aPH00/H01036aT`200?6=`03aP800T`01<H0a/H600;66`0001T0
0/H600G600A=00000lHe00?60`02C@C61P02aQ/0000I00;61P04aP=<0`03aS<00lH300=<1<H600;6
6`0001T00/H600?60P02C@@00/Hc00;61002C@800lH600;66`0001T00/H600;60`02C3l00T`300;6
1P02aQ/0000I00;61@03aP<00ddm00==0`03aPD00/HK00006@02aP@01<H4009<?@02C0@01<H400;6
6`0001T00/H300G61002CCd00Td400G60`02aQ/0000I00;60`02aPL00d`k00=<1`02aP<00/HK0000
6@02aP800lH8009=>`02C@P00lH200;66`0001T00/H01036a/H9009<>`02C0T00lH00`36aP0K0000
6@02aP030<K600X00ddi00==2P02aP030<K601/0000I00G62`02C3T00T`;00G66`0001T01<H<009=
>@02C@`01<HK000060001<I<C4`=00=<6`024AX00d`=00=<0/HI00005@04aPA=0/H;009=6`024AX0
0Td;00;614d5aQH0000B00W60d`4aPP00T`J00<A6P02C0P01<H3C0[64`0000l01lH00`36aP03aPA=
1LH500==6@044AP00dd500G614d5aP801lH@00003007aP<00lH200;614`7aP<00T`I00@A6002C0<0
1lH4C0;60P03aP@01lH=00002@07aPH00/H400;600<0CDd00Td00`36aP05aP9=60054AP00Td7aP03
04e=009=00<0a/H01002aPL01lH:00001`06aPP00lH400?600<0C4`00T`300G60T`G008A00@04A4A
5P03C0C60`04C0040<K6aP@00lH900G62@0000L00lH:00?61P03aP800dd500;60TdG008A0P024AH0
0Td2aPD00dd200?61P03aP/00/H900004`03aPP00lH200A<1@02C1H00a42008A5P02C0D014`200?6
2003aQD0000C00;62P02aP<014d400==5@024@<00a4D00==1004C@<00/H:00;65@0001800lH:00?6
1003C0@00T`E008A10024A@00T`400=<1003aPX00lHD00004@03aP`00lH400A=0P02CA@00a44008A
5002C@8014d400?63003aQ<0000A00;63P02aPD014`00`1<C00D008A1@034A<00T`00`1<C002C0D0
0/H>00;64`0001000lH>00?61P06CA<00Q46008A4P06C@H00lH>00?64P0000l00lH@00?61P05C180
0a46008A4P05C0H00lH@00?64@0000h00lHB00?61P04CA800Q4700<A4@04C@H00lHB00?6400000h0
0/HD00;62004C1000Q48008A3`04C0P00/HD00;6400002l014d>00<A20024@h014da0000;`05C0d0
0Q4900<A3005C340000_00M=2`024@X00Q4:00M=<@0003000T`00`1<C002C0T00a4:008A2@04C003
04a<0380000`009=0`03C@P00Q4;00<A1`03C@<00Tdb0000<003C0<014`6008A30024@D014`300=<
<P0003400Td400A=10034@`00Q4400A=1002CC<0000a009<1P03C0<00Q4=008A0`03C0H00T`c0000
<@03C@H014d00`0A4@0=00<A14d600==<`0003800T`700=<0a4>008A0d`7009<=00003800Td90004
CA4AC@d000A=4A5=2@02CC@0000b00=<2@024@9<2`02C0<A2003C3@0000c009=20034@==2@03C@03
014A00P00Tde0000<`02C0P00Q4200A<1@04C0800Q48009<=@0003<00dd7008A0`04C@<014d300<A
1P03CCD0000d009<1P034@D00d`0101<C4`6008A1P02C3H0000d009=1P024@L01Dd7008A1P02CCH0
000d00=<1@024@L01D`700<A1003C3H0000e009=10034@H00dd0101=CDd7008A1002CCL0000e009<
10024@D014`300A<1@024@@00T`g0000=@03C@<00Q4400A=1@04C@@00a4200===`0003H00T`200<A
0P04C0T014`3008A0P02C3P0000f009=0P024@8014d;00A=0P024@800Tdh0000=P03C004014A00=<
3`03C004014A4@=<>00003L00Td34@==4@04C@8A0Tdi0000=`02C08A0d`C00=<0Q42C3T0000g009=
0Q400dd0000E0005CA4A4Dd0>@0003P00a4I0003C14A03X0000h008A6`024CX0000h009<6`02C3X0
000g00==6`03CCT0000g009<7@02C3T0000g009=7@02CCT0000f00=<7@03C3P0000f009=7`02CCP0
000f009<7`02C3P0000e00==7`03CCL0000e009<8@02C3L0000e009=8@02CCL0000d00=<8@03C3H0
000d009=8`02CCH0000d009<8`02C3H0000c00==8`03CCD0000c009<9@02C3D0000c009=9@02CCD0
000b00=<9@03C3@0000b009=9`02CC@0000b009<9`02C3@0000a00==9`03CC<0000a009<:@02C3<0
000a009=:@02CC<0000`00=<:@03C380000`009=:`02CC80000`009<:`02C380000_00==:`03CC40
000_009<;@02C340000_009=;@02CC40000^00=<;@03C300000^009=;`02CC00000^009<;`02C300
000]00==;`03CBl0000]009<<@02C2l0000]009=<@02CBl0000/00=<<@03C2h0000/009=<`02CBh0
000/009<<`02C2h0000/009=<`02CBh0000[00=<<`03C2d0000[009==@02CBd0000[009<=@02C2d0
000Z00===@03CB`0000Z009<=`02C2`0000Z009==`02CB`0000Y00=<=`03C2/0000Y009=>@02CB/0
000Y009<>@02C2/0000X00==>@03CBX0000X009<>`02C2X0000X009=>`02CBX0000Q00;61003C3/0
0d`400;68`0002400/H4009=?@02C@@00/HS00008@02aP@00T`m009<1002aR<0000Q00;60`03CCd0
0dd300;68`0002400/H3009<1002aS<00/H4009<0`02aR<0000Q00;60`02C@@00/Hc00;61002C@<0
0/HS00008@02aP800d`300?6<`03aP<00d`200;68`0002400/H2009=0`03aSD00lH3009=0P02aR<0
000Q00;60P02C0800lHg00?60P02C0800/HS00008@02aP0404e=C@800/Hi00;60P03C@030<K602<0
000Q00;600<0C4`00P03aST00lH2009<00<0a/H08`0002400/H0101=C@03aS/00lH0101=C@02aR<0
000Q00;60d`3aSd00lH3C0;68`0001000lH>00;60Td00`36aP0o00;600<0CDd00/H>00?64P000100
1/H;00;60T`3aSl00lH2C0;62`06aQ80000B00O620001<I=CDd2aT400/H3C@03aP0000H01lHD0000
5@07aPD000?6C4`00/I300;60T`00lH0000300O65`0001P01lH20003aTe=00;6@`02aP9=00?60000
1lHJ00006`06aP=<00?60000@`001<I<C4`6aQd0000N00?60Td2aTD00/H2C@?6800001`01LH2C0G6
?`05aP9<1LHN00006008aP030<K600W6=`0;aP030<K600K66P0001D02<H500?60P09aRl02LH200?6
1@08aQL0000B00O62P03aPD02<HY00S61@03aPX01lHD00004006aPh00/H900K69@06aPT00/H>00K6
4P0001000lHA00?62`03aRD00lH;00?64@03aQ80000U00?6?`03aRL0000V00?6?@03aRP0000W00;6
?@02aRT0000W00?6>`03aRT0000X00?6>@03aRX0000Y00;6>@02aR/0000Y00?6=`03aR/0000Z00?6
=@03aR`0000[00?6<`03aRd0000/00;6<`02aRh0002A0000T@000940002A0000T@000940002A0000
T@000001\
\>"],
  ImageRangeCache->{{{0, 144}, {191, 0}} -> {0.104185, -0.0250053, 0.00549745,
   0.00549745}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.02 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.02 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.02 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.02 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.02 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.02 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
.2 0 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
.2 0 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
.2 0 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
.2 0 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
.2 0 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.452103 1.90421 0.0476051 1.90421 [
[ 0 0 0 0 ]
[ 1 1.99942 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.99942 L
0 1.99942 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.35792 .28654 m
.35792 .10263 L
s
P
p
0 .4 1 r
.018 w
.13058 1.72187 m
.07375 1.89679 L
s
P
p
0 .4 1 r
.018 w
.79033 .42704 m
.89844 .27825 L
s
P
p
.2 0 1 r
.016 w
.35792 1.02221 m
.35792 .28654 L
s
P
p
.2 0 1 r
.016 w
.35792 1.02221 m
.13058 1.72187 L
s
P
p
.2 0 1 r
.016 w
.35792 1.02221 m
.79033 .42704 L
s
P
p
0 .4 1 r
.018 w
.20967 .42704 m
.10156 .27825 L
s
P
p
0 .4 1 r
.018 w
.86942 1.72187 m
.92625 1.89679 L
s
P
p
0 .4 1 r
.018 w
.64208 .28654 m
.64208 .10263 L
s
P
p
.2 0 1 r
.016 w
.64208 1.02221 m
.20967 .42704 L
s
P
p
.2 0 1 r
.016 w
.64208 1.02221 m
.86942 1.72187 L
s
P
p
.2 0 1 r
.016 w
.64208 1.02221 m
.64208 .28654 L
s
P
p
1 .6 0 r
.016 w
.5 .58492 m
.35792 1.02221 L
s
P
p
1 .6 0 r
.016 w
.5 .58492 m
.64208 1.02221 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.19431 1.38862 0.0347155 1.38862 [
[ 0 0 0 0 ]
[ 1 1.45805 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.45805 L
0 1.45805 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.21702 .22098 m
.16985 .07583 L
s
P
p
0 .4 1 r
.018 w
.21702 1.23707 m
.16985 1.38223 L
s
P
p
0 .4 1 r
.018 w
.81426 .41504 m
.93774 .32533 L
s
P
p
.2 0 1 r
.016 w
.38209 .72903 m
.21702 .22098 L
s
P
p
.2 0 1 r
.016 w
.38209 .72903 m
.21702 1.23707 L
s
P
p
.2 0 1 r
.016 w
.38209 .72903 m
.81426 .41504 L
s
P
p
0 .4 1 r
.018 w
.18574 .41504 m
.06226 .32533 L
s
P
p
0 .4 1 r
.018 w
.78298 1.23707 m
.83015 1.38223 L
s
P
p
0 .4 1 r
.018 w
.78298 .22098 m
.83015 .07583 L
s
P
p
.2 0 1 r
.016 w
.61791 .72903 m
.18574 .41504 L
s
P
p
.2 0 1 r
.016 w
.61791 .72903 m
.78298 1.23707 L
s
P
p
.2 0 1 r
.016 w
.61791 .72903 m
.78298 .22098 L
s
P
p
1 .6 0 r
.016 w
.5 .36614 m
.38209 .72903 L
s
P
p
1 .6 0 r
.016 w
.5 .36614 m
.61791 .72903 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.018 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.018 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.018 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.018 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.018 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.018 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.8 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.8 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.8 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.8 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.8 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.8 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.164046 1.32809 0.0332023 1.32809 [
[ 0 0 0 0 ]
[ 1 1.3945 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.3945 L
0 1.3945 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.25957 .24188 m
.20409 .07112 L
s
P
p
0 .4 1 r
.018 w
.25957 1.15261 m
.20409 1.32338 L
s
P
p
0 .4 1 r
.018 w
.79488 .41582 m
.94014 .31028 L
s
P
p
.2 0 1 r
.016 w
.40753 .69725 m
.25957 .24188 L
s
P
p
.2 0 1 r
.016 w
.40753 .69725 m
.25957 1.15261 L
s
P
p
.2 0 1 r
.016 w
.40753 .69725 m
.79488 .41582 L
s
P
p
0 .4 1 r
.018 w
.20512 .41582 m
.05986 .31028 L
s
P
p
0 .4 1 r
.018 w
.74043 1.15261 m
.79591 1.32338 L
s
P
p
0 .4 1 r
.018 w
.74043 .24188 m
.79591 .07112 L
s
P
p
.2 0 1 r
.016 w
.59247 .69725 m
.20512 .41582 L
s
P
p
.2 0 1 r
.016 w
.59247 .69725 m
.74043 1.15261 L
s
P
p
.2 0 1 r
.016 w
.59247 .69725 m
.74043 .24188 L
s
P
p
1 .6 0 r
.016 w
.5 .41264 m
.40753 .69725 L
s
P
p
1 .6 0 r
.016 w
.5 .41264 m
.59247 .69725 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.125693 1.25139 0.0312847 1.25139 [
[ 0 0 0 0 ]
[ 1 1.31396 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.31396 L
0 1.31396 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.31972 .28709 m
.24761 .06516 L
s
P
p
0 .4 1 r
.018 w
.34376 .36107 m
.31972 .28709 L
s
P
p
.2 0 1 r
.02 w
.31972 1.02687 m
.24761 1.2488 L
s
P
p
0 .4 1 r
.018 w
.34376 .95289 m
.31972 1.02687 L
s
P
p
.2 0 1 r
.02 w
.75455 .42838 m
.94334 .29121 L
s
P
p
0 .4 1 r
.018 w
.69162 .4741 m
.75455 .42838 L
s
P
p
.2 0 1 r
.016 w
.43991 .65698 m
.34376 .36107 L
s
P
p
.2 0 1 r
.016 w
.43991 .65698 m
.34376 .95289 L
s
P
p
.2 0 1 r
.016 w
.43991 .65698 m
.69162 .4741 L
s
P
p
.2 0 1 r
.02 w
.24545 .42838 m
.05666 .29121 L
s
P
p
0 .4 1 r
.018 w
.30838 .4741 m
.24545 .42838 L
s
P
p
.2 0 1 r
.02 w
.68028 1.02687 m
.75239 1.2488 L
s
P
p
0 .4 1 r
.018 w
.65624 .95289 m
.68028 1.02687 L
s
P
p
.2 0 1 r
.02 w
.68028 .28709 m
.75239 .06516 L
s
P
p
0 .4 1 r
.018 w
.65624 .36107 m
.68028 .28709 L
s
P
p
.2 0 1 r
.016 w
.56009 .65698 m
.30838 .4741 L
s
P
p
.2 0 1 r
.016 w
.56009 .65698 m
.65624 .95289 L
s
P
p
.2 0 1 r
.016 w
.56009 .65698 m
.65624 .36107 L
s
P
p
1 .6 0 r
.016 w
.5 .47203 m
.43991 .65698 L
s
P
p
1 .6 0 r
.016 w
.5 .47203 m
.56009 .65698 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.21445 1.4289 0.0357225 1.4289 [
[ 0 0 0 0 ]
[ 1 1.50034 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.50034 L
0 1.50034 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.15034 .1979 m
.06292 .07758 L
s
P
p
0 .4 1 r
.018 w
.5 1.27404 m
.5 1.42276 L
s
P
p
0 .4 1 r
.018 w
.84966 .1979 m
.93708 .07758 L
s
P
p
.2 0 1 r
.016 w
.5 .67916 m
.15034 .1979 L
s
P
p
.2 0 1 r
.016 w
.5 .67916 m
.5 1.27404 L
s
P
p
.2 0 1 r
.016 w
.5 .67916 m
.84966 .1979 L
s
P
p
1 .6 0 r
.016 w
.5 .30736 m
.5 .67916 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.194931 1.38986 0.0347465 1.38986 [
[ 0 0 0 0 ]
[ 1 1.45935 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.45935 L
0 1.45935 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.19244 .19934 m
.12918 .07518 L
s
P
p
0 .4 1 r
.018 w
.3583 1.24654 m
.3365 1.38418 L
s
P
p
0 .4 1 r
.018 w
.83965 .30185 m
.93818 .20331 L
s
P
p
.2 0 1 r
.016 w
.4455 .696 m
.19244 .19934 L
s
P
p
.2 0 1 r
.016 w
.4455 .696 m
.3583 1.24654 L
s
P
p
.2 0 1 r
.016 w
.4455 .696 m
.83965 .30185 L
s
P
p
0 .4 1 r
.018 w
.16035 .30185 m
.06182 .20331 L
s
P
p
0 .4 1 r
.018 w
.6417 1.24654 m
.6635 1.38418 L
s
P
p
0 .4 1 r
.018 w
.80756 .19934 m
.87082 .07518 L
s
P
p
.2 0 1 r
.016 w
.5545 .696 m
.16035 .30185 L
s
P
p
.2 0 1 r
.016 w
.5545 .696 m
.6417 1.24654 L
s
P
p
.2 0 1 r
.016 w
.5545 .696 m
.80756 .19934 L
s
P
p
1 .6 0 r
.016 w
.5 .3519 m
.4455 .696 L
s
P
p
1 .6 0 r
.016 w
.5 .3519 m
.5545 .696 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.208517 1.41703 0.0354259 1.41703 [
[ 0 0 0 0 ]
[ 1 1.48789 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.48789 L
0 1.48789 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.19641 .21003 m
.15304 .07656 L
s
P
p
0 .4 1 r
.018 w
.19641 1.27785 m
.15304 1.41133 L
s
P
p
0 .4 1 r
.018 w
.82406 .41397 m
.93761 .33147 L
s
P
p
.2 0 1 r
.016 w
.36989 .74394 m
.19641 .21003 L
s
P
p
.2 0 1 r
.016 w
.36989 .74394 m
.19641 1.27785 L
s
P
p
.2 0 1 r
.016 w
.36989 .74394 m
.82406 .41397 L
s
P
p
0 .4 1 r
.018 w
.17594 .41397 m
.06239 .33147 L
s
P
p
0 .4 1 r
.018 w
.80359 1.27785 m
.84696 1.41133 L
s
P
p
0 .4 1 r
.018 w
.80359 .21003 m
.84696 .07656 L
s
P
p
.2 0 1 r
.016 w
.63011 .74394 m
.17594 .41397 L
s
P
p
.2 0 1 r
.016 w
.63011 .74394 m
.80359 1.27785 L
s
P
p
.2 0 1 r
.016 w
.63011 .74394 m
.80359 .21003 L
s
P
p
1 .6 0 r
.016 w
.5 .34351 m
.36989 .74394 L
s
P
p
1 .6 0 r
.016 w
.5 .34351 m
.63011 .74394 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.014 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.014 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
.8 1 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
.8 1 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.135024 0.952381 [
[ 0 0 0 0 ]
[ 1 .68233 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .68233 L
0 .68233 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.6918 .22882 m
.75478 .18306 L
s
P
p
0 .4 1 r
.018 w
.12843 .41187 m
.05058 .41187 L
s
P
p
0 .4 1 r
.018 w
.6918 .59492 m
.75478 .64068 L
s
P
p
0 .4 1 r
.018 w
.34362 .11569 m
.31956 .04165 L
s
P
p
.2 0 1 r
.016 w
.43985 .41187 m
.6918 .22882 L
s
P
p
.2 0 1 r
.016 w
.43985 .41187 m
.12843 .41187 L
s
P
p
.2 0 1 r
.016 w
.43985 .41187 m
.6918 .59492 L
s
P
p
.2 0 1 r
.016 w
.43985 .41187 m
.34362 .11569 L
s
P
p
0 .4 1 r
.018 w
.65638 .11569 m
.68044 .04165 L
s
P
p
0 .4 1 r
.018 w
.3082 .59492 m
.24522 .64068 L
s
P
p
0 .4 1 r
.018 w
.87157 .41187 m
.94942 .41187 L
s
P
p
0 .4 1 r
.018 w
.3082 .22882 m
.24522 .18306 L
s
P
p
.2 0 1 r
.016 w
.56015 .41187 m
.65638 .11569 L
s
P
p
.2 0 1 r
.016 w
.56015 .41187 m
.3082 .59492 L
s
P
p
.2 0 1 r
.016 w
.56015 .41187 m
.87157 .41187 L
s
P
p
.2 0 1 r
.016 w
.56015 .41187 m
.3082 .22882 L
s
P
p
1 .6 0 r
.016 w
.5 .22676 m
.43985 .41187 L
s
P
p
1 .6 0 r
.016 w
.5 .22676 m
.56015 .41187 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`00010000?600002`000lH0000B0003C@0000/000==00004P000lH0000;0003aP00018000?60000
2`000lH0000B0003aP0000/000?600004P000lH0000;0003aP00018000?600002`000lH0000?0000
40000lH0000;0003aP00018000=<00002`000d`0000B0003aP0000/000?600004P000lH0000;0003
aP00018000?600002`000lH0000B0003aP0000/000?600004P000lH0000;0003aP0000l0000A0003
aP0000T000?6000050000dd000090003C@0001@000?600002@000lH0000D0003aP0000T000?60000
50000lH000090003aP0001@000?600002@000lH0000D0003aP0000T000?600004000014000=<0000
2@000d`0000D0003C00000T000=<000050000d`000090003C00001@000=<00002@000d`0000D0003
C00000T000=<000050000d`000090003C00001@000=<00002@000d`0000@00004@000dd000090003
C@0001@000==00002@000dd0000D0003C@0000T000==000050000dd000090003C@0001@000==0000
2@000dd0000D0003C@0000T000==000050000dd000090003C@000100000=0003aP00008000=<0000
1`0014`00002aPh00T`30003C00000L000A<00000T`>00;60`000d`000070004C00000;63P02aP<0
00=<00001`0014`00002aPh00/H30003C00000L000A<00000/H>00;60`000d`000070004C00000;6
3P02aP<000=<00001`0014`00002aPh0000>0005aP0004d02@0014d00<HB0004C@00C@T000A=001=
4P001<H004d90004C@00aQ8000C6001=2@0014d00<HB0004aP00C@T000A=00364P001<H004d90004
C@00aQ8000C6001=2@0014d00<H@00003`02C00304`000<000<A00000P03C1@00d`400034@000080
0d`D00=<10000a40000200=<5003C0@000<A00000P03C1@00d`400034@0000800d`D00=<10000a40
000200=<5003C0@000<A00000P03C140000A0003C@1=00<000@A00000TdH009=0`0011400002CAP0
0Td300044@00009=6002C@<000@A00000TdH009=0`0011400002CAP00Td300044@00009=6002C@<0
00@A00000TdC00004P02C0<000DA0000C00J0005C00001400`000d`0000H0005C00001400`000d`0
000H0005C00001400`000d`0000H0005C00001400`000d`0000H0005C00001400`000d`0000H0005
C00001400`000d`0000B00004`02C@0401404@==6P03C@034@0A00==6P03C@034@0A00==6P03C@03
4@0A00==6P03C@034@0A00==6P03C@034@0A00==6P03C@034@0A00==500001@00T`01A404@1<01`0
00M<01404@1<01`000M<01404@1<01`000M<01404@1<01`000M<01404@1<01`000M<01404@1<01`0
00M<01404@1<01D0000D0007C@0ACA40C@0L0007C@0ACA40C@0L0007C@0ACA40C@0L0007C@0ACA40
C@0L0007C@0ACA40C@0L0007C@0ACA40C@0L0007C@0ACA40C@0E000050001d`AC01<4D`070001d`A
C01<4D`070001d`AC01<4D`070001d`AC01<4D`070001d`AC01<4D`070001d`AC01<4D`070001d`A
C01<4D`05@0001D000DA00004@0N00054@0001407P001A40000A01h000DA00004@0N00054@000140
7P001A40000A01h000DA00004@0F00005@001D`0001<01h000E<0000C00N0005C00004`07P001D`0
001<01h000E<0000C00N0005C00004`07P001D`0001<01H0000D0003C@0000<000==00006P000dd0
00030003C@0001X000==00000`000dd0000J0003C@0000<000==00006P000dd000030003C@0001X0
00==00000`000dd0000J0003C@0000<000==00004`0001@000=<00000`000d`0000J0003C00000<0
00=<00006P000d`000030003C00001X000=<00000`000d`0000J0003C00000<000=<00006P000d`0
00030003C00001X000=<00000`000d`0000C000050000dd000030003C@0001X000==00000`000dd0
000J0003C@0000<000==00006P000dd000030003C@0001X000==00000`000dd0000J0003C@0000<0
00==00006P000dd000030003C@0001<0000C0003C00000D000=<000060000d`000050003C00001P0
00=<00001@000d`0000H0003C00000D000=<000060000d`000050003C00001P000=<00001@000d`0
000H0003C00000D000=<00004P0001<000==00001@000dd0000H0003C@0000D000==000060000dd0
00050003C@0001P000==00001@000dd0000H0003C@0000D000==000060000dd000050003C@0001P0
00==00001@000dd0000B00004`000d`000050003C00001P000=<00001@000d`0000H0003C00000D0
00=<000060000d`000050003C00001P000=<00001@000d`0000H0003C00000D000=<000060000d`0
00050003C0000180000B0003C@0000L000==00005P000dd000070003C@0001H000==00001`000dd0
000F0003C@0000L000==00005P000dd000070003C@0001H000==00001`000dd0000F0003C@0000L0
00==00004@00018000=<00001`000d`0000F0003C00000L000=<00005P000d`000070003C00001H0
00=<00001`000d`0000F0003C00000L000=<00005P000d`000070003C00001H000=<00001`000d`0
000A00004P000dd000070003C@0001H000==00001`000dd0000F0003C@0000L000==00005P000dd0
00070003C@0001H000==00001`000dd0000F0003C@0000L000==00005P000dd000070003C@000140
000A0003C00000T000=<000050000d`000090003C00001@000=<00002@000d`0000D0003C00000T0
00=<000050000d`000090003C00001@000=<00002@000d`0000D0003C00000T000=<000040000140
00?600002@000lH0000D0003C@0000T000==000050000lH000090003aP0001@000?600002@000lH0
000D0003aP0000T000?6000050000lH000090003aP0001@000?600002@000lH0000@000040000lH0
000;0003aP00018000=<00002`000d`0000B0003aP0000/000?600004P000lH0000;0003aP000180
00?600002`000lH0000B0003aP0000/000?600004P000lH0000;0003aP0000l0000@0003aP0000/0
00?600004P000dd0000;0003C@00018000?600002`000lH0000B0003aP0000/000?600004P000lH0
000;0003aP00018000?600002`000lH0000B0003aP0000/000?600003`000?l00`000?l00`000?l0
0`000?l00`000?l00`000?l00`0001D000G60000aP0I0003aP0000/000?600004P000lH0000;0003
aP00018000?600002`000lH0000E0003aP0000D000?600005@000lH0000;0003aP00018000?60000
2`000lH0000?00005@001LH0003601T000?600002`000lH0000B0003aP0000/000?600004P000lH0
000;0003aP0001000lH00`3600080003aP0000;64P000lH0000;0003aP00018000?600002`000lH0
000?00005@001LH0003601X000?600002@000lH0000D0003aP0000T000?6000050000lH000090003
aP0001@000=<00002@000dc6000D0003aP0000T000?6000050000lH0000:0003aP0000l0000A0005
aP0004d00`001Dd0003601H000==00002@000dd0000D0003C@0000T000==000050000d8000090003
@P0001@000==00002@000dd0000D0003C@0000T000==000050000lH000090003aP000100000A0005
aP0004`00`0014`00<HG0003C00000T000=<000050000d`000090003C00001@000=200002@000d80
000B0004aP00C0T000A<003650000d`000090003C00001D000=<000020000d`0000@00004P0014d0
04d30003C@1=01@00/H20003C@0000P000E=0000aP0?00;60`000dd000070004C@0000;63P02aP<0
00=200001`0014800002aQ0000C6001=2@0014d00<H@00;60`000dd000070004C@0000;63P000lH0
00020003C@0000P000E=0000aP0>00004P0014`004`30003C01<01H000C6001<10000a4000020004
C000aQ8000C6001<2@0014`00<HB0004aP00@PT000A200364P001<H004`90004C000aQ8000C6001<
2@0014`00<HA0005aP0004`02@001D`0003600l0000C0006C@1=01400TdH00==10000a40000200==
5003C@@000<A00000P03CA@00d8400034@0000800d8B0003aTe=008000E=00004@030003C@00009=
0/HA00==10000a40000200==4`001LH0001=00P000A=0036400001@00T`0100A04`K0004C000008A
0`02C1P00T`300044@00009<6002@P<000@A00000T8B00;60`000d`0C00300074@0004`0C0040003
aP0001000T`300044@00009<5P02C00304`0008000<A00000P03C140000E0005C@0A04d070001dd0
01404@000TdJ0005C@0001400`000dd0000H0005@P0001400`000d80000G009=0`0011400002CAT0
00E=00004@030003C@0001L00Td300044@00009=4`0001D000E<4@0AC00L00=<00HA015<04`J00=<
00<A01400d`J00=200<A01400d8K0007C00A0140C00K00=<00<A01400d`J009<00D04@0A0002C1@0
000E0005CA5=4Dd0700024d04Dd04@1=70001dd04@0A04d070001d804@0A04807002C@034@0A009=
70001dd04@0A04d07002C@034@0A009=5@0001D000E<4D`AC00L0003C00A009<00<A04`070001d`0
4D`A04`070001d804D8A048070001d`04D`A04`070001d`04D`A04`070001d`04D`A04`05@0001D0
00DAC@1=4@0M0007CA4004dAC@0L0007CA5=04dAC@0L0007@Q52048A@P0M00054Dd0CA407@001ddA
C@1=4Dd07@001Q5=04dACAD0000E00054@0001407@000a40000200034@0001`000DA00004@0N0005
4@0001407P001A40000A01h000DA00004@0N00054@0001405P0001D000E=0000C@0M0003C@000080
00==000070001Dd0001=01h000E20000@P0N0005C@0004d07P001Dd0001=01h000E=0000C@0F0000
50000d`000030003C00001X000=<00000`000d`0000J0003C00000<000=<00006P000d8000030003
@P0001X000=<00000`000d`0000J0003C00000<000=<00006`000d`000020003C00001<0000D0003
C@0000<000==00006@000dd000040003C@0001X000==00000`000dd0000J0003@P0000<000=20000
6P000dd000030003C@0001X000==00000`000dd0000J0003C@0000<000==00004`0001@000=<0000
0`000d`0000I0003C00000@000=<00006P000d`000030003C00001X000=200000`000d80000J0003
C00000<000=<00006P000d`000030003C00001X000=<00000`000d`0000C00004`000dd000050003
C@0001P000==00001@000dd0000H0003C@0000D000==000060000d8000050003@P0001P000==0000
1@000dd0000H0003C@0000D000==00006@000dd000040003C@000180000C0003C00000D000=<0000
5`000d`000060003C00001P000=<00001@000d`0000H0003@P0000D000=2000060000d`000050003
C00001P000=<00001@000d`0000H0003C00000D000=<00004P0001<000==00001@000dd0000G0003
C@0000H000==000060000dd000050003C@0001P000=200001@000d80000H0003C@0000D000==0000
60000dd000050003C@0001P000==00001P000dd0000A00004P000d`000070003C00001H000=<0000
1`000d`0000F0003C00000L000=<00005P000d8000070003@P0001H000=<00001`000d`0000F0003
C00000L000=<00005`000d`000060003C0000140000B0003C@0000L000==00005P000dd000070003
C@0001H000==00001`000dd0000F0003@P0000L000=200005P000dd000070003C@0001H000==0000
1`000dd0000F0003C@0000L000==00004@00018000=<00001`000d`0000E0003C00000P000=<0000
5P000d`000070003C00001H000=200001`000d80000F0003C00000L000=<00005P000d`000070003
C00001H000=<000020000d`0000@00004@000dd000090003C@0001@000==00002@000dd0000D0003
C@0000T000==000050000d8000090003@P0001@000==00002@000dd0000D0003C@0000T000==0000
5@000lH000080003aP000100000A0003C00000T000=<000050000lH000090003aP0001@000?60000
2@000lH0000D0003aP0000T000?600004`000lI<000:0003C<K601@000?600002@000lH0000D0003
aP0000T000?600004000014000?600002@000lH0000C0003aP0000/000?600004P000lH0000;0003
aP00018000?600002`000lH0000@00;60P000lH000070005aP000<H04P000lH0000;0003aP0001<0
00?600002P000lH0000?000040000lH0000;0003aP00018000?600002`000lH0000B0003aP0000/0
00?600004P000lH0000;0003aP0001D000?600001@000lH0000E0003aP0000/000?600004P000lH0
000;0003aP0000l0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0000A0003C@0000T0
00==00004@000lH0000?0003aP0000l000?600003@000lH0000A0003aP0000/000?600004P000lH0
000;0003aP00018000?600002`000lH0000b00004@000d`000090003C000014000?600003P000lH0
000@0003aP0000d000?600004@000lH0000;0003aP00018000?600002`000lH0000B0003aP0000/0
00?60000<P00018000==00001`000dd0000C0003C@0000`000==00004P000dd0000;0003C@000180
00?600002P000lH0000D0003aP0000T000?6000050000lH000090003aP0003<0000B0003C00000L0
00=<00004`000d`0000<0003C00000l00/H00`1<000<0004C036aQ4000=<00002P000d`0000D0003
C00000T000=<000050000d`000090003C00003<0000B0003C@0000L000==000050000dd0000:0003
C@00018000?604d02`000dd0aP0C0003C@0000X000==000050000dd000090003C@0001@000==0000
2@000dd0000c00003002C0D000?600001@000lH00003009<4@000d`0000300034@00008000=<0000
5002C0/00T`B0004aP00C0D000<A00000`0014`00<H?00;60`000d`000070004C00000;63P02aP<0
00=<00001`0014`00002aQ8000?600002@000lH0000@00003P000dd000020003aP0000D000?60000
0P000dd0000B0003C@00008000<A00000P000dd0000E009=10000a400002009=50000lH0C@050003
4@00008000A=00364P001<H004d90004C@00aQ8000C6001=2@0014d00<HD0003aP0000T000?60000
400000l000E<0000C0070005C00004`05@000d`0000200054@0004`06@000d`0000200034@000080
00=<00005002C0@000<A01400`03C1@00d`400034@0000800d`D00=<10000ml0000200=<5P000d`0
00070003C0000140000@0004C@00C@L000A=001=5`001Dd0000A008000==00006@001Dd0000A00<0
00==00005`001dd0000A01400`000dd0000F009=0`0011400002CAP00Td30004gP00009=60000dd0
00070003C@000140000A0003aP1<00H000A<00366@0014`001420003C00001X000A<000A0P000d`0
000H00=<00D04@0A0002C1X000E<00004@030003C00001P000E<0000g`030003C00001@00/H20003
C00000D000=<00000/H@00004P03C@8000<A00000ddJ0006C@004@1=7@02C@034@0A009=6P0014d0
014300034@1=01X00dd00a404@03CAX00dd00mh0gP03CAP00dd300044@0000==4P0001@000E<000A
0002C1d000E<0140C00N0005C1404D`070002D`04D`0C140C00K0007C00A0140C00L0007C03O0=l0
C00K0005C00001400`000d`0000B00005002C@8A0TdO0003CA5=01l000E=4DdAC@0L0003C@0A00==
00<A04d06`001dd04DdA04d070001dd0gTgN04d070001dd04@0A04d05@0001D000E<4D`AC00P0003
4@0001l000<A01407@000d`AC0030003C14001/000M<4D`0C15<01`000M<gd`0C=m<01`00T`00a40
4@02C1D0000E00044@004B4000==00007`000dd0C@0N00034@0000<000<A00006`001A40000A01h0
00GN0000gP0M0007C@0ACA40C@0E00005@0014`004`Q0003C00001l000=<04`07P000d`000030003
C00001/000E<0000C00N0005C00004`07P001A5<04`A01H0000E0005C@0004d080000dd0000O0003
C@1=01d000==000010000dd0000J0003C@0000<000==00006P000dd000030003C@0000l00/H:C@05
4Dd0CA402Td2aPX0000D0003C000008000=<00007P000d`0000N0005C00004`070000d`000050003
C00001T000=<00000`000d`0000J0003C00000<000=<00007@000d`0000F000050000dd000030003
C@0001d000==00007P001Dd0001=01`000==00001@000dd0000I0003C@0000<000==00006P000dd0
00030003C@0001`000==04d05`0001@000=<00000`000d`0000M0003C00001h000E<0000C00K0003
C00000H000=<000060000d`000050003C00001P000=<00001@000d`0000I009<0`02C1D0000C0003
C@0000@000==00007@000dd0000N0005C@0004d06`000dd000070003C@0001L000==00001@000dd0
000H0003C@0000D000==000060000dd000050003C@000180000C0003C00000D000=<000070000d`0
000N0005C00004`06`000d`000070003C00001L000=<00001@000d`0000H0003C00000D000=<0000
5`000d`000070003C0000140000C0003aP0000D000?6000070000dd0000N0005C@0004d06P000dd0
00080003C@0001H000==00001`000dd0000F0003C@0000L000==00005@000dd000090003C@000100
000C0003aP0000D000?6000070000d`0000M0003C00000<000=<00005`000d`000080003C00001H0
00=<00001`000d`0000F0003C00000L000=<000050000lH0000;0003aP0000l0000C0003C@0000D0
00==000070000dd0000M0003C@0000<000==00005`000dd000090003C@0001D000==00001`000dd0
000F0003C@0000L000==00004`000lH0000=0003aP0000h0000B0003C00000L000=<00006`000d`0
000M0003C00000<000=<00005P000d`0000:0003C00001@000=<00002@000d`0000D0003C00000T0
00=<0000<`00018000==00001`000dd0000K0003aP0001d000?600000`000lH0000F0003aP0000X0
00?6000050000lH000090003aP0001@000?600002@000lH0000c00004P000d`000070003C00001/0
00?6000070000lH000050003aP0001D000?600002`000lH0000B0003aP0000/000?600004P000lH0
000;0003aP000380000A0003C@0000T000==00006P000lH0000L0003aP0000D000?600005@000lH0
000;0003aP00018000?600002`000lH0000B0003aP0000/000?60000<P000?l00`000?l00`000?l0
0`000?l00`000001\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.27001, -0.109418, 
  0.0329417, 0.0329417}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.424,
   -0.109418, 0.0329417, 0.0329417}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57799, -0.109418, 0.0329417, 0.0329417}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.73197, -0.109418, 0.0329417, 0.0329417}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88596, -0.109418, 0.0329417, 
  0.0329417}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.03995,
   -0.109418, 0.0329417, 0.0329417}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.19394, -0.109418, 0.0329417, 0.0329417}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.271521, -1.26686, 0.0330062, 0.0330062}, {{42.5, 74.3125},
   {69.375, 37.5625}} -> {-1.42777, -1.26686, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.58403, -1.26687, 0.0330064, 0.0330064},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74029, -1.26687, 0.0330064, 
  0.0330064}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.89653, -1.26687, 
  0.0330063, 0.0330063}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.0528,
   -1.26687, 0.0330064, 0.0330064}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.20905, -1.26687, 0.0330064, 0.0330064}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.27001, -2.41738, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42396, -2.41735, 0.0329411, 0.0329411}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57796, -2.41738, 0.0329414, 0.0329414}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.73198, -2.4174, 0.0329417, 
  0.0329417}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88596, -2.41739, 
  0.0329417, 0.0329417}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.03995,
   -2.41739, 0.0329417, 0.0329417}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1939, -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.32883 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{145, 192},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002A0000`0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000940002A0000T@000940002A0000T@000940
002A0000T@000940000/00;6<`02aRh0000/00;6<`02aRh0000[00?6<`03aRd0000Z00?6=@03aR`0
000Y00?6=`03aR/0000Y00;6>@02aR/0000X00?6>@03aRX0000W00?6>`03aRT0000V00?6?@03aRP0
000V00;6?`02aRP0000@00C64@03aSl00lHA00C64P0001001lH=00?6@@03aPd01lHB00004`08aPT0
0/I300;62@08aQD0000F00S61@03aT<00lH500S6600001X01lH01036a/I500?600<0a/H01LHL0000
7@04aP9=00?60000A@000lI=C@04aQl0000P0003aTa<04T00T`00lH0000P00008@02CDT00TdS0000
8@03C4L00d`S00008P02CDL00TdT00008P02C4L00T`T00008P03CDD00ddT00008`02C4D00T`U0000
8`02CDD00TdU00006@02aPP00da300=<2002aQ/0000I00;62@02CD<00Td900;66`0001T00/H9009<
@`02C0T00/HK00006@02aPT00de100==2@02aQ/0000I00;62P02C4400T`:00;66`0001T00/H:009=
@@02C@X00/HK00006@02aPX00d`o00=<2P02aQ/0000I00;62`02CCl00Td;00;66`0001T00/H;009<
?`02C0/00/HK00006@02aP/00ddm00==2`02aQ/0000I00;63002C3d00T`<00;66`0001T00/H<009=
?@02C@`00/HK00006@02aP`00d`k00=<3002aQ/0000I00;63@02CC/00Td=00;66`0001T00/H=009<
>`02C0d00/HK00006@02aPd00ddi00==3@02aQ/0000I00;63P02C3T00T`>00;66`0001T00/H>009=
>@02C@h00/HK000060001<I<C4`=00=<6`024AX00d`=00=<0/HI00005@04aPA=3@02CA/00Q4J009=
3@04C@G65P0001801lH200=<3002C1X00a4J009<3003C0<01lHC00003`07aPH014d:00==6@044AP0
0dd:00A=1`07aQ00000<00O62P04C0X00T`I00@A6002C0X014`;00O63@0000T01lH?00A=2002CAP0
1A4H009=2004CA001lH:00001`06aQ<014`700=<5`024@04014A4AH00d`700A<5005aPT0000700?6
6003C@L00TdG008A0P024AH00Td700==6@02aPT0000S00A<1@02C1H00a42008A5P02C0D014`U0000
9004C@@00ddE008A0`034A@00dd400A=9P0002H00d`4009<5@024@@00Q4D009<1003C2P0000W00A=
0P02CA@00a44008A5002C@8014dY0000:004C00304a<01@00Q4500<A4`02C00304a<009<:P0002X0
1TdC008A1P024A801Td/0000:`05C1800a46008A4P05C2d0000/00A=4P024@L00a4A00A=;P0002h0
14`@008A20024@l014``0000;`04C@h00a48008A3P04CC40000_00E<3@024@T00a4<00E<<@0002l0
1dd;008A2P024@X01dda0000<002C00304a<009<2@034@X00Q4900A<00<0C4`0<P0003000Td300==
20024@/00a4700==0`02CC80000`00=<0`04C0H00Q4<008A1@04C0<00d`b0000<@02C@@014d400<A
30024@@014d4009=<`0003400T`600=<0`024@d00Q4300=<1P02C3<0000a00==1P04C@03014A00d0
0a44C@H00ddc0000<P02C0L00d`34@h00Q43C0L00T`d0000<P02C@T000A=4A5=3@0014dA4Dd9009=
=00003800d`9008A0T`;009<0a4800=<=00003<00Td800<A0dd900==00<04A402002CCD0000c009<
20024@8014`500A<0P024@P00T`e0000<`03C@L00Q4300A=0`04C@<00a4600===@0003@00T`600<A
1@03C00404a<C0H00Q46009<=P0003@00Td6008A1`05C@L00Q46009==P0003@00d`5008A1`05C0L0
0a4400=<=P0003D00Td400<A1P03C@0404e=C@L00Q44009==`0003D00T`4008A1@04C0<014`5008A
1002C3L0000e00==0`024@@014d500A=10034@800ddg0000=P02C0800a4200A<2@04C0<00Q42009<
>00003H00Td2008A0P04C@/014d2008A0P02CCP0000f00=<00@04A400d`?00=<00@04A4A0d`h0000
=`02C@<A0ddA00A=0Q42CCT0000g009<0Q43C1<00d`24@9<>@0003L00Td24@03C@0001D000E=4A4A
C@0i0000>0034AT000=<4A40>P0003P00Q4K008A>P0003P00T`K009<>P0003L00ddK00==>@0003L0
0T`M009<>@0003L00TdM009=>@0003H00d`M00=<>00003H00TdO009=>00003H00T`O009<>00003D0
0ddO00===`0003D00T`Q009<=`0003D00TdQ009==`0003@00d`Q00=<=P0003@00TdS009==P0003@0
0T`S009<=P0003<00ddS00===@0003<00T`U009<=@0003<00TdU009==@0003800d`U00=<=0000380
0TdW009==00003800T`W009<=00003400ddW00==<`0003400T`Y009<<`0003400TdY009=<`000300
0d`Y00=<<P0003000Td[009=<P0003000T`[009<<P0002l00dd[00==<@0002l00T`]009<<@0002l0
0Td]009=<@0002h00d`]00=<<00002h00Td_009=<00002h00T`_009<<00002d00dd_00==;`0002d0
0T`a009<;`0002d00Tda009=;`0002`00d`a00=<;P0002`00Tdc009=;P0002`00T`c009<;P0002`0
0Tdc009=;P0002/00d`c00=<;@0002/00Tde009=;@0002/00T`e009<;@0002X00dde00==;00002X0
0T`g009<;00002X00Tdg009=;00002T00d`g00=<:`0002T00Tdi009=:`0002T00T`i009<:`0002P0
0ddi00==:P0002P00T`k009<:P0002P00Tdk009=:P0002L00d`k00=<:@0002L00Tdm009=:@0002L0
0T`m009<:@0002H00ddm00==:00002H00T`o009<:00002H00Tdo009=:00002D00d`o00=<9`0002D0
0Te1009=9`0002D00Ta1009<9`0002@00de100==9P0002@00Ta3009<9P0002@00Te3009=9P0002<0
0da300=<9@0002<00Te5009=9@0002<00Ta5009<9@0002800de500==900002800Ta7009<90000280
0Te7009=900002400da700=<8`0001l00/H2CDT00Td2aR40000L00G60Ta9009<1LHN00006008aP04
0<K6aTL00lH00`36aP06aQX0000E00S61@03aTD00lH500S65`0001801lH:00?6@`03aPX01lHD0000
4006aPh00/I300;63P06aQ80000@00?64@03aT400lHA00?64P0002D00lHo00?69`0002H00lHm00?6
:00002L00/Hm00;6:@0002L00lHk00?6:@0002P00lHi00?6:P0002T00/Hi00;6:`0002T00lHg00?6
:`0002X00lHe00?6;00002/00lHc00?6;@0002`00/Hc00;6;P000940002A0000T@000940002A0000
T@000940002A0000\
\>"],
  ImageRangeCache->{{{0, 144}, {191, 0}} -> {0.104185, -0.0250053, 0.00549745,
   0.00549745}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.02 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.02 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.02 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.02 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.02 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.02 w
.81819 .36074 m
.81819 .23159 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.02 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.02 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.02 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.02 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.02 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.02 w
.75943 .17307 m
.68351 .06857 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 1 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 1 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 1 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 1 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 1 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 1 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 1 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 1 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 1 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 1 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 1 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 1 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.221153 1.44231 0.0360577 1.44231 [
[ 0 0 0 0 ]
[ 1 1.51442 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.51442 L
0 1.51442 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.38597 .16493 m
.50538 .07817 L
s
P
p
0 .4 1 r
.018 w
.38597 .16493 m
.26656 .07817 L
s
P
p
0 .4 1 r
.018 w
.20353 1.31684 m
.06315 1.36245 L
s
P
p
0 .4 1 r
.018 w
.20353 1.31684 m
.29029 1.43625 L
s
P
p
0 .4 1 r
.018 w
.733 .27769 m
.8806 .27769 L
s
P
p
0 .4 1 r
.018 w
.733 .27769 m
.68739 .13731 L
s
P
p
.2 0 1 r
.016 w
.38597 .75533 m
.38597 .16493 L
s
P
p
.2 0 1 r
.016 w
.38597 .75533 m
.20353 1.31684 L
s
P
p
.2 0 1 r
.016 w
.38597 .75533 m
.733 .27769 L
s
P
p
0 .4 1 r
.018 w
.267 .27769 m
.31261 .13731 L
s
P
p
0 .4 1 r
.018 w
.267 .27769 m
.1194 .27769 L
s
P
p
0 .4 1 r
.018 w
.79647 1.31684 m
.70971 1.43625 L
s
P
p
0 .4 1 r
.018 w
.79647 1.31684 m
.93685 1.36245 L
s
P
p
0 .4 1 r
.018 w
.61403 .16493 m
.73344 .07817 L
s
P
p
0 .4 1 r
.018 w
.61403 .16493 m
.49462 .07817 L
s
P
p
.2 0 1 r
.016 w
.61403 .75533 m
.267 .27769 L
s
P
p
.2 0 1 r
.016 w
.61403 .75533 m
.79647 1.31684 L
s
P
p
.2 0 1 r
.016 w
.61403 .75533 m
.61403 .16493 L
s
P
p
1 .6 0 r
.016 w
.5 .40439 m
.38597 .75533 L
s
P
p
1 .6 0 r
.016 w
.5 .40439 m
.61403 .75533 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.14311 1.28622 0.0321555 1.28622 [
[ 0 0 0 0 ]
[ 1 1.35053 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.35053 L
0 1.35053 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.229 .18874 m
.31491 .07049 L
s
P
p
0 .4 1 r
.018 w
.229 .18874 m
.08999 .14357 L
s
P
p
0 .4 1 r
.018 w
.229 1.16179 m
.08999 1.20696 L
s
P
p
0 .4 1 r
.018 w
.229 1.16179 m
.31491 1.28004 L
s
P
p
0 .4 1 r
.018 w
.80095 .37457 m
.93996 .41974 L
s
P
p
0 .4 1 r
.018 w
.80095 .37457 m
.80095 .22841 L
s
P
p
.2 0 1 r
.016 w
.38708 .67527 m
.229 .18874 L
s
P
p
.2 0 1 r
.016 w
.38708 .67527 m
.229 1.16179 L
s
P
p
.2 0 1 r
.016 w
.38708 .67527 m
.80095 .37457 L
s
P
p
0 .4 1 r
.018 w
.19905 .37457 m
.19905 .22841 L
s
P
p
0 .4 1 r
.018 w
.19905 .37457 m
.06004 .41974 L
s
P
p
0 .4 1 r
.018 w
.771 1.16179 m
.68509 1.28004 L
s
P
p
0 .4 1 r
.018 w
.771 1.16179 m
.91001 1.20696 L
s
P
p
0 .4 1 r
.018 w
.771 .18874 m
.91001 .14357 L
s
P
p
0 .4 1 r
.018 w
.771 .18874 m
.68509 .07049 L
s
P
p
.2 0 1 r
.016 w
.61292 .67527 m
.19905 .37457 L
s
P
p
.2 0 1 r
.016 w
.61292 .67527 m
.771 1.16179 L
s
P
p
.2 0 1 r
.016 w
.61292 .67527 m
.771 .18874 L
s
P
p
1 .6 0 r
.016 w
.5 .32774 m
.38708 .67527 L
s
P
p
1 .6 0 r
.016 w
.5 .32774 m
.61292 .67527 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
.2 0 1 r
.014 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.014 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.014 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
.2 0 1 r
.014 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.014 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.014 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
.8 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.8 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.8 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
.8 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.8 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.8 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.177332 1.35466 0.0338666 1.35466 [
[ 0 0 0 0 ]
[ 1 1.4224 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.4224 L
0 1.4224 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23051 .20079 m
.18905 .07319 L
s
P
p
0 .4 1 r
.018 w
.23051 1.22161 m
.18905 1.34921 L
s
P
p
0 .4 1 r
.018 w
.83053 .39575 m
.93907 .31688 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 .20079 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.23051 1.22161 L
s
P
p
.2 0 1 r
.016 w
.39635 .7112 m
.83053 .39575 L
s
P
p
0 .4 1 r
.018 w
.16947 .39575 m
.06093 .31688 L
s
P
p
0 .4 1 r
.018 w
.76949 1.22161 m
.81095 1.34921 L
s
P
p
0 .4 1 r
.018 w
.76949 .20079 m
.81095 .07319 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.16947 .39575 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 1.22161 L
s
P
p
.2 0 1 r
.016 w
.60365 .7112 m
.76949 .20079 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.39635 .7112 L
s
P
p
1 .6 0 r
.016 w
.5 .39219 m
.60365 .7112 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.130057 1.26011 0.0315029 1.26011 [
[ 0 0 0 0 ]
[ 1 1.32312 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32312 L
0 1.32312 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.23592 .1614 m
.32889 .06843 L
s
P
p
0 .4 1 r
.018 w
.23592 .1614 m
.10606 .14083 L
s
P
p
0 .4 1 r
.018 w
.23592 1.16172 m
.10606 1.18229 L
s
P
p
0 .4 1 r
.018 w
.23592 1.16172 m
.32889 1.25469 L
s
P
p
0 .4 1 r
.018 w
.82389 .35244 m
.94104 .41213 L
s
P
p
0 .4 1 r
.018 w
.82389 .35244 m
.80332 .22259 L
s
P
p
.2 0 1 r
.016 w
.39843 .66156 m
.23592 .1614 L
s
P
p
.2 0 1 r
.016 w
.39843 .66156 m
.23592 1.16172 L
s
P
p
.2 0 1 r
.016 w
.39843 .66156 m
.82389 .35244 L
s
P
p
0 .4 1 r
.018 w
.17611 .35244 m
.19668 .22259 L
s
P
p
0 .4 1 r
.018 w
.17611 .35244 m
.05896 .41213 L
s
P
p
0 .4 1 r
.018 w
.76408 1.16172 m
.67111 1.25469 L
s
P
p
0 .4 1 r
.018 w
.76408 1.16172 m
.89394 1.18229 L
s
P
p
0 .4 1 r
.018 w
.76408 .1614 m
.89394 .14083 L
s
P
p
0 .4 1 r
.018 w
.76408 .1614 m
.67111 .06843 L
s
P
p
.2 0 1 r
.016 w
.60157 .66156 m
.17611 .35244 L
s
P
p
.2 0 1 r
.016 w
.60157 .66156 m
.76408 1.16172 L
s
P
p
.2 0 1 r
.016 w
.60157 .66156 m
.76408 .1614 L
s
P
p
1 .6 0 r
.016 w
.5 .34896 m
.39843 .66156 L
s
P
p
1 .6 0 r
.016 w
.5 .34896 m
.60157 .66156 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.168161 1.33632 0.0334081 1.33632 [
[ 0 0 0 0 ]
[ 1 1.40314 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.40314 L
0 1.40314 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.20006 .1335 m
.24395 .0731 L
s
P
p
0 .4 1 r
.018 w
.20006 .1335 m
.12906 .11043 L
s
P
p
0 .4 1 r
.018 w
.20006 1.26964 m
.12906 1.29271 L
s
P
p
0 .4 1 r
.018 w
.20006 1.26964 m
.24395 1.33004 L
s
P
p
0 .4 1 r
.018 w
.86787 .35049 m
.93887 .37356 L
s
P
p
0 .4 1 r
.018 w
.86787 .35049 m
.86787 .27582 L
s
P
p
.2 0 1 r
.016 w
.38464 .70157 m
.20006 .1335 L
s
P
p
.2 0 1 r
.016 w
.38464 .70157 m
.20006 1.26964 L
s
P
p
.2 0 1 r
.016 w
.38464 .70157 m
.86787 .35049 L
s
P
p
0 .4 1 r
.018 w
.13213 .35049 m
.13213 .27582 L
s
P
p
0 .4 1 r
.018 w
.13213 .35049 m
.06113 .37356 L
s
P
p
0 .4 1 r
.018 w
.79994 1.26964 m
.75605 1.33004 L
s
P
p
0 .4 1 r
.018 w
.79994 1.26964 m
.87094 1.29271 L
s
P
p
0 .4 1 r
.018 w
.79994 .1335 m
.87094 .11043 L
s
P
p
0 .4 1 r
.018 w
.79994 .1335 m
.75605 .0731 L
s
P
p
.2 0 1 r
.016 w
.61536 .70157 m
.13213 .35049 L
s
P
p
.2 0 1 r
.016 w
.61536 .70157 m
.79994 1.26964 L
s
P
p
.2 0 1 r
.016 w
.61536 .70157 m
.79994 .1335 L
s
P
p
1 .6 0 r
.016 w
.5 .34653 m
.38464 .70157 L
s
P
p
1 .6 0 r
.016 w
.5 .34653 m
.61536 .70157 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.031763 1.06353 0.0265882 1.06353 [
[ 0 0 0 0 ]
[ 1 1.1167 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.1167 L
0 1.1167 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39855 .22895 m
.52446 .05566 L
s
P
p
.2 0 1 r
.02 w
.28867 .26466 m
.08495 .19846 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.39855 .22895 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.28867 .26466 L
s
P
p
.2 0 1 r
.02 w
.28867 .85205 m
.08495 .91824 L
s
P
p
.2 0 1 r
.02 w
.39855 .88775 m
.52446 1.06105 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.28867 .85205 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.39855 .88775 L
s
P
p
.2 0 1 r
.02 w
.74381 .41254 m
.94753 .47873 L
s
P
p
.2 0 1 r
.02 w
.6759 .31907 m
.6759 .10486 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.74381 .41254 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.6759 .31907 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .28672 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .82998 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.6759 .39047 L
s
P
p
.2 0 1 r
.02 w
.3241 .31907 m
.3241 .10486 L
s
P
p
.2 0 1 r
.02 w
.25619 .41254 m
.05247 .47873 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.3241 .31907 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.25619 .41254 L
s
P
p
.2 0 1 r
.02 w
.60145 .88775 m
.47554 1.06105 L
s
P
p
.2 0 1 r
.02 w
.71133 .85205 m
.91505 .91824 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.60145 .88775 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.71133 .85205 L
s
P
p
.2 0 1 r
.02 w
.71133 .26466 m
.91505 .19846 L
s
P
p
.2 0 1 r
.02 w
.60145 .22895 m
.47554 .05566 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.71133 .26466 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.60145 .22895 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.3241 .39047 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .82998 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .28672 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.44484 .55835 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.55516 .55835 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.114401 1.2288 0.0307201 1.2288 [
[ 0 0 0 0 ]
[ 1 1.29024 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.29024 L
0 1.29024 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.19016 .19226 m
.23088 .06692 L
s
P
p
0 .4 1 r
.018 w
.19016 .19226 m
.05837 .19226 L
s
P
p
0 .4 1 r
.018 w
.5 1.14586 m
.39338 1.22332 L
s
P
p
0 .4 1 r
.018 w
.5 1.14586 m
.60662 1.22332 L
s
P
p
0 .4 1 r
.018 w
.80984 .19226 m
.94163 .19226 L
s
P
p
0 .4 1 r
.018 w
.80984 .19226 m
.76912 .06692 L
s
P
p
.2 0 1 r
.016 w
.5 .61872 m
.19016 .19226 L
s
P
p
.2 0 1 r
.016 w
.5 .61872 m
.5 1.14586 L
s
P
p
.2 0 1 r
.016 w
.5 .61872 m
.80984 .19226 L
s
P
p
1 .6 0 r
.016 w
.5 .28926 m
.5 .61872 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0468021 1.0936 0.0273401 1.0936 [
[ 0 0 0 0 ]
[ 1 1.14828 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.14828 L
0 1.14828 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.30107 .13922 m
.38096 .05933 L
s
P
p
0 .4 1 r
.018 w
.30107 .13922 m
.20039 .08793 L
s
P
p
0 .4 1 r
.018 w
.16659 .98828 m
.05499 1.00596 L
s
P
p
0 .4 1 r
.018 w
.16659 .98828 m
.21788 1.08895 L
s
P
p
0 .4 1 r
.018 w
.77445 .38042 m
.87512 .43172 L
s
P
p
0 .4 1 r
.018 w
.77445 .38042 m
.79212 .26883 L
s
P
p
.2 0 1 r
.016 w
.37176 .5856 m
.30107 .13922 L
s
P
p
.2 0 1 r
.016 w
.37176 .5856 m
.16659 .98828 L
s
P
p
.2 0 1 r
.016 w
.37176 .5856 m
.77445 .38042 L
s
P
p
0 .4 1 r
.018 w
.22555 .38042 m
.20788 .26883 L
s
P
p
0 .4 1 r
.018 w
.22555 .38042 m
.12488 .43172 L
s
P
p
0 .4 1 r
.018 w
.83341 .98828 m
.78212 1.08895 L
s
P
p
0 .4 1 r
.018 w
.83341 .98828 m
.94501 1.00596 L
s
P
p
0 .4 1 r
.018 w
.69893 .13922 m
.79961 .08793 L
s
P
p
0 .4 1 r
.018 w
.69893 .13922 m
.61904 .05933 L
s
P
p
.2 0 1 r
.016 w
.62824 .5856 m
.22555 .38042 L
s
P
p
.2 0 1 r
.016 w
.62824 .5856 m
.83341 .98828 L
s
P
p
.2 0 1 r
.016 w
.62824 .5856 m
.69893 .13922 L
s
P
p
1 .6 0 r
.016 w
.5 .33392 m
.37176 .5856 L
s
P
p
1 .6 0 r
.016 w
.5 .33392 m
.62824 .5856 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.107045 1.21409 0.0303523 1.21409 [
[ 0 0 0 0 ]
[ 1 1.27479 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.27479 L
0 1.27479 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.27026 .16603 m
.3431 .06579 L
s
P
p
0 .4 1 r
.018 w
.27026 .16603 m
.15242 .12774 L
s
P
p
0 .4 1 r
.018 w
.27026 1.10877 m
.15242 1.14706 L
s
P
p
0 .4 1 r
.018 w
.27026 1.10877 m
.3431 1.20901 L
s
P
p
0 .4 1 r
.018 w
.82439 .34608 m
.94223 .38436 L
s
P
p
0 .4 1 r
.018 w
.82439 .34608 m
.82439 .22217 L
s
P
p
.2 0 1 r
.016 w
.42342 .6374 m
.27026 .16603 L
s
P
p
.2 0 1 r
.016 w
.42342 .6374 m
.27026 1.10877 L
s
P
p
.2 0 1 r
.016 w
.42342 .6374 m
.82439 .34608 L
s
P
p
0 .4 1 r
.018 w
.17561 .34608 m
.17561 .22217 L
s
P
p
0 .4 1 r
.018 w
.17561 .34608 m
.05777 .38436 L
s
P
p
0 .4 1 r
.018 w
.72974 1.10877 m
.6569 1.20901 L
s
P
p
0 .4 1 r
.018 w
.72974 1.10877 m
.84758 1.14706 L
s
P
p
0 .4 1 r
.018 w
.72974 .16603 m
.84758 .12774 L
s
P
p
0 .4 1 r
.018 w
.72974 .16603 m
.6569 .06579 L
s
P
p
.2 0 1 r
.016 w
.57658 .6374 m
.17561 .34608 L
s
P
p
.2 0 1 r
.016 w
.57658 .6374 m
.72974 1.10877 L
s
P
p
.2 0 1 r
.016 w
.57658 .6374 m
.72974 .16603 L
s
P
p
1 .6 0 r
.016 w
.5 .40171 m
.42342 .6374 L
s
P
p
1 .6 0 r
.016 w
.5 .40171 m
.57658 .6374 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.014 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.014 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.132776 1.26555 0.0316388 1.26555 [
[ 0 0 0 0 ]
[ 1 1.32883 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.32883 L
0 1.32883 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.31649 .06857 L
s
P
p
0 .4 1 r
.018 w
.24057 .17307 m
.11773 .13315 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.11773 1.19567 L
s
P
p
0 .4 1 r
.018 w
.24057 1.15576 m
.31649 1.26025 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.94102 .40066 L
s
P
p
0 .4 1 r
.018 w
.81819 .36074 m
.81819 .23159 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 .17307 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.24057 1.15576 L
s
P
p
.2 0 1 r
.016 w
.40022 .66441 m
.81819 .36074 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.18181 .23159 L
s
P
p
0 .4 1 r
.018 w
.18181 .36074 m
.05898 .40066 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.68351 1.26025 L
s
P
p
0 .4 1 r
.018 w
.75943 1.15576 m
.88227 1.19567 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.88227 .13315 L
s
P
p
0 .4 1 r
.018 w
.75943 .17307 m
.68351 .06857 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.18181 .36074 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 1.15576 L
s
P
p
.2 0 1 r
.016 w
.59978 .66441 m
.75943 .17307 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.40022 .66441 L
s
P
p
1 .6 0 r
.016 w
.5 .35732 m
.59978 .66441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.19792 0.952381 [
[ 0 0 0 0 ]
[ 1 .55654 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .55654 L
0 .55654 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.05089 .16971 L
s
P
p
0 .4 1 r
.018 w
.10014 .23749 m
.05089 .30527 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.7064 .51826 L
s
P
p
0 .4 1 r
.018 w
.7064 .43448 m
.78609 .40859 L
s
P
p
.2 0 1 r
.016 w
.43527 .23749 m
.10014 .23749 L
s
P
p
.2 0 1 r
.016 w
.43527 .23749 m
.7064 .43448 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.21391 .40859 L
s
P
p
0 .4 1 r
.018 w
.2936 .43448 m
.2936 .51826 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.94911 .30527 L
s
P
p
0 .4 1 r
.018 w
.89986 .23749 m
.94911 .16971 L
s
P
p
.2 0 1 r
.016 w
.56473 .23749 m
.2936 .43448 L
s
P
p
.2 0 1 r
.016 w
.56473 .23749 m
.89986 .23749 L
s
P
p
1 .6 0 r
.016 w
.5 .03828 m
.43527 .23749 L
s
P
p
1 .6 0 r
.016 w
.5 .03828 m
.56473 .23749 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`00018000?600001P000lH0000H0003]00000D000>d000060000lH000050003aP0001P000?60000
1@000lH0000H0003aP0000D000?6000060000lH000050003aP0001P000?600001@000lH0000B0000
3P03aP030<H000P000?600000/H@00>d00<0]00020000k@00002]1000lH00`3600080003aP0000;6
4003aP030<H000P000?600000/H@00?600<0aP0020000lH00002aQ000lH00`3600080003aP0000;6
4003aP030<H000P000?600000/H?00004@000dd000090003CLH001@000==00002@000dfd000D0003
C@0000T000==aP0050000dd000090003CLH001@000==00002@000dg6000D0003C@0000T000==aP00
50000dd000090003CLH00100000A0003C00000T000=<000050000d`000090003C00001@000=<0000
2@000d`0000D0003C00000T000=<000050000d`000090003C00001@000=<00002@000d`0000D0003
C00000T000=<0000400000l000?604d02P0014d00<HB0004]000C@T000A=002d4P001<H004d90004
C@00aQ8000C6001=2@0014d00<HB0004aP00C@T000A=00364P001<H004d90004C@00aQ8000C6001=
2@0014d00<H@00003`001<H004`90004C000aQ8000Bd001<2@0014`00;@B0004aP00C0T000A<0036
4P001<H004`90004C000aQ8000C6001<2@0014`00<HB0004aP00C0T000A<00364P001<H004`90004
C000aQ00000?0004aP00C@T000A=00364P001;@004d90004C@00]18000C6001=2@0014d00<HB0004
aP00C@T000A=00364P001<H004d90004C@00aQ8000C6001=2@0014d00<HB0004aP00C@T000A=0036
400000h000G6C4`0C00400054@0004`00P02C003aP0000h000>dC4`00P001D`0000A00<000=<0000
0T`00k@0000>0003aTa<008000E<00004@030003C000009<0/H?0003aTa<008000E<00004@030003
C000009<0/H?0003aTa<008000E<00004@030003C000009<0/H?0003aTa<008000E<00004@030003
C000009<0/H?0003aTa<008000E<00004@030003C000009<0/H>00003002aP<00Td400074@0004d0
C@030003aP0000/00[@30003C@1=00<000LA0000C@1=00<000>d00002`02aP<000==04d00`001a40
001=04d010000lH0000:00;60`000dd0C@0300074@0004d0C@040003aP0000X00/H30003C@1=00<0
00LA0000C@1=00@000?600002P02aP<000==04d00`001a40001=04d010000lH0000:00;60`000dd0
C@0300074@0004d0C@040003aP0000/0000B009<0P024@<00T`H009<0`0011400002C1P00T`30004
4@00009<6002C0<000@A00000T`H009<0`0011400002C1P00T`300044@00009<6002C0<000@A0000
0T`C00004`02C@0401404@9=70001dd04@0A04d070001dd04@0A04d070001dd04@0A04d070001dd0
4@0A04d070001dd04@0A04d070001dd04@0A04d05@0001<000=<01400P000a40C00L009<00<A0140
0T`L009<00<A01400T`L009<00<A01400T`L009<00<A01400T`L009<00<A01400T`L009<00<A0140
0T`E00004`000dd04@02C@034@1=01`000M=015=4@1=01`000M=015=4@1=01`000M=015=4@1=01`0
00M=015=4@1=01`000M=015=4@1=01`000M=015=4@1=01D0000D0006C14004`A7P001A5<04`A01h0
00DAC01<4@0N00054D`0C1407P001A5<04`A01h000DAC01<4@0N00054D`0C1405P0001@000<A0000
0P000a40000L00054@0001407P001A40000A01h000DA00004@0N00054@0001407P001A40000A01h0
00DA00004@0F000050000d`000020003C00001`000E<0000C00N0005C00004`07P001D`0001<01h0
00E<0000C00N0005C00004`07P001D`0001<01H0000D0003C@0000<000==00006P000dd000030003
C@0001X000==00000`000dd0000J0003C@0000<000==00006P000dd000030003C@0001X000==0000
0`000dd0000J0003C@0000<000==00004`0001<000=<000010000d`0000J0003C00000<000=<0000
6P000d`000030003C00001X000=<00000`000d`0000J0003C00000<000=<00006P000d`000030003
C00001X000=<00000`000d`0000C00004`000dd000040003C@0001X000==00000`000dd0000J0003
C@0000<000==00006P000dd000030003C@0001X000==00000`000dd0000J0003C@0000<000==0000
6P000dd000030003C@0001<0000C0003C00000D000=<000060000d`000050003C00001P000=<0000
1@000d`0000H0003C00000D000=<000060000d`000050003C00001P000=<00001@000d`0000H0003
C00000D000=<00004P0001<000==00001@000dd0000H0003C@0000D000==000060000dd000050003
C@0001P000==00001@000dd0000H0003C@0000D000==000060000dd000050003C@0001P000==0000
1@000dd0000B00004P000d`000060003C00001P000=<00001@000d`0000H0003C00000D000=<0000
60000d`000050003C00001P000=<00001@000d`0000H0003C00000D000=<000060000d`000050003
C0000180000B0003C@0000L000==00005P000dd000070003C@0001H000==00001`000dd0000F0003
C@0000L000==00005P000dd000070003C@0001H000==00001`000dd0000F0003C@0000L000==0000
4@00018000=<00001`000d`0000F0003C00000L000=<00005P000d`000070003C00001H000=<0000
1`000d`0000F0003C00000L000=<00005P000d`000070003C00001H000=<00001`000d`0000A0000
4P000dd000070003C@0001H000==00001`000dd0000F0003C@0000L000==00005P000dd000070003
C@0001H000==00001`000dd0000F0003C@0000L000==00005P000dd000070003C@000140000A0003
C00000T000=<000050000d`000090003C00001@000=<00002@000d`0000D0003C00000T000=<0000
50000d`000090003C00001@000=<00002@000d`0000D0003C00000T000=<00004000010000?6C@00
2P000dg6aP0C0003]4d000X000==];@04`000lI=000:0003CLK601<000?6C@002P000dg6aP0C0003
aTd000X000==a/H04`000lI=000:0003CLK601<000?6C@002P000dg6aP0@00003P02aP030<H000T0
00G60000aP0@00:d0P000k@000070005]0000;@04002aP8000?600001`001LH0003601000/H20003
aP0000L000G60000aP0@00;60P000lH000070005aP000<H04002aP8000?600001`001LH000360100
0/H20003aP0000L000G60000aP0?00004P000lH000060003aP0001P000>d00001@000k@0000H0003
aP0000D000?6000060000lH000050003aP0001P000?600001@000lH0000H0003aP0000D000?60000
60000lH000050003aP000180003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0000B0004
aP0000;60`02aQT000?600001@000lH0000H0003aP0000D000?6000060000lH000050003aP0001D0
00?600002`000lH0000E0003aP0000D000?600005P000lH000090003aP000100000C0003aP360080
00C60<K66P000lH000050003aP0001<00lH00`3600080003aP0000;64003aP030<H000P000?60000
0/HB0003aP0000/000?6000050000lH000070003aP0001<000?6C@0030000dg6000?00004`000lI<
00030003C03601@00lH20003aP0000L000?600000lHB0003C00000T000=<aP0050000d8000090003
@/H001@000?600002@000lH0000A00?600=<00002@000dc6aP02aQ4000=<00002`000d`0000?0000
4P000lH0C@040004C@00aQH000?6C@002P000dg6000D0003C@0000T000==000050000d8000090003
@P0001@000==00002@000dd0000C0003aTd000X000==aP004`000dd0000;0003C@0000l0000?00?6
00=<04`0100014`004`3aQ<000?6C0002P000dc6000B0004aP00C0T000A<00364P001<H004890004
@P00aQ@000=<00002@000d`0000C0003aP1<00T000=<0<H04`000lH0C00;0003C0360100000B0003
C@1=00@000A=001=5P000lI=000:0003CLH0018000C6001=2@0014d00<HB0004aP00@PT000A20036
4002aP<000==00001`0014d00002aQ4000?604d02@000dd0aP0C0003aP1=00/000==0<H0400001<0
0T`40003C01<01L000?604`010000a4000020003C03601<000C6001<2@0014`00<HB0004aP00@PT0
00A200364P001<H004`90004C000aQ8000C6001<2@0014`00<HA0004aTa<C0D000<A00000`03C003
aP0000d0000D0005C@004@000TdG0004aTe=C@@000<A00000P03C@;640000lI=C@020005C@000140
0`000dd00002C@03aP0000h000?6@T800P001D80000A00<000=200000T82aQ400dd400034@000080
0ddB0003aTe=008000E=00004@030003C@00009=0/H>0004aP00009=10000a400002009=0`000lH0
000<000050001T`00140C1H00/H30007C00001404@030003C000008000?600002`02aP<000=<04`0
0`001a40001<04`00`000lH0000;00;60`000d80@P0300074@000480@P040003aP0001000T`30004
4@00009<4P02aP<000=<04`00`001a40001<04`010000lH0000@0007C00001404@030003C0000140
000D009=0Q42CA`00Td01@0A0140009=6@02C@<000@A00000TdH00920`0011400002@QT000E=0000
4@030003C@0001L00Td300044@00009=6003C@0501404@000ddC000050001T`04@0AC1`000U<04`A
015<04`06`001d`04@0A04`070001d804@0A04806`03C0034@0A00=<6`001d`04@0A04`06`002D`0
C1404D`0C00D000050001TdA04dACA`000U=015=04dA04d06`02C@034@0A009=7002@P034@0A0092
70001dd04@0A04d07002C@034@0A009=6`000dd04@03C@034@1=01@0000D0006C15<C15<70000d`0
4@03C0034@1<01/000M<015<4@1<01`000M201524@1201`000M<015<4@1<01`000M<015<4@1<01/0
00U<015<04`A04`0500001@000I=4@00CA4M0003CA40008000<AC@0070001A5=04dA01h000DA@P12
4@0M0007CA5=04dAC@0M00054Dd0CA407@000ddA000200034Dd001@0000D00034@00008000<A0000
6`000a40000300034@0001/000DA00004@0N00054@0001407P001A40000A01h000DA00004@0M0003
4@0000<000<A00004`0001@000==00000P000dd0000K0003C@0000<000==00006`001Dd0001=01h0
00E20000@P0N0005C@0004d07P001Dd0001=01d000==00000`000dd0000C000050000d`000030003
C00001X000=<00000`000d`0000J0003C00000<000=<00006P000d8000030003@P0001X000=<0000
0`000d`0000J0003C00000<000=<00006P000d`000030003C00001<0000C0003C@0000@000==0000
6@000dd000050003C@0001T000==00000`000dd0000J0003@P0000<000=200006P000dd000030003
C@0001X000==00000`000dd0000I0003C@0000D000==00004P0001<000=<000010000d`0000I0003
C00000D000=<00006@000d`000030003C00001X000=200000`000d80000J0003C00000<000=<0000
6P000d`000030003C00001T000=<00001@000d`0000B00004`000dd000050003C@0001P000==0000
1@000dd0000H0003C@0000D000==000060000d8000050003@P0001P000==00001@000dd0000H0003
C@0000D000==000060000dd000050003C@000180000C0003C00000D000=<00005`000d`000070003
C00001L000=<00001@000d`0000H0003@P0000D000=2000060000d`000050003C00001P000=<0000
1@000d`0000G0003C00000L000=<00004@00018000==00001P000dd0000G0003C@0000L000==0000
5`000dd000050003C@0001P000=200001@000d80000H0003C@0000D000==000060000dd000050003
C@0001L000==00001`000dd0000A00004P000d`000070003C00001H000=<00001`000d`0000F0003
C00000L000=<00005P000d8000070003@P0001H000=<00001`000d`0000F0003C00000L000=<0000
5P000d`000070003C0000140000B0003C@0000L000==00005P000dd000070003C@0001H000==0000
1`000dd0000F0003@P0000L000=200005P000dd000070003C@0001H000==00001`000dd0000E0003
C@0000T000==00004000018000=<00001`000d`0000E0003C00000T000=<00005@000d`000070003
C00001H000=200001`000d80000F0003C00000L000=<00005P000d`000070003C00001D000=<0000
2@000d`0000@00004@000dd000090003C@0001<000?6C@002P000dg6000D0003C@0000T000==0000
50000d8000090003@P0001@000==00002@000dd0000D0003C@0000T000==000050000dd000090003
C@000100000@0003aT`000X000=<a/H04@02aP030<H000X000C60<K64P000lI<000:0003C<K601<0
00?6@P002P000d;6aP0D0003aP0000T000?600004`000lI<000:0003C<K601<000=<00002`000d`0
000?00003P02aP030<H000T000G60000aP0?0003aP00008000?600001`000lH000020003aP0000d0
0/H20003aP0000L000G60000aP0@00;60P000lH000070005aP000<H04P000lH0000;0003aP000100
0/H20003aP0000L000C600000/H@0003aTd000`000==aP003`00018000?600001P000lH0000H0003
aP0000D000?6000060000lH000050003aP0001P000?600001@000lH0000E0003aP0000/000?60000
5@000lH000050003aP0001H000?600002@000lH0000@0000o`030000o`030000o`030000o`030000
o`030000o`0300005P000dd0C@0J0003aP0000/000?600005@02aPD000?600006@000lH000050003
aP0001P000?600001@000lH0000H0003aP0000D000?60000=@00018000M<0000C01<00<000=<0000
50000lH0000;0003aP0001400/H00`3600070003aP0000;64@03aP030<H000P000?600000/H@00?6
00<0aP0020000lH00002aQ000lH00`3600080003aP0000;6<P00018000==00000P000dd000020003
C@0001<000?600003@000lH0000B0003C@0000P000==aP005@000dd000090003CLH001@000==0000
2@000dg6000D0003C@0000T000==aP00<`00018000M<0000C01<00<000=<00004003aP03C00000d0
00A<a/K64@000d`000080003C00001D000=<00002@000d`0000D0003C00000T000=<000050000d`0
00090003C00003<0000;00==100014d004d30004C@00C@D00Td>0003C@0000d000==00004P000dd0
00080003C@0001<000C6001=2@0014d00<HB0004aP00C@T000A=00364P001<H004d90004C@00aS<0
000>00=<00@0C0361@000lH0C00200=<4@000d`0000400034@0000@000=<00004`000d`000080003
C00001<000C6001<2@0014`00<HB0004aP00C0T000A<00364P001<H004`90004C000aS<0000A0003
aTe=00L000A=a/I=5@000dd0000300034@0000<000==00004P001<H004d80005C@000<H04P001<H0
04d90004C@00aQ8000C6001=2@0014d00<HB0004aP00C@T000A=00366P000a40000F00004P000lI<
00060003C<H001L000=<00000P000a4000020003C00001<000C6001<10001A40001<00<000?60000
3`000lI<C0020003C00000D000=<00000T`2aPl000?6C4`00P001D`0000A00<000=<00000T`2aPl0
00?6C4`00P001D`0000A00<000=<00000T`2aQP000<A00005P00018000?6C@001@000dd0aP0I0005
C@0001400`000dd0000D0004aP00C@@000DA0000C@030003aP0000d00/H30003C@1=00<000LA0000
C@1=00@000?600002P02aP<000==04d00`001a40001=04d010000lH0000:00;60`000dd0C@030007
4@0004d0C@040003aP0001D000<A00005P00014000C6C4a<0P000a400003C003aP0001H000E<0000
4@030003C00001<000G6C4`0C00300034@0A008000=<00000T`00lH0000B009<0`0011400002C1P0
0T`300044@00009<6002C0<000@A00000T`L00034@0A01L0000?0003CLH0008000A=000A0P001Dd0
0036009=5P0014d001420003C@0001<000C600000Td300034@0A00800dd30003aP0001<000M=0140
4@1=01`000M=01404@1=01`000M=01404@1=01h000<A01405`0000`00d`5009<0Q42C0L00d`D0005
C00A04`06`03C0054@0001400T`K009<00<A01400T`L009<00<A01400T`L009<00<A01400T`A0003
aP0000X000<A014030000lH0000800002P02C@P000I=015=4Dd:0003C@00018000==4Dd07@000ddA
0003C@034Dd001/000M=015=4@1=01`000M=015=4@1=01`000M=015=4@1=014000?600002@001A40
000A00/000?60000200001D000E<4D`AC00P00034@0001`000Q<4Da<04`AC1d000DAC01<4@0N0005
4D`0C1407P001A5<04`A01<02d`01A5<04`A00]<2`0001D000@A000A8@000dd0000L00034@0000@0
00<A00006`001A40000A01h000DA00004@0N00054@0001404`000lH0000:0003C@0000X000?60000
2@0001D000A<001<8@000d`0000L0003C00000@000=<00006`001D`0001<01h000E<0000C00N0005
C00004`04P000lH00009009<00<0C4`02`000lH0000800005@001Dd0001=020000==00006`000dd0
00060003C@0001T000==00000`000dd0000J0003C@0000<000==00006P000dd000030003C@0001X0
00==00000`000dd0000C000050000d`000020003C00001h000=<00006`000d`000060003C00001T0
00=<00000`000d`0000J0003C00000<000=<00006P000d`000030003C00001P00T`7009<4`0001@0
00==00000P000dd0000N0003C@0001/000==00001`000dd0000H0003C@0000<000==00006P000dd0
00030003C@0001X000==00000`000dd0000D00;600<0C@002P0014d0a/H?000050000d`000030003
C00001d000=<00006P000d`000080003C00001L000=<00001@000d`0000H0003C00000D000=<0000
60000d`000050003C00001D000=<00002`000d`0000?000050000dd000030003C@0001d000==0000
6P000dd000090003C@0001H000==00001@000dd0000H0003C@0000D000==000060000dd000050003
C@0001D000?600002`000lH0000?00004`000d`000040003C00001d000=<00006@000d`0000:0003
C00001H000=<00001@000d`0000H0003C00000D000=<000060000d`000050003C00001D000?60000
2`000lH0000?0000400014g6aTd70003CLK6009=6P000dd0000I0003C@0000/000==000050000dd0
00070003C@0001H000==00001`000dd0000F0003C@0000L000==000050000lH0000;0003aP0000l0
000=00=<10000lH000030003aP0000<00d`G0003C00001P000=<000030000d`0000D0003C00000L0
00=<00005P000d`000070003C00001H000=<00001`000d`0000d00002`02C@L000==00000`000dd0
00060003C@0001@000==000060000dd0000=0003C@0001<000==00001`000dd0000F0003C@0000L0
00==00005P000dd000070003C@0003@0000E0005C00004`080000d`0000H0003C00000d000=<0000
4P000d`000090003C00001@000=<00002@000d`0000D0003C00000T000=<0000<`0001H000==04d0
80000lI=aP0E00?600==00003`0014g6a/H?0003aTd000X000==a/H04`000lI=000:0003CLK601<0
00?6C@002P000dg6aP0c00005`000d`0000N0005aP000<H05`000lH0000?0003aP0000h00/H20003
aP0000L000G60000aP0@00;60P000lH000070005aP000<H04002aP8000?600001`001LH000360380
000F0003C@1=01h000?600000`000lH0000E0003aP0000d000?6000050000lH000050003aP0001P0
00?600001@000lH0000H0003aP0000D000?60000=@000?l00`000?l00`000?l00`000?l00`000001
\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270001, -0.109412,
   0.0329412, 0.0329412}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42397,
   -0.109412, 0.0329412, 0.0329412}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57795, -0.109412, 0.0329412, 0.0329412}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.73192, -0.109412, 0.0329412, 0.0329412}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88589, -0.109412, 0.0329412, 
  0.0329412}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.03986,
   -0.109412, 0.0329412, 0.0329412}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.19384, -0.109412, 0.0329412, 0.0329412}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.271511, -1.26684, 0.0330058, 0.0330058}, {{42.5, 74.3125},
   {69.375, 37.5625}} -> {-1.42777, -1.26686, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.58402, -1.26687, 0.0330063, 0.0330063},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74028, -1.26687, 0.0330063, 
  0.0330063}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.89654, -1.26687, 
  0.0330064, 0.0330064}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05279,
   -1.26687, 0.0330063, 0.0330063}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.20904, -1.26687, 0.0330063, 0.0330063}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.270005, -2.41737, 0.0329413, 0.0329413}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42399, -2.41738, 0.0329415, 0.0329415}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.73194, -2.41737, 0.0329414, 
  0.0329414}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88589, -2.41736, 
  0.0329412, 0.0329412}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.03986,
   -2.41736, 0.0329412, 0.0329412}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1939, -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.1167 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.031763 1.06353 0.0265882 1.06353 [
[ 0 0 0 0 ]
[ 1 1.1167 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 1.1167 L
0 1.1167 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39855 .22895 m
.52446 .05566 L
s
P
p
.2 0 1 r
.02 w
.28867 .26466 m
.08495 .19846 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.39855 .22895 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.28867 .26466 L
s
P
p
.2 0 1 r
.02 w
.28867 .85205 m
.08495 .91824 L
s
P
p
.2 0 1 r
.02 w
.39855 .88775 m
.52446 1.06105 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.28867 .85205 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.39855 .88775 L
s
P
p
.2 0 1 r
.02 w
.74381 .41254 m
.94753 .47873 L
s
P
p
.2 0 1 r
.02 w
.6759 .31907 m
.6759 .10486 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.74381 .41254 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.6759 .31907 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .28672 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .82998 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.6759 .39047 L
s
P
p
.2 0 1 r
.02 w
.3241 .31907 m
.3241 .10486 L
s
P
p
.2 0 1 r
.02 w
.25619 .41254 m
.05247 .47873 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.3241 .31907 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.25619 .41254 L
s
P
p
.2 0 1 r
.02 w
.60145 .88775 m
.47554 1.06105 L
s
P
p
.2 0 1 r
.02 w
.71133 .85205 m
.91505 .91824 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.60145 .88775 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.71133 .85205 L
s
P
p
.2 0 1 r
.02 w
.71133 .26466 m
.91505 .19846 L
s
P
p
.2 0 1 r
.02 w
.60145 .22895 m
.47554 .05566 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.71133 .26466 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.60145 .22895 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.3241 .39047 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .82998 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .28672 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.44484 .55835 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.55516 .55835 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{159, 177},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002O0000/@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP0009l0002O0000W`0009l0002O0000W`0009l0
002O0000BP03C@@00de;0000BP03C0@00da;0000BP04C@8014e;0000BP0:C4/0001;00Q=C00004`0
1Ta=0000C006CDd0001=00A<CP0003800ddG00I=5`03CC<0000b00=<5P08C1H00d`c0000<P03CAH0
24dF00==<`0003800d`E00A<0P04C1D00d`c0000<P03CA@01Dd200E=5003CC<0000b00=<5004C0@0
14`D00=<<`0003800ddC00A=1P04CA<00ddc0000<P03C1801D`600E<4P03C3<0000b00==4@05C@P0
1DdA00==<`0003800d`A00A<2P04C1400d`c0000<P03CA0014d<00A=4003CC<0000b00=<3`05C0`0
1D`?00=<<`0003800dd?00A=3P04C@l00ddc0000<P03C0h014`@00A<3P03C3<0000b00==3@05CA00
1Dd=00==<`0000`01D`Q00=<3@04C18014`=00=<8@05C0d0000<00Q=7P03C@`014dD00A=3003CAh0
24d=0000300;C1/00d`;00E<5005C0/00d`K00]<3@0000l02ddH00==2`04CAH014d;00==600;CA00
000B00]<5@03C0X014`H00A<2P03C1D02d`C00005@0<CA400dd900E=6005C@T00ddA00a=5P0001P0
34`>00=<2@02aP9<6P0014c6aT`900=<3P0<C1T0000K00a=2`03C@T00/H00dd0000J00;600==0000
1`03C@/034dL00007`0;C0P00d`800?67@03aPT00d`800]<800002802dd500==1`03aQl00lH800==
1@0;CB<0000U00Y<0`03C0H00lHQ00?61`03C0<02T`V0000:004C@?60`03C@D00lHS00?61P03C@80
0lH5CBT0000[0003C<K600C60d`500;69@02aPH00T`6aP9<;00002h01<H3C@@00lHU00?61007aS00
000a0004aTa<C0K69`0:aS<0000b00==0/H2C@03aP0002L000?6CDd00lH3CC<0000b00=<0P02C2/0
0T`300=<<`0003800dd200==:@03C@<00ddc0000<P03C0<00T`Y009<1003C3<0000b00==0`02CBT0
0Td400==<`0003800/H014`00003C2L00d`400;600=<0000<@0003800/H00dd00002009=9`02C@D0
0/H00dd0000a0000<P02aPD00T`W009<1@02aS@0000b00;61@03CBD00dd500;6=00003800/H6009<
9@02C0H00/Hd0000<P02aPH00TdU009=1P02aS@0000b00;61P03C2<00d`600;6=00003800/H7009=
8`02C@L00/Hd0000<P02aPL00T`S009<1`02aS@0000b00;61`03CB400dd700;6=00003800/H8009<
8@02C0P00/Hd0000<@001<I=CDd7009=40024@l00Td700==00?60000<@0002h01<H4C0H00d`?008A
3P03C0H014`4aS00000[00O60P03C@H00Td>00<A3P02C@H00dd200O6;@0002D00d`7aPH014`4009<
3P044@d00T`400A<1P07aPA<9P0002801Dd5aPX014d300==3@044@`00dd300A=2P05aPI=8`0001l0
24`2aP03C00000`014`2009<30054@`00T`200A<3`02aPU<800001`02ddB00A=00<0CDd030024@04
014A4@/00Td00`1=C@02CA<02ddM00006@0;C1L01T`;008A0P024@X01T`H00]<6P0001D034dK00E=
2P034@800Q4:00E=700<CAH0000B00a<7`04C0X00Q4300<A2@04C20034`C00003`0<CB@014d8008A
10024@L014dU00a=400000`02d`Y00A<1P034@@00Q4600A<:P0;C0d0000900]=;005C@D00Q4500<A
1005CBd02dd:00001`0:C2l01d`3008A1P024@801d``00Y<200000L01ddc009=00<0CDd00Td0100A
4A46008A00<0CDd00Td00`1=C@0d00M=200000L014`f009<0`03C08A1`024@=<0`02C3L014`80000
@@03C@<00Td24@L00a4014d00003CD<00012009<10034@03C00000<00T`24@@00Ta40000@P02C@@0
0Q44C@0304e=009=0Q44009=A00004800d`3008A00<0C4`01D`0100A4A4200=<A00004<00Td200<A
0`03C@@00Q42009=A@0004<00T`2008A0P07C0800Q42009<A@0004<00dd0100A4@04C@0304e=009=
00@04A4A0de50000A002C0<A0d`500A<0Q42C4H00014009=0Q43C@L00dd24@9=AP0004@00T`24@03
C00000T000E<4A4AC0160000A@034@d000==4A40A`0004D00Q4?008AA`0004D00Td?009=A`0004@0
0d`?00=<AP0004@00TdA009=AP0004@00T`A009<AP0004<00ddA00==A@0004<00T`C009<A@0004<0
0TdC009=A@0004800d`C00=<A00004800TdE009=A00004800T`E009<A00004400ddE00==@`000440
0T`G009<@`0004400TdG009=@`0004000d`G00=<@P0004000TdI009=@P0004000T`I009<@P0003l0
0ddI00==@@0003l00T`K009<@@0003l00TdK009=@@0003h00d`K00=<@00003h00TdM009=@00003h0
0T`M009<@00003d00ddM00==?`0003d00T`O009<?`0003d00TdO009=?`0003`00d`O00=<?P0003`0
0TdQ009=?P0003`00T`Q009<?P0003/00ddQ00==?@0003/00T`S009<?@0003/00TdS009=?@0003X0
0d`S00=<?00003X00TdU009=?00003X00T`U009<?00003T00ddU00==>`0003T00T`W009<>`0003T0
0TdW009=>`0003P00d`W00=<>P0003P00TdY009=>P0003P00T`Y009<>P0003L00ddY00==>@0003H0
00?6C4`0:`02C003aP0003H0000c00C60Td[009=1<He0000<00:aRT02/Hb0000:P03C@O61003aRL0
0lH400O614d[00009`05C0G62003aRD00lH800G61T`X00009008C@;600==00002@03aR<00lH<00;6
2DdU00008@0;C0l00/HS00;6400;C280000N00]=4P03aR400lHC00]=7`0001X034`F00?60T`L0004
C<K6aQL034`K00005`0<CAX00lH00dd0000J00?66`0<CAP0000D00a<7P02aP9<6P0014c6aT`N00a<
5@0001402ddR00E=6005CB802ddB00003P0;C2H014`H00A<9P0;C0l0000<00Y=:P04CAH014dZ00Y=
3@0000`01d`]00E<5005C2d01d`=00003004CC4014dD00A=<@04C@d0001200A<4P04C4<0001200E=
4005CD<0001300A<4004C4@0001400A=3P04CDD0001400E<3005C4D0001500A=3004CDH0001600A<
2P04C4L0001600E=2005CDL0001700E<1P05C4P0001800A=1P04CDT0001900A<1004C4X0001900E=
0P05CDX0001:00A<0P04C4/0001;00Q=C00004/024a<0000C006CDd0001=00A<CP0004`01Te=0000
C006C4d0001;00Q=C00004X02Ta;0000BP04C@8014e;0000BP03C0@00da;0000W`0009l0002O0000
W`0009l0002O0000W`000001\
\>"],
  ImageRangeCache->{{{0, 158}, {176, 0}} -> {0.0286893, -0.0250052, 
  0.00596593, 0.00596593}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.031763 1.06353 0.0265882 1.06353 [
[ 0 0 0 0 ]
[ 1 1.1167 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.1167 L
0 1.1167 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39855 .22895 m
.52446 .05566 L
s
P
p
.2 0 1 r
.02 w
.28867 .26466 m
.08495 .19846 L
s
P
p
0 .4 1 r
.02 w
.35658 .28672 m
.39855 .22895 L
s
P
p
0 .4 1 r
.02 w
.35658 .28672 m
.28867 .26466 L
s
P
p
.2 0 1 r
.02 w
.28867 .85205 m
.08495 .91824 L
s
P
p
.2 0 1 r
.02 w
.39855 .88775 m
.52446 1.06105 L
s
P
p
0 .4 1 r
.02 w
.35658 .82998 m
.28867 .85205 L
s
P
p
0 .4 1 r
.02 w
.35658 .82998 m
.39855 .88775 L
s
P
p
.2 0 1 r
.02 w
.74381 .41254 m
.94753 .47873 L
s
P
p
.2 0 1 r
.02 w
.6759 .31907 m
.6759 .10486 L
s
P
p
0 .4 1 r
.02 w
.6759 .39047 m
.74381 .41254 L
s
P
p
0 .4 1 r
.02 w
.6759 .39047 m
.6759 .31907 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .28672 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .82998 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.6759 .39047 L
s
P
p
.2 0 1 r
.02 w
.3241 .31907 m
.3241 .10486 L
s
P
p
.2 0 1 r
.02 w
.25619 .41254 m
.05247 .47873 L
s
P
p
0 .4 1 r
.02 w
.3241 .39047 m
.3241 .31907 L
s
P
p
0 .4 1 r
.02 w
.3241 .39047 m
.25619 .41254 L
s
P
p
.2 0 1 r
.02 w
.60145 .88775 m
.47554 1.06105 L
s
P
p
.2 0 1 r
.02 w
.71133 .85205 m
.91505 .91824 L
s
P
p
0 .4 1 r
.02 w
.64342 .82998 m
.60145 .88775 L
s
P
p
0 .4 1 r
.02 w
.64342 .82998 m
.71133 .85205 L
s
P
p
.2 0 1 r
.02 w
.71133 .26466 m
.91505 .19846 L
s
P
p
.2 0 1 r
.02 w
.60145 .22895 m
.47554 .05566 L
s
P
p
0 .4 1 r
.02 w
.64342 .28672 m
.71133 .26466 L
s
P
p
0 .4 1 r
.02 w
.64342 .28672 m
.60145 .22895 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.3241 .39047 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .82998 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .28672 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.44484 .55835 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.55516 .55835 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.031763 1.06353 0.0265882 1.06353 [
[ 0 0 0 0 ]
[ 1 1.1167 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.1167 L
0 1.1167 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39855 .22895 m
.52446 .05566 L
s
P
p
.2 0 1 r
.02 w
.28867 .26466 m
.08495 .19846 L
s
P
p
.2 0 1 r
.018 w
.35658 .28672 m
.39855 .22895 L
s
P
p
.2 0 1 r
.018 w
.35658 .28672 m
.28867 .26466 L
s
P
p
.2 0 1 r
.02 w
.28867 .85205 m
.08495 .91824 L
s
P
p
.2 0 1 r
.02 w
.39855 .88775 m
.52446 1.06105 L
s
P
p
.2 0 1 r
.018 w
.35658 .82998 m
.28867 .85205 L
s
P
p
.2 0 1 r
.018 w
.35658 .82998 m
.39855 .88775 L
s
P
p
.2 0 1 r
.02 w
.74381 .41254 m
.94753 .47873 L
s
P
p
.2 0 1 r
.02 w
.6759 .31907 m
.6759 .10486 L
s
P
p
.2 0 1 r
.018 w
.6759 .39047 m
.74381 .41254 L
s
P
p
.2 0 1 r
.018 w
.6759 .39047 m
.6759 .31907 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .28672 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .82998 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.6759 .39047 L
s
P
p
.2 0 1 r
.02 w
.3241 .31907 m
.3241 .10486 L
s
P
p
.2 0 1 r
.02 w
.25619 .41254 m
.05247 .47873 L
s
P
p
.2 0 1 r
.018 w
.3241 .39047 m
.3241 .31907 L
s
P
p
.2 0 1 r
.018 w
.3241 .39047 m
.25619 .41254 L
s
P
p
.2 0 1 r
.02 w
.60145 .88775 m
.47554 1.06105 L
s
P
p
.2 0 1 r
.02 w
.71133 .85205 m
.91505 .91824 L
s
P
p
.2 0 1 r
.018 w
.64342 .82998 m
.60145 .88775 L
s
P
p
.2 0 1 r
.018 w
.64342 .82998 m
.71133 .85205 L
s
P
p
.2 0 1 r
.02 w
.71133 .26466 m
.91505 .19846 L
s
P
p
.2 0 1 r
.02 w
.60145 .22895 m
.47554 .05566 L
s
P
p
.2 0 1 r
.018 w
.64342 .28672 m
.71133 .26466 L
s
P
p
.2 0 1 r
.018 w
.64342 .28672 m
.60145 .22895 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.3241 .39047 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .82998 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .28672 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.44484 .55835 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.55516 .55835 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0499794 1.09996 0.027499 1.09996 [
[ 0 0 0 0 ]
[ 1 1.15496 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.15496 L
0 1.15496 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.5701 .13326 L
s
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.4656 .05734 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.12474 .16809 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.08483 .29094 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.40102 .2561 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.29382 .29094 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.08483 .86402 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.12474 .98686 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.4656 1.09761 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.5701 1.02169 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.29382 .86402 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.40102 .89885 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.90695 .55806 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.94686 .43522 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.7362 .14526 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.60704 .14526 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.73787 .43522 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.67162 .34403 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .31246 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .84249 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.67162 .41369 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.39296 .14526 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.2638 .14526 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.05314 .43522 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.09305 .55806 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.32838 .34403 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.26213 .43522 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.4299 1.02169 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.5344 1.09761 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.87526 .98686 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.91517 .86402 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.59898 .89885 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.70618 .86402 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.91517 .29094 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.87526 .16809 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.5344 .05734 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.4299 .13326 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.70618 .29094 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.59898 .2561 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.32838 .41369 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .84249 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .31246 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.44618 .57748 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.55382 .57748 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.031763 1.06353 0.0265882 1.06353 [
[ 0 0 0 0 ]
[ 1 1.1167 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.1167 L
0 1.1167 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39855 .22895 m
.52446 .05566 L
s
P
p
.2 0 1 r
.02 w
.28867 .26466 m
.08495 .19846 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.39855 .22895 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.28867 .26466 L
s
P
p
.2 0 1 r
.02 w
.28867 .85205 m
.08495 .91824 L
s
P
p
.2 0 1 r
.02 w
.39855 .88775 m
.52446 1.06105 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.28867 .85205 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.39855 .88775 L
s
P
p
.2 0 1 r
.02 w
.74381 .41254 m
.94753 .47873 L
s
P
p
.2 0 1 r
.02 w
.6759 .31907 m
.6759 .10486 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.74381 .41254 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.6759 .31907 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .28672 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .82998 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.6759 .39047 L
s
P
p
.2 0 1 r
.02 w
.3241 .31907 m
.3241 .10486 L
s
P
p
.2 0 1 r
.02 w
.25619 .41254 m
.05247 .47873 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.3241 .31907 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.25619 .41254 L
s
P
p
.2 0 1 r
.02 w
.60145 .88775 m
.47554 1.06105 L
s
P
p
.2 0 1 r
.02 w
.71133 .85205 m
.91505 .91824 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.60145 .88775 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.71133 .85205 L
s
P
p
.2 0 1 r
.02 w
.71133 .26466 m
.91505 .19846 L
s
P
p
.2 0 1 r
.02 w
.60145 .22895 m
.47554 .05566 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.71133 .26466 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.60145 .22895 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.3241 .39047 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .82998 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .28672 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.44484 .55835 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.55516 .55835 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0417841 1.08357 0.0270892 1.08357 [
[ 0 0 0 0 ]
[ 1 1.13775 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.13775 L
0 1.13775 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39039 .21297 m
.50375 .05694 L
s
P
p
.2 0 1 r
.02 w
.27167 .25155 m
.08824 .19195 L
s
P
p
0 .4 1 r
.018 w
.34504 .27539 m
.39039 .21297 L
s
P
p
0 .4 1 r
.018 w
.34504 .27539 m
.27167 .25155 L
s
P
p
.2 0 1 r
.02 w
.27167 .8862 m
.08824 .9458 L
s
P
p
.2 0 1 r
.02 w
.39039 .92477 m
.50375 1.08081 L
s
P
p
0 .4 1 r
.018 w
.34504 .86236 m
.27167 .8862 L
s
P
p
0 .4 1 r
.018 w
.34504 .86236 m
.39039 .92477 L
s
P
p
.2 0 1 r
.02 w
.76343 .41133 m
.94686 .47093 L
s
P
p
.2 0 1 r
.02 w
.69006 .31034 m
.69006 .11747 L
s
P
p
0 .4 1 r
.018 w
.69006 .38749 m
.76343 .41133 L
s
P
p
0 .4 1 r
.018 w
.69006 .38749 m
.69006 .31034 L
s
P
p
.2 0 1 r
.016 w
.4404 .56887 m
.34504 .27539 L
s
P
p
.2 0 1 r
.016 w
.4404 .56887 m
.34504 .86236 L
s
P
p
.2 0 1 r
.016 w
.4404 .56887 m
.69006 .38749 L
s
P
p
.2 0 1 r
.02 w
.30994 .31034 m
.30994 .11747 L
s
P
p
.2 0 1 r
.02 w
.23657 .41133 m
.05314 .47093 L
s
P
p
0 .4 1 r
.018 w
.30994 .38749 m
.30994 .31034 L
s
P
p
0 .4 1 r
.018 w
.30994 .38749 m
.23657 .41133 L
s
P
p
.2 0 1 r
.02 w
.60961 .92477 m
.49625 1.08081 L
s
P
p
.2 0 1 r
.02 w
.72833 .8862 m
.91176 .9458 L
s
P
p
0 .4 1 r
.018 w
.65496 .86236 m
.60961 .92477 L
s
P
p
0 .4 1 r
.018 w
.65496 .86236 m
.72833 .8862 L
s
P
p
.2 0 1 r
.02 w
.72833 .25155 m
.91176 .19195 L
s
P
p
.2 0 1 r
.02 w
.60961 .21297 m
.49625 .05694 L
s
P
p
0 .4 1 r
.018 w
.65496 .27539 m
.72833 .25155 L
s
P
p
0 .4 1 r
.018 w
.65496 .27539 m
.60961 .21297 L
s
P
p
.2 0 1 r
.016 w
.5596 .56887 m
.30994 .38749 L
s
P
p
.2 0 1 r
.016 w
.5596 .56887 m
.65496 .86236 L
s
P
p
.2 0 1 r
.016 w
.5596 .56887 m
.65496 .27539 L
s
P
p
1 .6 0 r
.016 w
.5 .38544 m
.4404 .56887 L
s
P
p
1 .6 0 r
.016 w
.5 .38544 m
.5596 .56887 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.031763 1.06353 0.0265882 1.06353 [
[ 0 0 0 0 ]
[ 1 1.1167 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.1167 L
0 1.1167 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.018 w
.39855 .22895 m
.52446 .05566 L
s
P
p
.2 0 1 r
.018 w
.28867 .26466 m
.08495 .19846 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.39855 .22895 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.28867 .26466 L
s
P
p
.2 0 1 r
.018 w
.28867 .85205 m
.08495 .91824 L
s
P
p
.2 0 1 r
.018 w
.39855 .88775 m
.52446 1.06105 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.28867 .85205 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.39855 .88775 L
s
P
p
.2 0 1 r
.018 w
.74381 .41254 m
.94753 .47873 L
s
P
p
.2 0 1 r
.018 w
.6759 .31907 m
.6759 .10486 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.74381 .41254 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.6759 .31907 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .28672 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .82998 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.6759 .39047 L
s
P
p
.2 0 1 r
.018 w
.3241 .31907 m
.3241 .10486 L
s
P
p
.2 0 1 r
.018 w
.25619 .41254 m
.05247 .47873 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.3241 .31907 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.25619 .41254 L
s
P
p
.2 0 1 r
.018 w
.60145 .88775 m
.47554 1.06105 L
s
P
p
.2 0 1 r
.018 w
.71133 .85205 m
.91505 .91824 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.60145 .88775 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.71133 .85205 L
s
P
p
.2 0 1 r
.018 w
.71133 .26466 m
.91505 .19846 L
s
P
p
.2 0 1 r
.018 w
.60145 .22895 m
.47554 .05566 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.71133 .26466 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.60145 .22895 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.3241 .39047 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .82998 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .28672 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.44484 .55835 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.55516 .55835 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.031763 1.06353 0.0265882 1.06353 [
[ 0 0 0 0 ]
[ 1 1.1167 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.1167 L
0 1.1167 L
closepath
clip
newpath
p
P
p
.8 0 1 r
.02 w
.39855 .22895 m
.52446 .05566 L
s
P
p
.8 0 1 r
.02 w
.28867 .26466 m
.08495 .19846 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.39855 .22895 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.28867 .26466 L
s
P
p
.8 0 1 r
.02 w
.28867 .85205 m
.08495 .91824 L
s
P
p
.8 0 1 r
.02 w
.39855 .88775 m
.52446 1.06105 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.28867 .85205 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.39855 .88775 L
s
P
p
.8 0 1 r
.02 w
.74381 .41254 m
.94753 .47873 L
s
P
p
.8 0 1 r
.02 w
.6759 .31907 m
.6759 .10486 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.74381 .41254 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.6759 .31907 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .28672 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .82998 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.6759 .39047 L
s
P
p
.8 0 1 r
.02 w
.3241 .31907 m
.3241 .10486 L
s
P
p
.8 0 1 r
.02 w
.25619 .41254 m
.05247 .47873 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.3241 .31907 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.25619 .41254 L
s
P
p
.8 0 1 r
.02 w
.60145 .88775 m
.47554 1.06105 L
s
P
p
.8 0 1 r
.02 w
.71133 .85205 m
.91505 .91824 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.60145 .88775 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.71133 .85205 L
s
P
p
.8 0 1 r
.02 w
.71133 .26466 m
.91505 .19846 L
s
P
p
.8 0 1 r
.02 w
.60145 .22895 m
.47554 .05566 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.71133 .26466 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.60145 .22895 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.3241 .39047 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .82998 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .28672 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.44484 .55835 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.55516 .55835 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0710028 1.14201 0.0285501 1.14201 [
[ 0 0 0 0 ]
[ 1 1.19911 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.19911 L
0 1.19911 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.5028 .2478 m
.68888 .1126 L
s
P
p
.2 0 1 r
.02 w
.37874 .2478 m
.19265 .1126 L
s
P
p
0 .4 1 r
.018 w
.44077 .29287 m
.5028 .2478 L
s
P
p
0 .4 1 r
.018 w
.44077 .29287 m
.37874 .2478 L
s
P
p
.2 0 1 r
.02 w
.27308 .91492 m
.05432 .986 L
s
P
p
.2 0 1 r
.02 w
.39106 .95326 m
.52626 1.13934 L
s
P
p
0 .4 1 r
.018 w
.346 .89123 m
.27308 .91492 L
s
P
p
0 .4 1 r
.018 w
.346 .89123 m
.39106 .95326 L
s
P
p
.2 0 1 r
.02 w
.6977 .35144 m
.92772 .35144 L
s
P
p
.2 0 1 r
.02 w
.59734 .27852 m
.52626 .05976 L
s
P
p
0 .4 1 r
.018 w
.62103 .35144 m
.6977 .35144 L
s
P
p
0 .4 1 r
.018 w
.62103 .35144 m
.59734 .27852 L
s
P
p
.2 0 1 r
.016 w
.44077 .59955 m
.44077 .29287 L
s
P
p
.2 0 1 r
.016 w
.44077 .59955 m
.346 .89123 L
s
P
p
.2 0 1 r
.016 w
.44077 .59955 m
.62103 .35144 L
s
P
p
.2 0 1 r
.02 w
.40266 .27852 m
.47374 .05976 L
s
P
p
.2 0 1 r
.02 w
.3023 .35144 m
.07228 .35144 L
s
P
p
0 .4 1 r
.018 w
.37897 .35144 m
.40266 .27852 L
s
P
p
0 .4 1 r
.018 w
.37897 .35144 m
.3023 .35144 L
s
P
p
.2 0 1 r
.02 w
.60894 .95326 m
.47374 1.13934 L
s
P
p
.2 0 1 r
.02 w
.72692 .91492 m
.94568 .986 L
s
P
p
0 .4 1 r
.018 w
.654 .89123 m
.60894 .95326 L
s
P
p
0 .4 1 r
.018 w
.654 .89123 m
.72692 .91492 L
s
P
p
.2 0 1 r
.02 w
.62126 .2478 m
.80735 .1126 L
s
P
p
.2 0 1 r
.02 w
.4972 .2478 m
.31112 .1126 L
s
P
p
0 .4 1 r
.018 w
.55923 .29287 m
.62126 .2478 L
s
P
p
0 .4 1 r
.018 w
.55923 .29287 m
.4972 .2478 L
s
P
p
.2 0 1 r
.016 w
.55923 .59955 m
.37897 .35144 L
s
P
p
.2 0 1 r
.016 w
.55923 .59955 m
.654 .89123 L
s
P
p
.2 0 1 r
.016 w
.55923 .59955 m
.55923 .29287 L
s
P
p
1 .6 0 r
.016 w
.5 .41726 m
.44077 .59955 L
s
P
p
1 .6 0 r
.016 w
.5 .41726 m
.55923 .59955 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0331844 1.06637 0.0266592 1.06637 [
[ 0 0 0 0 ]
[ 1 1.11969 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.11969 L
0 1.11969 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.3943 .21841 m
.51262 .05557 L
s
P
p
.2 0 1 r
.02 w
.29105 .25196 m
.09962 .18976 L
s
P
p
0 .4 1 r
.018 w
.35487 .27269 m
.3943 .21841 L
s
P
p
0 .4 1 r
.018 w
.35487 .27269 m
.29105 .25196 L
s
P
p
.2 0 1 r
.02 w
.29105 .86773 m
.09962 .92993 L
s
P
p
.2 0 1 r
.02 w
.3943 .90128 m
.51262 1.06412 L
s
P
p
0 .4 1 r
.018 w
.35487 .84699 m
.29105 .86773 L
s
P
p
0 .4 1 r
.018 w
.35487 .84699 m
.3943 .90128 L
s
P
p
.2 0 1 r
.02 w
.75624 .40311 m
.94768 .46531 L
s
P
p
.2 0 1 r
.02 w
.69243 .31528 m
.69243 .11399 L
s
P
p
0 .4 1 r
.018 w
.69243 .38237 m
.75624 .40311 L
s
P
p
0 .4 1 r
.018 w
.69243 .38237 m
.69243 .31528 L
s
P
p
.2 0 1 r
.016 w
.44817 .55984 m
.35487 .27269 L
s
P
p
.2 0 1 r
.016 w
.44817 .55984 m
.35487 .84699 L
s
P
p
.2 0 1 r
.016 w
.44817 .55984 m
.69243 .38237 L
s
P
p
.2 0 1 r
.02 w
.30757 .31528 m
.30757 .11399 L
s
P
p
.2 0 1 r
.02 w
.24376 .40311 m
.05232 .46531 L
s
P
p
0 .4 1 r
.018 w
.30757 .38237 m
.30757 .31528 L
s
P
p
0 .4 1 r
.018 w
.30757 .38237 m
.24376 .40311 L
s
P
p
.2 0 1 r
.02 w
.6057 .90128 m
.48738 1.06412 L
s
P
p
.2 0 1 r
.02 w
.70895 .86773 m
.90038 .92993 L
s
P
p
0 .4 1 r
.018 w
.64513 .84699 m
.6057 .90128 L
s
P
p
0 .4 1 r
.018 w
.64513 .84699 m
.70895 .86773 L
s
P
p
.2 0 1 r
.02 w
.70895 .25196 m
.90038 .18976 L
s
P
p
.2 0 1 r
.02 w
.6057 .21841 m
.48738 .05557 L
s
P
p
0 .4 1 r
.018 w
.64513 .27269 m
.70895 .25196 L
s
P
p
0 .4 1 r
.018 w
.64513 .27269 m
.6057 .21841 L
s
P
p
.2 0 1 r
.016 w
.55183 .55984 m
.30757 .38237 L
s
P
p
.2 0 1 r
.016 w
.55183 .55984 m
.64513 .84699 L
s
P
p
.2 0 1 r
.016 w
.55183 .55984 m
.64513 .27269 L
s
P
p
1 .6 0 r
.016 w
.5 .40032 m
.44817 .55984 L
s
P
p
1 .6 0 r
.016 w
.5 .40032 m
.55183 .55984 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.031763 1.06353 0.0265882 1.06353 [
[ 0 0 0 0 ]
[ 1 1.1167 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.1167 L
0 1.1167 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39855 .22895 m
.52446 .05566 L
s
P
p
.2 0 1 r
.02 w
.28867 .26466 m
.08495 .19846 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.39855 .22895 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.28867 .26466 L
s
P
p
.2 0 1 r
.02 w
.28867 .85205 m
.08495 .91824 L
s
P
p
.2 0 1 r
.02 w
.39855 .88775 m
.52446 1.06105 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.28867 .85205 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.39855 .88775 L
s
P
p
.2 0 1 r
.02 w
.74381 .41254 m
.94753 .47873 L
s
P
p
.2 0 1 r
.02 w
.6759 .31907 m
.6759 .10486 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.74381 .41254 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.6759 .31907 L
s
P
p
.2 0 1 r
.018 w
.44484 .55835 m
.35658 .28672 L
s
P
p
.2 0 1 r
.018 w
.44484 .55835 m
.35658 .82998 L
s
P
p
.2 0 1 r
.018 w
.44484 .55835 m
.6759 .39047 L
s
P
p
.2 0 1 r
.02 w
.3241 .31907 m
.3241 .10486 L
s
P
p
.2 0 1 r
.02 w
.25619 .41254 m
.05247 .47873 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.3241 .31907 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.25619 .41254 L
s
P
p
.2 0 1 r
.02 w
.60145 .88775 m
.47554 1.06105 L
s
P
p
.2 0 1 r
.02 w
.71133 .85205 m
.91505 .91824 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.60145 .88775 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.71133 .85205 L
s
P
p
.2 0 1 r
.02 w
.71133 .26466 m
.91505 .19846 L
s
P
p
.2 0 1 r
.02 w
.60145 .22895 m
.47554 .05566 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.71133 .26466 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.60145 .22895 L
s
P
p
.2 0 1 r
.018 w
.55516 .55835 m
.3241 .39047 L
s
P
p
.2 0 1 r
.018 w
.55516 .55835 m
.64342 .82998 L
s
P
p
.2 0 1 r
.018 w
.55516 .55835 m
.64342 .28672 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.44484 .55835 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.55516 .55835 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.031763 1.06353 0.0265882 1.06353 [
[ 0 0 0 0 ]
[ 1 1.1167 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.1167 L
0 1.1167 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39855 .22895 m
.52446 .05566 L
s
P
p
.2 0 1 r
.02 w
.28867 .26466 m
.08495 .19846 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.39855 .22895 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.28867 .26466 L
s
P
p
.2 0 1 r
.02 w
.28867 .85205 m
.08495 .91824 L
s
P
p
.2 0 1 r
.02 w
.39855 .88775 m
.52446 1.06105 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.28867 .85205 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.39855 .88775 L
s
P
p
.2 0 1 r
.02 w
.74381 .41254 m
.94753 .47873 L
s
P
p
.2 0 1 r
.02 w
.6759 .31907 m
.6759 .10486 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.74381 .41254 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.6759 .31907 L
s
P
p
0 .4 1 r
.016 w
.44484 .55835 m
.35658 .28672 L
s
P
p
0 .4 1 r
.016 w
.44484 .55835 m
.35658 .82998 L
s
P
p
0 .4 1 r
.016 w
.44484 .55835 m
.6759 .39047 L
s
P
p
.2 0 1 r
.02 w
.3241 .31907 m
.3241 .10486 L
s
P
p
.2 0 1 r
.02 w
.25619 .41254 m
.05247 .47873 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.3241 .31907 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.25619 .41254 L
s
P
p
.2 0 1 r
.02 w
.60145 .88775 m
.47554 1.06105 L
s
P
p
.2 0 1 r
.02 w
.71133 .85205 m
.91505 .91824 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.60145 .88775 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.71133 .85205 L
s
P
p
.2 0 1 r
.02 w
.71133 .26466 m
.91505 .19846 L
s
P
p
.2 0 1 r
.02 w
.60145 .22895 m
.47554 .05566 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.71133 .26466 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.60145 .22895 L
s
P
p
0 .4 1 r
.016 w
.55516 .55835 m
.3241 .39047 L
s
P
p
0 .4 1 r
.016 w
.55516 .55835 m
.64342 .82998 L
s
P
p
0 .4 1 r
.016 w
.55516 .55835 m
.64342 .28672 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.44484 .55835 L
s
P
p
1 .6 0 r
.016 w
.5 .38858 m
.55516 .55835 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.125693 1.25139 0.0312847 1.25139 [
[ 0 0 0 0 ]
[ 1 1.31396 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.31396 L
0 1.31396 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.42155 .36107 m
.6549 .36107 L
s
P
p
.2 0 1 r
.02 w
.31972 .28709 m
.24761 .06516 L
s
P
p
.2 0 1 r
.02 w
.28083 .40679 m
.09205 .54395 L
s
P
p
0 .4 1 r
.018 w
.34376 .36107 m
.42155 .36107 L
s
P
p
0 .4 1 r
.018 w
.34376 .36107 m
.31972 .28709 L
s
P
p
0 .4 1 r
.018 w
.34376 .36107 m
.28083 .40679 L
s
P
p
.2 0 1 r
.02 w
.28083 .90717 m
.09205 .77001 L
s
P
p
.2 0 1 r
.02 w
.31972 1.02687 m
.24761 1.2488 L
s
P
p
.2 0 1 r
.02 w
.42155 .95289 m
.6549 .95289 L
s
P
p
0 .4 1 r
.018 w
.34376 .95289 m
.28083 .90717 L
s
P
p
0 .4 1 r
.018 w
.34376 .95289 m
.31972 1.02687 L
s
P
p
0 .4 1 r
.018 w
.34376 .95289 m
.42155 .95289 L
s
P
p
.2 0 1 r
.02 w
.71566 .54807 m
.78777 .77001 L
s
P
p
.2 0 1 r
.02 w
.75455 .42838 m
.94334 .29121 L
s
P
p
.2 0 1 r
.02 w
.6287 .42838 m
.43991 .29121 L
s
P
p
0 .4 1 r
.018 w
.69162 .4741 m
.71566 .54807 L
s
P
p
0 .4 1 r
.018 w
.69162 .4741 m
.75455 .42838 L
s
P
p
0 .4 1 r
.018 w
.69162 .4741 m
.6287 .42838 L
s
P
p
.2 0 1 r
.016 w
.43991 .65698 m
.34376 .36107 L
s
P
p
.2 0 1 r
.016 w
.43991 .65698 m
.34376 .95289 L
s
P
p
.2 0 1 r
.016 w
.43991 .65698 m
.69162 .4741 L
s
P
p
.2 0 1 r
.02 w
.3713 .42838 m
.56009 .29121 L
s
P
p
.2 0 1 r
.02 w
.24545 .42838 m
.05666 .29121 L
s
P
p
.2 0 1 r
.02 w
.28434 .54807 m
.21223 .77001 L
s
P
p
0 .4 1 r
.018 w
.30838 .4741 m
.3713 .42838 L
s
P
p
0 .4 1 r
.018 w
.30838 .4741 m
.24545 .42838 L
s
P
p
0 .4 1 r
.018 w
.30838 .4741 m
.28434 .54807 L
s
P
p
.2 0 1 r
.02 w
.57845 .95289 m
.3451 .95289 L
s
P
p
.2 0 1 r
.02 w
.68028 1.02687 m
.75239 1.2488 L
s
P
p
.2 0 1 r
.02 w
.71917 .90717 m
.90795 .77001 L
s
P
p
0 .4 1 r
.018 w
.65624 .95289 m
.57845 .95289 L
s
P
p
0 .4 1 r
.018 w
.65624 .95289 m
.68028 1.02687 L
s
P
p
0 .4 1 r
.018 w
.65624 .95289 m
.71917 .90717 L
s
P
p
.2 0 1 r
.02 w
.71917 .40679 m
.90795 .54395 L
s
P
p
.2 0 1 r
.02 w
.68028 .28709 m
.75239 .06516 L
s
P
p
.2 0 1 r
.02 w
.57845 .36107 m
.3451 .36107 L
s
P
p
0 .4 1 r
.018 w
.65624 .36107 m
.71917 .40679 L
s
P
p
0 .4 1 r
.018 w
.65624 .36107 m
.68028 .28709 L
s
P
p
0 .4 1 r
.018 w
.65624 .36107 m
.57845 .36107 L
s
P
p
.2 0 1 r
.016 w
.56009 .65698 m
.30838 .4741 L
s
P
p
.2 0 1 r
.016 w
.56009 .65698 m
.65624 .95289 L
s
P
p
.2 0 1 r
.016 w
.56009 .65698 m
.65624 .36107 L
s
P
p
1 .6 0 r
.016 w
.5 .47203 m
.43991 .65698 L
s
P
p
1 .6 0 r
.016 w
.5 .47203 m
.56009 .65698 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0431658 1.08633 0.0271583 1.08633 [
[ 0 0 0 0 ]
[ 1 1.14065 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.14065 L
0 1.14065 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39163 .24302 m
.48657 .05668 L
s
P
p
.2 0 1 r
.02 w
.29787 .27348 m
.11153 .17854 L
s
P
p
0 .4 1 r
.018 w
.35998 .30513 m
.39163 .24302 L
s
P
p
0 .4 1 r
.018 w
.35998 .30513 m
.29787 .27348 L
s
P
p
.2 0 1 r
.02 w
.29787 .86717 m
.11153 .96211 L
s
P
p
.2 0 1 r
.02 w
.39163 .89763 m
.48657 1.08397 L
s
P
p
0 .4 1 r
.018 w
.35998 .83552 m
.29787 .86717 L
s
P
p
0 .4 1 r
.018 w
.35998 .83552 m
.39163 .89763 L
s
P
p
.2 0 1 r
.02 w
.74059 .41733 m
.94714 .45005 L
s
P
p
.2 0 1 r
.02 w
.68264 .33757 m
.71535 .13102 L
s
P
p
0 .4 1 r
.018 w
.67173 .40643 m
.74059 .41733 L
s
P
p
0 .4 1 r
.018 w
.67173 .40643 m
.68264 .33757 L
s
P
p
.2 0 1 r
.016 w
.44615 .57032 m
.35998 .30513 L
s
P
p
.2 0 1 r
.016 w
.44615 .57032 m
.35998 .83552 L
s
P
p
.2 0 1 r
.016 w
.44615 .57032 m
.67173 .40643 L
s
P
p
.2 0 1 r
.02 w
.31736 .33757 m
.28465 .13102 L
s
P
p
.2 0 1 r
.02 w
.25941 .41733 m
.05286 .45005 L
s
P
p
0 .4 1 r
.018 w
.32827 .40643 m
.31736 .33757 L
s
P
p
0 .4 1 r
.018 w
.32827 .40643 m
.25941 .41733 L
s
P
p
.2 0 1 r
.02 w
.60837 .89763 m
.51343 1.08397 L
s
P
p
.2 0 1 r
.02 w
.70213 .86717 m
.88847 .96211 L
s
P
p
0 .4 1 r
.018 w
.64002 .83552 m
.60837 .89763 L
s
P
p
0 .4 1 r
.018 w
.64002 .83552 m
.70213 .86717 L
s
P
p
.2 0 1 r
.02 w
.70213 .27348 m
.88847 .17854 L
s
P
p
.2 0 1 r
.02 w
.60837 .24302 m
.51343 .05668 L
s
P
p
0 .4 1 r
.018 w
.64002 .30513 m
.70213 .27348 L
s
P
p
0 .4 1 r
.018 w
.64002 .30513 m
.60837 .24302 L
s
P
p
.2 0 1 r
.016 w
.55385 .57032 m
.32827 .40643 L
s
P
p
.2 0 1 r
.016 w
.55385 .57032 m
.64002 .83552 L
s
P
p
.2 0 1 r
.016 w
.55385 .57032 m
.64002 .30513 L
s
P
p
1 .6 0 r
.016 w
.5 .40458 m
.44615 .57032 L
s
P
p
1 .6 0 r
.016 w
.5 .40458 m
.55385 .57032 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0231383 1.04628 0.0261569 1.04628 [
[ 0 0 0 0 ]
[ 1 1.09859 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.09859 L
0 1.09859 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.42511 .21584 m
.54229 .05455 L
s
P
p
.2 0 1 r
.02 w
.27172 .26568 m
.08211 .20408 L
s
P
p
0 .4 1 r
.018 w
.36652 .29649 m
.42511 .21584 L
s
P
p
0 .4 1 r
.018 w
.36652 .29649 m
.27172 .26568 L
s
P
p
.2 0 1 r
.02 w
.27172 .83291 m
.08211 .89451 L
s
P
p
.2 0 1 r
.02 w
.42511 .88275 m
.54229 1.04404 L
s
P
p
0 .4 1 r
.018 w
.36652 .8021 m
.27172 .83291 L
s
P
p
0 .4 1 r
.018 w
.36652 .8021 m
.42511 .88275 L
s
P
p
.2 0 1 r
.02 w
.75852 .42385 m
.94812 .48546 L
s
P
p
.2 0 1 r
.02 w
.66371 .29337 m
.66371 .09401 L
s
P
p
0 .4 1 r
.018 w
.66371 .39305 m
.75852 .42385 L
s
P
p
0 .4 1 r
.018 w
.66371 .39305 m
.66371 .29337 L
s
P
p
.2 0 1 r
.016 w
.44866 .5493 m
.36652 .29649 L
s
P
p
.2 0 1 r
.016 w
.44866 .5493 m
.36652 .8021 L
s
P
p
.2 0 1 r
.016 w
.44866 .5493 m
.66371 .39305 L
s
P
p
.2 0 1 r
.02 w
.33629 .29337 m
.33629 .09401 L
s
P
p
.2 0 1 r
.02 w
.24148 .42385 m
.05188 .48546 L
s
P
p
0 .4 1 r
.018 w
.33629 .39305 m
.33629 .29337 L
s
P
p
0 .4 1 r
.018 w
.33629 .39305 m
.24148 .42385 L
s
P
p
.2 0 1 r
.02 w
.57489 .88275 m
.45771 1.04404 L
s
P
p
.2 0 1 r
.02 w
.72828 .83291 m
.91789 .89451 L
s
P
p
0 .4 1 r
.018 w
.63348 .8021 m
.57489 .88275 L
s
P
p
0 .4 1 r
.018 w
.63348 .8021 m
.72828 .83291 L
s
P
p
.2 0 1 r
.02 w
.72828 .26568 m
.91789 .20408 L
s
P
p
.2 0 1 r
.02 w
.57489 .21584 m
.45771 .05455 L
s
P
p
0 .4 1 r
.018 w
.63348 .29649 m
.72828 .26568 L
s
P
p
0 .4 1 r
.018 w
.63348 .29649 m
.57489 .21584 L
s
P
p
.2 0 1 r
.016 w
.55134 .5493 m
.33629 .39305 L
s
P
p
.2 0 1 r
.016 w
.55134 .5493 m
.63348 .8021 L
s
P
p
.2 0 1 r
.016 w
.55134 .5493 m
.63348 .29649 L
s
P
p
1 .6 0 r
.016 w
.5 .39129 m
.44866 .5493 L
s
P
p
1 .6 0 r
.016 w
.5 .39129 m
.55134 .5493 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.21445 1.4289 0.0357225 1.4289 [
[ 0 0 0 0 ]
[ 1 1.50034 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.50034 L
0 1.50034 L
closepath
clip
newpath
p
P
p
1 .6 0 r
.016 w
.5 .09955 m
.0772 1.40079 L
s
P
p
1 .6 0 r
.016 w
.5 .09955 m
.9228 1.40079 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.000732183 1.00146 0.0250366 1.00146 [
[ 0 0 0 0 ]
[ 1 1.05154 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.05154 L
0 1.05154 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.35569 .25422 m
.4212 .05259 L
s
P
p
.2 0 1 r
.02 w
.26318 .32143 m
.05117 .32143 L
s
P
p
0 .4 1 r
.018 w
.33385 .32143 m
.35569 .25422 L
s
P
p
0 .4 1 r
.018 w
.33385 .32143 m
.26318 .32143 L
s
P
p
.2 0 1 r
.02 w
.44283 .87433 m
.27131 .99895 L
s
P
p
.2 0 1 r
.02 w
.55717 .87433 m
.72869 .99895 L
s
P
p
0 .4 1 r
.018 w
.5 .83279 m
.44283 .87433 L
s
P
p
0 .4 1 r
.018 w
.5 .83279 m
.55717 .87433 L
s
P
p
.2 0 1 r
.02 w
.73682 .32143 m
.94883 .32143 L
s
P
p
.2 0 1 r
.02 w
.64431 .25422 m
.5788 .05259 L
s
P
p
0 .4 1 r
.018 w
.66615 .32143 m
.73682 .32143 L
s
P
p
0 .4 1 r
.018 w
.66615 .32143 m
.64431 .25422 L
s
P
p
.2 0 1 r
.016 w
.5 .55012 m
.33385 .32143 L
s
P
p
.2 0 1 r
.016 w
.5 .55012 m
.5 .83279 L
s
P
p
.2 0 1 r
.016 w
.5 .55012 m
.66615 .32143 L
s
P
p
1 .6 0 r
.016 w
.5 .37345 m
.5 .55012 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0203987 0.959203 0.0239801 0.959203 [
[ 0 0 0 0 ]
[ 1 1.00716 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.00716 L
0 1.00716 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.43131 .18854 m
.56961 .05024 L
s
P
p
.2 0 1 r
.02 w
.32712 .20504 m
.15285 .11625 L
s
P
p
0 .4 1 r
.018 w
.38521 .23464 m
.43131 .18854 L
s
P
p
0 .4 1 r
.018 w
.38521 .23464 m
.32712 .20504 L
s
P
p
.2 0 1 r
.02 w
.24322 .73476 m
.05004 .76536 L
s
P
p
.2 0 1 r
.02 w
.33721 .78266 m
.42601 .95692 L
s
P
p
0 .4 1 r
.018 w
.30761 .72457 m
.24322 .73476 L
s
P
p
0 .4 1 r
.018 w
.30761 .72457 m
.33721 .78266 L
s
P
p
.2 0 1 r
.02 w
.71645 .40342 m
.89072 .49221 L
s
P
p
.2 0 1 r
.02 w
.66856 .30942 m
.69916 .11625 L
s
P
p
0 .4 1 r
.018 w
.65836 .37382 m
.71645 .40342 L
s
P
p
0 .4 1 r
.018 w
.65836 .37382 m
.66856 .30942 L
s
P
p
.2 0 1 r
.016 w
.42601 .49221 m
.38521 .23464 L
s
P
p
.2 0 1 r
.016 w
.42601 .49221 m
.30761 .72457 L
s
P
p
.2 0 1 r
.016 w
.42601 .49221 m
.65836 .37382 L
s
P
p
.2 0 1 r
.02 w
.33144 .30942 m
.30084 .11625 L
s
P
p
.2 0 1 r
.02 w
.28355 .40342 m
.10928 .49221 L
s
P
p
0 .4 1 r
.018 w
.34164 .37382 m
.33144 .30942 L
s
P
p
0 .4 1 r
.018 w
.34164 .37382 m
.28355 .40342 L
s
P
p
.2 0 1 r
.02 w
.66279 .78266 m
.57399 .95692 L
s
P
p
.2 0 1 r
.02 w
.75678 .73476 m
.94996 .76536 L
s
P
p
0 .4 1 r
.018 w
.69239 .72457 m
.66279 .78266 L
s
P
p
0 .4 1 r
.018 w
.69239 .72457 m
.75678 .73476 L
s
P
p
.2 0 1 r
.02 w
.67288 .20504 m
.84715 .11625 L
s
P
p
.2 0 1 r
.02 w
.56869 .18854 m
.43039 .05024 L
s
P
p
0 .4 1 r
.018 w
.61479 .23464 m
.67288 .20504 L
s
P
p
0 .4 1 r
.018 w
.61479 .23464 m
.56869 .18854 L
s
P
p
.2 0 1 r
.016 w
.57399 .49221 m
.34164 .37382 L
s
P
p
.2 0 1 r
.016 w
.57399 .49221 m
.69239 .72457 L
s
P
p
.2 0 1 r
.016 w
.57399 .49221 m
.61479 .23464 L
s
P
p
1 .6 0 r
.016 w
.5 .34699 m
.42601 .49221 L
s
P
p
1 .6 0 r
.016 w
.5 .34699 m
.57399 .49221 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0196345 1.03927 0.0259817 1.03927 [
[ 0 0 0 0 ]
[ 1 1.09123 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.09123 L
0 1.09123 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.41164 .22373 m
.53468 .05439 L
s
P
p
.2 0 1 r
.02 w
.30427 .25862 m
.1052 .19394 L
s
P
p
0 .4 1 r
.018 w
.37063 .28018 m
.41164 .22373 L
s
P
p
0 .4 1 r
.018 w
.37063 .28018 m
.30427 .25862 L
s
P
p
.2 0 1 r
.02 w
.30427 .83261 m
.1052 .8973 L
s
P
p
.2 0 1 r
.02 w
.41164 .8675 m
.53468 1.03685 L
s
P
p
0 .4 1 r
.018 w
.37063 .81105 m
.30427 .83261 L
s
P
p
0 .4 1 r
.018 w
.37063 .81105 m
.41164 .8675 L
s
P
p
.2 0 1 r
.02 w
.74903 .40313 m
.94811 .46781 L
s
P
p
.2 0 1 r
.02 w
.68267 .31179 m
.68267 .10247 L
s
P
p
0 .4 1 r
.018 w
.68267 .38157 m
.74903 .40313 L
s
P
p
0 .4 1 r
.018 w
.68267 .38157 m
.68267 .31179 L
s
P
p
.2 0 1 r
.016 w
.45688 .54562 m
.37063 .28018 L
s
P
p
.2 0 1 r
.016 w
.45688 .54562 m
.37063 .81105 L
s
P
p
.2 0 1 r
.016 w
.45688 .54562 m
.68267 .38157 L
s
P
p
.2 0 1 r
.02 w
.31733 .31179 m
.31733 .10247 L
s
P
p
.2 0 1 r
.02 w
.25097 .40313 m
.05189 .46781 L
s
P
p
0 .4 1 r
.018 w
.31733 .38157 m
.31733 .31179 L
s
P
p
0 .4 1 r
.018 w
.31733 .38157 m
.25097 .40313 L
s
P
p
.2 0 1 r
.02 w
.58836 .8675 m
.46532 1.03685 L
s
P
p
.2 0 1 r
.02 w
.69573 .83261 m
.8948 .8973 L
s
P
p
0 .4 1 r
.018 w
.62937 .81105 m
.58836 .8675 L
s
P
p
0 .4 1 r
.018 w
.62937 .81105 m
.69573 .83261 L
s
P
p
.2 0 1 r
.02 w
.69573 .25862 m
.8948 .19394 L
s
P
p
.2 0 1 r
.02 w
.58836 .22373 m
.46532 .05439 L
s
P
p
0 .4 1 r
.018 w
.62937 .28018 m
.69573 .25862 L
s
P
p
0 .4 1 r
.018 w
.62937 .28018 m
.58836 .22373 L
s
P
p
.2 0 1 r
.016 w
.54312 .54562 m
.31733 .38157 L
s
P
p
.2 0 1 r
.016 w
.54312 .54562 m
.62937 .81105 L
s
P
p
.2 0 1 r
.016 w
.54312 .54562 m
.62937 .28018 L
s
P
p
1 .6 0 r
.016 w
.5 .4129 m
.45688 .54562 L
s
P
p
1 .6 0 r
.016 w
.5 .4129 m
.54312 .54562 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.031763 1.06353 0.0265882 1.06353 [
[ 0 0 0 0 ]
[ 1 1.1167 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.1167 L
0 1.1167 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39855 .22895 m
.52446 .05566 L
s
P
p
.2 0 1 r
.02 w
.28867 .26466 m
.08495 .19846 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.39855 .22895 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.28867 .26466 L
s
P
p
.2 0 1 r
.02 w
.28867 .85205 m
.08495 .91824 L
s
P
p
.2 0 1 r
.02 w
.39855 .88775 m
.52446 1.06105 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.28867 .85205 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.39855 .88775 L
s
P
p
.2 0 1 r
.02 w
.74381 .41254 m
.94753 .47873 L
s
P
p
.2 0 1 r
.02 w
.6759 .31907 m
.6759 .10486 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.74381 .41254 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.6759 .31907 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .28672 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .82998 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.6759 .39047 L
s
P
p
.2 0 1 r
.02 w
.3241 .31907 m
.3241 .10486 L
s
P
p
.2 0 1 r
.02 w
.25619 .41254 m
.05247 .47873 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.3241 .31907 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.25619 .41254 L
s
P
p
.2 0 1 r
.02 w
.60145 .88775 m
.47554 1.06105 L
s
P
p
.2 0 1 r
.02 w
.71133 .85205 m
.91505 .91824 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.60145 .88775 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.71133 .85205 L
s
P
p
.2 0 1 r
.02 w
.71133 .26466 m
.91505 .19846 L
s
P
p
.2 0 1 r
.02 w
.60145 .22895 m
.47554 .05566 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.71133 .26466 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.60145 .22895 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.3241 .39047 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .82998 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .28672 L
s
P
p
1 .6 0 r
.018 w
.5 .38858 m
.44484 .55835 L
s
P
p
1 .6 0 r
.018 w
.5 .38858 m
.55516 .55835 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.031763 1.06353 0.0265882 1.06353 [
[ 0 0 0 0 ]
[ 1 1.1167 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.1167 L
0 1.1167 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39855 .22895 m
.52446 .05566 L
s
P
p
.2 0 1 r
.02 w
.28867 .26466 m
.08495 .19846 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.39855 .22895 L
s
P
p
0 .4 1 r
.018 w
.35658 .28672 m
.28867 .26466 L
s
P
p
.2 0 1 r
.02 w
.28867 .85205 m
.08495 .91824 L
s
P
p
.2 0 1 r
.02 w
.39855 .88775 m
.52446 1.06105 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.28867 .85205 L
s
P
p
0 .4 1 r
.018 w
.35658 .82998 m
.39855 .88775 L
s
P
p
.2 0 1 r
.02 w
.74381 .41254 m
.94753 .47873 L
s
P
p
.2 0 1 r
.02 w
.6759 .31907 m
.6759 .10486 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.74381 .41254 L
s
P
p
0 .4 1 r
.018 w
.6759 .39047 m
.6759 .31907 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .28672 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.35658 .82998 L
s
P
p
.2 0 1 r
.016 w
.44484 .55835 m
.6759 .39047 L
s
P
p
.2 0 1 r
.02 w
.3241 .31907 m
.3241 .10486 L
s
P
p
.2 0 1 r
.02 w
.25619 .41254 m
.05247 .47873 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.3241 .31907 L
s
P
p
0 .4 1 r
.018 w
.3241 .39047 m
.25619 .41254 L
s
P
p
.2 0 1 r
.02 w
.60145 .88775 m
.47554 1.06105 L
s
P
p
.2 0 1 r
.02 w
.71133 .85205 m
.91505 .91824 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.60145 .88775 L
s
P
p
0 .4 1 r
.018 w
.64342 .82998 m
.71133 .85205 L
s
P
p
.2 0 1 r
.02 w
.71133 .26466 m
.91505 .19846 L
s
P
p
.2 0 1 r
.02 w
.60145 .22895 m
.47554 .05566 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.71133 .26466 L
s
P
p
0 .4 1 r
.018 w
.64342 .28672 m
.60145 .22895 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.3241 .39047 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .82998 L
s
P
p
.2 0 1 r
.016 w
.55516 .55835 m
.64342 .28672 L
s
P
p
.8 1 0 r
.016 w
.5 .38858 m
.44484 .55835 L
s
P
p
.8 1 0 r
.016 w
.5 .38858 m
.55516 .55835 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.131947 0.952381 [
[ 0 0 0 0 ]
[ 1 .68849 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .68849 L
0 .68849 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.16124 .19468 m
.0498 .0413 L
s
P
p
.2 0 1 r
.02 w
.16124 .29694 m
.0498 .45032 L
s
P
p
0 .4 1 r
.018 w
.19839 .24581 m
.16124 .19468 L
s
P
p
0 .4 1 r
.018 w
.19839 .24581 m
.16124 .29694 L
s
P
p
.2 0 1 r
.02 w
.65569 .45759 m
.65569 .64719 L
s
P
p
.2 0 1 r
.02 w
.71579 .37487 m
.89611 .31628 L
s
P
p
0 .4 1 r
.018 w
.65569 .3944 m
.65569 .45759 L
s
P
p
0 .4 1 r
.018 w
.65569 .3944 m
.71579 .37487 L
s
P
p
.2 0 1 r
.016 w
.45118 .24581 m
.19839 .24581 L
s
P
p
.2 0 1 r
.016 w
.45118 .24581 m
.65569 .3944 L
s
P
p
.2 0 1 r
.02 w
.28421 .37487 m
.10389 .31628 L
s
P
p
.2 0 1 r
.02 w
.34431 .45759 m
.34431 .64719 L
s
P
p
0 .4 1 r
.018 w
.34431 .3944 m
.28421 .37487 L
s
P
p
0 .4 1 r
.018 w
.34431 .3944 m
.34431 .45759 L
s
P
p
.2 0 1 r
.02 w
.83876 .29694 m
.9502 .45032 L
s
P
p
.2 0 1 r
.02 w
.83876 .19468 m
.9502 .0413 L
s
P
p
0 .4 1 r
.018 w
.80161 .24581 m
.83876 .29694 L
s
P
p
0 .4 1 r
.018 w
.80161 .24581 m
.83876 .19468 L
s
P
p
.2 0 1 r
.016 w
.54882 .24581 m
.34431 .3944 L
s
P
p
.2 0 1 r
.016 w
.54882 .24581 m
.80161 .24581 L
s
P
p
1 .6 0 r
.016 w
.5 .09555 m
.45118 .24581 L
s
P
p
1 .6 0 r
.016 w
.5 .09555 m
.54882 .24581 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`0001H000==04d080000dd0C@0P0003C@1=020000==04d08@000dd0000O0003C@1=020000=20480
5`00018000M<0000C01<00<000=<00005P001d`0001<04`00`000d`0000J0003C01<01`000M<0000
C01<00<000=<00005P000d`000020003C000008000=<00005P001d`0001<04`00`000d`0000F0007
@P000480@P030003@P000140000B0003C@00008000==00000P000dd0000F0003C@00008000==0000
0P000dd0000D0004C@0000==00@0CDe=0P000dd0000E0003C@00008000==00000P000dd0000F0007
C@0004d0C@030003C@0001H000==00000P000dd000020003C@0001H000=200000P000d8000020003
@P000140000B0007C00004`0C0030003C00001H000M<0000C01<00<000=<00004@02C00304`00080
1d`20003C000009<4`001d`0001<04`00`000d`0000?00=<100014`004`30004C000C0D00T`A0007
C00004`0C0030003C00001H000M20000@P1200<000=200004@0000/00dd40004C@00C@<000A=001=
1@02C@X00dd40004C@00C@<000A=001=1@02C@h000M=04d0C@1=00<000M=04d0C@1=00h00dd40004
C@00C@<000A=001=1@02C@d00dd0101=0<H50003aP1=00800dd<00==100014d004d30004C@00C@D0
0Td:00=21000148004830004@P00@PD00T8<00003P03C00404`0aPD000?604`00P03C0l00d`0101<
04`50003C01<00800d`A009<00<0C<H01@000lI<0002C1800d`0101<0<H50003aP1<00800d`B0004
aT`0aPD000G60<K6C00B00=<00@0C0361@000lH0C00200=<3`03@P040480aPD000?604800P03@Ph0
000A0003aTe=00L000A=a/I=5@03C@L014d?00M=00?6CLH01@001<I=a/H5CA4000?6CDd01`0014g6
aTdF009=1`02CAL000?6CDd01`0014g6aTdE0003aT9=00L000A=a/I24@00018000?6C0001P000dc6
000G009<1`02C1P00T`7009<60000lI<00060003C<H001L000?6C0001P000dc6000G0003aT`000H0
00=<aP005`000lI<00060003C<H00180000B0003aTd000D000==0<H06002C@H000==04d060000lI=
00060003CLH001L000?6C@001P000dg6000G0003aTd000H000==aP005`000lI=00060003CLH001L0
00?6C@001P000dg6000B00004@001<I<C4`200034@0000=<00?600005004C08000<A000014`F0003
aTa<00<000<A00000d`00lH0000D0004aTa<C08000<A00000d`00lH0000D0004aTa<C08000<A0000
0d`00lH0000D0004aTa<C08000<A00000d`00lH0000D0004aTa<C08000<A00000d`00lH0000@0000
3`000dg600020004C@004@8000E=0000aP02CA400Td30004C@004@8000A=00000dd=00E=00G60000
C@0200044@00C@<000?6CDd00dd>0003CLH0008000A=000A0P001Dd00036009=3`03C@05aP0004d0
0P00114004d30004aTe=CA0000==aP000P0014d001420005C@000<H00TdA0003@/H0008000A=000A
0P001Dd0003600923`0000`00d`5009<0Q42C0L00d`;00=<1@02C08A0T`700=<3@000d`00003009<
0Q42C0H000=<00003003C0D00T`00a404@02C0H00d`900=<1`02C0034@0A009<1`03C0X00d`5009<
00<A01400T`600=<2`03@PD00T`00a404@02C0H00d8<00002P02C@P000I=015=4Dd:0003C@0000H0
0Td80006C@0ACA5=2P000dd000090003C@0000@000I=015=4Dd70003C@0000T00Td80007C@0ACA40
C@090003C@00010000M=015=4@1=01800Td80007C@0ACA40C@090003C@0000H00T880007C@0ACA40
C@090003@P0000T0000E0005C15<4D`07P001D`AC15<01D000=<00001P001D`AC15<00P000=<0000
4`001D`A015<01h000E<4@0AC00N0005C1404D`07P001D`A015<01H0000E00044@004Al000@A000A
7`001140014O00054@0001407P001A40000A01h000DA00004@0N00054@0001405P0001D000A<001<
7`0014`004`O0004C000C1l000E<0000C00N0005C00004`07P001D`0001<01h000E<0000C00F0000
5@001Dd0001=01h000E=0000C@0N0005C@0004d07P001Dd0001=01h000E=0000C@0N0005C@0004d0
7P001Dd0001=01H0000D0003C000008000=<00006`000d`000020003C00001/000=<00000P000d`0
000K0003C00000<000=<00006P000d`000030003C00001X000=<00000`000d`0000J0003C00000<0
00=<00004`0001@000==00000P000dd0000K0003C@00008000==00006`000dd000030003C@0001X0
00==00000`000dd0000J0003C@0000<000==00006P000dd000030003C@0001X000==00000`000dd0
000C000050000d`000030003C00001X000=<00000`000d`0000J0003C00000<000=<00006P000d`0
00030003C00001X000=<00000`000d`0000J0003C00000<000=<00006P000d`000030003C00001<0
000D0003C@0000<000==00006P000dd000030003C@0001T000==000010000dd0000J0003C@0000<0
00==00006P000dd000030003C@0001X000==00000`000dd0000J0003C@0000<000==00004`0001<0
00=<000010000d`0000I0003C00000@000=<000060000lI<00060003C<H001P000=<00001@000d`0
000H0003C00000D000=<000060000d`000050003C00001P000=<00001@000d`0000B0000400014g6
aTd70003CLK6009=4`04C@L01Dd>00I=00?60<H01`000lH0aP05CA0000A=a/I=1`000dg6aP02CAD0
00?6C@001P000dg6000E0004CLK6C@L000==a/H00TdC0004@/K6C@L000==a/H00T8@00003@03C0@0
00?600000`000lH0000300=<3@03C0@000=<00000`000d`0000300=<3`000d`000020003aT`00080
00=<aP000`000d`0000>00=<10000lH000030003aP0000<00d`@0004C<H0aPL000?60<H00T`@00=<
10000lH000030003aP0000<00d`=00=210000lH000030003aP0000<00d8=00002`02C@L000==0000
0`000dd000060003C@0000P00Td70003C@0000<000==00001P000dd0000;0003C@0000<000==04d0
0Td00`1=00040003C@0000/00Td70003C@0000<000==00001P000dd0000:00==10000lH000030003
aP0000<00dd;009=1`000dd000030003C@0000H000==00002002@PL000=200000`000d8000060003
@P0000X0000E0005C00004`07P001D`0001<01H000=<00001@02C00304a<00L000=<000050001D`0
001<01@00T`70003C00000<000=<00001P000d`0000B0005C00004`07P001D80001201H0000F0003
C@1=020000==04d07`001Dd0001=01l000==04d07`001Dd0001=01l000==04d080000d80@P0G0000
5`000d`0000P0003C00001h000E<0000C00P0003C00001l000=<04`08@000d`0000P0003@P0001H0
000F0003C@1=020000==04d080000dd0C@0P0003C@1=024000==00007`000dd0C@0P0003@P1201L0
003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0000F0003C01<024000=<00007`000d`0
C00P0003C01<01/000=<00002@000d`0000J0003C00001l000=<04`05`0000l00Td00`1=C@020003
C@1=00800Td00`1=C@0D0003C@0000<000==00000P000dd0000F0007C@0004d0C@030003C@0001H0
00M=0000C@1=00<000==00005@000dd000090003C@0001X000==00006`001dd0001=04d00`000dd0
000A00004@000d`00002C08000=<04`00P000d`0000D0003C000008000=<04`00`000d`0000F0003
C000008000=<00000P000d`0000F0003C000008000=<00000P000d`0000F0003C00000L000=<0000
5@000d`000020003C01<00@000=<00005@000d`000020003C000008000=<00004@00018000A=001=
0P02C@8000==00005@001Dd0001=00<000A=001=60001dd0001=04d00`000dd0000F0007C@0004d0
C@030003C@0001H000==00001`000dd0000@009=0`001Dd0001=00<000E=0000C@03009=4P001dd0
001=04d00`000dd0000A00004`001D`0C4`0009<00<0C0004P04C00504`00<H01@000lH0C00300=<
2`03C0@000A<001<0`0014`004`5009<2P03C0@000A<001<0`0014`004`5009<4@000d`000070003
C00001800T`00`1<00020005C00004`00`0014`0C4`=009<1@0014`00<H30004aP00C0D00T`<0000
50001Dd0a/H000;66002C@03aP3600D000C60<K60TdA00==00@0C@361@000lH0C@0200==3`03C@04
04d0aPD000?604d00P03C@d00Td50003aP0000==0P000lH00003009=4002C@8000?600000`000lH0
0002CA400dd20004C@00aP<000C6001=0P03C@h0000D0006aT`004c66P000d`0C007009<5`000lI<
C0070004C<K6C1D000?6C<H01`03aP03C00001000T`30006aP00C01<0P001<H00002C1<000C6C036
1@001<H0a/HE00;600=<0<H01@000lH0C002aQ40000<00I=0/H2C@8000==04d00/H6CA4000?604d0
1`000dg6000G0003aTd000H000==aP005`02aPL00/HF0003C@0000I=0/H014d004dF009=1`02CAP0
00?6C@001P000dg6000B00005002C08000=<04`06@000lH0C0060003C03601P000?6C0001P000dc6
000G00;61`02aQL00/H00dc600040004aTc6C1L000?6C0001P000dc6000G0003aT`000H000=<aP00
4P0001D000==01400TdJ009=00D0C@004@0200==00?6000050001<I=CDd200034@0000==00?60000
5004aP8000<A00001<HD009=00C60<I=1@0014g60<H2CA@000C6CDe=0P0011400002C@03aP0001D0
00?604d00P001Q40001=aQ<0000E0004C00AC1L00d`00lH00002C08000@A001<0`001<I<C4`@0003
C<H0008000A<000A0P001D`00036009<4@000dc600020004aP004@8000G60000aP02C10000A<0000
0d`200034@0000=<0`000d`0000>009<00G60000C00200044@00C0<000C6C4a<40000dc6aP03C080
00<A00000d`3aP03C00000d0000E0004CA4ACA@00dd7009=0Q42C@P00dd:00==1@02C@034@0A009=
1P03C@/00dd500;600<A01400/H600==30000dd000020007aP1=C@0A0002C@030<H000<000==0000
2P03C@L00Td24@9=1`03C@X00dd5009=00D04A40C@0600==300001D000A<4D`A7P001T`04D`AC1<0
0T`80007C00AC140C0090003C00000H00T`80007aP0AaQ40aP090003C00000h000=<00000T`00a5<
C0020003C00001T000I<4D`A04`B009<2@0014`A0142C0T000=<00002@0001D000A=4DdA7`001DdA
CA5=01h000E=4@0AC@0N0005aQ404LH06P002Dd0001=4DdAC@030003C@0001P000E=4DdAC@0N0005
CA5=4Dd05P0001D000@A000A7`001140014O00054@0001407P001A40000A01X000=<00000P000a40
4@040003C00001T000@A000A7`001140014F00005@0014d004dO0004C@00CAl000E=0000C@0N0005
aP000<H06P000dd000020003C@1=00@000==00006@0014d004dO0004C@00CAH0000E0005C00004`0
7P001D`0001<01h000E<0000C00N0005aP000<H06@000d`000020005C00004`010000d`0000G0005
C00004`07P001D`0001<01H0000D0003C@00008000==00006`000dd000020003C@0001/000==0000
0`000dd0000J0003aP0000<000?600004`02C@0304d000<000E=0000C@040004C@1=CAH000==0000
0P000dd0000K0003C@00008000==00004`0001@000=<00000P000d`0000K0003C000008000=<0000
6`000d`000030003C00001X000?600000`000lH0000E009<0`000d`000030004C000009<5`000d`0
00030003C00001X000=<00000`000d`0000C000050000dd000030003C@0001X000==00000`000dd0
000J0003C@0000<000==00006P000lH000030003aP0001L000A=001=1@0014d004dI0003C@0000<0
00==00006P000dd000030003C@0001<0000D0003C00000<000=<00006P000d`000030003C00001X0
00=<00000`000d`0000J0003aP0000<000?6000060000lH0C0050003C03601X000=<000010000d`0
000I0003C00000@000=<00004P0001<000==000010000dd0000I0003C@0000@000==00006@000dd0
00050003C@0001P000?600001@000lH0000H00I=0/H00dd0000G0003aTd000H000==aP005`000lI=
00060003CLK60180000@0004C<K6C0L000=<a/H00T`E0003aT`000H000=<aP005@0014c6aT`70003
C<K6009<4`0014c6a/H700?60T`F0003aP0000D000?600005@0014c60<H70004aP36C1<000E<a/H0
aP070005aP00aT`0400000d00dd40003aP0000<000?600000`03CA0000A=aP361`001<H0aTdA00==
10000lH000030003aP0000<00dd=00==10000lH000030003aP0000<00ddC0003aP0000D000?60000
4`02C@@000?600000`000lH00002009=3P03C@D000?600000`000lH0000300==3@0000/00T`70003
C00000<000=<00001P000d`0000:00=<10000lH000030003aP0000800d`<009<1`000d`000030003
C00000H000=<00002002C0L000=<00000`000d`000060003C000010000=<00001@000d`0000B0003
C00000@000=<00000`000d`000040003C00000X000=<00001`001LH0003600T000=<00002P0001D0
00E=0000C@0E0003C@0000D000==00000`000dd000050003C@0001<000E=0000C@0N0005C@0004d0
6`000dd000070003C@00010000==00001P001Dd0001=00P000==00004`001Dd0001=01H0000F0003
C01<01l000E<0000C00O0003C01<020000=<04`070000d`000070003C00001X000=<04`080000d`0
C00G00005`000dd0000O0003C@1=024000==000080000dd0000K0003C@0000L000==00006P000dd0
C@0Q0003C@0001H0000F0003C01<024000=<00007`000d`0C00P0003C01<01/000=<00002@000d`0
000J0003C00001l000=<04`05`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`0001L0
00<A00007P001Dd0001=01h000E=0000C@0O0003C@1=020000==04d080000dd0C@0j00005`000a40
000N0005C00004`07`000d`0C00L0007C00004`0C0030003C00001H000M<0000C01<00<000=<0000
5P001d`0001<04`00`000d`0000d00005`000a40000M0003C@0000<000==00004P02C@<000==0000
0`000dd000030004C@00009=4P000dd000020003C@00008000==00005P000dd000020003C@000080
00==00005P000dd000020003C@00008000==0000=00001H000<A01407P000d`000030003C00001@0
0T`00`1<00030003C01<00@000A<04a<50001d`0001<04`00`000d`0000F0007C00004`0C0030003
C00001H000M<0000C01<00<000=<0000=00001H000<A01407P000dd000030003C@0001H00Td30005
aP000<H00`02C@l00dd40004C@00C@<000A=001=1@02C@X00dd40004C@00C@<000A=001=1@02C@X0
0dd40004C@00C@<000A=001=1@02C@P000==00006@000dd0000800005P000a404@0M0003C00000D0
00=<00005P0014c60<H50004aP36C1<00d`0101<0<H50003aP1<00800d`?00=<00@0C0361@000lH0
C00200=<3`03C00404`0aPD000?604`00P03C0X000=<00006@000d`0000800005@001A40000A01`0
00?600001@000lH0000G009=1`02CAL000?6CDd01`0014g6aTdE0003aTe=00L000A=a/I=5@000lI=
C@070004CLK6C@h000==00002P000a40000:0003C@0000T0000E00054@00014070000lH000050003
aP0001L00T`7009<60000lI<00060003C<H001L000?6C0001P000dc6000G0003aT`000H000=<aP00
40000d`0000900034@0000T000=<00002P0001D000DA00004@0B00M=0/H00dd000070003CLK600M=
3`000lI=00060003CLH001L000?604d01@000dd0aP0H0003aTd000H000==aP005`000lI=00060003
CLH0010000==00002@024@X000==00002P0001@000<A00000`000a40000H0003C000008000<A0000
0P000d`0000F0003aP1<008000HA001<0<HG0004aTa<C0D00d`00lH0000D0004aTa<C08000<A0000
0d`00lH0000D0004aTa<C08000?O00000d`00lH0000?0003aP0000L000<A01402@000lH0000;0000
50000a40000300034@0001T000E=00004@030003C@0001H000C6CDe=0P000a400003C@03aP000180
00==aP000P0014d001420005C@000<H00TdA0003CLH0008000A=000A0P001Dd00036009=4@000dg6
00020004C@00gP8000E=0000aP02C@h000?600001`000a404@090003aP0000/0000D00034@0000<0
00<A00006P0014`001420003C00001D000=<aP000P02C0034@0A009<0`000lI<000>00=<1P001D`0
4@1<00L00d`;00=<1@02C0034@0A009<1P03C0/00d`5009<00?O0=l00T`600=<3009C0044Da<4@Q<
3P0001<000<A00001@000a40000J0005C@0A04d05P02C@D000M=01404@1=00D00Td;009=2@02C@03
4De=00X000==00001P02C@P000M=015=4@1=00T000==00001P02C@P000M=0=i=gP1=00T000==0000
2@000lH00007009=20000lH0000<00004`000a40000500034@0001X000E<0140C00E0003C00000H0
00E<4D`AC0080003C00001<000E<4D`AC00N0005C1404D`07P001DcO0=m<01<00d`8009<0P000d`0
00060003aTa<00/0000C00034@0000D000<A00006`000ddAC@0E0003C@0000L000DA00004@090003
C@0001<000<A01407`001A40000A01h000GN0000gP0E00A=10000dd000030003C@0000<00dd=0000
4P000a40000700034@0001/000<A00007P001D`0001<01l000=<04`07`001D`0001<01h000E<0000
C00D0003C00000800/H00`1<00060005C036aT`00`000d`0000:00004P000a40000700034@0001/0
00==00007@000dd000030003C@0001/000E=0000C@0N0005C@0004d07P001Dd0001=01<000==0000
1@000dd000070003C@0000D000==00002@00018000<A00001`000a40000K0003C00001d000=<0000
0`000d`0000K0005C00004`07@000d`000030003C00001X000=<00000`000d`0000?0003C00000H0
00?600001`000lH000060003C00000P0000A00034@0000T000<A00006P000dd0000L0003C@0000D0
00==00006P001Dd0001=01d000==00000`000dd0000J0003C@0000<000==000060000lH000070003
aP000140000A00034@0000T000<A00006P000d`0000K0003C00000L000=<000060000d`000030003
C00001X000=<00000`000d`0000J0003C00000<000=<000060000d`000070003C0000140000A0003
4@0000T000<A00006P000dd0000K0003C@0000L000==000060000dd000030003C@0001X000==0000
0`000dd0000J0003C@0000<000==000060000dd000070003C@000140000@00034@0000/000<A0000
6@000d`0000E00=<0/H00d`000090003C<K600=<50000d`000030003C00001T000=<00001@000d`0
000H0003C00000D000=<00005`000d`000070003C0000140000@00034@0000/000<A00006@000dd0
000B00==1@000lH000090003aP0000<00dd=0004CLK6C@L000==a/H00TdC0004CLK6C@L000==a/H0
0TdC0004CLK6C@L000==a/H00TdE0003C@0000L000==00004@00010000<A00002`000a40000I0003
C00001/000?600001`000lH0000A00=<10000lH000030003aP0000<00d`=00=<10000lH000030003
aP0000<00d`=00=<10000lH000030003aP0000<00d`B0003C00000L000=<00004@0000l000<A0000
3@000a40000G0003aP3601`000==00001`000dd0000?009=1`000dd000030003C@0000H000==0000
2002C@L000==00000`000dd000060003C@0000P00Td70003C@0000<000==00001P000dd0000?0003
C@0000L000==00004@0000l000<A00003@000a40000E0003C<H0008000?6C0006P000d`000050003
C00001X000E<0000C00N0005C00004`07P001D`0001<03T0000?00034@0000d000<A00004`02C@L0
0TdJ0003C@0000<000==000070000dd0C@0P0003C@1=020000==04d0>P0000h000<A00003`000a40
000A0003C00000T000=<00005`000d`000030003C00001d000=<000080000d`0000P0003C00003T0
000>00034@0000l000<A000040000dd0000;0003C@0001L000E=0000C@0O0003C@1=020000==04d0
80000dd0C@0j0000o`030000o`030000o`030000o`030000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270005, -0.109417,
   0.0329413, 0.0329413}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42398,
   -0.109417, 0.0329413, 0.0329413}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57798, -0.109418, 0.0329416, 0.0329416}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.73193, -0.109417, 0.0329413, 0.0329413}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.109418, 0.0329416, 
  0.0329416}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.03988,
   -0.109417, 0.0329413, 0.0329413}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.19386, -0.109417, 0.0329413, 0.0329413}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.271522, -1.26686, 0.0330062, 0.0330062}, {{42.5, 74.3125},
   {69.375, 37.5625}} -> {-1.42777, -1.26687, 0.0330063, 0.0330063}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.584, -1.26686, 0.033006, 0.033006}, {{
  112.562, 144.375}, {69.375, 37.5625}} -> {-3.74025, -1.26686, 0.033006, 
  0.033006}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.89652, -1.26686, 
  0.0330062, 0.0330062}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05279,
   -1.26687, 0.0330063, 0.0330063}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.20899, -1.26686, 0.0330061, 0.0330061}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.269997, -2.41735, 0.0329411, 0.0329411}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.424, -2.4174, 0.0329417, 0.0329417}, {{77.5, 109.375},
   {34.375, 2.5}} -> {-2.57796, -2.41737, 0.0329414, 0.0329414}, {{112.562, 
  144.375}, {34.375, 2.5}} -> {-3.73194, -2.41737, 0.0329414, 0.0329414}, {{
  147.562, 179.438}, {34.375, 2.5}} -> {-4.88591, -2.41737, 0.0329413, 
  0.0329413}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.03988, -2.41737, 
  0.0329413, 0.0329413}, {{217.625, 249.5}, {34.375, 2.5}} -> {-7.1939,
   -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.15496 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0499794 1.09996 0.027499 1.09996 [
[ 0 0 0 0 ]
[ 1 1.15496 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 1.15496 L
0 1.15496 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.5701 .13326 L
s
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.4656 .05734 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.12474 .16809 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.08483 .29094 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.40102 .2561 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.29382 .29094 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.08483 .86402 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.12474 .98686 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.4656 1.09761 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.5701 1.02169 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.29382 .86402 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.40102 .89885 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.90695 .55806 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.94686 .43522 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.7362 .14526 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.60704 .14526 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.73787 .43522 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.67162 .34403 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .31246 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .84249 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.67162 .41369 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.39296 .14526 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.2638 .14526 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.05314 .43522 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.09305 .55806 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.32838 .34403 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.26213 .43522 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.4299 1.02169 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.5344 1.09761 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.87526 .98686 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.91517 .86402 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.59898 .89885 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.70618 .86402 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.91517 .29094 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.87526 .16809 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.5344 .05734 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.4299 .13326 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.70618 .29094 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.59898 .2561 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.32838 .41369 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .84249 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .31246 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.44618 .57748 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.55382 .57748 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{156, 180},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002L0000]0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP0009`0002L0000W00009`0002L0000W00009`0
002L0000A`03C0L00da80000A`03C@L00de80000A`03C0L00da80000AP04C@L014e70000AP04C0L0
14a70000AP03C@T00de70000A@04C0T014a60000A@04C@T014e60000A@03C0/00da60000A004C@/0
14e50000A004C0/014a50000A003C@d00de50000@@06C0d01Ta20000@@06C@d01Te200009`03C140
0d`300I<3@06C0<00d`A00=<:00002L00ddA00==1007C@T01dd400==4@03CBP0000W00=<4@03C0@0
24`700Q<1003C1400d`X00009`04C@l014d400Y=0`0:C@@014d?00A=:000018014`A00A<3`04C0<0
14`200I<00<0C4`014`200A<0`04C0l014`A00A<4`0001801DdA00==3`03C@@014d300]=0`04C@@0
0dd?00==4@05CA<0000B00I<4004C0d014`400=<1P07C0H00d`400A<3@04C1001T`C00005006C@h0
14d=00A=0`04C@H01dd600A=0`04C@d014d>00I=5@0001D01T`>00=<3@03C0@014`500U<1@04C0@0
0d`=00=<3P06C1H0000F00M=3004C@/014d400==1006C@0304e=00A=1003C@@014d;00A=3007CAL0
000H00I<2`04C0/014`300A<0`06C0<01T`300A<0`04C0/014`;00I<6@0001T01Td;00==2`03C@@0
14d200I=1@06C@8014d400==2`03C@/01TdJ00006`06C0T014`900A<1003C00304a<00A<2@06C004
04a<C0@014`900A<2@06C1`0000L00I=2004C@T014d300Y=2`0:C@<014d900A=2006CAd0000M00I<
2003C0T00d`400U<3@09C0@00d`900=<2006C1h0000O00I=1P04C@L014d400M=4@07C@@014d700A=
1P06CB00000P00I<1@04C0L014`300M<4`07C0<014`700A<1@06C240000Q00I=1@03C@L00dd400E=
5`05C@@00dd700==1@06CB80000S00I<0`04C0D014`400;60T`I0004C<K6C0@014`500A<0`06C2@0
000T00I=0P04C@D014d400;600==00006@02aP03C@00008014d500A=0P06CBD0000U00M<00@0C4a<
1@03C0@00lHL00?61@03C0D00d`00`1<C005C2H0000W00Y=0`04C@<00lHN00?61004C@<02TdX0000
:009C0<014`200?68003aP<014`300U<:@0000`09Dd300==0P03aR800lH300==0`0UC@d0000<021<
0/H4C00304a<009<0P02aR@00/H300A<00<0C<H00lHQC0d0000<021=0/H4C@03aTe=009=00@0a/K6
9003aP800dd7aR5=3@0002l00d`01LI<C4`000?69P03aP030<K600G600=<0000;P0002l02Dd00lH0
000V0003aTe=00C614d`0000;`09C2X00T`00lI<C005C300000`00E=00@0CDe=:003C@801Dda0000
<005C0800T`X009<0`05C340000`00E=0P02CBP00Td300E=<@0003400/H014`00003C2H00d`400;6
00=<0000<00003400/H00dd00002009=9P02C@D00/H00dd0000`0000<@02aPD00T`V009<1@02aS<0
000a00;61@03CB@00dd500;6<`0003400/H6009<9002C0H00/Hc0000<@02aPH00TdT009=1P02aS<0
000a00;61P03C2800d`600;6<`0003400/H7009=8P02C@L00/Hc0000<@02aPL00T`R009<1`02aS<0
000a00;61`03CB000dd700;6<`0003400/H8009<3`024@l00T`800;6<`0002l00/H3C@L00Td?008A
3`02C@L00dd2aS40000/00G614`600=<3P024@h00d`600A<1LH^00001`0RC@O60`04C@D00Td=00@A
3@02C@D014d300O68dd800001`0PC0K61`04C0@00T`=00@A3@02C0@014`700K68D`800001`0PC@?6
3003C@<00dd<00@A3003C@<00dd<00?68Dd800008P06C0l014`2009<2`064@/00T`200A<4006C2<0
000Q00I=4@04C@0304e=00/00Q42008A2`02C@0304e=009=4P06CB80000O00M<5006C0X00Q42008A
2P06C1D01d`P00007P06CAL01Dd900<A0P034@T01DdH00I=7`0001d01T`J00=<2@024@@00Q4900=<
6`06C1h0000K00I=7@04C@L00Q44008A1`04CAh01TdL00006P06C1l014`500<A10034@D014`P00I<
6`0001T01TdP00I=0`024@H00Q4300I=8@06CAX0000G00I<8P07C0800Q46008A0P07C2<01T`H0000
5P06CB@00Td200==00<04A401P024@0404e=C@800TdU00I=5`0001D01T`U009<0`02C0<A1P034@9<
0`02C2H01T`F00004`06CBL00dd30004CA4AC@H000A=4A5=0`03CBP01TdD00004P06C2T00T`4008A
0d`200=<0Q44009<:P06C1<0000@00M=:P02C@<00a48C@<A0`02CB/01ddA00003`06C2`00d`2008A
0`04C0<00Q4200=<;@06C100000>00I=;P02C@800Q4200I=0P024@800Td_00I=3`0000d01D``009<
00D04A4A0008C005014A4@000T`a00E<3P0000d014da00==0Q44C@@014d24@==<P04C@h0000=00=<
<`02C08A0d`600=<0Q42C3@00d`>0000@`001DdA4A5=00X000E=4A4AC@150000@`0014`A4D`<0004
C14AC4D00014008A3P024DH0001300=<3P03C4D00013009=4002CDD00013009<4002C4D0001200==
4003CD@00012009<4P02C4@00012009=4P02CD@0001100=<4P03C4<00011009=5002CD<00011009<
5002C4<0001000==5003CD800010009<5P02C4800010009=5P02CD80000o00=<5P03C440000o009=
6002CD40000o009<6002C440000n00==6003CD00000n009<6P02C400000n009=6P02CD00000m00=<
6P03C3l0000m009=7002CCl0000m009<7002C3l0000l00==7003CCh0000l009<7P02C3h0000l009=
7P02CCh0000k00=<7P03C3d0000k009=8002CCd0000k009<8002C3d0000j00==8003CC`0000j009<
8P02C3`0000j009=8P02CC`0000i00=<8P03C3/0000i009=9002CC/0000i009<9002C3/0000h00==
9003CCX0000h009<9P02C3X0000h009=9P02CCX0000g00=<9P03C3T0000g009=:002CCT0000g009<
:002C3T0000d00;60ddX00==0/Hf0000<@05aP9<:P02C0G6<`0000`08Td7aP040<K6aRP00lH00`36
aP05aR==3@0000`084`6aPD00lHV00?61@06aR5<3@0000`084d3aPT00lHT00?62@03aR5=3@0002L0
1T`<00?68P03aPd01T`X00009P06C@h00/HR00;63`06CBL0000T00M<3`03aR000lH@00M<9@0002<0
1TdB00?60ddI009=0lHC00I=900002801T`D00?60d`G009<0lHE00I<8`0002001TdG00;614dE00==
0/H00dd0000E00I=8@0001l01T`H00Q<4@08C1P01T`P00007P06CAT02Dd?00U=6@06CAl0000L00I<
700:C0/02T`L00I<7@0001/01TdM00A=00<0CDd014d900I=00<0CDd00TdM00I=700001X01T`N00A<
0P06C0L01T`200A<7P06C1/0000H00I=8@03C@@01Td300I=1003CB401TdI00005`06C28014`400I<
00<0C4`014`400A<8P06C1P0000E00M=8`04C@D02dd500A=8`07CAH0000D00I<9P03C0L01d`700=<
9P06C1D0000C00I=9`04C@H01dd600A=9`06CA@0000B00E<:@04C0D02D`500A<:@05C1<0000B00A=
:`03C@<01Td00`1=C@04C@<00dd[00A=4`0001800d`/00A<00<0C4`014`300I<00<0C4`00T`/00=<
4`0004402Td500Y=@P0004801d`900M<@`0004801Td;00I=@`0004401D`?00E<@P0004401Dd?00E=
@P0004401T`=00I<@P0004<014d=00A=A00004@00d`=00=<A@0004@014d;00A=A@0004@014`;00A<
A@0004D00dd;00==AP0004D014`900A<AP0004D014d900A=AP0004H00d`900=<A`0004H014d700A=
A`0004H014`700A<A`0004L00dd700==B00004L00d`700=<B00009`0002L0000W00009`0002L0000
W00009`00000\
\>"],
  ImageRangeCache->{{{0, 155}, {179, 0}} -> {0.0453852, -0.0250053, 
  0.00586599, 0.00586599}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0499794 1.09996 0.027499 1.09996 [
[ 0 0 0 0 ]
[ 1 1.15496 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.15496 L
0 1.15496 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.5701 .13326 L
s
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.4656 .05734 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.12474 .16809 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.08483 .29094 L
s
P
p
0 .4 1 r
.016 w
.36007 .31246 m
.40102 .2561 L
s
P
p
0 .4 1 r
.016 w
.36007 .31246 m
.29382 .29094 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.08483 .86402 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.12474 .98686 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.4656 1.09761 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.5701 1.02169 L
s
P
p
0 .4 1 r
.016 w
.36007 .84249 m
.29382 .86402 L
s
P
p
0 .4 1 r
.016 w
.36007 .84249 m
.40102 .89885 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.90695 .55806 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.94686 .43522 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.7362 .14526 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.60704 .14526 L
s
P
p
0 .4 1 r
.016 w
.67162 .41369 m
.73787 .43522 L
s
P
p
0 .4 1 r
.016 w
.67162 .41369 m
.67162 .34403 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .31246 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .84249 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.67162 .41369 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.39296 .14526 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.2638 .14526 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.05314 .43522 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.09305 .55806 L
s
P
p
0 .4 1 r
.016 w
.32838 .41369 m
.32838 .34403 L
s
P
p
0 .4 1 r
.016 w
.32838 .41369 m
.26213 .43522 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.4299 1.02169 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.5344 1.09761 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.87526 .98686 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.91517 .86402 L
s
P
p
0 .4 1 r
.016 w
.63993 .84249 m
.59898 .89885 L
s
P
p
0 .4 1 r
.016 w
.63993 .84249 m
.70618 .86402 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.91517 .29094 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.87526 .16809 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.5344 .05734 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.4299 .13326 L
s
P
p
0 .4 1 r
.016 w
.63993 .31246 m
.70618 .29094 L
s
P
p
0 .4 1 r
.016 w
.63993 .31246 m
.59898 .2561 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.32838 .41369 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .84249 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .31246 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.44618 .57748 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.55382 .57748 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0499794 1.09996 0.027499 1.09996 [
[ 0 0 0 0 ]
[ 1 1.15496 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.15496 L
0 1.15496 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.5701 .13326 L
s
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.4656 .05734 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.12474 .16809 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.08483 .29094 L
s
P
p
0 1 1 r
.018 w
.36007 .31246 m
.40102 .2561 L
s
P
p
0 1 1 r
.018 w
.36007 .31246 m
.29382 .29094 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.08483 .86402 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.12474 .98686 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.4656 1.09761 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.5701 1.02169 L
s
P
p
0 1 1 r
.018 w
.36007 .84249 m
.29382 .86402 L
s
P
p
0 1 1 r
.018 w
.36007 .84249 m
.40102 .89885 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.90695 .55806 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.94686 .43522 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.7362 .14526 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.60704 .14526 L
s
P
p
0 1 1 r
.018 w
.67162 .41369 m
.73787 .43522 L
s
P
p
0 1 1 r
.018 w
.67162 .41369 m
.67162 .34403 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .31246 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .84249 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.67162 .41369 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.39296 .14526 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.2638 .14526 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.05314 .43522 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.09305 .55806 L
s
P
p
0 1 1 r
.018 w
.32838 .41369 m
.32838 .34403 L
s
P
p
0 1 1 r
.018 w
.32838 .41369 m
.26213 .43522 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.4299 1.02169 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.5344 1.09761 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.87526 .98686 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.91517 .86402 L
s
P
p
0 1 1 r
.018 w
.63993 .84249 m
.59898 .89885 L
s
P
p
0 1 1 r
.018 w
.63993 .84249 m
.70618 .86402 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.91517 .29094 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.87526 .16809 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.5344 .05734 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.4299 .13326 L
s
P
p
0 1 1 r
.018 w
.63993 .31246 m
.70618 .29094 L
s
P
p
0 1 1 r
.018 w
.63993 .31246 m
.59898 .2561 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.32838 .41369 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .84249 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .31246 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.44618 .57748 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.55382 .57748 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0725609 1.14512 0.028628 1.14512 [
[ 0 0 0 0 ]
[ 1 1.20238 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.20238 L
0 1.20238 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39893 .27303 m
.60189 .20708 L
s
P
p
.2 0 1 r
.02 w
.39893 .27303 m
.52437 .10038 L
s
P
p
.2 0 1 r
.02 w
.39893 .27303 m
.39893 .05962 L
s
P
p
.2 0 1 r
.02 w
.28947 .30859 m
.16403 .13595 L
s
P
p
.2 0 1 r
.02 w
.28947 .30859 m
.08651 .24265 L
s
P
p
.2 0 1 r
.02 w
.28947 .30859 m
.08651 .37454 L
s
P
p
0 .4 1 r
.018 w
.35712 .33058 m
.39893 .27303 L
s
P
p
0 .4 1 r
.018 w
.35712 .33058 m
.28947 .30859 L
s
P
p
.2 0 1 r
.02 w
.28947 .89378 m
.08651 .82784 L
s
P
p
.2 0 1 r
.02 w
.28947 .89378 m
.08651 .95973 L
s
P
p
.2 0 1 r
.02 w
.28947 .89378 m
.16403 1.06643 L
s
P
p
.2 0 1 r
.02 w
.39893 .92935 m
.39893 1.14275 L
s
P
p
.2 0 1 r
.02 w
.39893 .92935 m
.52437 1.102 L
s
P
p
.2 0 1 r
.02 w
.39893 .92935 m
.60189 .9953 L
s
P
p
0 .4 1 r
.018 w
.35712 .8718 m
.28947 .89378 L
s
P
p
0 .4 1 r
.018 w
.35712 .8718 m
.39893 .92935 L
s
P
p
.2 0 1 r
.02 w
.7429 .45592 m
.86833 .62857 L
s
P
p
.2 0 1 r
.02 w
.7429 .45592 m
.94585 .52187 L
s
P
p
.2 0 1 r
.02 w
.7429 .45592 m
.94585 .38998 L
s
P
p
.2 0 1 r
.02 w
.67524 .36281 m
.80068 .19016 L
s
P
p
.2 0 1 r
.02 w
.67524 .36281 m
.67524 .1494 L
s
P
p
.2 0 1 r
.02 w
.67524 .36281 m
.54981 .19016 L
s
P
p
0 .4 1 r
.018 w
.67524 .43394 m
.7429 .45592 L
s
P
p
0 .4 1 r
.018 w
.67524 .43394 m
.67524 .36281 L
s
P
p
.2 0 1 r
.016 w
.44505 .60119 m
.35712 .33058 L
s
P
p
.2 0 1 r
.016 w
.44505 .60119 m
.35712 .8718 L
s
P
p
.2 0 1 r
.016 w
.44505 .60119 m
.67524 .43394 L
s
P
p
.2 0 1 r
.02 w
.32476 .36281 m
.45019 .19016 L
s
P
p
.2 0 1 r
.02 w
.32476 .36281 m
.32476 .1494 L
s
P
p
.2 0 1 r
.02 w
.32476 .36281 m
.19932 .19016 L
s
P
p
.2 0 1 r
.02 w
.2571 .45592 m
.05415 .38998 L
s
P
p
.2 0 1 r
.02 w
.2571 .45592 m
.05415 .52187 L
s
P
p
.2 0 1 r
.02 w
.2571 .45592 m
.13167 .62857 L
s
P
p
0 .4 1 r
.018 w
.32476 .43394 m
.32476 .36281 L
s
P
p
0 .4 1 r
.018 w
.32476 .43394 m
.2571 .45592 L
s
P
p
.2 0 1 r
.02 w
.60107 .92935 m
.39811 .9953 L
s
P
p
.2 0 1 r
.02 w
.60107 .92935 m
.47563 1.102 L
s
P
p
.2 0 1 r
.02 w
.60107 .92935 m
.60107 1.14275 L
s
P
p
.2 0 1 r
.02 w
.71053 .89378 m
.83597 1.06643 L
s
P
p
.2 0 1 r
.02 w
.71053 .89378 m
.91349 .95973 L
s
P
p
.2 0 1 r
.02 w
.71053 .89378 m
.91349 .82784 L
s
P
p
0 .4 1 r
.018 w
.64288 .8718 m
.60107 .92935 L
s
P
p
0 .4 1 r
.018 w
.64288 .8718 m
.71053 .89378 L
s
P
p
.2 0 1 r
.02 w
.71053 .30859 m
.91349 .37454 L
s
P
p
.2 0 1 r
.02 w
.71053 .30859 m
.91349 .24265 L
s
P
p
.2 0 1 r
.02 w
.71053 .30859 m
.83597 .13595 L
s
P
p
.2 0 1 r
.02 w
.60107 .27303 m
.60107 .05962 L
s
P
p
.2 0 1 r
.02 w
.60107 .27303 m
.47563 .10038 L
s
P
p
.2 0 1 r
.02 w
.60107 .27303 m
.39811 .20708 L
s
P
p
0 .4 1 r
.018 w
.64288 .33058 m
.71053 .30859 L
s
P
p
0 .4 1 r
.018 w
.64288 .33058 m
.60107 .27303 L
s
P
p
.2 0 1 r
.016 w
.55495 .60119 m
.32476 .43394 L
s
P
p
.2 0 1 r
.016 w
.55495 .60119 m
.64288 .8718 L
s
P
p
.2 0 1 r
.016 w
.55495 .60119 m
.64288 .33058 L
s
P
p
1 .6 0 r
.016 w
.5 .43206 m
.44505 .60119 L
s
P
p
1 .6 0 r
.016 w
.5 .43206 m
.55495 .60119 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0403668 1.08073 0.0270183 1.08073 [
[ 0 0 0 0 ]
[ 1 1.13477 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.13477 L
0 1.13477 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.40036 .24388 m
.54912 .09512 L
s
P
p
.2 0 1 r
.02 w
.40036 .24388 m
.49587 .05643 L
s
P
p
.2 0 1 r
.02 w
.29245 .27894 m
.105 .18343 L
s
P
p
.2 0 1 r
.02 w
.29245 .27894 m
.08466 .24603 L
s
P
p
0 .4 1 r
.018 w
.35914 .30061 m
.40036 .24388 L
s
P
p
0 .4 1 r
.018 w
.35914 .30061 m
.29245 .27894 L
s
P
p
.2 0 1 r
.02 w
.29245 .85583 m
.08466 .88874 L
s
P
p
.2 0 1 r
.02 w
.29245 .85583 m
.105 .95134 L
s
P
p
.2 0 1 r
.02 w
.40036 .89089 m
.49587 1.07834 L
s
P
p
.2 0 1 r
.02 w
.40036 .89089 m
.54912 1.03965 L
s
P
p
0 .4 1 r
.018 w
.35914 .83416 m
.29245 .85583 L
s
P
p
0 .4 1 r
.018 w
.35914 .83416 m
.40036 .89089 L
s
P
p
.2 0 1 r
.02 w
.73945 .42418 m
.9269 .51969 L
s
P
p
.2 0 1 r
.02 w
.73945 .42418 m
.94724 .45709 L
s
P
p
.2 0 1 r
.02 w
.67276 .33238 m
.70567 .1246 L
s
P
p
.2 0 1 r
.02 w
.67276 .33238 m
.63985 .1246 L
s
P
p
0 .4 1 r
.018 w
.67276 .40251 m
.73945 .42418 L
s
P
p
0 .4 1 r
.018 w
.67276 .40251 m
.67276 .33238 L
s
P
p
.2 0 1 r
.016 w
.44582 .56739 m
.35914 .30061 L
s
P
p
.2 0 1 r
.016 w
.44582 .56739 m
.35914 .83416 L
s
P
p
.2 0 1 r
.016 w
.44582 .56739 m
.67276 .40251 L
s
P
p
.2 0 1 r
.02 w
.32724 .33238 m
.36015 .1246 L
s
P
p
.2 0 1 r
.02 w
.32724 .33238 m
.29433 .1246 L
s
P
p
.2 0 1 r
.02 w
.26055 .42418 m
.05276 .45709 L
s
P
p
.2 0 1 r
.02 w
.26055 .42418 m
.0731 .51969 L
s
P
p
0 .4 1 r
.018 w
.32724 .40251 m
.32724 .33238 L
s
P
p
0 .4 1 r
.018 w
.32724 .40251 m
.26055 .42418 L
s
P
p
.2 0 1 r
.02 w
.59964 .89089 m
.45088 1.03965 L
s
P
p
.2 0 1 r
.02 w
.59964 .89089 m
.50413 1.07834 L
s
P
p
.2 0 1 r
.02 w
.70755 .85583 m
.895 .95134 L
s
P
p
.2 0 1 r
.02 w
.70755 .85583 m
.91534 .88874 L
s
P
p
0 .4 1 r
.018 w
.64086 .83416 m
.59964 .89089 L
s
P
p
0 .4 1 r
.018 w
.64086 .83416 m
.70755 .85583 L
s
P
p
.2 0 1 r
.02 w
.70755 .27894 m
.91534 .24603 L
s
P
p
.2 0 1 r
.02 w
.70755 .27894 m
.895 .18343 L
s
P
p
.2 0 1 r
.02 w
.59964 .24388 m
.50413 .05643 L
s
P
p
.2 0 1 r
.02 w
.59964 .24388 m
.45088 .09512 L
s
P
p
0 .4 1 r
.018 w
.64086 .30061 m
.70755 .27894 L
s
P
p
0 .4 1 r
.018 w
.64086 .30061 m
.59964 .24388 L
s
P
p
.2 0 1 r
.016 w
.55418 .56739 m
.32724 .40251 L
s
P
p
.2 0 1 r
.016 w
.55418 .56739 m
.64086 .83416 L
s
P
p
.2 0 1 r
.016 w
.55418 .56739 m
.64086 .30061 L
s
P
p
1 .6 0 r
.016 w
.5 .40065 m
.44582 .56739 L
s
P
p
1 .6 0 r
.016 w
.5 .40065 m
.55418 .56739 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0580095 1.11602 0.0279005 1.11602 [
[ 0 0 0 0 ]
[ 1 1.17182 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.17182 L
0 1.17182 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.3928 .23783 m
.5454 .12696 L
s
P
p
.2 0 1 r
.02 w
.3928 .23783 m
.45109 .05843 L
s
P
p
.2 0 1 r
.02 w
.27669 .27556 m
.12408 .16468 L
s
P
p
.2 0 1 r
.02 w
.27669 .27556 m
.08806 .27556 L
s
P
p
0 .4 1 r
.018 w
.34845 .29887 m
.3928 .23783 L
s
P
p
0 .4 1 r
.018 w
.34845 .29887 m
.27669 .27556 L
s
P
p
.2 0 1 r
.02 w
.27669 .89626 m
.08806 .89626 L
s
P
p
.2 0 1 r
.02 w
.27669 .89626 m
.12408 1.00714 L
s
P
p
.2 0 1 r
.02 w
.3928 .93399 m
.45109 1.11339 L
s
P
p
.2 0 1 r
.02 w
.3928 .93399 m
.5454 1.04486 L
s
P
p
0 .4 1 r
.018 w
.34845 .87295 m
.27669 .89626 L
s
P
p
0 .4 1 r
.018 w
.34845 .87295 m
.3928 .93399 L
s
P
p
.2 0 1 r
.02 w
.75764 .43183 m
.91024 .5427 L
s
P
p
.2 0 1 r
.02 w
.75764 .43183 m
.94627 .43183 L
s
P
p
.2 0 1 r
.02 w
.68588 .33306 m
.74417 .15366 L
s
P
p
.2 0 1 r
.02 w
.68588 .33306 m
.62759 .15366 L
s
P
p
0 .4 1 r
.018 w
.68588 .40851 m
.75764 .43183 L
s
P
p
0 .4 1 r
.018 w
.68588 .40851 m
.68588 .33306 L
s
P
p
.2 0 1 r
.016 w
.44171 .58591 m
.34845 .29887 L
s
P
p
.2 0 1 r
.016 w
.44171 .58591 m
.34845 .87295 L
s
P
p
.2 0 1 r
.016 w
.44171 .58591 m
.68588 .40851 L
s
P
p
.2 0 1 r
.02 w
.31412 .33306 m
.37241 .15366 L
s
P
p
.2 0 1 r
.02 w
.31412 .33306 m
.25583 .15366 L
s
P
p
.2 0 1 r
.02 w
.24236 .43183 m
.05373 .43183 L
s
P
p
.2 0 1 r
.02 w
.24236 .43183 m
.08976 .5427 L
s
P
p
0 .4 1 r
.018 w
.31412 .40851 m
.31412 .33306 L
s
P
p
0 .4 1 r
.018 w
.31412 .40851 m
.24236 .43183 L
s
P
p
.2 0 1 r
.02 w
.6072 .93399 m
.4546 1.04486 L
s
P
p
.2 0 1 r
.02 w
.6072 .93399 m
.54891 1.11339 L
s
P
p
.2 0 1 r
.02 w
.72331 .89626 m
.87592 1.00714 L
s
P
p
.2 0 1 r
.02 w
.72331 .89626 m
.91194 .89626 L
s
P
p
0 .4 1 r
.018 w
.65155 .87295 m
.6072 .93399 L
s
P
p
0 .4 1 r
.018 w
.65155 .87295 m
.72331 .89626 L
s
P
p
.2 0 1 r
.02 w
.72331 .27556 m
.91194 .27556 L
s
P
p
.2 0 1 r
.02 w
.72331 .27556 m
.87592 .16468 L
s
P
p
.2 0 1 r
.02 w
.6072 .23783 m
.54891 .05843 L
s
P
p
.2 0 1 r
.02 w
.6072 .23783 m
.4546 .12696 L
s
P
p
0 .4 1 r
.018 w
.65155 .29887 m
.72331 .27556 L
s
P
p
0 .4 1 r
.018 w
.65155 .29887 m
.6072 .23783 L
s
P
p
.2 0 1 r
.016 w
.55829 .58591 m
.31412 .40851 L
s
P
p
.2 0 1 r
.016 w
.55829 .58591 m
.65155 .87295 L
s
P
p
.2 0 1 r
.016 w
.55829 .58591 m
.65155 .29887 L
s
P
p
1 .6 0 r
.016 w
.5 .40651 m
.44171 .58591 L
s
P
p
1 .6 0 r
.016 w
.5 .40651 m
.55829 .58591 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0499794 1.09996 0.027499 1.09996 [
[ 0 0 0 0 ]
[ 1 1.15496 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.15496 L
0 1.15496 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.018 w
.40102 .2561 m
.5701 .13326 L
s
P
p
.2 0 1 r
.018 w
.40102 .2561 m
.4656 .05734 L
s
P
p
.2 0 1 r
.018 w
.29382 .29094 m
.12474 .16809 L
s
P
p
.2 0 1 r
.018 w
.29382 .29094 m
.08483 .29094 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.40102 .2561 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.29382 .29094 L
s
P
p
.2 0 1 r
.018 w
.29382 .86402 m
.08483 .86402 L
s
P
p
.2 0 1 r
.018 w
.29382 .86402 m
.12474 .98686 L
s
P
p
.2 0 1 r
.018 w
.40102 .89885 m
.4656 1.09761 L
s
P
p
.2 0 1 r
.018 w
.40102 .89885 m
.5701 1.02169 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.29382 .86402 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.40102 .89885 L
s
P
p
.2 0 1 r
.018 w
.73787 .43522 m
.90695 .55806 L
s
P
p
.2 0 1 r
.018 w
.73787 .43522 m
.94686 .43522 L
s
P
p
.2 0 1 r
.018 w
.67162 .34403 m
.7362 .14526 L
s
P
p
.2 0 1 r
.018 w
.67162 .34403 m
.60704 .14526 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.73787 .43522 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.67162 .34403 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .31246 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .84249 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.67162 .41369 L
s
P
p
.2 0 1 r
.018 w
.32838 .34403 m
.39296 .14526 L
s
P
p
.2 0 1 r
.018 w
.32838 .34403 m
.2638 .14526 L
s
P
p
.2 0 1 r
.018 w
.26213 .43522 m
.05314 .43522 L
s
P
p
.2 0 1 r
.018 w
.26213 .43522 m
.09305 .55806 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.32838 .34403 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.26213 .43522 L
s
P
p
.2 0 1 r
.018 w
.59898 .89885 m
.4299 1.02169 L
s
P
p
.2 0 1 r
.018 w
.59898 .89885 m
.5344 1.09761 L
s
P
p
.2 0 1 r
.018 w
.70618 .86402 m
.87526 .98686 L
s
P
p
.2 0 1 r
.018 w
.70618 .86402 m
.91517 .86402 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.59898 .89885 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.70618 .86402 L
s
P
p
.2 0 1 r
.018 w
.70618 .29094 m
.91517 .29094 L
s
P
p
.2 0 1 r
.018 w
.70618 .29094 m
.87526 .16809 L
s
P
p
.2 0 1 r
.018 w
.59898 .2561 m
.5344 .05734 L
s
P
p
.2 0 1 r
.018 w
.59898 .2561 m
.4299 .13326 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.70618 .29094 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.59898 .2561 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.32838 .41369 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .84249 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .31246 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.44618 .57748 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.55382 .57748 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0499794 1.09996 0.027499 1.09996 [
[ 0 0 0 0 ]
[ 1 1.15496 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.15496 L
0 1.15496 L
closepath
clip
newpath
p
P
p
.8 0 1 r
.02 w
.40102 .2561 m
.5701 .13326 L
s
P
p
.8 0 1 r
.02 w
.40102 .2561 m
.4656 .05734 L
s
P
p
.8 0 1 r
.02 w
.29382 .29094 m
.12474 .16809 L
s
P
p
.8 0 1 r
.02 w
.29382 .29094 m
.08483 .29094 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.40102 .2561 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.29382 .29094 L
s
P
p
.8 0 1 r
.02 w
.29382 .86402 m
.08483 .86402 L
s
P
p
.8 0 1 r
.02 w
.29382 .86402 m
.12474 .98686 L
s
P
p
.8 0 1 r
.02 w
.40102 .89885 m
.4656 1.09761 L
s
P
p
.8 0 1 r
.02 w
.40102 .89885 m
.5701 1.02169 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.29382 .86402 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.40102 .89885 L
s
P
p
.8 0 1 r
.02 w
.73787 .43522 m
.90695 .55806 L
s
P
p
.8 0 1 r
.02 w
.73787 .43522 m
.94686 .43522 L
s
P
p
.8 0 1 r
.02 w
.67162 .34403 m
.7362 .14526 L
s
P
p
.8 0 1 r
.02 w
.67162 .34403 m
.60704 .14526 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.73787 .43522 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.67162 .34403 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .31246 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .84249 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.67162 .41369 L
s
P
p
.8 0 1 r
.02 w
.32838 .34403 m
.39296 .14526 L
s
P
p
.8 0 1 r
.02 w
.32838 .34403 m
.2638 .14526 L
s
P
p
.8 0 1 r
.02 w
.26213 .43522 m
.05314 .43522 L
s
P
p
.8 0 1 r
.02 w
.26213 .43522 m
.09305 .55806 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.32838 .34403 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.26213 .43522 L
s
P
p
.8 0 1 r
.02 w
.59898 .89885 m
.4299 1.02169 L
s
P
p
.8 0 1 r
.02 w
.59898 .89885 m
.5344 1.09761 L
s
P
p
.8 0 1 r
.02 w
.70618 .86402 m
.87526 .98686 L
s
P
p
.8 0 1 r
.02 w
.70618 .86402 m
.91517 .86402 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.59898 .89885 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.70618 .86402 L
s
P
p
.8 0 1 r
.02 w
.70618 .29094 m
.91517 .29094 L
s
P
p
.8 0 1 r
.02 w
.70618 .29094 m
.87526 .16809 L
s
P
p
.8 0 1 r
.02 w
.59898 .2561 m
.5344 .05734 L
s
P
p
.8 0 1 r
.02 w
.59898 .2561 m
.4299 .13326 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.70618 .29094 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.59898 .2561 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.32838 .41369 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .84249 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .31246 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.44618 .57748 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.55382 .57748 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00111824 0.997764 0.0249441 0.997764 [
[ 0 0 0 0 ]
[ 1 1.04765 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.04765 L
0 1.04765 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.31877 .24524 m
.43231 .08897 L
s
P
p
.2 0 1 r
.02 w
.31877 .24524 m
.31877 .05208 L
s
P
p
.2 0 1 r
.02 w
.23449 .30647 m
.05078 .24678 L
s
P
p
.2 0 1 r
.02 w
.23449 .30647 m
.05078 .36616 L
s
P
p
0 .4 1 r
.018 w
.29888 .30647 m
.31877 .24524 L
s
P
p
0 .4 1 r
.018 w
.29888 .30647 m
.23449 .30647 L
s
P
p
.2 0 1 r
.02 w
.30944 .77967 m
.11628 .77967 L
s
P
p
.2 0 1 r
.02 w
.30944 .77967 m
.15317 .89321 L
s
P
p
.2 0 1 r
.02 w
.40852 .81187 m
.46821 .99557 L
s
P
p
.2 0 1 r
.02 w
.40852 .81187 m
.56479 .9254 L
s
P
p
0 .4 1 r
.018 w
.37067 .75978 m
.30944 .77967 L
s
P
p
0 .4 1 r
.018 w
.37067 .75978 m
.40852 .81187 L
s
P
p
.2 0 1 r
.02 w
.74729 .47309 m
.86083 .62936 L
s
P
p
.2 0 1 r
.02 w
.74729 .47309 m
.931 .53278 L
s
P
p
.2 0 1 r
.02 w
.7151 .37401 m
.82863 .21774 L
s
P
p
.2 0 1 r
.02 w
.7151 .37401 m
.7151 .18085 L
s
P
p
0 .4 1 r
.018 w
.6952 .43525 m
.74729 .47309 L
s
P
p
0 .4 1 r
.018 w
.6952 .43525 m
.7151 .37401 L
s
P
p
.2 0 1 r
.016 w
.45026 .51483 m
.29888 .30647 L
s
P
p
.2 0 1 r
.016 w
.45026 .51483 m
.37067 .75978 L
s
P
p
.2 0 1 r
.016 w
.45026 .51483 m
.6952 .43525 L
s
P
p
.2 0 1 r
.02 w
.2849 .37401 m
.2849 .18085 L
s
P
p
.2 0 1 r
.02 w
.2849 .37401 m
.17137 .21774 L
s
P
p
.2 0 1 r
.02 w
.25271 .47309 m
.069 .53278 L
s
P
p
.2 0 1 r
.02 w
.25271 .47309 m
.13917 .62936 L
s
P
p
0 .4 1 r
.018 w
.3048 .43525 m
.2849 .37401 L
s
P
p
0 .4 1 r
.018 w
.3048 .43525 m
.25271 .47309 L
s
P
p
.2 0 1 r
.02 w
.59148 .81187 m
.43521 .9254 L
s
P
p
.2 0 1 r
.02 w
.59148 .81187 m
.53179 .99557 L
s
P
p
.2 0 1 r
.02 w
.69056 .77967 m
.84683 .89321 L
s
P
p
.2 0 1 r
.02 w
.69056 .77967 m
.88372 .77967 L
s
P
p
0 .4 1 r
.018 w
.62933 .75978 m
.59148 .81187 L
s
P
p
0 .4 1 r
.018 w
.62933 .75978 m
.69056 .77967 L
s
P
p
.2 0 1 r
.02 w
.76551 .30647 m
.94922 .36616 L
s
P
p
.2 0 1 r
.02 w
.76551 .30647 m
.94922 .24678 L
s
P
p
.2 0 1 r
.02 w
.68123 .24524 m
.68123 .05208 L
s
P
p
.2 0 1 r
.02 w
.68123 .24524 m
.56769 .08897 L
s
P
p
0 .4 1 r
.018 w
.70112 .30647 m
.76551 .30647 L
s
P
p
0 .4 1 r
.018 w
.70112 .30647 m
.68123 .24524 L
s
P
p
.2 0 1 r
.016 w
.54974 .51483 m
.3048 .43525 L
s
P
p
.2 0 1 r
.016 w
.54974 .51483 m
.62933 .75978 L
s
P
p
.2 0 1 r
.016 w
.54974 .51483 m
.70112 .30647 L
s
P
p
1 .6 0 r
.016 w
.5 .36175 m
.45026 .51483 L
s
P
p
1 .6 0 r
.016 w
.5 .36175 m
.54974 .51483 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0496309 1.09926 0.0274815 1.09926 [
[ 0 0 0 0 ]
[ 1 1.15422 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.15422 L
0 1.15422 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.40589 .2696 m
.58627 .13855 L
s
P
p
.2 0 1 r
.02 w
.40589 .2696 m
.47479 .05755 L
s
P
p
.2 0 1 r
.02 w
.29152 .30676 m
.11115 .17571 L
s
P
p
.2 0 1 r
.02 w
.29152 .30676 m
.06856 .30676 L
s
P
p
0 .4 1 r
.018 w
.3622 .32973 m
.40589 .2696 L
s
P
p
0 .4 1 r
.018 w
.3622 .32973 m
.29152 .30676 L
s
P
p
.2 0 1 r
.02 w
.29152 .84747 m
.06856 .84747 L
s
P
p
.2 0 1 r
.02 w
.29152 .84747 m
.11115 .97852 L
s
P
p
.2 0 1 r
.02 w
.40589 .88462 m
.47479 1.09667 L
s
P
p
.2 0 1 r
.02 w
.40589 .88462 m
.58627 1.01568 L
s
P
p
0 .4 1 r
.018 w
.3622 .8245 m
.29152 .84747 L
s
P
p
0 .4 1 r
.018 w
.3622 .8245 m
.40589 .88462 L
s
P
p
.2 0 1 r
.02 w
.72371 .44718 m
.90408 .57824 L
s
P
p
.2 0 1 r
.02 w
.72371 .44718 m
.94666 .44718 L
s
P
p
.2 0 1 r
.02 w
.65302 .3499 m
.72192 .13785 L
s
P
p
.2 0 1 r
.02 w
.65302 .3499 m
.58413 .13785 L
s
P
p
0 .4 1 r
.018 w
.65302 .42422 m
.72371 .44718 L
s
P
p
0 .4 1 r
.018 w
.65302 .42422 m
.65302 .3499 L
s
P
p
.2 0 1 r
.016 w
.44259 .57711 m
.3622 .32973 L
s
P
p
.2 0 1 r
.016 w
.44259 .57711 m
.3622 .8245 L
s
P
p
.2 0 1 r
.016 w
.44259 .57711 m
.65302 .42422 L
s
P
p
.2 0 1 r
.02 w
.34698 .3499 m
.41587 .13785 L
s
P
p
.2 0 1 r
.02 w
.34698 .3499 m
.27808 .13785 L
s
P
p
.2 0 1 r
.02 w
.27629 .44718 m
.05334 .44718 L
s
P
p
.2 0 1 r
.02 w
.27629 .44718 m
.09592 .57824 L
s
P
p
0 .4 1 r
.018 w
.34698 .42422 m
.34698 .3499 L
s
P
p
0 .4 1 r
.018 w
.34698 .42422 m
.27629 .44718 L
s
P
p
.2 0 1 r
.02 w
.59411 .88462 m
.41373 1.01568 L
s
P
p
.2 0 1 r
.02 w
.59411 .88462 m
.52521 1.09667 L
s
P
p
.2 0 1 r
.02 w
.70848 .84747 m
.88885 .97852 L
s
P
p
.2 0 1 r
.02 w
.70848 .84747 m
.93144 .84747 L
s
P
p
0 .4 1 r
.018 w
.6378 .8245 m
.59411 .88462 L
s
P
p
0 .4 1 r
.018 w
.6378 .8245 m
.70848 .84747 L
s
P
p
.2 0 1 r
.02 w
.70848 .30676 m
.93144 .30676 L
s
P
p
.2 0 1 r
.02 w
.70848 .30676 m
.88885 .17571 L
s
P
p
.2 0 1 r
.02 w
.59411 .2696 m
.52521 .05755 L
s
P
p
.2 0 1 r
.02 w
.59411 .2696 m
.41373 .13855 L
s
P
p
0 .4 1 r
.018 w
.6378 .32973 m
.70848 .30676 L
s
P
p
0 .4 1 r
.018 w
.6378 .32973 m
.59411 .2696 L
s
P
p
.2 0 1 r
.016 w
.55741 .57711 m
.34698 .42422 L
s
P
p
.2 0 1 r
.016 w
.55741 .57711 m
.6378 .8245 L
s
P
p
.2 0 1 r
.016 w
.55741 .57711 m
.6378 .32973 L
s
P
p
1 .6 0 r
.016 w
.5 .40041 m
.44259 .57711 L
s
P
p
1 .6 0 r
.016 w
.5 .40041 m
.55741 .57711 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0499794 1.09996 0.027499 1.09996 [
[ 0 0 0 0 ]
[ 1 1.15496 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.15496 L
0 1.15496 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.5701 .13326 L
s
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.4656 .05734 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.12474 .16809 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.08483 .29094 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.40102 .2561 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.29382 .29094 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.08483 .86402 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.12474 .98686 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.4656 1.09761 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.5701 1.02169 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.29382 .86402 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.40102 .89885 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.90695 .55806 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.94686 .43522 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.7362 .14526 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.60704 .14526 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.73787 .43522 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.67162 .34403 L
s
P
p
.2 0 1 r
.014 w
.44618 .57748 m
.36007 .31246 L
s
P
p
.2 0 1 r
.014 w
.44618 .57748 m
.36007 .84249 L
s
P
p
.2 0 1 r
.014 w
.44618 .57748 m
.67162 .41369 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.39296 .14526 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.2638 .14526 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.05314 .43522 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.09305 .55806 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.32838 .34403 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.26213 .43522 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.4299 1.02169 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.5344 1.09761 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.87526 .98686 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.91517 .86402 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.59898 .89885 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.70618 .86402 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.91517 .29094 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.87526 .16809 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.5344 .05734 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.4299 .13326 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.70618 .29094 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.59898 .2561 L
s
P
p
.2 0 1 r
.014 w
.55382 .57748 m
.32838 .41369 L
s
P
p
.2 0 1 r
.014 w
.55382 .57748 m
.63993 .84249 L
s
P
p
.2 0 1 r
.014 w
.55382 .57748 m
.63993 .31246 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.44618 .57748 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.55382 .57748 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0499794 1.09996 0.027499 1.09996 [
[ 0 0 0 0 ]
[ 1 1.15496 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.15496 L
0 1.15496 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.5701 .13326 L
s
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.4656 .05734 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.12474 .16809 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.08483 .29094 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.40102 .2561 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.29382 .29094 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.08483 .86402 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.12474 .98686 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.4656 1.09761 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.5701 1.02169 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.29382 .86402 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.40102 .89885 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.90695 .55806 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.94686 .43522 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.7362 .14526 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.60704 .14526 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.73787 .43522 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.67162 .34403 L
s
P
p
.8 0 1 r
.016 w
.44618 .57748 m
.36007 .31246 L
s
P
p
.8 0 1 r
.016 w
.44618 .57748 m
.36007 .84249 L
s
P
p
.8 0 1 r
.016 w
.44618 .57748 m
.67162 .41369 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.39296 .14526 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.2638 .14526 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.05314 .43522 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.09305 .55806 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.32838 .34403 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.26213 .43522 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.4299 1.02169 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.5344 1.09761 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.87526 .98686 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.91517 .86402 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.59898 .89885 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.70618 .86402 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.91517 .29094 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.87526 .16809 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.5344 .05734 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.4299 .13326 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.70618 .29094 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.59898 .2561 L
s
P
p
.8 0 1 r
.016 w
.55382 .57748 m
.32838 .41369 L
s
P
p
.8 0 1 r
.016 w
.55382 .57748 m
.63993 .84249 L
s
P
p
.8 0 1 r
.016 w
.55382 .57748 m
.63993 .31246 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.44618 .57748 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.55382 .57748 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0953259 1.19065 0.0297663 1.19065 [
[ 0 0 0 0 ]
[ 1 1.25018 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.25018 L
0 1.25018 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.42676 .34884 m
.63395 .41616 L
s
P
p
.2 0 1 r
.02 w
.42676 .34884 m
.63395 .28152 L
s
P
p
.2 0 1 r
.02 w
.3317 .27978 m
.3317 .06192 L
s
P
p
.2 0 1 r
.02 w
.3317 .27978 m
.20365 .10353 L
s
P
p
.2 0 1 r
.02 w
.29539 .39152 m
.0882 .45884 L
s
P
p
.2 0 1 r
.02 w
.29539 .39152 m
.16734 .56777 L
s
P
p
0 .4 1 r
.018 w
.35414 .34884 m
.42676 .34884 L
s
P
p
0 .4 1 r
.018 w
.35414 .34884 m
.3317 .27978 L
s
P
p
0 .4 1 r
.018 w
.35414 .34884 m
.29539 .39152 L
s
P
p
.2 0 1 r
.02 w
.29539 .85866 m
.16734 .68242 L
s
P
p
.2 0 1 r
.02 w
.29539 .85866 m
.0882 .79134 L
s
P
p
.2 0 1 r
.02 w
.3317 .97041 m
.20365 1.14666 L
s
P
p
.2 0 1 r
.02 w
.3317 .97041 m
.3317 1.18826 L
s
P
p
.2 0 1 r
.02 w
.42676 .90135 m
.63395 .96867 L
s
P
p
.2 0 1 r
.02 w
.42676 .90135 m
.63395 .83403 L
s
P
p
0 .4 1 r
.018 w
.35414 .90135 m
.29539 .85866 L
s
P
p
0 .4 1 r
.018 w
.35414 .90135 m
.3317 .97041 L
s
P
p
0 .4 1 r
.018 w
.35414 .90135 m
.42676 .90135 L
s
P
p
.2 0 1 r
.02 w
.70134 .52342 m
.70134 .74127 L
s
P
p
.2 0 1 r
.02 w
.70134 .52342 m
.82939 .69967 L
s
P
p
.2 0 1 r
.02 w
.73764 .41167 m
.94483 .34435 L
s
P
p
.2 0 1 r
.02 w
.73764 .41167 m
.86569 .23543 L
s
P
p
.2 0 1 r
.02 w
.62015 .41167 m
.4921 .23543 L
s
P
p
.2 0 1 r
.02 w
.62015 .41167 m
.41296 .34435 L
s
P
p
0 .4 1 r
.018 w
.6789 .45436 m
.70134 .52342 L
s
P
p
0 .4 1 r
.018 w
.6789 .45436 m
.73764 .41167 L
s
P
p
0 .4 1 r
.018 w
.6789 .45436 m
.62015 .41167 L
s
P
p
.2 0 1 r
.016 w
.4439 .62509 m
.35414 .34884 L
s
P
p
.2 0 1 r
.016 w
.4439 .62509 m
.35414 .90135 L
s
P
p
.2 0 1 r
.016 w
.4439 .62509 m
.6789 .45436 L
s
P
p
.2 0 1 r
.02 w
.37985 .41167 m
.58704 .34435 L
s
P
p
.2 0 1 r
.02 w
.37985 .41167 m
.5079 .23543 L
s
P
p
.2 0 1 r
.02 w
.26236 .41167 m
.13431 .23543 L
s
P
p
.2 0 1 r
.02 w
.26236 .41167 m
.05517 .34435 L
s
P
p
.2 0 1 r
.02 w
.29866 .52342 m
.17061 .69967 L
s
P
p
.2 0 1 r
.02 w
.29866 .52342 m
.29866 .74127 L
s
P
p
0 .4 1 r
.018 w
.3211 .45436 m
.37985 .41167 L
s
P
p
0 .4 1 r
.018 w
.3211 .45436 m
.26236 .41167 L
s
P
p
0 .4 1 r
.018 w
.3211 .45436 m
.29866 .52342 L
s
P
p
.2 0 1 r
.02 w
.57324 .90135 m
.36605 .83403 L
s
P
p
.2 0 1 r
.02 w
.57324 .90135 m
.36605 .96867 L
s
P
p
.2 0 1 r
.02 w
.6683 .97041 m
.6683 1.18826 L
s
P
p
.2 0 1 r
.02 w
.6683 .97041 m
.79635 1.14666 L
s
P
p
.2 0 1 r
.02 w
.70461 .85866 m
.9118 .79134 L
s
P
p
.2 0 1 r
.02 w
.70461 .85866 m
.83266 .68242 L
s
P
p
0 .4 1 r
.018 w
.64586 .90135 m
.57324 .90135 L
s
P
p
0 .4 1 r
.018 w
.64586 .90135 m
.6683 .97041 L
s
P
p
0 .4 1 r
.018 w
.64586 .90135 m
.70461 .85866 L
s
P
p
.2 0 1 r
.02 w
.70461 .39152 m
.83266 .56777 L
s
P
p
.2 0 1 r
.02 w
.70461 .39152 m
.9118 .45884 L
s
P
p
.2 0 1 r
.02 w
.6683 .27978 m
.79635 .10353 L
s
P
p
.2 0 1 r
.02 w
.6683 .27978 m
.6683 .06192 L
s
P
p
.2 0 1 r
.02 w
.57324 .34884 m
.36605 .28152 L
s
P
p
.2 0 1 r
.02 w
.57324 .34884 m
.36605 .41616 L
s
P
p
0 .4 1 r
.018 w
.64586 .34884 m
.70461 .39152 L
s
P
p
0 .4 1 r
.018 w
.64586 .34884 m
.6683 .27978 L
s
P
p
0 .4 1 r
.018 w
.64586 .34884 m
.57324 .34884 L
s
P
p
.2 0 1 r
.016 w
.5561 .62509 m
.3211 .45436 L
s
P
p
.2 0 1 r
.016 w
.5561 .62509 m
.64586 .90135 L
s
P
p
.2 0 1 r
.016 w
.5561 .62509 m
.64586 .34884 L
s
P
p
1 .6 0 r
.016 w
.5 .45243 m
.4439 .62509 L
s
P
p
1 .6 0 r
.016 w
.5 .45243 m
.5561 .62509 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0380075 1.07601 0.0269004 1.07601 [
[ 0 0 0 0 ]
[ 1 1.12982 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.12982 L
0 1.12982 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.40785 .24549 m
.59711 .14906 L
s
P
p
.2 0 1 r
.02 w
.40785 .24549 m
.50428 .05623 L
s
P
p
.2 0 1 r
.02 w
.28785 .28448 m
.0986 .18805 L
s
P
p
.2 0 1 r
.02 w
.28785 .28448 m
.07806 .31771 L
s
P
p
0 .4 1 r
.018 w
.35778 .29556 m
.40785 .24549 L
s
P
p
0 .4 1 r
.018 w
.35778 .29556 m
.28785 .28448 L
s
P
p
.2 0 1 r
.02 w
.28785 .84533 m
.07806 .81211 L
s
P
p
.2 0 1 r
.02 w
.28785 .84533 m
.0986 .94177 L
s
P
p
.2 0 1 r
.02 w
.40785 .88432 m
.50428 1.07358 L
s
P
p
.2 0 1 r
.02 w
.40785 .88432 m
.59711 .98076 L
s
P
p
0 .4 1 r
.018 w
.35778 .83426 m
.28785 .84533 L
s
P
p
0 .4 1 r
.018 w
.35778 .83426 m
.40785 .88432 L
s
P
p
.2 0 1 r
.02 w
.73751 .43058 m
.88771 .58078 L
s
P
p
.2 0 1 r
.02 w
.73751 .43058 m
.9473 .46381 L
s
P
p
.2 0 1 r
.02 w
.66335 .32851 m
.69658 .11872 L
s
P
p
.2 0 1 r
.02 w
.66335 .32851 m
.56692 .13925 L
s
P
p
0 .4 1 r
.018 w
.67442 .39844 m
.73751 .43058 L
s
P
p
0 .4 1 r
.018 w
.67442 .39844 m
.66335 .32851 L
s
P
p
.2 0 1 r
.016 w
.4453 .56491 m
.35778 .29556 L
s
P
p
.2 0 1 r
.016 w
.4453 .56491 m
.35778 .83426 L
s
P
p
.2 0 1 r
.016 w
.4453 .56491 m
.67442 .39844 L
s
P
p
.2 0 1 r
.02 w
.33665 .32851 m
.43308 .13925 L
s
P
p
.2 0 1 r
.02 w
.33665 .32851 m
.30342 .11872 L
s
P
p
.2 0 1 r
.02 w
.26249 .43058 m
.0527 .46381 L
s
P
p
.2 0 1 r
.02 w
.26249 .43058 m
.11229 .58078 L
s
P
p
0 .4 1 r
.018 w
.32558 .39844 m
.33665 .32851 L
s
P
p
0 .4 1 r
.018 w
.32558 .39844 m
.26249 .43058 L
s
P
p
.2 0 1 r
.02 w
.59215 .88432 m
.40289 .98076 L
s
P
p
.2 0 1 r
.02 w
.59215 .88432 m
.49572 1.07358 L
s
P
p
.2 0 1 r
.02 w
.71215 .84533 m
.9014 .94177 L
s
P
p
.2 0 1 r
.02 w
.71215 .84533 m
.92194 .81211 L
s
P
p
0 .4 1 r
.018 w
.64222 .83426 m
.59215 .88432 L
s
P
p
0 .4 1 r
.018 w
.64222 .83426 m
.71215 .84533 L
s
P
p
.2 0 1 r
.02 w
.71215 .28448 m
.92194 .31771 L
s
P
p
.2 0 1 r
.02 w
.71215 .28448 m
.9014 .18805 L
s
P
p
.2 0 1 r
.02 w
.59215 .24549 m
.49572 .05623 L
s
P
p
.2 0 1 r
.02 w
.59215 .24549 m
.40289 .14906 L
s
P
p
0 .4 1 r
.018 w
.64222 .29556 m
.71215 .28448 L
s
P
p
0 .4 1 r
.018 w
.64222 .29556 m
.59215 .24549 L
s
P
p
.2 0 1 r
.016 w
.5547 .56491 m
.32558 .39844 L
s
P
p
.2 0 1 r
.016 w
.5547 .56491 m
.64222 .83426 L
s
P
p
.2 0 1 r
.016 w
.5547 .56491 m
.64222 .29556 L
s
P
p
1 .6 0 r
.016 w
.5 .39656 m
.4453 .56491 L
s
P
p
1 .6 0 r
.016 w
.5 .39656 m
.5547 .56491 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0611679 1.12234 0.0280584 1.12234 [
[ 0 0 0 0 ]
[ 1 1.17845 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.17845 L
0 1.17845 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.37119 .27306 m
.55351 .14059 L
s
P
p
.2 0 1 r
.02 w
.37119 .27306 m
.44083 .05872 L
s
P
p
.2 0 1 r
.02 w
.31339 .29184 m
.13106 .15937 L
s
P
p
.2 0 1 r
.02 w
.31339 .29184 m
.08802 .29184 L
s
P
p
0 .4 1 r
.018 w
.34911 .30345 m
.37119 .27306 L
s
P
p
0 .4 1 r
.018 w
.34911 .30345 m
.31339 .29184 L
s
P
p
.2 0 1 r
.02 w
.31339 .88661 m
.08802 .88661 L
s
P
p
.2 0 1 r
.02 w
.31339 .88661 m
.13106 1.01908 L
s
P
p
.2 0 1 r
.02 w
.37119 .90539 m
.44083 1.11973 L
s
P
p
.2 0 1 r
.02 w
.37119 .90539 m
.55351 1.03786 L
s
P
p
0 .4 1 r
.018 w
.34911 .87501 m
.31339 .88661 L
s
P
p
0 .4 1 r
.018 w
.34911 .87501 m
.37119 .90539 L
s
P
p
.2 0 1 r
.02 w
.72079 .42421 m
.90311 .55668 L
s
P
p
.2 0 1 r
.02 w
.72079 .42421 m
.94615 .42421 L
s
P
p
.2 0 1 r
.02 w
.68506 .37504 m
.75471 .16071 L
s
P
p
.2 0 1 r
.02 w
.68506 .37504 m
.61542 .16071 L
s
P
p
0 .4 1 r
.018 w
.68506 .4126 m
.72079 .42421 L
s
P
p
0 .4 1 r
.018 w
.68506 .4126 m
.68506 .37504 L
s
P
p
.2 0 1 r
.016 w
.44197 .58923 m
.34911 .30345 L
s
P
p
.2 0 1 r
.016 w
.44197 .58923 m
.34911 .87501 L
s
P
p
.2 0 1 r
.016 w
.44197 .58923 m
.68506 .4126 L
s
P
p
.2 0 1 r
.02 w
.31494 .37504 m
.38458 .16071 L
s
P
p
.2 0 1 r
.02 w
.31494 .37504 m
.24529 .16071 L
s
P
p
.2 0 1 r
.02 w
.27921 .42421 m
.05385 .42421 L
s
P
p
.2 0 1 r
.02 w
.27921 .42421 m
.09689 .55668 L
s
P
p
0 .4 1 r
.018 w
.31494 .4126 m
.31494 .37504 L
s
P
p
0 .4 1 r
.018 w
.31494 .4126 m
.27921 .42421 L
s
P
p
.2 0 1 r
.02 w
.62881 .90539 m
.44649 1.03786 L
s
P
p
.2 0 1 r
.02 w
.62881 .90539 m
.55917 1.11973 L
s
P
p
.2 0 1 r
.02 w
.68661 .88661 m
.86894 1.01908 L
s
P
p
.2 0 1 r
.02 w
.68661 .88661 m
.91198 .88661 L
s
P
p
0 .4 1 r
.018 w
.65089 .87501 m
.62881 .90539 L
s
P
p
0 .4 1 r
.018 w
.65089 .87501 m
.68661 .88661 L
s
P
p
.2 0 1 r
.02 w
.68661 .29184 m
.91198 .29184 L
s
P
p
.2 0 1 r
.02 w
.68661 .29184 m
.86894 .15937 L
s
P
p
.2 0 1 r
.02 w
.62881 .27306 m
.55917 .05872 L
s
P
p
.2 0 1 r
.02 w
.62881 .27306 m
.44649 .14059 L
s
P
p
0 .4 1 r
.018 w
.65089 .30345 m
.68661 .29184 L
s
P
p
0 .4 1 r
.018 w
.65089 .30345 m
.62881 .27306 L
s
P
p
.2 0 1 r
.016 w
.55803 .58923 m
.31494 .4126 L
s
P
p
.2 0 1 r
.016 w
.55803 .58923 m
.65089 .87501 L
s
P
p
.2 0 1 r
.016 w
.55803 .58923 m
.65089 .30345 L
s
P
p
1 .6 0 r
.016 w
.5 .41061 m
.44197 .58923 L
s
P
p
1 .6 0 r
.016 w
.5 .41061 m
.55803 .58923 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.21445 1.4289 0.0357225 1.4289 [
[ 0 0 0 0 ]
[ 1 1.50034 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.50034 L
0 1.50034 L
closepath
clip
newpath
p
P
p
1 .6 0 r
.016 w
.5 .09955 m
.0772 1.40079 L
s
P
p
1 .6 0 r
.016 w
.5 .09955 m
.9228 1.40079 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00226622 0.952381 [
[ 0 0 0 0 ]
[ 1 .94785 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .94785 L
0 .94785 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.46123 .19062 m
.62871 .1362 L
s
P
p
.2 0 1 r
.02 w
.46123 .19062 m
.56474 .04815 L
s
P
p
.2 0 1 r
.02 w
.36626 .19062 m
.26275 .04815 L
s
P
p
.2 0 1 r
.02 w
.36626 .19062 m
.19878 .1362 L
s
P
p
0 .4 1 r
.018 w
.41375 .22512 m
.46123 .19062 L
s
P
p
0 .4 1 r
.018 w
.41375 .22512 m
.36626 .19062 L
s
P
p
.2 0 1 r
.02 w
.21704 .64986 m
.04956 .59545 L
s
P
p
.2 0 1 r
.02 w
.21704 .64986 m
.04956 .70428 L
s
P
p
.2 0 1 r
.02 w
.29388 .70569 m
.29388 .88178 L
s
P
p
.2 0 1 r
.02 w
.29388 .70569 m
.39738 .84815 L
s
P
p
0 .4 1 r
.018 w
.27574 .64986 m
.21704 .64986 L
s
P
p
0 .4 1 r
.018 w
.27574 .64986 m
.29388 .70569 L
s
P
p
.2 0 1 r
.02 w
.68453 .42186 m
.78804 .56432 L
s
P
p
.2 0 1 r
.02 w
.68453 .42186 m
.85201 .47627 L
s
P
p
.2 0 1 r
.02 w
.65519 .33153 m
.75869 .18907 L
s
P
p
.2 0 1 r
.02 w
.65519 .33153 m
.65519 .15544 L
s
P
p
0 .4 1 r
.018 w
.63705 .38736 m
.68453 .42186 L
s
P
p
0 .4 1 r
.018 w
.63705 .38736 m
.65519 .33153 L
s
P
p
.2 0 1 r
.016 w
.41375 .45991 m
.41375 .22512 L
s
P
p
.2 0 1 r
.016 w
.41375 .45991 m
.27574 .64986 L
s
P
p
.2 0 1 r
.016 w
.41375 .45991 m
.63705 .38736 L
s
P
p
.2 0 1 r
.02 w
.38013 .24216 m
.48364 .0997 L
s
P
p
.2 0 1 r
.02 w
.38013 .24216 m
.38013 .06607 L
s
P
p
.2 0 1 r
.02 w
.30329 .29799 m
.13582 .24357 L
s
P
p
.2 0 1 r
.02 w
.30329 .29799 m
.13582 .3524 L
s
P
p
0 .4 1 r
.018 w
.36199 .29799 m
.38013 .24216 L
s
P
p
0 .4 1 r
.018 w
.36199 .29799 m
.30329 .29799 L
s
P
p
.2 0 1 r
.02 w
.45251 .75723 m
.28504 .81165 L
s
P
p
.2 0 1 r
.02 w
.45251 .75723 m
.34901 .8997 L
s
P
p
.2 0 1 r
.02 w
.54749 .75723 m
.65099 .8997 L
s
P
p
.2 0 1 r
.02 w
.54749 .75723 m
.71496 .81165 L
s
P
p
0 .4 1 r
.018 w
.5 .72273 m
.45251 .75723 L
s
P
p
0 .4 1 r
.018 w
.5 .72273 m
.54749 .75723 L
s
P
p
.2 0 1 r
.02 w
.69671 .29799 m
.86418 .3524 L
s
P
p
.2 0 1 r
.02 w
.69671 .29799 m
.86418 .24357 L
s
P
p
.2 0 1 r
.02 w
.61987 .24216 m
.61987 .06607 L
s
P
p
.2 0 1 r
.02 w
.61987 .24216 m
.51636 .0997 L
s
P
p
0 .4 1 r
.018 w
.63801 .29799 m
.69671 .29799 L
s
P
p
0 .4 1 r
.018 w
.63801 .29799 m
.61987 .24216 L
s
P
p
.2 0 1 r
.016 w
.5 .48794 m
.36199 .29799 L
s
P
p
.2 0 1 r
.016 w
.5 .48794 m
.5 .72273 L
s
P
p
.2 0 1 r
.016 w
.5 .48794 m
.63801 .29799 L
s
P
p
.2 0 1 r
.02 w
.34481 .33153 m
.34481 .15544 L
s
P
p
.2 0 1 r
.02 w
.34481 .33153 m
.24131 .18907 L
s
P
p
.2 0 1 r
.02 w
.31547 .42186 m
.14799 .47627 L
s
P
p
.2 0 1 r
.02 w
.31547 .42186 m
.21196 .56432 L
s
P
p
0 .4 1 r
.018 w
.36295 .38736 m
.34481 .33153 L
s
P
p
0 .4 1 r
.018 w
.36295 .38736 m
.31547 .42186 L
s
P
p
.2 0 1 r
.02 w
.70612 .70569 m
.60262 .84815 L
s
P
p
.2 0 1 r
.02 w
.70612 .70569 m
.70612 .88178 L
s
P
p
.2 0 1 r
.02 w
.78296 .64986 m
.95044 .70428 L
s
P
p
.2 0 1 r
.02 w
.78296 .64986 m
.95044 .59545 L
s
P
p
0 .4 1 r
.018 w
.72426 .64986 m
.70612 .70569 L
s
P
p
0 .4 1 r
.018 w
.72426 .64986 m
.78296 .64986 L
s
P
p
.2 0 1 r
.02 w
.63374 .19062 m
.80122 .1362 L
s
P
p
.2 0 1 r
.02 w
.63374 .19062 m
.73725 .04815 L
s
P
p
.2 0 1 r
.02 w
.53877 .19062 m
.43526 .04815 L
s
P
p
.2 0 1 r
.02 w
.53877 .19062 m
.37129 .1362 L
s
P
p
0 .4 1 r
.018 w
.58625 .22512 m
.63374 .19062 L
s
P
p
0 .4 1 r
.018 w
.58625 .22512 m
.53877 .19062 L
s
P
p
.2 0 1 r
.016 w
.58625 .45991 m
.36295 .38736 L
s
P
p
.2 0 1 r
.016 w
.58625 .45991 m
.72426 .64986 L
s
P
p
.2 0 1 r
.016 w
.58625 .45991 m
.58625 .22512 L
s
P
p
1 .6 0 r
.016 w
.5 .34119 m
.41375 .45991 L
s
P
p
1 .6 0 r
.016 w
.5 .34119 m
.5 .48794 L
s
P
p
1 .6 0 r
.016 w
.5 .34119 m
.58625 .45991 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.00715727 1.01431 0.0253579 1.01431 [
[ 0 0 0 0 ]
[ 1 1.06503 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.06503 L
0 1.06503 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.43148 .22676 m
.60532 .13818 L
s
P
p
.2 0 1 r
.02 w
.43148 .22676 m
.52005 .05292 L
s
P
p
.2 0 1 r
.02 w
.32755 .24322 m
.18959 .10526 L
s
P
p
.2 0 1 r
.02 w
.32755 .24322 m
.13485 .2127 L
s
P
p
0 .4 1 r
.018 w
.38549 .27274 m
.43148 .22676 L
s
P
p
0 .4 1 r
.018 w
.38549 .27274 m
.32755 .24322 L
s
P
p
.2 0 1 r
.02 w
.24385 .77164 m
.05115 .74112 L
s
P
p
.2 0 1 r
.02 w
.24385 .77164 m
.07002 .86021 L
s
P
p
.2 0 1 r
.02 w
.33761 .81941 m
.36813 1.01211 L
s
P
p
.2 0 1 r
.02 w
.33761 .81941 m
.47557 .95737 L
s
P
p
0 .4 1 r
.018 w
.30809 .76146 m
.24385 .77164 L
s
P
p
0 .4 1 r
.018 w
.30809 .76146 m
.33761 .81941 L
s
P
p
.2 0 1 r
.02 w
.71592 .4411 m
.85388 .57906 L
s
P
p
.2 0 1 r
.02 w
.71592 .4411 m
.90862 .47162 L
s
P
p
.2 0 1 r
.02 w
.66815 .34735 m
.75672 .17351 L
s
P
p
.2 0 1 r
.02 w
.66815 .34735 m
.63762 .15464 L
s
P
p
0 .4 1 r
.018 w
.65797 .41158 m
.71592 .4411 L
s
P
p
0 .4 1 r
.018 w
.65797 .41158 m
.66815 .34735 L
s
P
p
.2 0 1 r
.016 w
.42619 .52968 m
.38549 .27274 L
s
P
p
.2 0 1 r
.016 w
.42619 .52968 m
.30809 .76146 L
s
P
p
.2 0 1 r
.016 w
.42619 .52968 m
.65797 .41158 L
s
P
p
.2 0 1 r
.02 w
.33185 .34735 m
.36238 .15464 L
s
P
p
.2 0 1 r
.02 w
.33185 .34735 m
.24328 .17351 L
s
P
p
.2 0 1 r
.02 w
.28408 .4411 m
.09138 .47162 L
s
P
p
.2 0 1 r
.02 w
.28408 .4411 m
.14612 .57906 L
s
P
p
0 .4 1 r
.018 w
.34203 .41158 m
.33185 .34735 L
s
P
p
0 .4 1 r
.018 w
.34203 .41158 m
.28408 .4411 L
s
P
p
.2 0 1 r
.02 w
.66239 .81941 m
.52443 .95737 L
s
P
p
.2 0 1 r
.02 w
.66239 .81941 m
.63187 1.01211 L
s
P
p
.2 0 1 r
.02 w
.75615 .77164 m
.92998 .86021 L
s
P
p
.2 0 1 r
.02 w
.75615 .77164 m
.94885 .74112 L
s
P
p
0 .4 1 r
.018 w
.69191 .76146 m
.66239 .81941 L
s
P
p
0 .4 1 r
.018 w
.69191 .76146 m
.75615 .77164 L
s
P
p
.2 0 1 r
.02 w
.67245 .24322 m
.86515 .2127 L
s
P
p
.2 0 1 r
.02 w
.67245 .24322 m
.81041 .10526 L
s
P
p
.2 0 1 r
.02 w
.56852 .22676 m
.47995 .05292 L
s
P
p
.2 0 1 r
.02 w
.56852 .22676 m
.39468 .13818 L
s
P
p
0 .4 1 r
.018 w
.61451 .27274 m
.67245 .24322 L
s
P
p
0 .4 1 r
.018 w
.61451 .27274 m
.56852 .22676 L
s
P
p
.2 0 1 r
.016 w
.57381 .52968 m
.34203 .41158 L
s
P
p
.2 0 1 r
.016 w
.57381 .52968 m
.69191 .76146 L
s
P
p
.2 0 1 r
.016 w
.57381 .52968 m
.61451 .27274 L
s
P
p
1 .6 0 r
.016 w
.5 .38481 m
.42619 .52968 L
s
P
p
1 .6 0 r
.016 w
.5 .38481 m
.57381 .52968 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0627898 1.12558 0.0281395 1.12558 [
[ 0 0 0 0 ]
[ 1 1.18186 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.18186 L
0 1.18186 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.3877 .26207 m
.56072 .13637 L
s
P
p
.2 0 1 r
.02 w
.3877 .26207 m
.45379 .05868 L
s
P
p
.2 0 1 r
.02 w
.278 .29771 m
.10499 .17201 L
s
P
p
.2 0 1 r
.02 w
.278 .29771 m
.06414 .29771 L
s
P
p
0 .4 1 r
.018 w
.3458 .31974 m
.3877 .26207 L
s
P
p
0 .4 1 r
.018 w
.3458 .31974 m
.278 .29771 L
s
P
p
.2 0 1 r
.02 w
.278 .88415 m
.06414 .88415 L
s
P
p
.2 0 1 r
.02 w
.278 .88415 m
.10499 1.00985 L
s
P
p
.2 0 1 r
.02 w
.3877 .91979 m
.45379 1.12318 L
s
P
p
.2 0 1 r
.02 w
.3877 .91979 m
.56072 1.04549 L
s
P
p
0 .4 1 r
.018 w
.3458 .86212 m
.278 .88415 L
s
P
p
0 .4 1 r
.018 w
.3458 .86212 m
.3877 .91979 L
s
P
p
.2 0 1 r
.02 w
.7324 .44535 m
.90541 .57106 L
s
P
p
.2 0 1 r
.02 w
.7324 .44535 m
.94626 .44535 L
s
P
p
.2 0 1 r
.02 w
.6646 .35204 m
.73069 .14865 L
s
P
p
.2 0 1 r
.02 w
.6646 .35204 m
.59851 .14865 L
s
P
p
0 .4 1 r
.018 w
.6646 .42333 m
.7324 .44535 L
s
P
p
0 .4 1 r
.018 w
.6646 .42333 m
.6646 .35204 L
s
P
p
.2 0 1 r
.016 w
.43391 .59093 m
.3458 .31974 L
s
P
p
.2 0 1 r
.016 w
.43391 .59093 m
.3458 .86212 L
s
P
p
.2 0 1 r
.016 w
.43391 .59093 m
.6646 .42333 L
s
P
p
.2 0 1 r
.02 w
.3354 .35204 m
.40149 .14865 L
s
P
p
.2 0 1 r
.02 w
.3354 .35204 m
.26931 .14865 L
s
P
p
.2 0 1 r
.02 w
.2676 .44535 m
.05374 .44535 L
s
P
p
.2 0 1 r
.02 w
.2676 .44535 m
.09459 .57106 L
s
P
p
0 .4 1 r
.018 w
.3354 .42333 m
.3354 .35204 L
s
P
p
0 .4 1 r
.018 w
.3354 .42333 m
.2676 .44535 L
s
P
p
.2 0 1 r
.02 w
.6123 .91979 m
.43928 1.04549 L
s
P
p
.2 0 1 r
.02 w
.6123 .91979 m
.54621 1.12318 L
s
P
p
.2 0 1 r
.02 w
.722 .88415 m
.89501 1.00985 L
s
P
p
.2 0 1 r
.02 w
.722 .88415 m
.93586 .88415 L
s
P
p
0 .4 1 r
.018 w
.6542 .86212 m
.6123 .91979 L
s
P
p
0 .4 1 r
.018 w
.6542 .86212 m
.722 .88415 L
s
P
p
.2 0 1 r
.02 w
.722 .29771 m
.93586 .29771 L
s
P
p
.2 0 1 r
.02 w
.722 .29771 m
.89501 .17201 L
s
P
p
.2 0 1 r
.02 w
.6123 .26207 m
.54621 .05868 L
s
P
p
.2 0 1 r
.02 w
.6123 .26207 m
.43928 .13637 L
s
P
p
0 .4 1 r
.018 w
.6542 .31974 m
.722 .29771 L
s
P
p
0 .4 1 r
.018 w
.6542 .31974 m
.6123 .26207 L
s
P
p
.2 0 1 r
.016 w
.56609 .59093 m
.3354 .42333 L
s
P
p
.2 0 1 r
.016 w
.56609 .59093 m
.6542 .86212 L
s
P
p
.2 0 1 r
.016 w
.56609 .59093 m
.6542 .31974 L
s
P
p
1 .6 0 r
.016 w
.5 .38754 m
.43391 .59093 L
s
P
p
1 .6 0 r
.016 w
.5 .38754 m
.56609 .59093 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0499794 1.09996 0.027499 1.09996 [
[ 0 0 0 0 ]
[ 1 1.15496 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.15496 L
0 1.15496 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.5701 .13326 L
s
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.4656 .05734 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.12474 .16809 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.08483 .29094 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.40102 .2561 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.29382 .29094 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.08483 .86402 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.12474 .98686 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.4656 1.09761 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.5701 1.02169 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.29382 .86402 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.40102 .89885 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.90695 .55806 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.94686 .43522 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.7362 .14526 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.60704 .14526 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.73787 .43522 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.67162 .34403 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .31246 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .84249 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.67162 .41369 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.39296 .14526 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.2638 .14526 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.05314 .43522 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.09305 .55806 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.32838 .34403 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.26213 .43522 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.4299 1.02169 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.5344 1.09761 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.87526 .98686 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.91517 .86402 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.59898 .89885 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.70618 .86402 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.91517 .29094 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.87526 .16809 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.5344 .05734 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.4299 .13326 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.70618 .29094 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.59898 .2561 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.32838 .41369 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .84249 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .31246 L
s
P
p
1 .6 0 r
.014 w
.5 .41184 m
.44618 .57748 L
s
P
p
1 .6 0 r
.014 w
.5 .41184 m
.55382 .57748 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0499794 1.09996 0.027499 1.09996 [
[ 0 0 0 0 ]
[ 1 1.15496 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.15496 L
0 1.15496 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.5701 .13326 L
s
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.4656 .05734 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.12474 .16809 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.08483 .29094 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.40102 .2561 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.29382 .29094 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.08483 .86402 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.12474 .98686 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.4656 1.09761 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.5701 1.02169 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.29382 .86402 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.40102 .89885 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.90695 .55806 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.94686 .43522 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.7362 .14526 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.60704 .14526 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.73787 .43522 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.67162 .34403 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .31246 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .84249 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.67162 .41369 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.39296 .14526 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.2638 .14526 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.05314 .43522 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.09305 .55806 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.32838 .34403 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.26213 .43522 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.4299 1.02169 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.5344 1.09761 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.87526 .98686 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.91517 .86402 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.59898 .89885 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.70618 .86402 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.91517 .29094 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.87526 .16809 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.5344 .05734 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.4299 .13326 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.70618 .29094 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.59898 .2561 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.32838 .41369 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .84249 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .31246 L
s
P
p
.8 1 0 r
.016 w
.5 .41184 m
.44618 .57748 L
s
P
p
.8 1 0 r
.016 w
.5 .41184 m
.55382 .57748 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0344054 0.952381 [
[ 0 0 0 0 ]
[ 1 .88357 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88357 L
0 .88357 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.83792 .46216 L
s
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.87107 .36016 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.69614 .11939 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.58888 .11939 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.69753 .36016 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.64251 .28443 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.13629 .26644 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.04952 .32948 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.04952 .6271 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.13629 .69014 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .43149 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .52509 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.58888 .83719 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.69614 .83719 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.87107 .59642 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.83792 .49442 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.64251 .67215 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.69753 .59642 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.55821 .10942 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.47144 .04638 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.18839 .13834 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.15525 .24035 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.41781 .21142 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.32879 .24035 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .34228 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.22392 .47829 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .6143 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.38381 .25822 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.84475 .24035 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.81161 .13834 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.52856 .04638 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.44179 .10942 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.67121 .24035 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.58219 .21142 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.16208 .49442 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.12893 .59642 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.30386 .83719 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.41112 .83719 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.30247 .59642 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.35749 .67215 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.86371 .69014 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.95048 .6271 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.95048 .32948 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.86371 .26644 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .52509 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .43149 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.41112 .11939 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.30386 .11939 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.12893 .36016 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.16208 .46216 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.35749 .28443 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.30247 .36016 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.61619 .25822 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .6143 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.77608 .47829 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .34228 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.45531 .47829 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.54469 .47829 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`0001H000==04d080000dd0C@0N0003C@0000<000==00007@000dd0000O0003C@1=020000==04d0
80000d80@P0G00005P000d`0C00P0003C01<01h000M<04`0C01<01h00d`P0003C01<020000=<04`0
80000d80@P0G0000400014d00003C@0404e=C@8000==00004`0014d00003C@0404e=C@8000==0000
4@001dd0001=04d00P001Td004d0C@<000==00004@000dd0C@0200==0P000dd0C@0E0004C@0000M=
0`000dd0000C0003C@0000==00@0CDe=0`000dd0000C0003@P0000=200@0@T920`000d80000?0000
3@02C00304`000801d`20003C000009<3P02C00304`000801d`20003C000009<3`02C08000]<04`0
C01<04`0C002009<3P02C0<000A<04`00T`01`1<C01<04`00`02C0d00T`00`1<000200=<00@0C4a<
0`0014`0C4`>009<0P000d`00007C0<000A<04a<3P02@P8000=200001d830004@P12@Ph0000?0007
C@1=04d0C@030007C@1=04d0C@0B0007C@1=04d0C@030007C@1=04d0C@0?009=00H0C@00C@07C@06
04d004d00Td>009=00H0C@1=04d30006C@1=04d00TdA0007C@1=04d0C@030007C@1=04d0C@0B0007
C@1=04d0C@030007C@1=04d0C@0B0007@P120480@P030007@P120480@P0@00004002C00304c600D0
00?6C0000T`D009<00<0C;@01@000kA<0002C1800d`0101<0<H2C00704a<aP1<0003C0d014`01P1<
04`0aPD000K604`0C004C0l00T`00`1<aP050003aT`0009<5002C00304c600D000?6C0000T`D0092
00<0@/H01@000lI20002@Q40000;00M=00?6CLH01@001<I=a/H5C@/01dd00kA=]0050004]4fd]0E=
4003C@0304d000@000G60<K6C@0C009=00C6C@361@001<H0a/H2C@l01Td00lI=00060003CLK600E=
3005C@04aTe=aPD000C6CLK61Dd<00E200C6@T;61@001<I2a/H6@P`0000B009<1`02C1P00T`7009<
4`03C00404a<C0L00d`0101<C4`C0003aT`000H000=<aP005`000lI<00060003C<H001L00T`7009<
60000d9<00060003C4800180000B0003aTd000H000==aP005`000kA=00060003CK@001000dd40003
aTd000H000==aP001002CA4000?6C@001P000dg6000G0003aTd000H000==aP005`000lI=00060003
CLH001L000?6C@001P000dg6000B00004@000lI<C00300034@0000=<5`000kA<C00300034@0000=<
5003C0030<I<00H000=<0<H00P03C18000?6C4`00`000a400003C003aP0001@000C6C4a<0P000a40
0003C003aP0001@000C6C4a<0P0011400002C003aP0001@000C6C4a<0P0011400002C003aP000100
000;00E=00G60000C@0200044@00C@8000?6CDd014d:00E=00Fd0000C@0200044@00C@8000>dCDd0
14d?0003CLI=009=0P000a400003C@03aTe=01000dd01LH0001=008000@A001=0`001<I=CDd<00E=
00G60000C@0200044@00C@<000?6CDd00dd:00E=00G60000C@0200044@00C@<000?6CDd00dd:00E2
00G60000C@0200044@00C@<000?6@T800d8<00003P000d`00003009<0Q42C0D00T`@0003C00000<0
0T`24@9<1@02C0l00d`01@1<001<008000@A04a<0P000d`00003C0X01D`5009<0Q42C0H01D`<0003
C00000<00T`00a404@02C0D000=<00003P000d`00004009<0Q42C0D000=<00003P000d800004009<
0Q42C0D000=200003@0000d000==000010001Td04DdAC@L000==000030000dd000040006C@0ACA5=
1`000dd0000:009=0`0014d00002C@8A0Td40003C@00008000==00002@000dd000050006C@0ACA5=
20000dd0000;0003C@0000@000M=015=4@1=00H000==000030000dd000050006CA5=4@1=1P000dd0
000<0003@P0000D000I=4DdA04d60003@P0000`0000<0003C00000H000E<4D`AC0080003C00000X0
00=<00001P001D`AC15<00P000=<00003@000d`000030005C15<4D`01@000d`0000<0003C00000L0
00E<4D`AC0090003C00000T000=<00001P001D`A015<00P000=<00002P000d`000060005C15<4D`0
20000d`0000:0003@P0000H000E<4D`AC0080003@P0000/0000E00044@004Al000@A000A60000dd0
000400044@004@L000==00005@001140014O00054@0001407`001140014O00044@004AH0000E0004
C000C1l000A<001<5`000d`000050004C000C0P000=<0000500014`004`O0005C00004`07`0014`0
04`O0004C000C1H0000E0005C@0004d07P001Dd0001=01h000E=0000C@0N0005C@0004d07P001Dd0
001=01h000E=0000C@0N0005C@0004d05P0001@000=<00000P000d`0000K0003C000008000=<0000
6`000d`000020003C00001/000=<00000P000d`0000K0003C00000<000=<00006`000d`000020003
C00001/000=<00000P000d`0000C000050000dd000030003C@0001X000==00000`000dd0000J0003
C@0000<000==00006P000dd000030003C@0001X000==00000`000dd0000J0003C@0000<000==0000
6P000dd000030003C@0001<0000D0003C00000<000=<00006P000d`000030003C00001X000=<0000
0`000d`0000J0003C00000<000=<00006P000d`000030003C00001X000=<00000`000d`0000J0003
C00000<000=<00004`0001<000==000010000dd0000I0003C@0000@000==00004P02C@D000==0000
10000dd00004009=4`000dd000040003C@0001X000==00000`000dd0000J0003C@0000@000==0000
6@000dd000040003C@000180000B0003aT`000H000=<aP005`000kA<00060003C;@001<00d`00`36
C0070003C<H000=<50000lI<00060003C<H001P000=<00001@000d`0000G0003aT`000H000=<aP00
5`000lI<00060003C<H00180000;00I=00?60<H01`000lH0aP05C@/01Td00k@0]0070003]02d00E=
400014g60<H70004aP36CA800dd00lH0aP070003aP3600==3P05C@;600==00001@000dg6aP05C@`0
1Dd00lH0aP070003aP3600E=3005@P03aP3600L000?60<H01T8<00003`000d`000020003aT`00080
00=<aP000`000d`0000@0003C000008000>dC0000P000dbd00030003C00000h00d`01@1<003600E<
00G6001<0003C0`01D`40003aP0000<000?600000P05C0h000=<00000P000lI<00020003C<H000<0
00=<000040000d`000020003aT`0008000=<aP000`000d`0000@0003@P00008000?6@P000P000d;6
00030003@P0000h0000>0003C@0000<000==04d00Td00`1=00040003C@0000h000==00000`000dd0
C@02C@0304d000@000==000030001Dd0001=00<00dd0101=CDd30005C@0004d03@000dd00004009=
0`02C@H000==00003@000dd000030007C@1=04d0C@050003C@0000h000==00000`000dd0C@02C@03
04d000@000==00003P000d8000030003@P12009200<0@P0010000d80000=00003@000d`00005009<
00<0C4`01`000d`0000<0003C00000D00T`00`1<C0070003C00000h000=<00000P001d`0C01<04`0
10000d`0000=0003C00000H00T`00`1<C0080003C00000/000=<00001@001D`0C01<00L000=<0000
30000d`00005009<00<0C4`01`000d`0000<0003@P0000D00T800`12@P070003@P0000`0000E0005
C@0004d07P001Dd0001=01L000==00000`0014d004d20003C@0000<000==00005P03CAl00Td00`1=
C@0N0005C@0004d07P001D80001201H0000E0005C00004`07P001D`0001<01d000M<04`0C01<01h0
00=<04`07`001D`0001<01h000E<0000C00N0005@P0004805P0001H000==04d080000dd0C@0N0003
C@0000<000==00007@000dd0000O0003C@1=020000==04d080000d80@P0G0000o`030000o`030000
o`030000o`030000o`030000o`0300004@000d`000080003C00001X000=<04`080000d`0C00P0003
C01<01d000=<00001@000d`0000L0003C00001h000E<0000C00F00004@001Dd0001=00<000A=001=
70000dd0C@0P0003C@1=020000==04d06@001Dd0001=00L000E=0000C@0D0003C@0000<000==0000
0`000dd0000H0005C@0004d05P00014000E<0000C0030004C000C1L000A<00000T`00`1<C0030003
C00001<000A<00000d`0101<C4`20003C00001<000A<00000d`0101<C4`20003C00001<000A<001<
1`0014`004`E0003C00000=<00@0C4a<0P000d`0000@009<00<0C0000P07C0<000A<04a<3P000140
00A=001=1@000dd0C@0B009=0`002Dd0001=04d0C@030004C@00009=3@02C@0304d000801dd20003
C@00009=3P02C@0304d000801dd20003C@00009=4P000dd0C@070003C@1=01400Td30004C@0000E=
0`0014d00002C@l00Td30003C@1=00A=0`02CA00000@009<00<0C0001P03C1<000I<0000C003C006
04a<C01<0`000d`0000?0007C01<04`0C0030007C01<04`0C00B0007C01<04`0C0030007C01<04`0
C00A0004C000009<0`0014`00002C0<000=<00003P02C00404`000=<00@0C4a<0P0014`0C4`B009<
00@0C4a<1002C00304a<0140000=0003C@0000==2003C@<000==00003P001Dd004d0009=0`02C@05
04d004d04`02C@0304g600D000?6C@000TdD009=00<0CLH01@000lI=0002CA8000==00000P001/I=
C@1=009=00?600000P000dd0000@0005C@1=CLH01@001LI=C@1=01D000A=04g61P000lH0C@0B0000
2@05C08000=<aP002@001/I<001<00A<3@001D`0C01<00D000G604`0C00@00I<00?6C<H01@001<I<
a/H5C0`01T`00lI<aP050004aTc6aPE<3`001D`0003600800d`20005aP0004`04@03C003aTa<00L0
00=<a/H00d`>00I<00?6C0001P000dc6C005C0d0000=009=00?6CDd02`000dg6aP02C@`01Td2aP03
C@0000D000==a/H01TdA009=1`02CAP000==@P001P000d9=000A009=0P001Dd004g6009=00D0CLK6
C@020003C@00009=2`03C@@000?6C@001P000dg6000300==4@02C@L00TdC00002`03C00404a<C0/0
0T`300=<4@000lH000050003C00001L000?6C0001P000dc6000G0003aT8000H000=2aP004`04C003
aT`000E<00<0C<H014`D0003aT`000H000=<aP005`000lI<00060003C<H001800009009=1@000lH0
C@0400034@00008000==aP001P000dd0000>0005aP0001400P000dg6000H0003aTd0008000HA001=
0<HH0003aT80008000HA00120<HD00==00C6CLI=1@0014g6CLH3CA<000C6CDe=0P000a400003C@03
aP0001D00dd200034@0000==4`00010000?604`010001a40001<0<H04006C0;60T`200034@00009<
0/H6C0X01D`2aP=<0P000a400003C003aTa<00A<2P05C0;60d8200034@0000=20/H5C0`000A<0000
14`200034@0000A<0`000d`0000<00=<00G60000C00200044@00C0<000C6C4a<3006C004aP00C080
00@A001<0P000lI<C004C0`0000@0004aTe=C@800Q420004C@1=CA@000==00000P02C@8A00<0C@00
10000dd0000?0003C@0000<000E=014A0002C@@00Td@0003C@0000<000E2014A0002@PD000==0000
400014d0aP02C@030140009=00@0aP1=3P03C@8000==00000P02C@034@0A009=10000dd00003C@`0
0Td4009=00<A01400Td4009=3`0000h000=<aP000P03C0034@0A00=<0P000lI<C00@0003C00000<0
00I<015<4D`60003C00000d000=<00001002C0044@0AC0L000=<000030000d`00004009200@A0152
1`000d`0000?0003C01<00800T`00a5<C0020003C01<018000=<00000`001d`04D`A04`01@000d`0
000=0003C00000@000M<015<4@1<00H000=<0000300000/00dd00`1=00030006C@0ACA5=10000dd0
0003C@`000==00001@001DdACA5=00L000==00002`000dd000060005CA5=4Dd020000dd0000:0003
C@0000H000E24D8A@P080003C@0000d000A=04e=0P001DdACA5=00800Td00`1=000?0003C@0000D0
00E=4@0AC@070003C@0000/000==00001P001DdA015=00P000==00002`0000X000E<0000C0060004
4@004@H000=<00000P000d`000080003C00000H000@A000A2@000d`0000C00044@004Al000@A000A
6P000d`0C00300034@0A00<000=<04`040000d`0000600054@00014020000d`0000C00054@000140
5P0000d000==00001@0014d004d70003C@0001D000A=001=7`0014d004dO0004@P00@QT00Td00`1=
00020003C@1=00<000A=04e=60001Dd0001=01h000E=0000C@0F00003@000d`000050005C00004`0
1`000d`0000D0005C00004`07P001D`0001<01h000E20000@P0H0004C000C08000E<0000C0020004
C000C1P000E<0000C00N0005C00004`05P0000`000==00001@000dd000020003C@0000H000==0000
4P000dd000020003C@0001/000==00000P000dd0000K0003@P00008000=200005`000dd0C@020005
C@0004d00P000dd0C@0H0003C@0000<000==00006P000dd000030003C@0001<0000D0003C00000<0
00=<00006P000d`000030003C00001X000=<00000`000d`0000J0003@P0000<000=200004`02C080
00A<001<1@0014`004`2009<5@000d`000030003C00001X000=<00000`000d`0000C000050000dd0
00030003C@0001X000==00000`000dd0000J0003C@0000<000==00006P000d8000030003@P0001D0
0dd2009=0`02C@800ddG0003C@0000<000==00006P000dd000030003C@0001<0000C0003C00000@0
00=<00006@000d`000040003C00001T000=<000010000d`0000I0003@P0000@000=2000060001<H0
C003C00404`0aQX000=<00000`000d`0000J0003C00000<000=<00004`00018000?6C@001P000dg6
000@00I=0/H00dd000050003CLK600I=4@000lI=00060003CLH001L000?6@P001P000d;6000H0006
CLK6C@1=0/H00dd0000@00A=10000dd000050003C@00008014dB0003C@0000D000==00004P0000/0
1T`00lH0aP070003aP3600I<3P001D`0003600L000G60000C00?00E<00?60<H01`000lH0aP05C0`0
1D`00lH0aP070003aP3600E<4`000lH0C004C0030<H001D00T`2aP03C00000D000=<a/H00T`?00I<
00?6C0001P000dc6C005C0d0000>009=10000lI=00020003CLH000<000==00003`000dd000030003
aTd0008000==aP0010000dd0000?0003C@00008000?6C@000P000dg600030003C@00010000==0000
0P000lI=00020003CLH000<000==000050000lI=00040003CLH001@00Td40003aTd0008000==aP00
0`02CA8000I=0000aTd40005CLH004d04@0000d000=<000010000d`0C002C00304`000@000=<0000
3@000d`000040003C01<009<00<0C0001@000d`0000=0003C00000<000=<04`00T`00`1<00040003
C00000h000=<00000`000d`0C002C00304`000@000=<00004P02C0L00T`C0003C00000@000=<04`0
0T`00`1<00050003C00000h000=<00000P000d`0C003C00304`0008000=<00003P0000`000==0000
1P02C@0304e=00L000==00002`000dd00006009=00<0CDd020000dd0000;0003C@0000D00Td00`1=
C@070003C@0000`000==00001@02C@0304e=00L000==000040000dd0C@070003C@1=014000==0000
1P02C@0304e=00P000==000030000dd000030003C@00009=00<0C@0010000dd0000=00005@001D`0
001<01h000E<0000C00N0005C00004`07P001D`0001<01T000A<001<1`0014`004`H0007C01<04`0
C00E0003C00000D00T`2009<1P000d`0000<00005@001Dd0001=01h000E=0000C@0N0005C@0004d0
7P001Dd0001=01P000E=0000C@070005C@0004d06@000dd0C@0O0003C@00008000==00004`0001H0
00=<04`080000d`0C00P0003C01<020000=<04`07@000d`000050003C00001`000=<00007P001D`0
001<01H0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0000G00034@00048000==04d0
80000dd0C@0P0003C@1=020000==04d0>P0001L000<A000060001d`0001<04`00`000d`0C0020003
C000010000=<00001@000d`0C0070003C00001H000=<04`080000d`0C00P0003C01<020000=<04`0
5`0001L000<A00006@001Dd004d000==00@0C@1=0P000dd0000A0003C@0000800Td00`1=0002C@@0
00==00004P000dd00003C@0404e=C@8000==00004`0014d00003C@0404e=C@<000==00004`000dd0
0003C@0404e=C@<000==000060000dd0C@0G00005P000a404@0G00=<00<0C0000T`01@1<C4`0009<
00<0C0000T`A009<0P000d`00003C08000=<00000T`?009<0`000d`00007C08000A<00000T`=009<
00<0C0000P07C0<000A<04a<3P02C08000=<00001d`30004C01<C1H00T`00`1<C00F00005P000a40
4@0J00A=00<0CDd00dd00`1=C@02CA0014d0101=04d20003C@1=008000A=04d014d>009=0P0014d0
CDd3009=00@0C@000TdA0007C@1=04d0C@030007C@1=04d0C@0B0007C@1=04d0C@030007C@1=04d0
C@0@009=0P000dd00002C@0304d0009=0P001Dd0001=00h0000F00034@0A01T000=<00000d`2aP06
0<K60<I<0P000d`0000A009<00C6C0360`001<H0a/H2C1@000E<04`0C0050005aP1<04`05002C003
04c600D000?6C0000T`D009<00<0C<H01@000lI<0002C1<000=<04`00P03C00404a<C08000A<001<
3`0001D000DA00004@0H0003C@0000==1@03C@8000==00004@000dd00002C@D00Td20003C@0000d0
1Td01<I=CLH50004aTg6aPI=2`06C@03aTg600D000C6CLK61Dd<00E=00C6CDg61@001<I=a/H5CA00
00A=04d00Td300==00@0C@1=400001D000DA00004@0D00A<00H0C01<aT`50006C<I<04`00d`A009<
00<0C000100014`0C4`H0003C00000D000=<00005`02C0L00T`H009<1`02C1L00d`00lH000030005
aTa<04`04@0001D000DA00004@0H00I=1@02C@;60TdD009=00<0C@00100014d0CDdH0003aP0000D0
00==00005`000lI=00060003CLH001L000?6C@001P000dg6000@00U=1`000dg6aP06C@`0000D0003
4@0000<000<A00004`03C00304a<009<1@04C00404a<C1<000?604`01@000d`0aP0I0005aP000140
0`000d`0000G0003aP1<008000HA001<0<HH0003aP1<008000KO0000C<HA0003C00000D000?60000
1@000dc600050003C00000X0000D00034@0000<000<A00004@02C@D000?604d00P001Q4004d0aPD0
00==00003`001<I=CDd200034@0000==4@06C@;60Td200034@00009=0/H6C@X01Dd2aP==0P000a40
0003C@;61Dd:00E=0/H3C@8000?N00000dd2aPE=200014d004d60003aTd000@000==0<H01@0014d0
04d:000050000a40000300034@0001P000?6C4`00P000a400002C003aP0001800T`01<H00002C003
0140009<0P001<I<C4`A0003C00000800T`00a404@02C0@000=<000040000d`00002009<00<04@00
0T`40003C000010000=<00000P02C0050=oO04`010000d`0000;00M<0/H2C08000<A00000d`00lI<
C005C0/0000C00034@0000D000<A00005@0014g60002C@<A0Td20003aTd000h00dd00`1=00040005
CA404Dd01@000dd0C@02C@d000==00000`001dd04DdA04d01@000dd0000>0003C@0000@000E=4@0A
C@060003C@0000h000==0000100014gN0=h2C@D000==00002`02C@8000==00000`0014d04@02C@@0
00==00000Td<00004`000a40000500034@0001800d`02`1<001<4D`AC15<008000=<04`00T`?0003
C00000@000E<4D`AC0060003C00000d000=<00001@001D`A015<00L000=<000030000d`000050005
C15<4D`01`000d`0000<0003C00000D000E<gdcOC0070003C00000/00d`6009<00<AC4`01P03C0d0
000C00034@0000D000<A00004@001Dd0001=00<000LA04dAC@0A00<000E=0000C@0=0003C@0000D0
00DA00004@070003C@0000/000==00001P001A40000A00P000==00002P000dd0000700034@0A00T0
00==00002P000dd000070004gP00gPP000==00002`000dd000050005CA5=4Dd01`000lH0000<0000
4P000a40000700034@0001<000=<00000P0014`001420003C000008000=<00003@000d`000060005
C00004`020000d`0000C0005C00004`07`000d`0C00P0004C000C1D000=<04`01d`00a5<4@08C003
04`000`0000B00034@0000L000<A00004`001Dd0001=00<000E=0000C@030003C@0001D000==0000
0`000dd0000K0005C@0004d07P001Dd0001=01h000E=0000C@0E009=00?600001P02C@L000?6CDd0
3@00018000<A00001`000a40000B0005C00004`010000d`000020005C00004`05P000d`000030003
C00001X000=<00000`000d`0000K0005C00004`07P000d`000020003C000018000A<aTa<1P0014`0
04`5009<00?6C0003000014000<A00002@000a40000<009=1`000dd000020003C@00008000==0000
1@02CA0000==00001@000dd0000I0003C@0000<000==00006P000dd000030003C@0001X000==0000
0`000dd0000A0003C@1=008000==00000P000dd000020005C@0004d00P000dd0C@0<00004@000a40
000900034@0000h00d`30003C00000<000=<00000`0014`00003C14000=<00001`000d`0000H0003
C00000<000=<00006P000d`000030003C00001X000=<00000`000d`0000@00M<0/H00`1<00050003
C03600M<2`00014000<A00002@000a40000?009=0/H00dd000040003C@0000@000==a/H00dd900A=
10000dd000070003C@0000<00ddA0003C@0000D000==00006@000dd000030003C@0001X000==0000
10000dd0000>0004C@00C@H000==00001P000dd000030004C@00C@X0000@00034@0000/000<A0000
2`03C0@000?6000010000d`000030003aP0000@00T`;0004C<K6C0/000=<a/H00T`C0003aT`000H0
00=<aP005`000lI<00060003C<H001L000?6C0001P000dc6000A0003C00000@000?600001P000lH0
00030003C00000/0000@00034@0000/000<A00004P000dd000030003aTd000@000==00003`02C@<0
00?600002@001<H00002C@/01Td00lH0aP070003aP3600I=2`05C@03aP3600L000?60<H01Dd<00E=
00?60<H01`000lH0aP05C@/000==00001@000dd000060003C@0000@000==00002P00010000<A0000
2`000a40000B009<0P001Dc60036009<00<0C4`040000d`000040003aP0000L000?6000010000d`0
000;009<10000lI<00020003C<H000<00T`A0003C000008000?6C0000P000dc600030003C0000100
00=<00000P000lI<00020003C<H000<000=<00004`02C0L00T`C00003`000a40000=00034@000140
14d01@1=001=00800dd?0003C@0000D00Td7009=1`000dd000090003C@0000@000==04d00Td00`1=
00050003C@0000d000==00000`000dd0C@02C@0304d000@000==00003P000dd000030003C@1=009=
00<0C@0010000dd0000B009=1`02CA<0000?00034@0000d000<A00004@000d`00002C0@000A<04`0
0T`F0003C01<00D000=<04`04P000d`00006009<00<0C4`020000d`0000;0003C00000D00T`00`1<
C0070003C00000`000=<00001@02C00304a<00L000=<00004@000d`0C0060003C01<0180000?0003
4@0000d000<A00004@000dd00002C@D000A=001=60000dd0C@030003C@1=01`000E=0000C@0N0005
C@0004d07P001Dd0001=01X000A=001=1@0014d004dB00003P000a40000?00034@00010000A<001<
1`000d`0C00H0006C000C01<0P000d`0000J0005C00004`07P001D`0001<01h000E<0000C00J0004
C000C0D000A<001<4P0000h000<A00003`000a40000B0003C@0000L000==00005`000dd000050003
C@0001/000==04d080000dd0C@0P0003C@1=03X0003o00<0003o00<0003o00<0003o00<00000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.27001, -0.109418, 
  0.0329416, 0.0329416}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42399,
   -0.109418, 0.0329416, 0.0329416}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57798, -0.109418, 0.0329416, 0.0329416}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.73197, -0.109418, 0.0329416, 0.0329416}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88593, -0.109418, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.03993,
   -0.109418, 0.0329416, 0.0329416}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.19391, -0.109418, 0.0329416, 0.0329416}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.271519, -1.26686, 0.0330062, 0.0330062}, {{42.5, 74.3125},
   {69.375, 37.5625}} -> {-1.42776, -1.26686, 0.0330061, 0.0330061}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.58402, -1.26687, 0.0330063, 0.0330063},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74028, -1.26687, 0.0330063, 
  0.0330063}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.89651, -1.26686, 
  0.0330062, 0.0330062}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05282,
   -1.26688, 0.0330065, 0.0330065}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.20897, -1.26686, 0.033006, 0.033006}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.269997, -2.41735, 0.0329411, 0.0329411}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57798, -2.41739, 0.0329416, 0.0329416}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.73196, -2.41738, 0.0329415, 
  0.0329415}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88595, -2.41739, 
  0.0329416, 0.0329416}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.03993,
   -2.41739, 0.0329416, 0.0329416}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1939, -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .88357 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0344054 0.952381 [
[ 0 0 0 0 ]
[ 1 .88357 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .88357 L
0 .88357 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.83792 .46216 L
s
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.87107 .36016 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.69614 .11939 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.58888 .11939 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.69753 .36016 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.64251 .28443 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.13629 .26644 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.04952 .32948 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.04952 .6271 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.13629 .69014 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .43149 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .52509 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.58888 .83719 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.69614 .83719 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.87107 .59642 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.83792 .49442 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.64251 .67215 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.69753 .59642 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.55821 .10942 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.47144 .04638 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.18839 .13834 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.15525 .24035 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.41781 .21142 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.32879 .24035 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .34228 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.22392 .47829 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .6143 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.38381 .25822 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.84475 .24035 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.81161 .13834 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.52856 .04638 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.44179 .10942 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.67121 .24035 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.58219 .21142 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.16208 .49442 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.12893 .59642 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.30386 .83719 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.41112 .83719 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.30247 .59642 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.35749 .67215 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.86371 .69014 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.95048 .6271 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.95048 .32948 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.86371 .26644 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .52509 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .43149 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.41112 .11939 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.30386 .11939 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.12893 .36016 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.16208 .46216 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.35749 .28443 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.30247 .36016 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.61619 .25822 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .6143 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.77608 .47829 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .34228 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.45531 .47829 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.54469 .47829 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{178, 157},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002b0000W@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000;80002b0000/P000;80002b0000/P000;80
002b0000DP03C@L00deC0000DP03C0L00daC0000D@04C@L014eB0000D@04C0L014aB0000D@03C@T0
0deB0000D004C0T014aA0000D004C@T014eA0000D003C0/00daA0000C`04C@/014e@0000C`04C0/0
14a@0000C`03C@d00de@0000C@05C0d01Da>0000C@05C@d01De>0000=003C1000d`300I<2`06C0<0
0d`@00=<=@0003@00dd@00==0`08C@L024d300==4003CCD0000d00A<3`03C0<02D`500U<0`03C0l0
14`e00008004CA0014d>00A=0`03C@0304e=00E=00<0CDd01Dd0101=CDd300A=3P04CA0014dQ0000
8005C1000d`>00A<0P04C0<02d`300A<0P04C0h00d`@00E<8@0002001Td?00A=3@03C@<014d400U=
1004C@<00dd=00A=3`06CB40000R00I<3@04C0`014`300=<1P07C0H00d`300A<3004C0d01T`S0000
8`06C@d00dd<00A=0P04C@D02Dd500A=0P04C@`00dd=00I=900002@01d`;00A<2`03C0<014`300e<
0`04C0<00d`;00A<2`07C2D0000V00I=2P04C@X014d300==0`06C@<01Td300==0`04C@X014d:00I=
9`0002L01T`:00=<2P04C08014`200I<1@06C08014`200A<2P03C0X01T`X0000:@06C@P014d900==
0`0:C@T02Td300==2@04C@P01TdZ0000:P06C0L014`800A<0`09C0/02D`300A<2004C0L01T`[0000
:`07C@H00dd800A=0P09C@d02Dd200A=2003C@H01dd/0000;@06C0D014`700=<0`07C1401d`300=<
1`04C0D01T`^0000;P06C@@014d600A=0`06CA<01Td300A=1P04C@@01Td_0000<006C0<00d`600A<
0P03aP9<5`02C0?60P04C0H00d`300I<<@0003401Td200A=1@03C@<00lH00dd0000G0004CLK6aP<0
0dd500A=0P06CC80000b00]<1@03C0801<HK00C60P03C0D02d`c0000=009C@@014d00`36aP03aQ/0
1LH00`1=C@02C@@02Dde0000=@09C0<014`5aQd01LH4C0<02D`f00006P0OC@03aTe=009=0`03C@03
0<K600;67`04aP0404e=C@<000==a/H00/HOCA/0000J01m<0/H3C0;614`4aR401<H4C0O67d`K0000
6P0OC@;614d00lI=C@02C@C68@0?aQm=6`0003/014`01<I<C4`4aR<03<Hl0000?008C@;69@000lI=
C@05aP9=?@0001L00d`R00Q<00?600009@02C0;61D`R00=<600001L00ddR00U=9P03C@0304e=00A=
8P03CAP0000G00=<8`05C00304a<02H00T`200E<8`03C1P0000G00A=8P001Tg6a/I=009=9P02C@80
00E=a/K6C@0R00A=600001L014`R0004C<K6aP800d`T00=<0`03aP03C000020014`H00006003CB<0
0lH3009=9002C@@00lHS00==6@0001P014`R00?60`02C2@00T`400?68P04C1T0000H00A=8P03aP<0
0ddR00==1003aR8014dI00006@03C2800lH4009<8P02C0D00lHR00=<6P0001T014dQ00?61002CB80
0Td500?68@04CAX0000I00A<8@03aP@00d`P00=<1@03aR4014`J00001`04C@l00ddQ00?61@02CB00
0Td600?68@03C@l014d800001`05C0h014`P00?61@02C2000T`600?68004C0h01D`800001`06C@d0
14dN00G61@03CAh00dd600G67P04C@d01Td800002@06C0`00d`K00G60d`6009<3P024@h00T`600=<
1/HK00=<3006C0X0000:00I=2`04CAL02<H4C@D00Td>008A3P02C@D014d9aQL014d;00I=2`0000/0
1d`301m<2/H200=<1003C0`0114<00=<1003C0<02/HOC0<01d`<00003@06C@807dd7aPH014d3009=
30044@`00Td300A=1`07aQm=0P06C@h0000>00I<00<0C4`07D`4aPX014`2009<30044@`00T`200A<
2`04aQm<00<0C4`014`?00004006C@H014d?00I=3`07C@X01Q4:00M=4006C@l014d600I=4@000140
1T`500A<3P06C1401T`:008A0P024@X01T`B00I<3P04C0D01T`B00004P07C@@00dd<00M=5004C@X0
0Q42008A2P04CAD01dd<00==1007CA<0000D00I<0`04C0X01T`G00A<20034@800a4800A<6006C0X0
14`300I<5@0001D01Td200A=2@06CAT014d7008A10024@L014dJ00I=2@04C@801TdF00005`06C004
04a<C0L01T`L00A<1P024@@00Q4600A<7@06C0L00d`00`1<C004C1P0000H00Y=1@06CAd01Td300<A
10034@<01TdN00I=1@0:CAT0000I00U<0`07C1l01T`2008A1P024@801T`P00M<0`09C1X0000K00M=
0P06CB400Td200A=0Q46008A14d2009=8P06C@801ddL0000700=C2800d`2009<0a4600<A0T`200=<
8`0=C1d0000N009=00?6CDd014dU009=10024@03C@0000@000==4A401002CBH014d3aP9=7`0001l0
1d`V009<10024@=<0P03C08A1002C2L00d`3aP03C00001h0000N00M=9`03C@800a48C@<A0P03CBP0
00==a/H00/H2CAl0000M00I<0/HX009<0P024@<014`3008A0P02C2T01LH3C1h0000L00I=1<HW009=
0P024@801Td2008A0P02CBP01LH5CAd0000K00E<0P04aRL00d`34@0304a<00I<00@04A4A0d`X00C6
0P05C1`0000K00A=1004aRL00Td24@A=1004C@8A0TdX00C61004CA`0000K00=<1@05aRH00T`24@=<
1P03C08A0T`W00G61@03C1`0000T00G69@001DdA4A5=00X000E=4A4AC@0V00G69@0002D000?6C4`0
9d`24@03C00000X000=<4A40:D`2aRH0000U0003aTe=02M=0Q42C@X00Td24BU=0/HV00006`04C0D0
1LHX00=<2003C2T01LH500A<700001/01Dd300G6:P04C@@014d[00G60`05CA`0000K00I<0P04aR`0
14`200A<;@04aP801T`L00007@06C@?6;`06CC001<H5CAh0000N00I<0/H`00A<<@05aP=<7`0001l0
1dd_00I=<0000dg6aP03aP03C@0001h0000N009<00?6C4`014`/00A<0P04C2d00d`4aP9<7`0001d0
0dd2aPI=:P04C@@014d[00E=0lH3CAh0000K00Q<00<0C4`014`W00=<2003C2P01T`00`1<C006C1`0
000J00U=0P06CB@014d:00A=9@06C@802DdK0000600:C0@01d`Q00A<3004C2801d`400Y<6@0001L0
1Td00`1=C@02C@H01TdN00A=4004CAl01Td600A=00<0CDd014dH00005P06C08014`700I<7004C180
14`M00I<1`04C0801T`G00005006C@@00dd:00I=6@03CAH00ddJ00I=2P03C@@01TdE00004`06C0@0
14`;00I<5P04C1P014`G00I<2`04C0@01T`D00004@07C@D014d<00M=4`04CAX014dD00M=3004C@D0
1ddB00004006C0L00d`?00I<4@03C1h00d`B00I<3`03C0L01T`A00003`06C@L014d@00I=3P04CB00
14d?00I=4004C@L01Td@00003@06C0807d`5aPX014`R00A<2`05aQm<0P06C0h0000<00I=0`0OC@S6
1@04CBH014d600S67dd300I=3@0000X01d`401m<2lH00`1<C002C2P014`200_67d`400M<2`0000T0
1Td<00A=6008aP==;003C@W66004C@`01Td:00002006C0d00d`L00C60d`^00=<1LHL00=<3@06C0T0
000700E=3`03CAl000C6CDg6;`02C@;67`03C@l01Dd800001`04C0l014`P00?6;`03aR0014`?00A<
200000L00dd@00A=8003aRl00lHP00A=4003C@P0000J00=<8@03aRl00lHQ00=<6`0001T014dQ00?6
;`03aR4014dJ00006@04C2400lH_00?68@04C1X0000I00==8P03aRl00lHR00==6P0001P014`R00?6
;`03aR8014`I00006004CB800lH_00?68P04CAT0000H00=<8`03aRl00lHS00=<6@0001L014dR0004
CLK6aRl00lH00dd0000P00A=600001L014`R00E<;@05C28014`H00005`03CB<01Dd]00E=8`03CAP0
000G00=<8P06C2d01T`R00=<600003`01dd[00M=?@0003`01d`[00M<?@0003/014d0101=CDd[00==
00<0CDd00Tdl0000>`04C00304a<009<:@04C00304a<009<?00003/00dd200A=:@04C@800ddl0000
>P04C0<00d`Y00=<0`04C3/0000j00A=0`04CBL014d300A=>`0003X00d`400A<9`04C0@00d`k0000
>@04C@D00ddW00==1@04CCX0000i00A<1@04C2D014`500A<>P0003T00dd600A=9@04C@H00ddj0000
>004C0L00d`U00=<1`04C3T0000h00A=1`03CBD00dd700A=>@0003P00d`800A<8`04C0P00d`i0000
=`04C@P014dS00A=2004CCP0000g00A<2@03C2<00d`900A<>00003L00dd:00A=8@04C@X00ddh0000
=P04C0X014`Q00A<2P04C3L0000f00A=2`03CB400dd;00A==`0003H00d`<00A<7`04C0`00d`g0000
=@04C@`014dO00A=3004CCH0000e00A<3@03C1l00d`=00A<=P0003D00dd>00A=7@04C@h00ddf0000
=004C0h014`M00A<3P04C3D0000d00A=3`03CAd00dd?00A==@0003@00d`@00=<7@03C1000d`e0000
/P000;80002b0000/P000;80002b0000/P000001\
\>"],
  ImageRangeCache->{{{0, 177}, {156, 0}} -> {-0.0263241, 0.036121, 0.00594716,
   0.00594716}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0344054 0.952381 [
[ 0 0 0 0 ]
[ 1 .88357 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88357 L
0 .88357 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.83792 .46216 L
s
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.87107 .36016 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.69614 .11939 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.58888 .11939 L
s
P
p
0 .4 1 r
.016 w
.64251 .34228 m
.69753 .36016 L
s
P
p
0 .4 1 r
.016 w
.64251 .34228 m
.64251 .28443 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.13629 .26644 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.04952 .32948 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.04952 .6271 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.13629 .69014 L
s
P
p
0 .4 1 r
.016 w
.22392 .47829 m
.18992 .43149 L
s
P
p
0 .4 1 r
.016 w
.22392 .47829 m
.18992 .52509 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.58888 .83719 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.69614 .83719 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.87107 .59642 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.83792 .49442 L
s
P
p
0 .4 1 r
.016 w
.64251 .6143 m
.64251 .67215 L
s
P
p
0 .4 1 r
.016 w
.64251 .6143 m
.69753 .59642 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.55821 .10942 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.47144 .04638 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.18839 .13834 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.15525 .24035 L
s
P
p
0 .4 1 r
.016 w
.38381 .25822 m
.41781 .21142 L
s
P
p
0 .4 1 r
.016 w
.38381 .25822 m
.32879 .24035 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .34228 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.22392 .47829 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .6143 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.38381 .25822 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.84475 .24035 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.81161 .13834 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.52856 .04638 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.44179 .10942 L
s
P
p
0 .4 1 r
.016 w
.61619 .25822 m
.67121 .24035 L
s
P
p
0 .4 1 r
.016 w
.61619 .25822 m
.58219 .21142 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.16208 .49442 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.12893 .59642 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.30386 .83719 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.41112 .83719 L
s
P
p
0 .4 1 r
.016 w
.35749 .6143 m
.30247 .59642 L
s
P
p
0 .4 1 r
.016 w
.35749 .6143 m
.35749 .67215 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.86371 .69014 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.95048 .6271 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.95048 .32948 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.86371 .26644 L
s
P
p
0 .4 1 r
.016 w
.77608 .47829 m
.81008 .52509 L
s
P
p
0 .4 1 r
.016 w
.77608 .47829 m
.81008 .43149 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.41112 .11939 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.30386 .11939 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.12893 .36016 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.16208 .46216 L
s
P
p
0 .4 1 r
.016 w
.35749 .34228 m
.35749 .28443 L
s
P
p
0 .4 1 r
.016 w
.35749 .34228 m
.30247 .36016 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.61619 .25822 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .6143 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.77608 .47829 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .34228 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.45531 .47829 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.54469 .47829 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0344054 0.952381 [
[ 0 0 0 0 ]
[ 1 .88357 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88357 L
0 .88357 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.83792 .46216 L
s
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.87107 .36016 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.69614 .11939 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.58888 .11939 L
s
P
p
0 1 1 r
.018 w
.64251 .34228 m
.69753 .36016 L
s
P
p
0 1 1 r
.018 w
.64251 .34228 m
.64251 .28443 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.13629 .26644 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.04952 .32948 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.04952 .6271 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.13629 .69014 L
s
P
p
0 1 1 r
.018 w
.22392 .47829 m
.18992 .43149 L
s
P
p
0 1 1 r
.018 w
.22392 .47829 m
.18992 .52509 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.58888 .83719 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.69614 .83719 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.87107 .59642 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.83792 .49442 L
s
P
p
0 1 1 r
.018 w
.64251 .6143 m
.64251 .67215 L
s
P
p
0 1 1 r
.018 w
.64251 .6143 m
.69753 .59642 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.55821 .10942 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.47144 .04638 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.18839 .13834 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.15525 .24035 L
s
P
p
0 1 1 r
.018 w
.38381 .25822 m
.41781 .21142 L
s
P
p
0 1 1 r
.018 w
.38381 .25822 m
.32879 .24035 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .34228 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.22392 .47829 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .6143 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.38381 .25822 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.84475 .24035 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.81161 .13834 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.52856 .04638 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.44179 .10942 L
s
P
p
0 1 1 r
.018 w
.61619 .25822 m
.67121 .24035 L
s
P
p
0 1 1 r
.018 w
.61619 .25822 m
.58219 .21142 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.16208 .49442 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.12893 .59642 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.30386 .83719 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.41112 .83719 L
s
P
p
0 1 1 r
.018 w
.35749 .6143 m
.30247 .59642 L
s
P
p
0 1 1 r
.018 w
.35749 .6143 m
.35749 .67215 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.86371 .69014 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.95048 .6271 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.95048 .32948 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.86371 .26644 L
s
P
p
0 1 1 r
.018 w
.77608 .47829 m
.81008 .52509 L
s
P
p
0 1 1 r
.018 w
.77608 .47829 m
.81008 .43149 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.41112 .11939 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.30386 .11939 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.12893 .36016 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.16208 .46216 L
s
P
p
0 1 1 r
.018 w
.35749 .34228 m
.35749 .28443 L
s
P
p
0 1 1 r
.018 w
.35749 .34228 m
.30247 .36016 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.61619 .25822 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .6143 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.77608 .47829 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .34228 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.45531 .47829 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.54469 .47829 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0475773 0.952381 [
[ 0 0 0 0 ]
[ 1 .85723 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85723 L
0 .85723 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.68734 .35119 m
.78409 .48436 L
s
P
p
.2 0 1 r
.02 w
.68734 .35119 m
.84388 .40206 L
s
P
p
.2 0 1 r
.02 w
.68734 .35119 m
.84388 .30033 L
s
P
p
.2 0 1 r
.02 w
.63516 .27937 m
.73191 .14621 L
s
P
p
.2 0 1 r
.02 w
.63516 .27937 m
.63516 .11478 L
s
P
p
.2 0 1 r
.02 w
.63516 .27937 m
.53842 .14621 L
s
P
p
0 .4 1 r
.018 w
.63516 .33424 m
.68734 .35119 L
s
P
p
0 .4 1 r
.018 w
.63516 .33424 m
.63516 .27937 L
s
P
p
.2 0 1 r
.02 w
.2059 .41885 m
.2059 .25425 L
s
P
p
.2 0 1 r
.02 w
.2059 .41885 m
.10915 .28569 L
s
P
p
.2 0 1 r
.02 w
.2059 .41885 m
.04936 .36799 L
s
P
p
.2 0 1 r
.02 w
.2059 .50762 m
.04936 .55849 L
s
P
p
.2 0 1 r
.02 w
.2059 .50762 m
.10915 .64079 L
s
P
p
.2 0 1 r
.02 w
.2059 .50762 m
.2059 .67222 L
s
P
p
0 .4 1 r
.018 w
.23815 .46324 m
.2059 .41885 L
s
P
p
0 .4 1 r
.018 w
.23815 .46324 m
.2059 .50762 L
s
P
p
.2 0 1 r
.02 w
.63516 .6471 m
.53842 .78026 L
s
P
p
.2 0 1 r
.02 w
.63516 .6471 m
.63516 .8117 L
s
P
p
.2 0 1 r
.02 w
.63516 .6471 m
.73191 .78026 L
s
P
p
.2 0 1 r
.02 w
.68734 .57528 m
.84388 .62614 L
s
P
p
.2 0 1 r
.02 w
.68734 .57528 m
.84388 .52442 L
s
P
p
.2 0 1 r
.02 w
.68734 .57528 m
.78409 .44212 L
s
P
p
0 .4 1 r
.018 w
.63516 .59223 m
.63516 .6471 L
s
P
p
0 .4 1 r
.018 w
.63516 .59223 m
.68734 .57528 L
s
P
p
.2 0 1 r
.02 w
.42205 .21013 m
.57859 .15926 L
s
P
p
.2 0 1 r
.02 w
.42205 .21013 m
.51879 .07697 L
s
P
p
.2 0 1 r
.02 w
.42205 .21013 m
.42205 .04553 L
s
P
p
.2 0 1 r
.02 w
.33762 .23756 m
.24087 .1044 L
s
P
p
.2 0 1 r
.02 w
.33762 .23756 m
.18107 .1867 L
s
P
p
.2 0 1 r
.02 w
.33762 .23756 m
.18107 .28842 L
s
P
p
0 .4 1 r
.018 w
.3898 .25451 m
.42205 .21013 L
s
P
p
0 .4 1 r
.018 w
.3898 .25451 m
.33762 .23756 L
s
P
p
.2 0 1 r
.016 w
.45761 .46324 m
.63516 .33424 L
s
P
p
.2 0 1 r
.016 w
.45761 .46324 m
.23815 .46324 L
s
P
p
.2 0 1 r
.016 w
.45761 .46324 m
.63516 .59223 L
s
P
p
.2 0 1 r
.016 w
.45761 .46324 m
.3898 .25451 L
s
P
p
.2 0 1 r
.02 w
.66238 .23756 m
.81893 .28842 L
s
P
p
.2 0 1 r
.02 w
.66238 .23756 m
.81893 .1867 L
s
P
p
.2 0 1 r
.02 w
.66238 .23756 m
.75913 .1044 L
s
P
p
.2 0 1 r
.02 w
.57795 .21013 m
.57795 .04553 L
s
P
p
.2 0 1 r
.02 w
.57795 .21013 m
.48121 .07697 L
s
P
p
.2 0 1 r
.02 w
.57795 .21013 m
.42141 .15926 L
s
P
p
0 .4 1 r
.018 w
.6102 .25451 m
.66238 .23756 L
s
P
p
0 .4 1 r
.018 w
.6102 .25451 m
.57795 .21013 L
s
P
p
.2 0 1 r
.02 w
.31266 .57528 m
.21591 .44212 L
s
P
p
.2 0 1 r
.02 w
.31266 .57528 m
.15612 .52442 L
s
P
p
.2 0 1 r
.02 w
.31266 .57528 m
.15612 .62614 L
s
P
p
.2 0 1 r
.02 w
.36484 .6471 m
.26809 .78026 L
s
P
p
.2 0 1 r
.02 w
.36484 .6471 m
.36484 .8117 L
s
P
p
.2 0 1 r
.02 w
.36484 .6471 m
.46158 .78026 L
s
P
p
0 .4 1 r
.018 w
.36484 .59223 m
.31266 .57528 L
s
P
p
0 .4 1 r
.018 w
.36484 .59223 m
.36484 .6471 L
s
P
p
.2 0 1 r
.02 w
.7941 .50762 m
.7941 .67222 L
s
P
p
.2 0 1 r
.02 w
.7941 .50762 m
.89085 .64079 L
s
P
p
.2 0 1 r
.02 w
.7941 .50762 m
.95064 .55849 L
s
P
p
.2 0 1 r
.02 w
.7941 .41885 m
.95064 .36799 L
s
P
p
.2 0 1 r
.02 w
.7941 .41885 m
.89085 .28569 L
s
P
p
.2 0 1 r
.02 w
.7941 .41885 m
.7941 .25425 L
s
P
p
0 .4 1 r
.018 w
.76185 .46324 m
.7941 .50762 L
s
P
p
0 .4 1 r
.018 w
.76185 .46324 m
.7941 .41885 L
s
P
p
.2 0 1 r
.02 w
.36484 .27937 m
.46158 .14621 L
s
P
p
.2 0 1 r
.02 w
.36484 .27937 m
.36484 .11478 L
s
P
p
.2 0 1 r
.02 w
.36484 .27937 m
.26809 .14621 L
s
P
p
.2 0 1 r
.02 w
.31266 .35119 m
.15612 .30033 L
s
P
p
.2 0 1 r
.02 w
.31266 .35119 m
.15612 .40206 L
s
P
p
.2 0 1 r
.02 w
.31266 .35119 m
.21591 .48436 L
s
P
p
0 .4 1 r
.018 w
.36484 .33424 m
.36484 .27937 L
s
P
p
0 .4 1 r
.018 w
.36484 .33424 m
.31266 .35119 L
s
P
p
.2 0 1 r
.016 w
.54239 .46324 m
.6102 .25451 L
s
P
p
.2 0 1 r
.016 w
.54239 .46324 m
.36484 .59223 L
s
P
p
.2 0 1 r
.016 w
.54239 .46324 m
.76185 .46324 L
s
P
p
.2 0 1 r
.016 w
.54239 .46324 m
.36484 .33424 L
s
P
p
1 .6 0 r
.016 w
.5 .33279 m
.45761 .46324 L
s
P
p
1 .6 0 r
.016 w
.5 .33279 m
.54239 .46324 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.019561 0.952381 [
[ 0 0 0 0 ]
[ 1 .91326 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .91326 L
0 .91326 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.70554 .36296 m
.86644 .44494 L
s
P
p
.2 0 1 r
.02 w
.70554 .36296 m
.8839 .39121 L
s
P
p
.2 0 1 r
.02 w
.64829 .28416 m
.67654 .1058 L
s
P
p
.2 0 1 r
.02 w
.64829 .28416 m
.62004 .1058 L
s
P
p
0 .4 1 r
.018 w
.64829 .34436 m
.70554 .36296 L
s
P
p
0 .4 1 r
.018 w
.64829 .34436 m
.64829 .28416 L
s
P
p
.2 0 1 r
.02 w
.17734 .43719 m
.09535 .27628 L
s
P
p
.2 0 1 r
.02 w
.17734 .43719 m
.04964 .30949 L
s
P
p
.2 0 1 r
.02 w
.17734 .53458 m
.04964 .66228 L
s
P
p
.2 0 1 r
.02 w
.17734 .53458 m
.09535 .69549 L
s
P
p
0 .4 1 r
.018 w
.21272 .48589 m
.17734 .43719 L
s
P
p
0 .4 1 r
.018 w
.21272 .48589 m
.17734 .53458 L
s
P
p
.2 0 1 r
.02 w
.64829 .68761 m
.62004 .86597 L
s
P
p
.2 0 1 r
.02 w
.64829 .68761 m
.67654 .86597 L
s
P
p
.2 0 1 r
.02 w
.70554 .60881 m
.8839 .58056 L
s
P
p
.2 0 1 r
.02 w
.70554 .60881 m
.86644 .52683 L
s
P
p
0 .4 1 r
.018 w
.64829 .62741 m
.64829 .68761 L
s
P
p
0 .4 1 r
.018 w
.64829 .62741 m
.70554 .60881 L
s
P
p
.2 0 1 r
.02 w
.41447 .20819 m
.54217 .0805 L
s
P
p
.2 0 1 r
.02 w
.41447 .20819 m
.49646 .04729 L
s
P
p
.2 0 1 r
.02 w
.32184 .23829 m
.16094 .15631 L
s
P
p
.2 0 1 r
.02 w
.32184 .23829 m
.14348 .21004 L
s
P
p
0 .4 1 r
.018 w
.37909 .25689 m
.41447 .20819 L
s
P
p
0 .4 1 r
.018 w
.37909 .25689 m
.32184 .23829 L
s
P
p
.2 0 1 r
.016 w
.4535 .48589 m
.64829 .34436 L
s
P
p
.2 0 1 r
.016 w
.4535 .48589 m
.21272 .48589 L
s
P
p
.2 0 1 r
.016 w
.4535 .48589 m
.64829 .62741 L
s
P
p
.2 0 1 r
.016 w
.4535 .48589 m
.37909 .25689 L
s
P
p
.2 0 1 r
.02 w
.67816 .23829 m
.85652 .21004 L
s
P
p
.2 0 1 r
.02 w
.67816 .23829 m
.83906 .15631 L
s
P
p
.2 0 1 r
.02 w
.58553 .20819 m
.50354 .04729 L
s
P
p
.2 0 1 r
.02 w
.58553 .20819 m
.45783 .0805 L
s
P
p
0 .4 1 r
.018 w
.62091 .25689 m
.67816 .23829 L
s
P
p
0 .4 1 r
.018 w
.62091 .25689 m
.58553 .20819 L
s
P
p
.2 0 1 r
.02 w
.29446 .60881 m
.13356 .52683 L
s
P
p
.2 0 1 r
.02 w
.29446 .60881 m
.1161 .58056 L
s
P
p
.2 0 1 r
.02 w
.35171 .68761 m
.32346 .86597 L
s
P
p
.2 0 1 r
.02 w
.35171 .68761 m
.37996 .86597 L
s
P
p
0 .4 1 r
.018 w
.35171 .62741 m
.29446 .60881 L
s
P
p
0 .4 1 r
.018 w
.35171 .62741 m
.35171 .68761 L
s
P
p
.2 0 1 r
.02 w
.82266 .53458 m
.90465 .69549 L
s
P
p
.2 0 1 r
.02 w
.82266 .53458 m
.95036 .66228 L
s
P
p
.2 0 1 r
.02 w
.82266 .43719 m
.95036 .30949 L
s
P
p
.2 0 1 r
.02 w
.82266 .43719 m
.90465 .27628 L
s
P
p
0 .4 1 r
.018 w
.78728 .48589 m
.82266 .53458 L
s
P
p
0 .4 1 r
.018 w
.78728 .48589 m
.82266 .43719 L
s
P
p
.2 0 1 r
.02 w
.35171 .28416 m
.37996 .1058 L
s
P
p
.2 0 1 r
.02 w
.35171 .28416 m
.32346 .1058 L
s
P
p
.2 0 1 r
.02 w
.29446 .36296 m
.1161 .39121 L
s
P
p
.2 0 1 r
.02 w
.29446 .36296 m
.13356 .44494 L
s
P
p
0 .4 1 r
.018 w
.35171 .34436 m
.35171 .28416 L
s
P
p
0 .4 1 r
.018 w
.35171 .34436 m
.29446 .36296 L
s
P
p
.2 0 1 r
.016 w
.5465 .48589 m
.62091 .25689 L
s
P
p
.2 0 1 r
.016 w
.5465 .48589 m
.35171 .62741 L
s
P
p
.2 0 1 r
.016 w
.5465 .48589 m
.78728 .48589 L
s
P
p
.2 0 1 r
.016 w
.5465 .48589 m
.35171 .34436 L
s
P
p
1 .6 0 r
.016 w
.5 .34276 m
.4535 .48589 L
s
P
p
1 .6 0 r
.016 w
.5 .34276 m
.5465 .48589 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0421757 0.952381 [
[ 0 0 0 0 ]
[ 1 .86803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .86803 L
0 .86803 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.70827 .34795 m
.83164 .43758 L
s
P
p
.2 0 1 r
.02 w
.70827 .34795 m
.86076 .34795 L
s
P
p
.2 0 1 r
.02 w
.65026 .2681 m
.69738 .12308 L
s
P
p
.2 0 1 r
.02 w
.65026 .2681 m
.60314 .12308 L
s
P
p
0 .4 1 r
.018 w
.65026 .3291 m
.70827 .34795 L
s
P
p
0 .4 1 r
.018 w
.65026 .3291 m
.65026 .2681 L
s
P
p
.2 0 1 r
.02 w
.17305 .42316 m
.12593 .27814 L
s
P
p
.2 0 1 r
.02 w
.17305 .42316 m
.04968 .33353 L
s
P
p
.2 0 1 r
.02 w
.17305 .52185 m
.04968 .61148 L
s
P
p
.2 0 1 r
.02 w
.17305 .52185 m
.12593 .66687 L
s
P
p
0 .4 1 r
.018 w
.2089 .47251 m
.17305 .42316 L
s
P
p
0 .4 1 r
.018 w
.2089 .47251 m
.17305 .52185 L
s
P
p
.2 0 1 r
.02 w
.65026 .67691 m
.60314 .82193 L
s
P
p
.2 0 1 r
.02 w
.65026 .67691 m
.69738 .82193 L
s
P
p
.2 0 1 r
.02 w
.70827 .59706 m
.86076 .59706 L
s
P
p
.2 0 1 r
.02 w
.70827 .59706 m
.83164 .50743 L
s
P
p
0 .4 1 r
.018 w
.65026 .61591 m
.65026 .67691 L
s
P
p
0 .4 1 r
.018 w
.65026 .61591 m
.70827 .59706 L
s
P
p
.2 0 1 r
.02 w
.41334 .19112 m
.5367 .10149 L
s
P
p
.2 0 1 r
.02 w
.41334 .19112 m
.46046 .0461 L
s
P
p
.2 0 1 r
.02 w
.31948 .22162 m
.19611 .13199 L
s
P
p
.2 0 1 r
.02 w
.31948 .22162 m
.16699 .22162 L
s
P
p
0 .4 1 r
.018 w
.37749 .24047 m
.41334 .19112 L
s
P
p
0 .4 1 r
.018 w
.37749 .24047 m
.31948 .22162 L
s
P
p
.2 0 1 r
.016 w
.45288 .47251 m
.65026 .3291 L
s
P
p
.2 0 1 r
.016 w
.45288 .47251 m
.2089 .47251 L
s
P
p
.2 0 1 r
.016 w
.45288 .47251 m
.65026 .61591 L
s
P
p
.2 0 1 r
.016 w
.45288 .47251 m
.37749 .24047 L
s
P
p
.2 0 1 r
.02 w
.68052 .22162 m
.83301 .22162 L
s
P
p
.2 0 1 r
.02 w
.68052 .22162 m
.80389 .13199 L
s
P
p
.2 0 1 r
.02 w
.58666 .19112 m
.53954 .0461 L
s
P
p
.2 0 1 r
.02 w
.58666 .19112 m
.4633 .10149 L
s
P
p
0 .4 1 r
.018 w
.62251 .24047 m
.68052 .22162 L
s
P
p
0 .4 1 r
.018 w
.62251 .24047 m
.58666 .19112 L
s
P
p
.2 0 1 r
.02 w
.29173 .59706 m
.16836 .50743 L
s
P
p
.2 0 1 r
.02 w
.29173 .59706 m
.13924 .59706 L
s
P
p
.2 0 1 r
.02 w
.34974 .67691 m
.30262 .82193 L
s
P
p
.2 0 1 r
.02 w
.34974 .67691 m
.39686 .82193 L
s
P
p
0 .4 1 r
.018 w
.34974 .61591 m
.29173 .59706 L
s
P
p
0 .4 1 r
.018 w
.34974 .61591 m
.34974 .67691 L
s
P
p
.2 0 1 r
.02 w
.82695 .52185 m
.87407 .66687 L
s
P
p
.2 0 1 r
.02 w
.82695 .52185 m
.95032 .61148 L
s
P
p
.2 0 1 r
.02 w
.82695 .42316 m
.95032 .33353 L
s
P
p
.2 0 1 r
.02 w
.82695 .42316 m
.87407 .27814 L
s
P
p
0 .4 1 r
.018 w
.7911 .47251 m
.82695 .52185 L
s
P
p
0 .4 1 r
.018 w
.7911 .47251 m
.82695 .42316 L
s
P
p
.2 0 1 r
.02 w
.34974 .2681 m
.39686 .12308 L
s
P
p
.2 0 1 r
.02 w
.34974 .2681 m
.30262 .12308 L
s
P
p
.2 0 1 r
.02 w
.29173 .34795 m
.13924 .34795 L
s
P
p
.2 0 1 r
.02 w
.29173 .34795 m
.16836 .43758 L
s
P
p
0 .4 1 r
.018 w
.34974 .3291 m
.34974 .2681 L
s
P
p
0 .4 1 r
.018 w
.34974 .3291 m
.29173 .34795 L
s
P
p
.2 0 1 r
.016 w
.54712 .47251 m
.62251 .24047 L
s
P
p
.2 0 1 r
.016 w
.54712 .47251 m
.34974 .61591 L
s
P
p
.2 0 1 r
.016 w
.54712 .47251 m
.7911 .47251 L
s
P
p
.2 0 1 r
.016 w
.54712 .47251 m
.34974 .3291 L
s
P
p
1 .6 0 r
.016 w
.5 .32748 m
.45288 .47251 L
s
P
p
1 .6 0 r
.016 w
.5 .32748 m
.54712 .47251 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0344054 0.952381 [
[ 0 0 0 0 ]
[ 1 .88357 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88357 L
0 .88357 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.018 w
.69753 .36016 m
.83792 .46216 L
s
P
p
.2 0 1 r
.018 w
.69753 .36016 m
.87107 .36016 L
s
P
p
.2 0 1 r
.018 w
.64251 .28443 m
.69614 .11939 L
s
P
p
.2 0 1 r
.018 w
.64251 .28443 m
.58888 .11939 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.69753 .36016 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.64251 .28443 L
s
P
p
.2 0 1 r
.018 w
.18992 .43149 m
.13629 .26644 L
s
P
p
.2 0 1 r
.018 w
.18992 .43149 m
.04952 .32948 L
s
P
p
.2 0 1 r
.018 w
.18992 .52509 m
.04952 .6271 L
s
P
p
.2 0 1 r
.018 w
.18992 .52509 m
.13629 .69014 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .43149 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .52509 L
s
P
p
.2 0 1 r
.018 w
.64251 .67215 m
.58888 .83719 L
s
P
p
.2 0 1 r
.018 w
.64251 .67215 m
.69614 .83719 L
s
P
p
.2 0 1 r
.018 w
.69753 .59642 m
.87107 .59642 L
s
P
p
.2 0 1 r
.018 w
.69753 .59642 m
.83792 .49442 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.64251 .67215 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.69753 .59642 L
s
P
p
.2 0 1 r
.018 w
.41781 .21142 m
.55821 .10942 L
s
P
p
.2 0 1 r
.018 w
.41781 .21142 m
.47144 .04638 L
s
P
p
.2 0 1 r
.018 w
.32879 .24035 m
.18839 .13834 L
s
P
p
.2 0 1 r
.018 w
.32879 .24035 m
.15525 .24035 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.41781 .21142 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.32879 .24035 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .34228 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.22392 .47829 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .6143 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.38381 .25822 L
s
P
p
.2 0 1 r
.018 w
.67121 .24035 m
.84475 .24035 L
s
P
p
.2 0 1 r
.018 w
.67121 .24035 m
.81161 .13834 L
s
P
p
.2 0 1 r
.018 w
.58219 .21142 m
.52856 .04638 L
s
P
p
.2 0 1 r
.018 w
.58219 .21142 m
.44179 .10942 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.67121 .24035 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.58219 .21142 L
s
P
p
.2 0 1 r
.018 w
.30247 .59642 m
.16208 .49442 L
s
P
p
.2 0 1 r
.018 w
.30247 .59642 m
.12893 .59642 L
s
P
p
.2 0 1 r
.018 w
.35749 .67215 m
.30386 .83719 L
s
P
p
.2 0 1 r
.018 w
.35749 .67215 m
.41112 .83719 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.30247 .59642 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.35749 .67215 L
s
P
p
.2 0 1 r
.018 w
.81008 .52509 m
.86371 .69014 L
s
P
p
.2 0 1 r
.018 w
.81008 .52509 m
.95048 .6271 L
s
P
p
.2 0 1 r
.018 w
.81008 .43149 m
.95048 .32948 L
s
P
p
.2 0 1 r
.018 w
.81008 .43149 m
.86371 .26644 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .52509 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .43149 L
s
P
p
.2 0 1 r
.018 w
.35749 .28443 m
.41112 .11939 L
s
P
p
.2 0 1 r
.018 w
.35749 .28443 m
.30386 .11939 L
s
P
p
.2 0 1 r
.018 w
.30247 .36016 m
.12893 .36016 L
s
P
p
.2 0 1 r
.018 w
.30247 .36016 m
.16208 .46216 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.35749 .28443 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.30247 .36016 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.61619 .25822 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .6143 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.77608 .47829 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .34228 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.45531 .47829 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.54469 .47829 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0344054 0.952381 [
[ 0 0 0 0 ]
[ 1 .88357 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88357 L
0 .88357 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.02 w
.69753 .36016 m
.83792 .46216 L
s
P
p
0 .4 1 r
.02 w
.69753 .36016 m
.87107 .36016 L
s
P
p
0 .4 1 r
.02 w
.64251 .28443 m
.69614 .11939 L
s
P
p
0 .4 1 r
.02 w
.64251 .28443 m
.58888 .11939 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.69753 .36016 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.64251 .28443 L
s
P
p
0 .4 1 r
.02 w
.18992 .43149 m
.13629 .26644 L
s
P
p
0 .4 1 r
.02 w
.18992 .43149 m
.04952 .32948 L
s
P
p
0 .4 1 r
.02 w
.18992 .52509 m
.04952 .6271 L
s
P
p
0 .4 1 r
.02 w
.18992 .52509 m
.13629 .69014 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .43149 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .52509 L
s
P
p
0 .4 1 r
.02 w
.64251 .67215 m
.58888 .83719 L
s
P
p
0 .4 1 r
.02 w
.64251 .67215 m
.69614 .83719 L
s
P
p
0 .4 1 r
.02 w
.69753 .59642 m
.87107 .59642 L
s
P
p
0 .4 1 r
.02 w
.69753 .59642 m
.83792 .49442 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.64251 .67215 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.69753 .59642 L
s
P
p
0 .4 1 r
.02 w
.41781 .21142 m
.55821 .10942 L
s
P
p
0 .4 1 r
.02 w
.41781 .21142 m
.47144 .04638 L
s
P
p
0 .4 1 r
.02 w
.32879 .24035 m
.18839 .13834 L
s
P
p
0 .4 1 r
.02 w
.32879 .24035 m
.15525 .24035 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.41781 .21142 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.32879 .24035 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .34228 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.22392 .47829 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .6143 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.38381 .25822 L
s
P
p
0 .4 1 r
.02 w
.67121 .24035 m
.84475 .24035 L
s
P
p
0 .4 1 r
.02 w
.67121 .24035 m
.81161 .13834 L
s
P
p
0 .4 1 r
.02 w
.58219 .21142 m
.52856 .04638 L
s
P
p
0 .4 1 r
.02 w
.58219 .21142 m
.44179 .10942 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.67121 .24035 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.58219 .21142 L
s
P
p
0 .4 1 r
.02 w
.30247 .59642 m
.16208 .49442 L
s
P
p
0 .4 1 r
.02 w
.30247 .59642 m
.12893 .59642 L
s
P
p
0 .4 1 r
.02 w
.35749 .67215 m
.30386 .83719 L
s
P
p
0 .4 1 r
.02 w
.35749 .67215 m
.41112 .83719 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.30247 .59642 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.35749 .67215 L
s
P
p
0 .4 1 r
.02 w
.81008 .52509 m
.86371 .69014 L
s
P
p
0 .4 1 r
.02 w
.81008 .52509 m
.95048 .6271 L
s
P
p
0 .4 1 r
.02 w
.81008 .43149 m
.95048 .32948 L
s
P
p
0 .4 1 r
.02 w
.81008 .43149 m
.86371 .26644 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .52509 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .43149 L
s
P
p
0 .4 1 r
.02 w
.35749 .28443 m
.41112 .11939 L
s
P
p
0 .4 1 r
.02 w
.35749 .28443 m
.30386 .11939 L
s
P
p
0 .4 1 r
.02 w
.30247 .36016 m
.12893 .36016 L
s
P
p
0 .4 1 r
.02 w
.30247 .36016 m
.16208 .46216 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.35749 .28443 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.30247 .36016 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.61619 .25822 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .6143 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.77608 .47829 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .34228 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.45531 .47829 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.54469 .47829 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0837567 0.952381 [
[ 0 0 0 0 ]
[ 1 .78487 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78487 L
0 .78487 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.79178 .57374 L
s
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.86468 .50084 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.81993 .21828 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.72807 .17148 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.71605 .42511 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.70197 .33624 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.18602 .17148 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.09415 .21828 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.0494 .50084 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.1223 .57374 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.21211 .33624 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.19804 .42511 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.63783 .74125 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.73966 .72512 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.86953 .47022 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.82273 .37836 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.66392 .57648 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.70477 .49632 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.3842 .05975 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.28237 .04362 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.08008 .24591 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.09621 .34774 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.30846 .20838 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.24484 .272 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.67673 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.23736 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.65522 .52156 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.29976 .26331 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.90379 .34774 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.91992 .24591 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.71763 .04362 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.6158 .05975 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.75516 .272 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.69154 .20838 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.17727 .37836 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.13047 .47022 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.26034 .72512 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.36217 .74125 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.29523 .49632 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.33608 .57648 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.8777 .57374 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.9506 .50084 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.90585 .21828 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.81398 .17148 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.80196 .42511 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.78789 .33624 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.27193 .17148 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.18007 .21828 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.13532 .50084 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.20822 .57374 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.29803 .33624 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.28395 .42511 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.70024 .26331 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.34478 .52156 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.76264 .38579 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.32327 .38579 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.45704 .42058 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.54296 .42058 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0375176 0.952381 [
[ 0 0 0 0 ]
[ 1 .87735 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .87735 L
0 .87735 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.70768 .3509 m
.83966 .44679 L
s
P
p
.2 0 1 r
.02 w
.70768 .3509 m
.87082 .3509 L
s
P
p
.2 0 1 r
.02 w
.65596 .27971 m
.70638 .12456 L
s
P
p
.2 0 1 r
.02 w
.65596 .27971 m
.60555 .12456 L
s
P
p
0 .4 1 r
.018 w
.65596 .33409 m
.70768 .3509 L
s
P
p
0 .4 1 r
.018 w
.65596 .33409 m
.65596 .27971 L
s
P
p
.2 0 1 r
.02 w
.18132 .43393 m
.1309 .27878 L
s
P
p
.2 0 1 r
.02 w
.18132 .43393 m
.04934 .33804 L
s
P
p
.2 0 1 r
.02 w
.18132 .52192 m
.04934 .61781 L
s
P
p
.2 0 1 r
.02 w
.18132 .52192 m
.1309 .67708 L
s
P
p
0 .4 1 r
.018 w
.21328 .47793 m
.18132 .43393 L
s
P
p
0 .4 1 r
.018 w
.21328 .47793 m
.18132 .52192 L
s
P
p
.2 0 1 r
.02 w
.65596 .67614 m
.60555 .8313 L
s
P
p
.2 0 1 r
.02 w
.65596 .67614 m
.70638 .8313 L
s
P
p
.2 0 1 r
.02 w
.70768 .60496 m
.87082 .60496 L
s
P
p
.2 0 1 r
.02 w
.70768 .60496 m
.83966 .50907 L
s
P
p
0 .4 1 r
.018 w
.65596 .62176 m
.65596 .67614 L
s
P
p
0 .4 1 r
.018 w
.65596 .62176 m
.70768 .60496 L
s
P
p
.2 0 1 r
.02 w
.41433 .2012 m
.54632 .10531 L
s
P
p
.2 0 1 r
.02 w
.41433 .2012 m
.46475 .04605 L
s
P
p
.2 0 1 r
.02 w
.33065 .22839 m
.19867 .1325 L
s
P
p
.2 0 1 r
.02 w
.33065 .22839 m
.16751 .22839 L
s
P
p
0 .4 1 r
.018 w
.38237 .2452 m
.41433 .2012 L
s
P
p
0 .4 1 r
.018 w
.38237 .2452 m
.33065 .22839 L
s
P
p
.2 0 1 r
.016 w
.45799 .47793 m
.65596 .33409 L
s
P
p
.2 0 1 r
.016 w
.45799 .47793 m
.21328 .47793 L
s
P
p
.2 0 1 r
.016 w
.45799 .47793 m
.65596 .62176 L
s
P
p
.2 0 1 r
.016 w
.45799 .47793 m
.38237 .2452 L
s
P
p
.2 0 1 r
.02 w
.66935 .22839 m
.83249 .22839 L
s
P
p
.2 0 1 r
.02 w
.66935 .22839 m
.80133 .1325 L
s
P
p
.2 0 1 r
.02 w
.58567 .2012 m
.53525 .04605 L
s
P
p
.2 0 1 r
.02 w
.58567 .2012 m
.45368 .10531 L
s
P
p
0 .4 1 r
.018 w
.61763 .2452 m
.66935 .22839 L
s
P
p
0 .4 1 r
.018 w
.61763 .2452 m
.58567 .2012 L
s
P
p
.2 0 1 r
.02 w
.29232 .60496 m
.16034 .50907 L
s
P
p
.2 0 1 r
.02 w
.29232 .60496 m
.12918 .60496 L
s
P
p
.2 0 1 r
.02 w
.34404 .67614 m
.29362 .8313 L
s
P
p
.2 0 1 r
.02 w
.34404 .67614 m
.39445 .8313 L
s
P
p
0 .4 1 r
.018 w
.34404 .62176 m
.29232 .60496 L
s
P
p
0 .4 1 r
.018 w
.34404 .62176 m
.34404 .67614 L
s
P
p
.2 0 1 r
.02 w
.81868 .52192 m
.8691 .67708 L
s
P
p
.2 0 1 r
.02 w
.81868 .52192 m
.95066 .61781 L
s
P
p
.2 0 1 r
.02 w
.81868 .43393 m
.95066 .33804 L
s
P
p
.2 0 1 r
.02 w
.81868 .43393 m
.8691 .27878 L
s
P
p
0 .4 1 r
.018 w
.78672 .47793 m
.81868 .52192 L
s
P
p
0 .4 1 r
.018 w
.78672 .47793 m
.81868 .43393 L
s
P
p
.2 0 1 r
.02 w
.34404 .27971 m
.39445 .12456 L
s
P
p
.2 0 1 r
.02 w
.34404 .27971 m
.29362 .12456 L
s
P
p
.2 0 1 r
.02 w
.29232 .3509 m
.12918 .3509 L
s
P
p
.2 0 1 r
.02 w
.29232 .3509 m
.16034 .44679 L
s
P
p
0 .4 1 r
.018 w
.34404 .33409 m
.34404 .27971 L
s
P
p
0 .4 1 r
.018 w
.34404 .33409 m
.29232 .3509 L
s
P
p
.2 0 1 r
.016 w
.54201 .47793 m
.61763 .2452 L
s
P
p
.2 0 1 r
.016 w
.54201 .47793 m
.34404 .62176 L
s
P
p
.2 0 1 r
.016 w
.54201 .47793 m
.78672 .47793 L
s
P
p
.2 0 1 r
.016 w
.54201 .47793 m
.34404 .33409 L
s
P
p
1 .6 0 r
.016 w
.5 .34863 m
.45799 .47793 L
s
P
p
1 .6 0 r
.016 w
.5 .34863 m
.54201 .47793 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0344054 0.952381 [
[ 0 0 0 0 ]
[ 1 .88357 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88357 L
0 .88357 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.83792 .46216 L
s
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.87107 .36016 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.69614 .11939 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.58888 .11939 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.69753 .36016 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.64251 .28443 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.13629 .26644 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.04952 .32948 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.04952 .6271 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.13629 .69014 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .43149 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .52509 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.58888 .83719 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.69614 .83719 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.87107 .59642 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.83792 .49442 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.64251 .67215 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.69753 .59642 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.55821 .10942 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.47144 .04638 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.18839 .13834 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.15525 .24035 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.41781 .21142 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.32879 .24035 L
s
P
p
.2 0 1 r
.018 w
.45531 .47829 m
.64251 .34228 L
s
P
p
.2 0 1 r
.018 w
.45531 .47829 m
.22392 .47829 L
s
P
p
.2 0 1 r
.018 w
.45531 .47829 m
.64251 .6143 L
s
P
p
.2 0 1 r
.018 w
.45531 .47829 m
.38381 .25822 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.84475 .24035 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.81161 .13834 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.52856 .04638 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.44179 .10942 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.67121 .24035 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.58219 .21142 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.16208 .49442 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.12893 .59642 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.30386 .83719 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.41112 .83719 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.30247 .59642 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.35749 .67215 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.86371 .69014 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.95048 .6271 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.95048 .32948 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.86371 .26644 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .52509 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .43149 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.41112 .11939 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.30386 .11939 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.12893 .36016 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.16208 .46216 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.35749 .28443 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.30247 .36016 L
s
P
p
.2 0 1 r
.018 w
.54469 .47829 m
.61619 .25822 L
s
P
p
.2 0 1 r
.018 w
.54469 .47829 m
.35749 .6143 L
s
P
p
.2 0 1 r
.018 w
.54469 .47829 m
.77608 .47829 L
s
P
p
.2 0 1 r
.018 w
.54469 .47829 m
.35749 .34228 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.45531 .47829 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.54469 .47829 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0344054 0.952381 [
[ 0 0 0 0 ]
[ 1 .88357 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88357 L
0 .88357 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.83792 .46216 L
s
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.87107 .36016 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.69614 .11939 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.58888 .11939 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.69753 .36016 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.64251 .28443 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.13629 .26644 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.04952 .32948 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.04952 .6271 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.13629 .69014 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .43149 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .52509 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.58888 .83719 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.69614 .83719 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.87107 .59642 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.83792 .49442 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.64251 .67215 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.69753 .59642 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.55821 .10942 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.47144 .04638 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.18839 .13834 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.15525 .24035 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.41781 .21142 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.32879 .24035 L
s
P
p
.8 0 1 r
.016 w
.45531 .47829 m
.64251 .34228 L
s
P
p
.8 0 1 r
.016 w
.45531 .47829 m
.22392 .47829 L
s
P
p
.8 0 1 r
.016 w
.45531 .47829 m
.64251 .6143 L
s
P
p
.8 0 1 r
.016 w
.45531 .47829 m
.38381 .25822 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.84475 .24035 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.81161 .13834 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.52856 .04638 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.44179 .10942 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.67121 .24035 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.58219 .21142 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.16208 .49442 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.12893 .59642 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.30386 .83719 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.41112 .83719 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.30247 .59642 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.35749 .67215 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.86371 .69014 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.95048 .6271 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.95048 .32948 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.86371 .26644 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .52509 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .43149 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.41112 .11939 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.30386 .11939 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.12893 .36016 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.16208 .46216 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.35749 .28443 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.30247 .36016 L
s
P
p
.8 0 1 r
.016 w
.54469 .47829 m
.61619 .25822 L
s
P
p
.8 0 1 r
.016 w
.54469 .47829 m
.35749 .6143 L
s
P
p
.8 0 1 r
.016 w
.54469 .47829 m
.77608 .47829 L
s
P
p
.8 0 1 r
.016 w
.54469 .47829 m
.35749 .34228 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.45531 .47829 L
s
P
p
1 .6 0 r
.016 w
.5 .34075 m
.54469 .47829 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0901953 0.952381 [
[ 0 0 0 0 ]
[ 1 .77199 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .77199 L
0 .77199 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.64489 .37526 m
.64489 .53204 L
s
P
p
.2 0 1 r
.02 w
.64489 .37526 m
.73704 .5021 L
s
P
p
.2 0 1 r
.02 w
.67102 .29484 m
.82013 .24639 L
s
P
p
.2 0 1 r
.02 w
.67102 .29484 m
.76317 .168 L
s
P
p
.2 0 1 r
.02 w
.58646 .29484 m
.49431 .168 L
s
P
p
.2 0 1 r
.02 w
.58646 .29484 m
.43736 .24639 L
s
P
p
0 .4 1 r
.018 w
.62874 .32556 m
.64489 .37526 L
s
P
p
0 .4 1 r
.018 w
.62874 .32556 m
.67102 .29484 L
s
P
p
0 .4 1 r
.018 w
.62874 .32556 m
.58646 .29484 L
s
P
p
.2 0 1 r
.02 w
.26674 .39873 m
.35889 .27189 L
s
P
p
.2 0 1 r
.02 w
.26674 .39873 m
.26674 .24195 L
s
P
p
.2 0 1 r
.02 w
.19833 .44843 m
.04922 .39998 L
s
P
p
.2 0 1 r
.02 w
.19833 .44843 m
.04922 .49687 L
s
P
p
.2 0 1 r
.02 w
.26674 .49813 m
.26674 .65491 L
s
P
p
.2 0 1 r
.02 w
.26674 .49813 m
.35889 .62497 L
s
P
p
0 .4 1 r
.018 w
.25059 .44843 m
.26674 .39873 L
s
P
p
0 .4 1 r
.018 w
.25059 .44843 m
.19833 .44843 L
s
P
p
0 .4 1 r
.018 w
.25059 .44843 m
.26674 .49813 L
s
P
p
.2 0 1 r
.02 w
.58646 .60201 m
.43736 .65046 L
s
P
p
.2 0 1 r
.02 w
.58646 .60201 m
.49431 .72885 L
s
P
p
.2 0 1 r
.02 w
.67102 .60201 m
.76317 .72885 L
s
P
p
.2 0 1 r
.02 w
.67102 .60201 m
.82013 .65046 L
s
P
p
.2 0 1 r
.02 w
.64489 .5216 m
.73704 .39476 L
s
P
p
.2 0 1 r
.02 w
.64489 .5216 m
.64489 .36482 L
s
P
p
0 .4 1 r
.018 w
.62874 .5713 m
.58646 .60201 L
s
P
p
0 .4 1 r
.018 w
.62874 .5713 m
.67102 .60201 L
s
P
p
0 .4 1 r
.018 w
.62874 .5713 m
.64489 .5216 L
s
P
p
.2 0 1 r
.02 w
.44729 .24962 m
.5964 .29807 L
s
P
p
.2 0 1 r
.02 w
.44729 .24962 m
.5964 .20117 L
s
P
p
.2 0 1 r
.02 w
.37888 .19992 m
.37888 .04314 L
s
P
p
.2 0 1 r
.02 w
.37888 .19992 m
.28673 .07308 L
s
P
p
.2 0 1 r
.02 w
.35275 .28034 m
.20365 .32878 L
s
P
p
.2 0 1 r
.02 w
.35275 .28034 m
.2606 .40717 L
s
P
p
0 .4 1 r
.018 w
.39503 .24962 m
.44729 .24962 L
s
P
p
0 .4 1 r
.018 w
.39503 .24962 m
.37888 .19992 L
s
P
p
0 .4 1 r
.018 w
.39503 .24962 m
.35275 .28034 L
s
P
p
.2 0 1 r
.016 w
.45963 .44843 m
.62874 .32556 L
s
P
p
.2 0 1 r
.016 w
.45963 .44843 m
.25059 .44843 L
s
P
p
.2 0 1 r
.016 w
.45963 .44843 m
.62874 .5713 L
s
P
p
.2 0 1 r
.016 w
.45963 .44843 m
.39503 .24962 L
s
P
p
.2 0 1 r
.02 w
.64725 .28034 m
.7394 .40717 L
s
P
p
.2 0 1 r
.02 w
.64725 .28034 m
.79635 .32878 L
s
P
p
.2 0 1 r
.02 w
.62112 .19992 m
.71327 .07308 L
s
P
p
.2 0 1 r
.02 w
.62112 .19992 m
.62112 .04314 L
s
P
p
.2 0 1 r
.02 w
.55271 .24962 m
.4036 .20117 L
s
P
p
.2 0 1 r
.02 w
.55271 .24962 m
.4036 .29807 L
s
P
p
0 .4 1 r
.018 w
.60497 .24962 m
.64725 .28034 L
s
P
p
0 .4 1 r
.018 w
.60497 .24962 m
.62112 .19992 L
s
P
p
0 .4 1 r
.018 w
.60497 .24962 m
.55271 .24962 L
s
P
p
.2 0 1 r
.02 w
.35511 .5216 m
.35511 .36482 L
s
P
p
.2 0 1 r
.02 w
.35511 .5216 m
.26296 .39476 L
s
P
p
.2 0 1 r
.02 w
.32898 .60201 m
.17987 .65046 L
s
P
p
.2 0 1 r
.02 w
.32898 .60201 m
.23683 .72885 L
s
P
p
.2 0 1 r
.02 w
.41354 .60201 m
.50569 .72885 L
s
P
p
.2 0 1 r
.02 w
.41354 .60201 m
.56264 .65046 L
s
P
p
0 .4 1 r
.018 w
.37126 .5713 m
.35511 .5216 L
s
P
p
0 .4 1 r
.018 w
.37126 .5713 m
.32898 .60201 L
s
P
p
0 .4 1 r
.018 w
.37126 .5713 m
.41354 .60201 L
s
P
p
.2 0 1 r
.02 w
.73326 .49813 m
.64111 .62497 L
s
P
p
.2 0 1 r
.02 w
.73326 .49813 m
.73326 .65491 L
s
P
p
.2 0 1 r
.02 w
.80167 .44843 m
.95078 .49687 L
s
P
p
.2 0 1 r
.02 w
.80167 .44843 m
.95078 .39998 L
s
P
p
.2 0 1 r
.02 w
.73326 .39873 m
.73326 .24195 L
s
P
p
.2 0 1 r
.02 w
.73326 .39873 m
.64111 .27189 L
s
P
p
0 .4 1 r
.018 w
.74941 .44843 m
.73326 .49813 L
s
P
p
0 .4 1 r
.018 w
.74941 .44843 m
.80167 .44843 L
s
P
p
0 .4 1 r
.018 w
.74941 .44843 m
.73326 .39873 L
s
P
p
.2 0 1 r
.02 w
.41354 .29484 m
.56264 .24639 L
s
P
p
.2 0 1 r
.02 w
.41354 .29484 m
.50569 .168 L
s
P
p
.2 0 1 r
.02 w
.32898 .29484 m
.23683 .168 L
s
P
p
.2 0 1 r
.02 w
.32898 .29484 m
.17987 .24639 L
s
P
p
.2 0 1 r
.02 w
.35511 .37526 m
.26296 .5021 L
s
P
p
.2 0 1 r
.02 w
.35511 .37526 m
.35511 .53204 L
s
P
p
0 .4 1 r
.018 w
.37126 .32556 m
.41354 .29484 L
s
P
p
0 .4 1 r
.018 w
.37126 .32556 m
.32898 .29484 L
s
P
p
0 .4 1 r
.018 w
.37126 .32556 m
.35511 .37526 L
s
P
p
.2 0 1 r
.016 w
.54037 .44843 m
.60497 .24962 L
s
P
p
.2 0 1 r
.016 w
.54037 .44843 m
.37126 .5713 L
s
P
p
.2 0 1 r
.016 w
.54037 .44843 m
.74941 .44843 L
s
P
p
.2 0 1 r
.016 w
.54037 .44843 m
.37126 .32556 L
s
P
p
1 .6 0 r
.016 w
.5 .32417 m
.45963 .44843 L
s
P
p
1 .6 0 r
.016 w
.5 .32417 m
.54037 .44843 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0446795 0.952381 [
[ 0 0 0 0 ]
[ 1 .86302 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .86302 L
0 .86302 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.69076 .34769 m
.8385 .42297 L
s
P
p
.2 0 1 r
.02 w
.69076 .34769 m
.85453 .32175 L
s
P
p
.2 0 1 r
.02 w
.64481 .28445 m
.72009 .13671 L
s
P
p
.2 0 1 r
.02 w
.64481 .28445 m
.61887 .12068 L
s
P
p
0 .4 1 r
.018 w
.63616 .33904 m
.69076 .34769 L
s
P
p
0 .4 1 r
.018 w
.63616 .33904 m
.64481 .28445 L
s
P
p
.2 0 1 r
.02 w
.19713 .42991 m
.12185 .28217 L
s
P
p
.2 0 1 r
.02 w
.19713 .42991 m
.04938 .35463 L
s
P
p
.2 0 1 r
.02 w
.19713 .50808 m
.04938 .58336 L
s
P
p
.2 0 1 r
.02 w
.19713 .50808 m
.12185 .65582 L
s
P
p
0 .4 1 r
.018 w
.23621 .469 m
.19713 .42991 L
s
P
p
0 .4 1 r
.018 w
.23621 .469 m
.19713 .50808 L
s
P
p
.2 0 1 r
.02 w
.64481 .65354 m
.61887 .81732 L
s
P
p
.2 0 1 r
.02 w
.64481 .65354 m
.72009 .80129 L
s
P
p
.2 0 1 r
.02 w
.69076 .5903 m
.85453 .61624 L
s
P
p
.2 0 1 r
.02 w
.69076 .5903 m
.8385 .51502 L
s
P
p
0 .4 1 r
.018 w
.63616 .59895 m
.64481 .65354 L
s
P
p
0 .4 1 r
.018 w
.63616 .59895 m
.69076 .5903 L
s
P
p
.2 0 1 r
.02 w
.41407 .20948 m
.53132 .09223 L
s
P
p
.2 0 1 r
.02 w
.41407 .20948 m
.44001 .0457 L
s
P
p
.2 0 1 r
.02 w
.33973 .23364 m
.22248 .11638 L
s
P
p
.2 0 1 r
.02 w
.33973 .23364 m
.17596 .2077 L
s
P
p
0 .4 1 r
.018 w
.38898 .25873 m
.41407 .20948 L
s
P
p
0 .4 1 r
.018 w
.38898 .25873 m
.33973 .23364 L
s
P
p
.2 0 1 r
.016 w
.4573 .469 m
.63616 .33904 L
s
P
p
.2 0 1 r
.016 w
.4573 .469 m
.23621 .469 L
s
P
p
.2 0 1 r
.016 w
.4573 .469 m
.63616 .59895 L
s
P
p
.2 0 1 r
.016 w
.4573 .469 m
.38898 .25873 L
s
P
p
.2 0 1 r
.02 w
.66027 .23364 m
.82404 .2077 L
s
P
p
.2 0 1 r
.02 w
.66027 .23364 m
.77752 .11638 L
s
P
p
.2 0 1 r
.02 w
.58593 .20948 m
.55999 .0457 L
s
P
p
.2 0 1 r
.02 w
.58593 .20948 m
.46868 .09223 L
s
P
p
0 .4 1 r
.018 w
.61102 .25873 m
.66027 .23364 L
s
P
p
0 .4 1 r
.018 w
.61102 .25873 m
.58593 .20948 L
s
P
p
.2 0 1 r
.02 w
.30924 .5903 m
.1615 .51502 L
s
P
p
.2 0 1 r
.02 w
.30924 .5903 m
.14547 .61624 L
s
P
p
.2 0 1 r
.02 w
.35519 .65354 m
.27991 .80129 L
s
P
p
.2 0 1 r
.02 w
.35519 .65354 m
.38113 .81732 L
s
P
p
0 .4 1 r
.018 w
.36384 .59895 m
.30924 .5903 L
s
P
p
0 .4 1 r
.018 w
.36384 .59895 m
.35519 .65354 L
s
P
p
.2 0 1 r
.02 w
.80287 .50808 m
.87815 .65582 L
s
P
p
.2 0 1 r
.02 w
.80287 .50808 m
.95062 .58336 L
s
P
p
.2 0 1 r
.02 w
.80287 .42991 m
.95062 .35463 L
s
P
p
.2 0 1 r
.02 w
.80287 .42991 m
.87815 .28217 L
s
P
p
0 .4 1 r
.018 w
.76379 .469 m
.80287 .50808 L
s
P
p
0 .4 1 r
.018 w
.76379 .469 m
.80287 .42991 L
s
P
p
.2 0 1 r
.02 w
.35519 .28445 m
.38113 .12068 L
s
P
p
.2 0 1 r
.02 w
.35519 .28445 m
.27991 .13671 L
s
P
p
.2 0 1 r
.02 w
.30924 .34769 m
.14547 .32175 L
s
P
p
.2 0 1 r
.02 w
.30924 .34769 m
.1615 .42297 L
s
P
p
0 .4 1 r
.018 w
.36384 .33904 m
.35519 .28445 L
s
P
p
0 .4 1 r
.018 w
.36384 .33904 m
.30924 .34769 L
s
P
p
.2 0 1 r
.016 w
.5427 .469 m
.61102 .25873 L
s
P
p
.2 0 1 r
.016 w
.5427 .469 m
.36384 .59895 L
s
P
p
.2 0 1 r
.016 w
.5427 .469 m
.76379 .469 L
s
P
p
.2 0 1 r
.016 w
.5427 .469 m
.36384 .33904 L
s
P
p
1 .6 0 r
.016 w
.5 .33758 m
.4573 .469 L
s
P
p
1 .6 0 r
.016 w
.5 .33758 m
.5427 .469 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0229568 0.952381 [
[ 0 0 0 0 ]
[ 1 .90647 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .90647 L
0 .90647 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.7169 .38051 m
.85223 .47883 L
s
P
p
.2 0 1 r
.02 w
.7169 .38051 m
.88418 .38051 L
s
P
p
.2 0 1 r
.02 w
.63736 .27103 m
.68905 .11194 L
s
P
p
.2 0 1 r
.02 w
.63736 .27103 m
.58567 .11194 L
s
P
p
0 .4 1 r
.018 w
.63736 .35466 m
.7169 .38051 L
s
P
p
0 .4 1 r
.018 w
.63736 .35466 m
.63736 .27103 L
s
P
p
.2 0 1 r
.02 w
.18473 .41809 m
.13304 .25901 L
s
P
p
.2 0 1 r
.02 w
.18473 .41809 m
.04941 .31977 L
s
P
p
.2 0 1 r
.02 w
.18473 .55342 m
.04941 .65174 L
s
P
p
.2 0 1 r
.02 w
.18473 .55342 m
.13304 .71251 L
s
P
p
0 .4 1 r
.018 w
.23389 .48576 m
.18473 .41809 L
s
P
p
0 .4 1 r
.018 w
.23389 .48576 m
.18473 .55342 L
s
P
p
.2 0 1 r
.02 w
.63736 .70049 m
.58567 .85957 L
s
P
p
.2 0 1 r
.02 w
.63736 .70049 m
.68905 .85957 L
s
P
p
.2 0 1 r
.02 w
.7169 .59101 m
.88418 .59101 L
s
P
p
.2 0 1 r
.02 w
.7169 .59101 m
.85223 .49269 L
s
P
p
0 .4 1 r
.018 w
.63736 .61685 m
.63736 .70049 L
s
P
p
0 .4 1 r
.018 w
.63736 .61685 m
.7169 .59101 L
s
P
p
.2 0 1 r
.02 w
.43717 .20598 m
.57249 .10766 L
s
P
p
.2 0 1 r
.02 w
.43717 .20598 m
.48886 .04689 L
s
P
p
.2 0 1 r
.02 w
.30846 .2478 m
.17314 .14948 L
s
P
p
.2 0 1 r
.02 w
.30846 .2478 m
.14119 .2478 L
s
P
p
0 .4 1 r
.018 w
.388 .27364 m
.43717 .20598 L
s
P
p
0 .4 1 r
.018 w
.388 .27364 m
.30846 .2478 L
s
P
p
.2 0 1 r
.016 w
.45692 .48576 m
.63736 .35466 L
s
P
p
.2 0 1 r
.016 w
.45692 .48576 m
.23389 .48576 L
s
P
p
.2 0 1 r
.016 w
.45692 .48576 m
.63736 .61685 L
s
P
p
.2 0 1 r
.016 w
.45692 .48576 m
.388 .27364 L
s
P
p
.2 0 1 r
.02 w
.69154 .2478 m
.85881 .2478 L
s
P
p
.2 0 1 r
.02 w
.69154 .2478 m
.82686 .14948 L
s
P
p
.2 0 1 r
.02 w
.56283 .20598 m
.51114 .04689 L
s
P
p
.2 0 1 r
.02 w
.56283 .20598 m
.42751 .10766 L
s
P
p
0 .4 1 r
.018 w
.612 .27364 m
.69154 .2478 L
s
P
p
0 .4 1 r
.018 w
.612 .27364 m
.56283 .20598 L
s
P
p
.2 0 1 r
.02 w
.2831 .59101 m
.14777 .49269 L
s
P
p
.2 0 1 r
.02 w
.2831 .59101 m
.11582 .59101 L
s
P
p
.2 0 1 r
.02 w
.36264 .70049 m
.31095 .85957 L
s
P
p
.2 0 1 r
.02 w
.36264 .70049 m
.41433 .85957 L
s
P
p
0 .4 1 r
.018 w
.36264 .61685 m
.2831 .59101 L
s
P
p
0 .4 1 r
.018 w
.36264 .61685 m
.36264 .70049 L
s
P
p
.2 0 1 r
.02 w
.81527 .55342 m
.86696 .71251 L
s
P
p
.2 0 1 r
.02 w
.81527 .55342 m
.95059 .65174 L
s
P
p
.2 0 1 r
.02 w
.81527 .41809 m
.95059 .31977 L
s
P
p
.2 0 1 r
.02 w
.81527 .41809 m
.86696 .25901 L
s
P
p
0 .4 1 r
.018 w
.76611 .48576 m
.81527 .55342 L
s
P
p
0 .4 1 r
.018 w
.76611 .48576 m
.81527 .41809 L
s
P
p
.2 0 1 r
.02 w
.36264 .27103 m
.41433 .11194 L
s
P
p
.2 0 1 r
.02 w
.36264 .27103 m
.31095 .11194 L
s
P
p
.2 0 1 r
.02 w
.2831 .38051 m
.11582 .38051 L
s
P
p
.2 0 1 r
.02 w
.2831 .38051 m
.14777 .47883 L
s
P
p
0 .4 1 r
.018 w
.36264 .35466 m
.36264 .27103 L
s
P
p
0 .4 1 r
.018 w
.36264 .35466 m
.2831 .38051 L
s
P
p
.2 0 1 r
.016 w
.54308 .48576 m
.612 .27364 L
s
P
p
.2 0 1 r
.016 w
.54308 .48576 m
.36264 .61685 L
s
P
p
.2 0 1 r
.016 w
.54308 .48576 m
.76611 .48576 L
s
P
p
.2 0 1 r
.016 w
.54308 .48576 m
.36264 .35466 L
s
P
p
1 .6 0 r
.016 w
.5 .35319 m
.45692 .48576 L
s
P
p
1 .6 0 r
.016 w
.5 .35319 m
.54308 .48576 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.21445 1.4289 0.0357225 1.4289 [
[ 0 0 0 0 ]
[ 1 1.50034 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.50034 L
0 1.50034 L
closepath
clip
newpath
p
P
p
1 .6 0 r
.016 w
.5 .09955 m
.0772 1.40079 L
s
P
p
1 .6 0 r
.016 w
.5 .09955 m
.9228 1.40079 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0739716 0.952381 [
[ 0 0 0 0 ]
[ 1 .80444 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .80444 L
0 .80444 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.65862 .36516 m
.7476 .48762 L
s
P
p
.2 0 1 r
.02 w
.65862 .36516 m
.80258 .41194 L
s
P
p
.2 0 1 r
.02 w
.6334 .28752 m
.72237 .16506 L
s
P
p
.2 0 1 r
.02 w
.6334 .28752 m
.6334 .13615 L
s
P
p
0 .4 1 r
.018 w
.6178 .3355 m
.65862 .36516 L
s
P
p
0 .4 1 r
.018 w
.6178 .3355 m
.6334 .28752 L
s
P
p
.2 0 1 r
.02 w
.21832 .28752 m
.21832 .13615 L
s
P
p
.2 0 1 r
.02 w
.21832 .28752 m
.12934 .16506 L
s
P
p
.2 0 1 r
.02 w
.19309 .36516 m
.04913 .41194 L
s
P
p
.2 0 1 r
.02 w
.19309 .36516 m
.10412 .48762 L
s
P
p
0 .4 1 r
.018 w
.23391 .3355 m
.21832 .28752 L
s
P
p
0 .4 1 r
.018 w
.23391 .3355 m
.19309 .36516 L
s
P
p
.2 0 1 r
.02 w
.52889 .60914 m
.43992 .7316 L
s
P
p
.2 0 1 r
.02 w
.52889 .60914 m
.52889 .76051 L
s
P
p
.2 0 1 r
.02 w
.59494 .56115 m
.7389 .60793 L
s
P
p
.2 0 1 r
.02 w
.59494 .56115 m
.7389 .51438 L
s
P
p
0 .4 1 r
.018 w
.54449 .56115 m
.52889 .60914 L
s
P
p
0 .4 1 r
.018 w
.54449 .56115 m
.59494 .56115 L
s
P
p
.2 0 1 r
.02 w
.46668 .16639 m
.61064 .11961 L
s
P
p
.2 0 1 r
.02 w
.46668 .16639 m
.55565 .04393 L
s
P
p
.2 0 1 r
.02 w
.38504 .16639 m
.29606 .04393 L
s
P
p
.2 0 1 r
.02 w
.38504 .16639 m
.24108 .11961 L
s
P
p
0 .4 1 r
.018 w
.42586 .19605 m
.46668 .16639 L
s
P
p
0 .4 1 r
.018 w
.42586 .19605 m
.38504 .16639 L
s
P
p
.2 0 1 r
.016 w
.42586 .39787 m
.6178 .3355 L
s
P
p
.2 0 1 r
.016 w
.42586 .39787 m
.23391 .3355 L
s
P
p
.2 0 1 r
.016 w
.42586 .39787 m
.54449 .56115 L
s
P
p
.2 0 1 r
.016 w
.42586 .39787 m
.42586 .19605 L
s
P
p
.2 0 1 r
.02 w
.66909 .25868 m
.81305 .30546 L
s
P
p
.2 0 1 r
.02 w
.66909 .25868 m
.81305 .21191 L
s
P
p
.2 0 1 r
.02 w
.60304 .2107 m
.60304 .05933 L
s
P
p
.2 0 1 r
.02 w
.60304 .2107 m
.51407 .08824 L
s
P
p
0 .4 1 r
.018 w
.61863 .25868 m
.66909 .25868 L
s
P
p
0 .4 1 r
.018 w
.61863 .25868 m
.60304 .2107 L
s
P
p
.2 0 1 r
.02 w
.26723 .45467 m
.17826 .33221 L
s
P
p
.2 0 1 r
.02 w
.26723 .45467 m
.12327 .4079 L
s
P
p
.2 0 1 r
.02 w
.29246 .53232 m
.20349 .65478 L
s
P
p
.2 0 1 r
.02 w
.29246 .53232 m
.29246 .68369 L
s
P
p
0 .4 1 r
.018 w
.30805 .48433 m
.26723 .45467 L
s
P
p
0 .4 1 r
.018 w
.30805 .48433 m
.29246 .53232 L
s
P
p
.2 0 1 r
.02 w
.70754 .53232 m
.70754 .68369 L
s
P
p
.2 0 1 r
.02 w
.70754 .53232 m
.79651 .65478 L
s
P
p
.2 0 1 r
.02 w
.73277 .45467 m
.87673 .4079 L
s
P
p
.2 0 1 r
.02 w
.73277 .45467 m
.82174 .33221 L
s
P
p
0 .4 1 r
.018 w
.69195 .48433 m
.70754 .53232 L
s
P
p
0 .4 1 r
.018 w
.69195 .48433 m
.73277 .45467 L
s
P
p
.2 0 1 r
.02 w
.39696 .2107 m
.48593 .08824 L
s
P
p
.2 0 1 r
.02 w
.39696 .2107 m
.39696 .05933 L
s
P
p
.2 0 1 r
.02 w
.33091 .25868 m
.18695 .21191 L
s
P
p
.2 0 1 r
.02 w
.33091 .25868 m
.18695 .30546 L
s
P
p
0 .4 1 r
.018 w
.38137 .25868 m
.39696 .2107 L
s
P
p
0 .4 1 r
.018 w
.38137 .25868 m
.33091 .25868 L
s
P
p
.2 0 1 r
.016 w
.5 .42196 m
.61863 .25868 L
s
P
p
.2 0 1 r
.016 w
.5 .42196 m
.30805 .48433 L
s
P
p
.2 0 1 r
.016 w
.5 .42196 m
.69195 .48433 L
s
P
p
.2 0 1 r
.016 w
.5 .42196 m
.38137 .25868 L
s
P
p
.2 0 1 r
.02 w
.61496 .16639 m
.75892 .11961 L
s
P
p
.2 0 1 r
.02 w
.61496 .16639 m
.70394 .04393 L
s
P
p
.2 0 1 r
.02 w
.53332 .16639 m
.44435 .04393 L
s
P
p
.2 0 1 r
.02 w
.53332 .16639 m
.38936 .11961 L
s
P
p
0 .4 1 r
.018 w
.57414 .19605 m
.61496 .16639 L
s
P
p
0 .4 1 r
.018 w
.57414 .19605 m
.53332 .16639 L
s
P
p
.2 0 1 r
.02 w
.40506 .56115 m
.2611 .51438 L
s
P
p
.2 0 1 r
.02 w
.40506 .56115 m
.2611 .60793 L
s
P
p
.2 0 1 r
.02 w
.47111 .60914 m
.47111 .76051 L
s
P
p
.2 0 1 r
.02 w
.47111 .60914 m
.56008 .7316 L
s
P
p
0 .4 1 r
.018 w
.45551 .56115 m
.40506 .56115 L
s
P
p
0 .4 1 r
.018 w
.45551 .56115 m
.47111 .60914 L
s
P
p
.2 0 1 r
.02 w
.80691 .36516 m
.89588 .48762 L
s
P
p
.2 0 1 r
.02 w
.80691 .36516 m
.95087 .41194 L
s
P
p
.2 0 1 r
.02 w
.78168 .28752 m
.87066 .16506 L
s
P
p
.2 0 1 r
.02 w
.78168 .28752 m
.78168 .13615 L
s
P
p
0 .4 1 r
.018 w
.76609 .3355 m
.80691 .36516 L
s
P
p
0 .4 1 r
.018 w
.76609 .3355 m
.78168 .28752 L
s
P
p
.2 0 1 r
.02 w
.3666 .28752 m
.3666 .13615 L
s
P
p
.2 0 1 r
.02 w
.3666 .28752 m
.27763 .16506 L
s
P
p
.2 0 1 r
.02 w
.34138 .36516 m
.19742 .41194 L
s
P
p
.2 0 1 r
.02 w
.34138 .36516 m
.2524 .48762 L
s
P
p
0 .4 1 r
.018 w
.3822 .3355 m
.3666 .28752 L
s
P
p
0 .4 1 r
.018 w
.3822 .3355 m
.34138 .36516 L
s
P
p
.2 0 1 r
.016 w
.57414 .39787 m
.57414 .19605 L
s
P
p
.2 0 1 r
.016 w
.57414 .39787 m
.45551 .56115 L
s
P
p
.2 0 1 r
.016 w
.57414 .39787 m
.76609 .3355 L
s
P
p
.2 0 1 r
.016 w
.57414 .39787 m
.3822 .3355 L
s
P
p
1 .6 0 r
.016 w
.5 .29582 m
.42586 .39787 L
s
P
p
1 .6 0 r
.016 w
.5 .29582 m
.5 .42196 L
s
P
p
1 .6 0 r
.016 w
.5 .29582 m
.57414 .39787 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.045847 0.952381 [
[ 0 0 0 0 ]
[ 1 .86069 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .86069 L
0 .86069 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.6998 .32264 m
.85573 .40209 L
s
P
p
.2 0 1 r
.02 w
.6998 .32264 m
.87265 .29526 L
s
P
p
.2 0 1 r
.02 w
.63306 .2559 m
.66043 .08305 L
s
P
p
.2 0 1 r
.02 w
.63306 .2559 m
.55361 .09997 L
s
P
p
0 .4 1 r
.018 w
.64218 .31352 m
.6998 .32264 L
s
P
p
0 .4 1 r
.018 w
.64218 .31352 m
.63306 .2559 L
s
P
p
.2 0 1 r
.02 w
.20547 .47376 m
.12602 .31783 L
s
P
p
.2 0 1 r
.02 w
.20547 .47376 m
.04954 .39431 L
s
P
p
.2 0 1 r
.02 w
.22024 .56699 m
.09649 .69073 L
s
P
p
.2 0 1 r
.02 w
.22024 .56699 m
.19286 .73984 L
s
P
p
0 .4 1 r
.018 w
.24672 .51501 m
.20547 .47376 L
s
P
p
0 .4 1 r
.018 w
.24672 .51501 m
.22024 .56699 L
s
P
p
.2 0 1 r
.02 w
.69422 .64206 m
.66684 .81491 L
s
P
p
.2 0 1 r
.02 w
.69422 .64206 m
.77367 .79799 L
s
P
p
.2 0 1 r
.02 w
.73707 .55796 m
.90992 .53058 L
s
P
p
.2 0 1 r
.02 w
.73707 .55796 m
.86081 .43421 L
s
P
p
0 .4 1 r
.018 w
.68509 .58444 m
.69422 .64206 L
s
P
p
0 .4 1 r
.018 w
.68509 .58444 m
.73707 .55796 L
s
P
p
.2 0 1 r
.02 w
.39774 .21863 m
.52148 .09488 L
s
P
p
.2 0 1 r
.02 w
.39774 .21863 m
.42511 .04578 L
s
P
p
.2 0 1 r
.02 w
.31364 .26148 m
.15771 .18203 L
s
P
p
.2 0 1 r
.02 w
.31364 .26148 m
.14079 .28886 L
s
P
p
0 .4 1 r
.018 w
.37125 .2706 m
.39774 .21863 L
s
P
p
0 .4 1 r
.018 w
.37125 .2706 m
.31364 .26148 L
s
P
p
.2 0 1 r
.016 w
.47719 .47851 m
.64218 .31352 L
s
P
p
.2 0 1 r
.016 w
.47719 .47851 m
.24672 .51501 L
s
P
p
.2 0 1 r
.016 w
.47719 .47851 m
.68509 .58444 L
s
P
p
.2 0 1 r
.016 w
.47719 .47851 m
.37125 .2706 L
s
P
p
.2 0 1 r
.02 w
.68636 .26148 m
.85921 .28886 L
s
P
p
.2 0 1 r
.02 w
.68636 .26148 m
.84229 .18203 L
s
P
p
.2 0 1 r
.02 w
.60226 .21863 m
.57489 .04578 L
s
P
p
.2 0 1 r
.02 w
.60226 .21863 m
.47852 .09488 L
s
P
p
0 .4 1 r
.018 w
.62875 .2706 m
.68636 .26148 L
s
P
p
0 .4 1 r
.018 w
.62875 .2706 m
.60226 .21863 L
s
P
p
.2 0 1 r
.02 w
.26293 .55796 m
.13919 .43421 L
s
P
p
.2 0 1 r
.02 w
.26293 .55796 m
.09008 .53058 L
s
P
p
.2 0 1 r
.02 w
.30578 .64206 m
.22633 .79799 L
s
P
p
.2 0 1 r
.02 w
.30578 .64206 m
.33316 .81491 L
s
P
p
0 .4 1 r
.018 w
.31491 .58444 m
.26293 .55796 L
s
P
p
0 .4 1 r
.018 w
.31491 .58444 m
.30578 .64206 L
s
P
p
.2 0 1 r
.02 w
.77976 .56699 m
.80714 .73984 L
s
P
p
.2 0 1 r
.02 w
.77976 .56699 m
.90351 .69073 L
s
P
p
.2 0 1 r
.02 w
.79453 .47376 m
.95046 .39431 L
s
P
p
.2 0 1 r
.02 w
.79453 .47376 m
.87398 .31783 L
s
P
p
0 .4 1 r
.018 w
.75328 .51501 m
.77976 .56699 L
s
P
p
0 .4 1 r
.018 w
.75328 .51501 m
.79453 .47376 L
s
P
p
.2 0 1 r
.02 w
.36694 .2559 m
.44639 .09997 L
s
P
p
.2 0 1 r
.02 w
.36694 .2559 m
.33957 .08305 L
s
P
p
.2 0 1 r
.02 w
.3002 .32264 m
.12735 .29526 L
s
P
p
.2 0 1 r
.02 w
.3002 .32264 m
.14427 .40209 L
s
P
p
0 .4 1 r
.018 w
.35782 .31352 m
.36694 .2559 L
s
P
p
0 .4 1 r
.018 w
.35782 .31352 m
.3002 .32264 L
s
P
p
.2 0 1 r
.016 w
.52281 .47851 m
.62875 .2706 L
s
P
p
.2 0 1 r
.016 w
.52281 .47851 m
.31491 .58444 L
s
P
p
.2 0 1 r
.016 w
.52281 .47851 m
.75328 .51501 L
s
P
p
.2 0 1 r
.016 w
.52281 .47851 m
.35782 .31352 L
s
P
p
1 .6 0 r
.016 w
.5 .33447 m
.47719 .47851 L
s
P
p
1 .6 0 r
.016 w
.5 .33447 m
.52281 .47851 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0259445 0.952381 [
[ 0 0 0 0 ]
[ 1 .90049 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .90049 L
0 .90049 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.71061 .36698 m
.85384 .47103 L
s
P
p
.2 0 1 r
.02 w
.71061 .36698 m
.88765 .36698 L
s
P
p
.2 0 1 r
.02 w
.65449 .28973 m
.7092 .12136 L
s
P
p
.2 0 1 r
.02 w
.65449 .28973 m
.59979 .12136 L
s
P
p
0 .4 1 r
.018 w
.65449 .34874 m
.71061 .36698 L
s
P
p
0 .4 1 r
.018 w
.65449 .34874 m
.65449 .28973 L
s
P
p
.2 0 1 r
.02 w
.1928 .43974 m
.1381 .27138 L
s
P
p
.2 0 1 r
.02 w
.1928 .43974 m
.04958 .33569 L
s
P
p
.2 0 1 r
.02 w
.1928 .53523 m
.04958 .63928 L
s
P
p
.2 0 1 r
.02 w
.1928 .53523 m
.1381 .70359 L
s
P
p
0 .4 1 r
.018 w
.22749 .48748 m
.1928 .43974 L
s
P
p
0 .4 1 r
.018 w
.22749 .48748 m
.1928 .53523 L
s
P
p
.2 0 1 r
.02 w
.65449 .68524 m
.59979 .8536 L
s
P
p
.2 0 1 r
.02 w
.65449 .68524 m
.7092 .8536 L
s
P
p
.2 0 1 r
.02 w
.71061 .60799 m
.88765 .60799 L
s
P
p
.2 0 1 r
.02 w
.71061 .60799 m
.85384 .50393 L
s
P
p
0 .4 1 r
.018 w
.65449 .62623 m
.65449 .68524 L
s
P
p
0 .4 1 r
.018 w
.65449 .62623 m
.71061 .60799 L
s
P
p
.2 0 1 r
.02 w
.42527 .21525 m
.5685 .1112 L
s
P
p
.2 0 1 r
.02 w
.42527 .21525 m
.47998 .04689 L
s
P
p
.2 0 1 r
.02 w
.33447 .24476 m
.19124 .1407 L
s
P
p
.2 0 1 r
.02 w
.33447 .24476 m
.15743 .24476 L
s
P
p
0 .4 1 r
.018 w
.39059 .263 m
.42527 .21525 L
s
P
p
0 .4 1 r
.018 w
.39059 .263 m
.33447 .24476 L
s
P
p
.2 0 1 r
.016 w
.46353 .48748 m
.65449 .34874 L
s
P
p
.2 0 1 r
.016 w
.46353 .48748 m
.22749 .48748 L
s
P
p
.2 0 1 r
.016 w
.46353 .48748 m
.65449 .62623 L
s
P
p
.2 0 1 r
.016 w
.46353 .48748 m
.39059 .263 L
s
P
p
.2 0 1 r
.02 w
.66553 .24476 m
.84257 .24476 L
s
P
p
.2 0 1 r
.02 w
.66553 .24476 m
.80876 .1407 L
s
P
p
.2 0 1 r
.02 w
.57473 .21525 m
.52002 .04689 L
s
P
p
.2 0 1 r
.02 w
.57473 .21525 m
.4315 .1112 L
s
P
p
0 .4 1 r
.018 w
.60941 .263 m
.66553 .24476 L
s
P
p
0 .4 1 r
.018 w
.60941 .263 m
.57473 .21525 L
s
P
p
.2 0 1 r
.02 w
.28939 .60799 m
.14616 .50393 L
s
P
p
.2 0 1 r
.02 w
.28939 .60799 m
.11235 .60799 L
s
P
p
.2 0 1 r
.02 w
.34551 .68524 m
.2908 .8536 L
s
P
p
.2 0 1 r
.02 w
.34551 .68524 m
.40021 .8536 L
s
P
p
0 .4 1 r
.018 w
.34551 .62623 m
.28939 .60799 L
s
P
p
0 .4 1 r
.018 w
.34551 .62623 m
.34551 .68524 L
s
P
p
.2 0 1 r
.02 w
.8072 .53523 m
.8619 .70359 L
s
P
p
.2 0 1 r
.02 w
.8072 .53523 m
.95042 .63928 L
s
P
p
.2 0 1 r
.02 w
.8072 .43974 m
.95042 .33569 L
s
P
p
.2 0 1 r
.02 w
.8072 .43974 m
.8619 .27138 L
s
P
p
0 .4 1 r
.018 w
.77251 .48748 m
.8072 .53523 L
s
P
p
0 .4 1 r
.018 w
.77251 .48748 m
.8072 .43974 L
s
P
p
.2 0 1 r
.02 w
.34551 .28973 m
.40021 .12136 L
s
P
p
.2 0 1 r
.02 w
.34551 .28973 m
.2908 .12136 L
s
P
p
.2 0 1 r
.02 w
.28939 .36698 m
.11235 .36698 L
s
P
p
.2 0 1 r
.02 w
.28939 .36698 m
.14616 .47103 L
s
P
p
0 .4 1 r
.018 w
.34551 .34874 m
.34551 .28973 L
s
P
p
0 .4 1 r
.018 w
.34551 .34874 m
.28939 .36698 L
s
P
p
.2 0 1 r
.016 w
.53647 .48748 m
.60941 .263 L
s
P
p
.2 0 1 r
.016 w
.53647 .48748 m
.34551 .62623 L
s
P
p
.2 0 1 r
.016 w
.53647 .48748 m
.77251 .48748 L
s
P
p
.2 0 1 r
.016 w
.53647 .48748 m
.34551 .34874 L
s
P
p
1 .6 0 r
.016 w
.5 .37524 m
.46353 .48748 L
s
P
p
1 .6 0 r
.016 w
.5 .37524 m
.53647 .48748 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0344054 0.952381 [
[ 0 0 0 0 ]
[ 1 .88357 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88357 L
0 .88357 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.83792 .46216 L
s
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.87107 .36016 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.69614 .11939 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.58888 .11939 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.69753 .36016 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.64251 .28443 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.13629 .26644 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.04952 .32948 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.04952 .6271 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.13629 .69014 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .43149 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .52509 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.58888 .83719 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.69614 .83719 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.87107 .59642 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.83792 .49442 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.64251 .67215 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.69753 .59642 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.55821 .10942 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.47144 .04638 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.18839 .13834 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.15525 .24035 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.41781 .21142 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.32879 .24035 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .34228 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.22392 .47829 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .6143 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.38381 .25822 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.84475 .24035 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.81161 .13834 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.52856 .04638 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.44179 .10942 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.67121 .24035 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.58219 .21142 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.16208 .49442 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.12893 .59642 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.30386 .83719 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.41112 .83719 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.30247 .59642 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.35749 .67215 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.86371 .69014 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.95048 .6271 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.95048 .32948 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.86371 .26644 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .52509 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .43149 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.41112 .11939 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.30386 .11939 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.12893 .36016 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.16208 .46216 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.35749 .28443 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.30247 .36016 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.61619 .25822 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .6143 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.77608 .47829 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .34228 L
s
P
p
1 .6 0 r
.014 w
.5 .34075 m
.45531 .47829 L
s
P
p
1 .6 0 r
.014 w
.5 .34075 m
.54469 .47829 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0344054 0.952381 [
[ 0 0 0 0 ]
[ 1 .88357 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88357 L
0 .88357 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.83792 .46216 L
s
P
p
.2 0 1 r
.02 w
.69753 .36016 m
.87107 .36016 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.69614 .11939 L
s
P
p
.2 0 1 r
.02 w
.64251 .28443 m
.58888 .11939 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.69753 .36016 L
s
P
p
0 .4 1 r
.018 w
.64251 .34228 m
.64251 .28443 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.13629 .26644 L
s
P
p
.2 0 1 r
.02 w
.18992 .43149 m
.04952 .32948 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.04952 .6271 L
s
P
p
.2 0 1 r
.02 w
.18992 .52509 m
.13629 .69014 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .43149 L
s
P
p
0 .4 1 r
.018 w
.22392 .47829 m
.18992 .52509 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.58888 .83719 L
s
P
p
.2 0 1 r
.02 w
.64251 .67215 m
.69614 .83719 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.87107 .59642 L
s
P
p
.2 0 1 r
.02 w
.69753 .59642 m
.83792 .49442 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.64251 .67215 L
s
P
p
0 .4 1 r
.018 w
.64251 .6143 m
.69753 .59642 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.55821 .10942 L
s
P
p
.2 0 1 r
.02 w
.41781 .21142 m
.47144 .04638 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.18839 .13834 L
s
P
p
.2 0 1 r
.02 w
.32879 .24035 m
.15525 .24035 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.41781 .21142 L
s
P
p
0 .4 1 r
.018 w
.38381 .25822 m
.32879 .24035 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .34228 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.22392 .47829 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.64251 .6143 L
s
P
p
.2 0 1 r
.016 w
.45531 .47829 m
.38381 .25822 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.84475 .24035 L
s
P
p
.2 0 1 r
.02 w
.67121 .24035 m
.81161 .13834 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.52856 .04638 L
s
P
p
.2 0 1 r
.02 w
.58219 .21142 m
.44179 .10942 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.67121 .24035 L
s
P
p
0 .4 1 r
.018 w
.61619 .25822 m
.58219 .21142 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.16208 .49442 L
s
P
p
.2 0 1 r
.02 w
.30247 .59642 m
.12893 .59642 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.30386 .83719 L
s
P
p
.2 0 1 r
.02 w
.35749 .67215 m
.41112 .83719 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.30247 .59642 L
s
P
p
0 .4 1 r
.018 w
.35749 .6143 m
.35749 .67215 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.86371 .69014 L
s
P
p
.2 0 1 r
.02 w
.81008 .52509 m
.95048 .6271 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.95048 .32948 L
s
P
p
.2 0 1 r
.02 w
.81008 .43149 m
.86371 .26644 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .52509 L
s
P
p
0 .4 1 r
.018 w
.77608 .47829 m
.81008 .43149 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.41112 .11939 L
s
P
p
.2 0 1 r
.02 w
.35749 .28443 m
.30386 .11939 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.12893 .36016 L
s
P
p
.2 0 1 r
.02 w
.30247 .36016 m
.16208 .46216 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.35749 .28443 L
s
P
p
0 .4 1 r
.018 w
.35749 .34228 m
.30247 .36016 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.61619 .25822 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .6143 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.77608 .47829 L
s
P
p
.2 0 1 r
.016 w
.54469 .47829 m
.35749 .34228 L
s
P
p
.8 1 0 r
.016 w
.5 .34075 m
.45531 .47829 L
s
P
p
.8 1 0 r
.016 w
.5 .34075 m
.54469 .47829 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0499794 1.09996 0.027499 1.09996 [
[ 0 0 0 0 ]
[ 1 1.15496 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.15496 L
0 1.15496 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.5701 .13326 L
s
P
p
.2 0 1 r
.02 w
.40102 .2561 m
.4656 .05734 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.12474 .16809 L
s
P
p
.2 0 1 r
.02 w
.29382 .29094 m
.08483 .29094 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.40102 .2561 L
s
P
p
0 .4 1 r
.018 w
.36007 .31246 m
.29382 .29094 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.08483 .86402 L
s
P
p
.2 0 1 r
.02 w
.29382 .86402 m
.12474 .98686 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.4656 1.09761 L
s
P
p
.2 0 1 r
.02 w
.40102 .89885 m
.5701 1.02169 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.29382 .86402 L
s
P
p
0 .4 1 r
.018 w
.36007 .84249 m
.40102 .89885 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.90695 .55806 L
s
P
p
.2 0 1 r
.02 w
.73787 .43522 m
.94686 .43522 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.7362 .14526 L
s
P
p
.2 0 1 r
.02 w
.67162 .34403 m
.60704 .14526 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.73787 .43522 L
s
P
p
0 .4 1 r
.018 w
.67162 .41369 m
.67162 .34403 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .31246 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.36007 .84249 L
s
P
p
.2 0 1 r
.016 w
.44618 .57748 m
.67162 .41369 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.39296 .14526 L
s
P
p
.2 0 1 r
.02 w
.32838 .34403 m
.2638 .14526 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.05314 .43522 L
s
P
p
.2 0 1 r
.02 w
.26213 .43522 m
.09305 .55806 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.32838 .34403 L
s
P
p
0 .4 1 r
.018 w
.32838 .41369 m
.26213 .43522 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.4299 1.02169 L
s
P
p
.2 0 1 r
.02 w
.59898 .89885 m
.5344 1.09761 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.87526 .98686 L
s
P
p
.2 0 1 r
.02 w
.70618 .86402 m
.91517 .86402 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.59898 .89885 L
s
P
p
0 .4 1 r
.018 w
.63993 .84249 m
.70618 .86402 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.91517 .29094 L
s
P
p
.2 0 1 r
.02 w
.70618 .29094 m
.87526 .16809 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.5344 .05734 L
s
P
p
.2 0 1 r
.02 w
.59898 .2561 m
.4299 .13326 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.70618 .29094 L
s
P
p
0 .4 1 r
.018 w
.63993 .31246 m
.59898 .2561 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.32838 .41369 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .84249 L
s
P
p
.2 0 1 r
.016 w
.55382 .57748 m
.63993 .31246 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.44618 .57748 L
s
P
p
1 .6 0 r
.016 w
.5 .41184 m
.55382 .57748 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`0001H000=<04`080000d`0C0140003C000048000=<04`080000lH0aP0G00005P000dd0
C@0P0003C@1=01h000==00000P000dd0000M00==80000dd0C@0P0003C@1=020000?60<H05`0001D0
00=<00000T`N009<00<0C4`07@0014`0C002C1X000=<04`00P03C08000=<04`06`03C1l00T`00`1<
C00N00;600<0a/H05P0000d000E=0000C@0200E=00D0C@00C@02009=3P001Dd0001=00800Td00`1=
0002C@8000==00000Td@0004C@00009=00L0CDd0C@1=00<000==00003@02C@<000A=04d00Td01`1=
C@1=04d00`02C@d00Td20003C@0000==00@0CDe=0P000dd00002C@h00Td20003C@00009=00<0C@00
0Td20003C@00009=3P02aP8000?600000/H00`360002aP8000G60000aP0>00003P0014`004`200A<
00<0C4`00P000d`0C00A0004C000C0800d`0101<C4`20003C01<01800T`200M<00@0C0000T`A009<
00H0C01<04`30006C01<04`00T`A0003C01<00800T`3009<0P000d`0C00B0003C01<00800d`0101<
C4`20003C01<018000?60<H00P03aP040<K6aP8000C600363`0000l000A=04d00dd200==00@0C@1=
4`0014d0C@03C@<00Td0101=04dA009=00@0C@001dd01P1=001=009=3@06C@0304g600D000?6C@00
0Td0101=CDd@009=00<0CLH01@000lI=0002CA@00Td0101=CDd300==00<0CDd050001<H0aP02aP<0
0lH010360<H@000040001D`0C4c600@00/H3C1D000E<04a<]0050004]4a<C1@00d`0101<aT`30004
aP1<00=<4`001Dc6C03600D000C60<K60T`?00E<00C6C4c61@001<I<a/H5C1400d`00lH000030004
aTa<C1H01<H500?600<0aP00400000/01Td00lI=C@070003CLI=00E=2`06C@03]4e=00L000==]4d0
1Dd>0003C@0000A=1@0014g6aTd20003C@0000X000==00001@02C@L00Td70003C@0000h00Td7009=
4@09C@L000==aTd01Td:00W61`000dg6aP06aP`0000;0003C00000@000?6C0001P000d`000040003
C00000T000=<000010000kA<00060003C00000@000=<0000200014`00003C08000?60000100014c6
0003C08000=<00001P02C0L000?6C0001P000dc60006009<20000d`000040003aT`000H000=<aP00
1@000d`000080003C00000@000?6C0001P000dc600050003C00000P000?600001@000lH000050003
C<H000D000?600002P0000T000A=001=1@000lI=00050003CLH000D000A=001=1P0014d004d50003
]4d000D000==]0001@0014d004d70003C@1=009=10000lI=00040003CLH000<014d9009=1@000lI=
C@0300034@0000==00?600000`02C@T000==000010000lH0C@060003CLH000D000==00001P0014d0
04d50003aP1=00D000==0<H01@0014d004d60004aP00aPH000?6C@0010000dd0aP050004aP00aPX0
000:00M<00C6C4a<0P000a400002C0;61d`800M<00BdC4a<0P000a400002C0:d1d`90003C00000=<
00@0aTa<0P000a40C002C003aP1<009<00<0C0002P02C00404a<aP<000A<000A0P001D`0003600E<
2002C00304a<009<0/H3C08000<A00000d`2aPM<1`07C004aTa<C08000<A00000d`00lI<C005C0P0
2LH2C08000<A00000d`8aP/0000;009=0P000dd000020006C@004@1=1@001Dd0C@1=00X00Td20003
C@00008000I=000A04d50005C@1=04d02002C@0304d000==00W60000C@0A04d00`000lI=C@02C@80
0Td800A=1@02C@8A0Td600A=2P02C@0304d000@00Td01@0A001=00D000A=04e=2P02C@8000==0000
0P02C@030140009=10000dd00002C@X00/H20003aP0000<000A=01400Td40003aP0000;6300000`0
0d`5009<0Q42C0H00d`<00=<1@02C08A0T`600=<2`04C08000A<00000T`00a5<C0030003C00000A<
2`000dc600050006C00AC15<1`000lI<000;009<1`02C08A0T`6009<3003C0H00T`00a5<C00600=<
3003aPH00T`00a5<C00600?63@0000d000==00001@001DdACA5=00L000?6000030000dd000050005
CA5=4Dd01`000k@0000=0003C@1=00@000A=4DdA1@000dd0aP0=0003C@3600L000E=4DdAC@070003
aP1=00/000==aP001P001DdACA5=00L000?6C@0030000dd000050005CA5=4Dd01`000lH0000<0003
aP0000D000E=4DdAC@070003aP0000`0000<0003C01<00I<00@AC4`A24`00`1<000;0003C01<00I<
00@AC4`A24`00`1<000=00Q<00<AC14024`@00M<00@AC4`A24`@00Q<00@AC4`A1d`>0003C01<00M<
00<AC14024`00`1<000;0003aP1<00M<00<AC14024`00`36000<00003002C@03aP0000D00Td80003
aTe=00`00Td00k@00005009=20000kA=C@0>009=1P000dd0C@060003aTd000`00Td00lH0000600==
20000lI=C@0;009=00?600001P02C@L000?6CDd03002C@03aP0000D000==04d01`000lI=C@0<00?6
1`000dd0C@0700?63@0000`000A<aTa<1002C0800T`5009<00?6C0002`0014bdC4`4009<0P02C0D0
0T`00kA<000;009<00?604`010001D`0001<00@000=<0<H00d`<009<1@02C0<000=<00001002C0d0
00=<aT`01P02C08000=<000010000dc6C00<0004C<I<C0@00T`3009<1002C003aT`000/01<H50004
C000009<1004aPd0000;0003C@1=008000A=001=1P001Dd0001=008000==04d02P000dd0C@020004
C@00C@H000E=0000C@020003C@1=00P00dd00`1=C@02C@<000==00000`0014d00003C@<00Td800E=
0`000dd00004009=0`000dd0C@02C@X000E=04d0C@040003C@0000<000==00000P001Dd0C@1=00X0
00==04d00P0014d004d70004C@00C@8000==04d02P000lH0aP020005aP0004d01P0014d00<H20003
aP3600`0000:00M<00?6C0001`000dc6aP07C0P01d`00kA<00070003C;Bd00M<2P000d`0C002C0;6
00=<00001@000dc6aP04C0`00T`20004C<K6C0T000=<a/H00T`00`1<C0090003C01<00=<0/H00`1<
00060004C036aPI<2007C003aT`000P000=<aT`01T`800W600=<00001P000dc6aP06aP/000090004
C@00C@D000?600001P000lH000040004C@00C@H000A=001=1@000k@000060003]00000@000A=001=
2004C@@000?600001@000lH0000200==2P02C@H000?600001`000lH00004009=1`0014d004d50003
C@0000L000==00000`0014d004d60004C@00C@D000?600001`000lH000030004C@00C@H000C60036
1P000lH000060003aP0000<000C600362P0000`000=<00000`000lH000060003aP0000@000=<0000
2P000d`000030003]00000H000>d000010000d`000080005C00004`010000lH000050003aP000080
00A<001<20000d`0C0060003aP0000L000?6000010000d`0C0080003C00000@000?600001`000lH0
00040003C00000T000=<00000`000lH000070003aP0000<000=<00002P000lH000040003aP0000H0
00?600000`000lH0000;00002`000dd000040003C@0000H000==000010000dd000090003C@0000@0
00==00001P000dd000040003C@0000`000==00000P000dd000050003C@00008000==00002P000dd0
00050003C@0000L000==00001@000dd0000>0003aP0000L000?600003`000dd000040003C@0000L0
00==000010000dd000080003aP0000D000?600001P000lH000040003aP0000X0000B009<1`02C1P0
0T`7009<6003C0D00d`H0003C00000L000=<00005P000d`000070003C00001H00T`7009<6002aPL0
0/HC00004P02C@L00TdH009=1`02CAL000E=04d0C@030005C@1=04d05`000dd000070003C@0001H0
0Td7009=6002C@L00TdH00;61`02aQ<0000A0003C01<00H000=<04`05`000d`0C0060003C01<01H0
00A<001<0P000d`0C0020004C000C1D000=<04`01`000d`0C00F0003C01<00L000=<04`05P000d`0
C0070003C01<01L000?60<H01P000lH0aP0B00004@0014d004d50004C@00CAH000A=001=1@0014d0
04dH0003C@0000D000==00005P000dd0C@070003C@1=01H000A=001=1@0014d004dF0004C@00C@D0
00A=001=5P001<H00<H50004aP00aQ80000A0004C000C0D000A<001<5P0014`004`50004C000C3T0
00=<04`01`000d`0C00i0004C000C0D000A<001<5P001<H00<H50004aP00aQ80003o00<0003o00<0
003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0001L0003C@1=020000==04d0I`000dd0
000F0000>@000d`0C00P0003C01<020000=<04`0@P001D`0001<020000=<00005P00010000A=001=
1`0014d004dI00A=7`02C@0304e=01h00Td00`1=C@0L0003C@0000D000==00006P02C@0304e=01X0
00==00000dd0101=CDd20003C@000100000@0004C000C0L000A<001<4@02C00304`000801d`20004
C01<C0l000E<0000C002009<00<0C0000T`20003C000009<3P02C08000=<00000T`00`1<0002C080
00=<00000T`A0004C000C0L000A<001<4P000d`000020009C01<04`0C01<00@000=<00003@02C080
00E<001<0003C00504`004`00P02C0h0000@0003C@1=00T000==04d04`02C@<00Td3009=0P02CA80
00A=001=0P03C@0404e=C@8000==04d04P000dd0C@0200==00@0CDe=0P000dd0C@0C0004C@00C@L0
00A=001=4`02C@800Td01@1=04d0009=0P02CA8000i=001=04d0C@1=04d0C@8000==00003P000140
0T`9009<5P0014`0C<H50004aT`0C1@000A<04`00d`3009<00@0C01<5002C00404a<C0<00d`00`1<
C00E0003C01<00L000=<04`05@000d`00003C0<00d`20003C000018000I<04a<0<H30006aP1<C01<
4@0000d000==00000dd900==0P000dd0000;00I=00?6CLH01@000lI=aP05CA4000E=04e=aP050004
aTe=CAH00dd00lH000030004aTe=CA@000==00000Td30004C@00009=0P000dd0000>00I=00<0aP00
10001LH0CDd000==3@05C@04aTe=aPD000C6CLK61Td<00002P0014`004`20003C<H000X000G6C000
C0020003C00000d000=<04`01`02C1401T`00lI<C0070003C<I<00I<2P09C0L000=2aT`01T`>0005
C0000<H00T`00`1<0002C005aP0004`05002C0;61@000lH0aP02C0l000=<00001@000lH000050003
C00000D000=<00002P0000T01Dd20003CLH000X000?6C@001Dd90003C@0000@000?6C@001P000dg6
00050003C@0000P000==000010000lI=00060003C@0000D000==000020000dd000040003aT8000H0
00=2aP001@000dd0000=0004C@00aP800dd20004aP00C@l000==000010000lH0C@060003CLH000D0
00==000020000dd000050003aP0000D000==00001@000dd0000:00003003C003aTa<00/000=<a/H0
0d`;0003C00000@000?604`01@000d`0aP060003C00000H000A<001<1@000lH0C0050003C<H000D0
00A<001<1P0014`004`50003aP1200D000=20<H01@0014`004`:00E<00<0aT`01d`00`1<C003C0`0
00=<000010000lH0C0060003C<H000D000=<00001P02C00304`000D000?6C00010000dc600050004
C01<C0X0000<00E=00<0C@000`000a40000200==00@0CDe=2@07C@;60dd200034@0000==0/H7C@L0
1dd01<I=CDd200034@00009=0/H7C@P01dd01<I2@T8200034@0000=200?6CDd01Dd>009=00?6CLH0
0Td200==00?6CDd04005C@;60dd0100A0002C@;61Dd;009=1@000lI=C@0200034@00009=0/H4009=
300000/000I<00360<H20005C00001400`000d`0aP020004aP00C0X00T`00`1<0004009<00<04@00
0T`50004C01<C0X00T`20003C00000800T`0100A04`50003C000009<2P02C08000=<00000P02@P03
0140009210000d`00002C0d00d`00`1<C002C003014000A<00@0C4a<2`02C00304`0009<1@0014`0
4@02C0@00T`00`1<0002C0P01D`2aP<000E<0140C0040003aTa<00=<300000X000M=0000aP3600<0
00A=000A0P0014d00<H20005aP0004d02P02C@L00Td00a5=C@07009=3003C@H00Td00a5=C@0600==
3003C@H00T800a52@P0600==4003C@09aP1=0140C@3600==3`03C@L00Td00a5=C@0700==30000lI=
0005009=00<ACDd01P000dg6000=00003@000dc6C006C0034@0A00M<00?6C00030000dc600060005
C15<4D`01`000lI<000<0003C00000D000E<4D`AC0070003aP0000`000=<00001@001D8A@Q5200L0
00?600002002C0@00T`010360002C0034Da<008000A<0<I<1002C0T000=<a/H01`00115<4D`600;6
00=<00002`000dc600050005C15<4D`01`000lH0000<000030001Dg6CDg600<00Td00a5=4@03C@80
00G6C@36C@0>00Q=00<ACA4024d>0003C@1=00M=00<ACA4024d00`1=000;0003C@1200M200<A@Q40
24800`1=000:009=0P0014g604d300034DdA00<000A=0<I=0P02C@d000?6CDd01Dd00a5=4@07C@03
aP0000`00Td00`1=C@05C@034DdA00Y=3@0000X01d`4009<00<0C4`010000d`0C004C0X00T`00lH0
00050003C01<00L000?6C4`03002C003aP0000D00T`80003aTa<00`00T`00lH000050003@P1200L0
00?6C4`030000dc6aP07C0034D`A00M<0/H00d`0000:0003C<H000L000=<04`020000lI<000=0003
C00000D000=<04`01`000lH0000=00002@000dd0C@04C@;600<0CDd01@02C@030<I=00E=00<0C@00
20000dg6C@060005C@0004d01P000dg6C@0<0004CLI=C@D000A=001=1P02C@03aTd000/000A=aTe=
1@001D80001200D00Td00lI=0009009=0`001<I=CDd30003C@1=00<00dd01<H00002C@T00dd70005
C@0004d01`03C@/000A=aP1=1@001Dd0001=00D000A=0<I=3@0000`000A<001<0P000d`000070004
C000C08000=<00002@001D`0C01<00@000=<00000`000d`000020005C01<04`02P000d`0C0020005
C00004`010000d`000020006C000C01<2P000d`0C0020005C00004801@001D80001<008000=<04`0
20000d`000030004C<H0C08000E<0000C0020004aP36C0D000=<00001@0014`0C003C0<000=<0000
0`0014`00003C00404`0C0T01D`3aP0304`000@000=<00000/H5C0`0000<0004C@00C@8000?60000
1`001<H004d20003C@0000P01Td2aP0304d000H000A=0<K61Td800M=00?604d01P0014d0a/H7C@P0
1dd00lH0@P070003@P3600M=3P001Dd0C@1=00D000E=0<H0C@0=0004C@00C@800Td2aP03C@0000D0
00==a/H00dd01@1=001=00L000==04d01P000dd000050003CLH000@000==04d02`0000/000A<001<
0`000lH000070005aP0004`00P000d`000060004C000C0D000=<00001`000d`000030004C000C0H0
00A<001<1@000d`000060003C00000@000A<001<1P0014`004`50003@P0000L000=200000`0014`0
04`=009<00<0C0001P0014`0C4`@00=<10000lH000050003aP0000<00T`90004C000C0H000?60000
1@000lH000040004C000C0X0000B0003C@0000L000==000040000dd000030003aP0000L000?60000
0`000dd0000:0003C@0000<000?600001P000lH000040003C@0000X000==00000`000lH000070003
aP0000<000==00003P02C@03aP3600E=00?604d00dd>0003C@0000@000?600001`000lH000040003
C@0000T000==000010000lH000050003aP0000@000==00002`0001400T`9009<40000d`000040003
aP0000L000?6000010000d`000080003C00000@000=<00001P000d`000050003C00000P000=<0000
10000d`000070003C00000@000=<00002P04C00304a<00U<00<0C0000T`C0003C00000L000=<0000
3`000d`000050003aP0000D000?600001@000d`0000:000040000dd0C@080004C@00CAH000==0000
1`000dd0000F009=1`02CAP00Td7009=5P02C@<000E=0000C@03009=5@02C@T00TdH0003C@0000D0
00==00004P00010000=<04`0200014`004`E0003C01<00L00T`H009<1`02C1P00T`7009<5P000d`0
00030003C01<00D000=<00004`000d`0C0070003C01<01L00T`7009<4`0000l000A=001=20001Dd0
001=01@000==04d01`000dd0C@0F0003C@1=00H000==04d05`000dd0C@070003C@1=01@000==0000
1@000dd000050003C@00018000==04d01`000dd0C@0G0003C@1=00D000==04d04`0003@000=<04`0
1`000d`0C00F0004C000C0D000A<001<5P0014`004`50004C000C3P000A<001<1`0014`004`F0003
C01<00D000=<04`04`0003<000E=0000C@050004C@00CAH000A=001=1@0014d004dF0004C@00C@D0
00A=001=G00014d004d50004C@00CA80003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0
003o00<0000G00034@000<h000==04d05`0001L000<A0000I@000d`0C00P0003C01<020000=<04`0
80000d`0C00G00005`000a4000110005C@0004d07`000dd0C@0P0003C@1=020000==04d06`000dd0
0003C@0404e=C@<000==00003`0001H000<A01406P0014`00002C0<00T`20003C00001D000=<0000
0T`00`1<C0020003C00001T00T`00`1<C00N009<00<0C4`07P02C00304a<01H00T`20003C00000M<
0`0014`0C4`>00005P000a404@0J0004C@0000A=00<0CDd00P000dd0000E0008C@00C@1=04d20003
C@0001400Td00`1=00020007C@1=04d0C@030004C@1=C@h00Td20003C@00009=00<0C@000Td20003
C@00009=3P02C@8000==00000Td00`1=0002C@8000==00000Td@0007C@1=04d0C@030007C@1=04d0
C@0@00005P000a404@0I00=<00@0C4`01D`00`1<0002C1D000=<04`00T`01P1<C4`0C1D00T`3009<
00<0C0000T`3009<4P000d`0C00200=<00@0C4a<0P000d`0C00B0003C01<00800d`0101<C4`20003
C01<01<00T`00`1<aP050003aT`0009<4@0001D000DA00004@0G0003C@0000Q=00<0CDd00Td20003
C@0000`00Td40004C@1=C@<00Td00`1=0003009=4002C@0304d0009=00H0CDd0C@02CA@00Td0101=
CDd300==00<0CDd05002C@0404e=C@<00dd00`1=C@0@00E=00C6CDg61@001<I=a/H6C@`0000E0005
4@00014050001T`004`0C0800d`01<H0aT`2aP8000=<04`00P000d`0000;009<0`02C0D000?6C000
0P02C1<000=<04`00/H30005aP1<04`05P03C003aP0000<000C6C4a<5P03C003aP0000<000C6C4a<
5`02C0L00T`C00005@001A40000A01D01Td0101=aTd30006CLI=04d014d@0003C@00009=1@001LI=
001=00l01dd00lI=00050003CLK600I=2`09C@L000==aTd01Td:00U=1`000dg6C@06CA4000?6C@00
1P000dg6000B000050000a40000300034@0001<00T`200=<00<0C0000P0014`0C<H2C00304a<00l0
0d`3aPL000=<a/H00d`=0003C00000@000?6C0001@000d`0aP050003C00000T000=<000010000lI<
00060003C<H000D000=<000020000d`000040003aT`000H000=<aP001@000d`0000?0003aP1<0080
00HA0000C<HC000050000a40000300034@0001@00dd20003aP1=00<000==04d00P02C@03aP0000/0
14d3009=1`000dg6000200A=200014d004d50003aP1=00D000==0<H01@0014d004d60004C@00C@D0
00?604d01@000dd0aP050004C@00C@H000A=001=1@000lH0C@050003C@3600D000A=001=2005C@;6
0dd200034@0000==0/H5C@`0000D00034@0000<000<A00004`000dc600030006aTa<01400T`00lH0
00020003aT`000/000A<00000T`01<H0C4`200034@00009<00@0aTa<0`000d`0000700I<0/H3C0@0
00A<04a<0/H6C0P01d`01<I<C4`200034@0000=<00?6C4`01D`800M<00C6C4a<0P000ml00003C003
aTa<00E<3@000d`00002009<00D04A40C0040003C00000h0000C00034@0000D000<A00004P04C@80
0dd00`0A0003C@800Td00lI=000<00A=100014d001420003C@00008014d;009=0P000dd00002009=
00<04@000Td40005C@1=04d02P02C@8000==00000P02C@030140009=10000dd00002C@X00Td20003
C@0000800Td00`3N0002C@@000==00000Td=0003C@0000@000A=4@0A0Td50003C@0000d0000C0003
4@0000D000<A00004003C0800T`01<I<04`34@03C01<00A<00@0aTa<2002C00304a<00L000E<0140
C007009<00<0C4`02@03C0H00T`00a5<C00600=<3003C0H00T`00a5<C00600=<3003C0H00T`00mm<
C00600=<3@000d`000050005C15<4D`01`000d`0000<00004`000a40000500034@0000h01dd2000;
C@1=4DdACA5=04d00`06C@P00dd70005CA404Dd01`03C@`000==00001@0014dACA480003aP0000`0
00==00001@001DdACA5=00L000?6000030000dd000050005CMi=gTd01`000lH0000;0003C@0000L0
00@A000A20000dd0000;00004P000a40000700034@00010014`00`1<0002009<00<AC4`00`000d`0
C003C0`000=<0<H01P001D`AC15<00H000?6C00030000d`0C007C0034D`A00Q<00<0C0002`000d`0
C007C0034D`A00Q<00<0C0002`000d`0C007C003gdcO00Q<00<0C0005@0014`004`F00004P000a40
000700034@0000l000==00000P000dd00004C@0304d000==00<0aP000`000dd0000:0003CLH000<0
0dd00a5=4@04C@<000?600003002C@03aP0000D000==04d01`000lI=C@0<009=00?600001@000dd0
C@070003aTe=00`00Td00lH000050003C@1=00L000?6CDd05@001Dd0001=01H0000B00034@0000L0
00<A00003P000d`000020004C01<C0@000=<00000`000d`0C0040003C00000H02D`01@1<C4`000=<
0P03C00304a<009<2P000dc6C0060005C00004`01P000dc6C00<0004C<I<C0D000E<0000C005009<
00?6C0002`0014c6C4`50005C00004`01@02C003aT`001@000=<00000P000d`0000C00004@000a40
000900034@00018014d3009=1@000dg6C@0A0004CLK6009=1`02C@040<I=aPd000E=04d0C@040003
C@0000<000==00000P001Dd0C@1=00X000==04d00P001Dd0001=00D000E=0000C@020003C@1=00X0
00==04d00P001Dd0001=00D000E=0000C@020003C@1=01<000==00000`000dd0000C00004@000a40
000900034@0001<000I<001<aT`20003C<K6009<00<0C0004002C08000=<00002@000d`00002C0/0
1T`2aP0304`000H000A<0<K61T`800M<00?604`01`000d`0aP07C0P01d`00lH0C0070003C03600M<
4P000d`000030003C00001<0000A00034@0000T000<A00004P04C@8000C600360`04C@l000==04d0
0P000lH000090006aP00C@1=2@0014d004d50003C@0000L000==00000`0014d004d60004C@00C@D0
00==00001`000dd000030004C@00C@H000A=001=1@000dd000070003C@0000<000A=001=4@000dd0
00040003C@000180000@00034@0000/000<A00004003C0D000?60<H01@02C0h000A<001<0P000lH0
00090004aP00C08000=<00002@000d`000030003aP0000L000?600000`000d`0000:0003C00000<0
00?600001`000lH000030003C00000X000=<00000`000lH000070003aP0000<000=<000040000lI<
00060003C<H00180000@00034@0000/000<A00003`0014d004d50003C@1=00D000==04d0300014d0
04d30003C@0000T000E=0000C@020003C@0000L000==000010000lH000070003aP0000<000==0000
2@000dd000040003C@0000L000==000010000dd000080003C@0000@000==00001`000dd000040003
C@0000T01Dd00lH0aP070003aP3600I=3000010000<A00002`000a40000B0003C00000<00d`50003
C00000l000=<00000T`;009<0P000d`0000A0003C00000L000=<00005P02C0L00T`H009<1`02C1D0
00=<00000P000lI<00020003C<H000<000=<00003P0000l000<A00003@000a40000G0003C@1=01L0
00==04d00P000dd000070006C@00C@1=4P000dd0C@070003C@1=01L00Td7009=6002C@L00TdD0003
C@0000<000==04d00Td00`1=00040003C@0000d0000?00034@0000d000<A00005P02C00304a<01P0
00A<001<2@0014`004`D0003C01<00L000=<04`05P000d`0C0070003C01<01H000=<04`01`000d`0
C00B0003C00000D00T`00`1<C0070003C00000`0000?00034@0000d000<A0000<P001Dd0001=00T0
00E=0000C@0C0003C@1=00L000==04d05P0014d004d50004C@00CAH000A=001=1@0014d004dJ0005
C@0004d05P0000h000<A00003`000a40001F0005C00004`01@001D`0001<01D000A<001<1@0014`0
04`F0004C000C0D000A<001<6P001D`0001<01H0000>00034@0000l000<A0000a@000dd0C@0G0000
o`030000o`030000o`030000o`030000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.109418,
   0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110615, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.109416, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.74027, -0.110615, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.109418, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277,
   -0.110615, 0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.1939, -0.109418, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.270008, -1.2634, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  69.375, 37.5625}} -> {-1.42777, -1.26686, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26686, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.88594, -1.2634, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277,
   -1.26687, 0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.1939, -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.269997, -2.41735, 0.0329411, 0.0329411}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.74027, -2.42311, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277,
   -2.42311, 0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.19391, -2.41739, 0.0329416, 0.0329416}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .78487 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0837567 0.952381 [
[ 0 0 0 0 ]
[ 1 .78487 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .78487 L
0 .78487 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.79178 .57374 L
s
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.86468 .50084 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.81993 .21828 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.72807 .17148 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.71605 .42511 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.70197 .33624 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.18602 .17148 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.09415 .21828 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.0494 .50084 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.1223 .57374 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.21211 .33624 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.19804 .42511 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.63783 .74125 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.73966 .72512 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.86953 .47022 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.82273 .37836 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.66392 .57648 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.70477 .49632 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.3842 .05975 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.28237 .04362 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.08008 .24591 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.09621 .34774 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.30846 .20838 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.24484 .272 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.67673 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.23736 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.65522 .52156 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.29976 .26331 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.90379 .34774 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.91992 .24591 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.71763 .04362 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.6158 .05975 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.75516 .272 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.69154 .20838 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.17727 .37836 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.13047 .47022 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.26034 .72512 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.36217 .74125 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.29523 .49632 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.33608 .57648 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.8777 .57374 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.9506 .50084 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.90585 .21828 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.81398 .17148 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.80196 .42511 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.78789 .33624 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.27193 .17148 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.18007 .21828 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.13532 .50084 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.20822 .57374 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.29803 .33624 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.28395 .42511 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.70024 .26331 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.34478 .52156 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.76264 .38579 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.32327 .38579 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.45704 .42058 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.54296 .42058 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{189, 148},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002m0000U0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000;d0002m0000_@000;d0002m0000_@000;d0
002m0000=003C4h00d`e0000=003CDh00dde0000=003C4h00d`e0000=003CA000ddX00==4003CCD0
000d00A<3`03C2P00d`?00A<=@0003@014d>00A=:004C@h014de0000=@03C0h014`X00A<3P03C3H0
000e00==3@04CBX014d=00===P0003D00d`=00A<:P04C0d00d`f0000=@03C@`014d/00A=3003CCH0
000e00A<2`04C2`014`;00A<=P0003D014d:00A=;P04C@X014df0000=P03C0X014`^00A<2P03C3L0
000f00==2@04CC0014d900===`0003H00d`900A<<004C0T00d`g0000=P03C@P014db00A=2003CCL0
000f00A<1`04C38014`700A<=`0003H014d600A==004C@H014dg0000=`03C0H014`d00A<1P03C3P0
000g00==1@04CCH014d500==>00003L00d`500A<=P04C0D00d`h0000=`03C@@014dh00A=1003CCP0
000g00=<1004C3P014`400=<>00003L014d200A=>P04C@8014dh00008P03C0d00d`200A<0P04C3X0
14`200A<0P03C0d00d`S00008P03C@d00dd300==00<0CDd00Tdl00A=00@0CDe=0`03C@d00ddS0000
8P03C0d00d`300=<00<0C4`00T`l00A<00@0C4a<0`03C0d00d`S00008P03C@d00dd300M=?P07C@<0
0dd=00==8`00028014`<00A<0P07C3h01d`200A<3004C2<0000R00A=3004C@801Te000I=0P04C@`0
14dS00008`03C0d00d`200I<@006C0800d`=00=<900002<00dd=00==0`03aP03C@00040000A=a/K6
0`03C@d00ddT00004004C0d01D`=00=<0`03aP03C000040000A<a/K60`03C0d01D`=00A<4@000100
1Dd<00E=3@03C@<00lI400?60`03C@d01Dd<00E=4@0001001T`;00I<3004C0030<K600;6A004aP03
04a<009<3006C0/01T`A00004P05C@/01Dd<00A=00<0a/H00/I400C600<0CDd00Td<00E=2`05CA<0
000C00E<2`05C0`00d`01036a/I600?600@0C4a<3005C0/01D`D00005005C@/01Dd;00==00@0a/K6
AP03aP0404e=C@/01Dd;00E=5@0000h034`:00I<2P03C0040<K6aTH00lH0101<C4`:00I<2P0<C0l0
000>00m=1`07C@T00dd4aTH01<H3C@T01dd700m=3`0000h07T`800A<0lI600C60d`801i<3`0001<0
6Td500;614d2aTP02<H501Y=500001T05D`7aPA<00?60000AP02C0_654`J00006P05C@<03Dd6aPE=
A`03C@_62dd300E=6`0001/01D`500]<1<H00`1<C004C4D00d`01@1<C4`000O624`500E<700001`0
1Dd400a=1003C@0404e=CD<00dd200==100<C@@01DdM00007@05C0<01d`00`1<C003C0<014`0101<
C4a100=<0P04C0<01D`00`1<C005C0<01D`N00007P0<C@@01Dd200A=0P03CAl00Q4N00==0`04C@80
1Dd400a=7`0001l02T`600E<0P03C0<00d`N008A7@03C0@00d`200E<1P0:C200000O00Y=1`05C@04
04e=C@@00ddL00@A6`03C@D00dd00`1=C@03C@L02TdP00007@0<C0P024`500=<6`044AX00d`600Q<
200<C1h0000K00i=2@07C@H00ddJ00@A6@03C@L01dd900i=700001T024`200M<2@07C0H00d`H00HA
5`03C0L01d`900M<0P08C1X0000H00M=1@06C@X01Td700==5`024@800Q4F00==2006C@X01Td500M=
6@0001H01d`8009<0lH;009<0lH800=<5P024@800Q4E00=<2@03aP9<2`03aP9<2007C1L0000D00M=
2`0014g6a/H<0004CLK6aPT00ddD00<A0P034A<00dd:00?600==00002P03aP03C@0000T01ddE0000
4P08C0d01<H<00C62@03C1<00Q44008A4P03C0X01<H<00C63@08C1<0000A00M=3`04aP`01<H:00==
4@034@@00Q4A00==2`04aP`01<H?00M=4P0001401D`B00?63@03aP/00d`@008A1@034@l00d`<00?6
3@03aQ801D`B00004@03CA@01<H<00C62`03C@l00Q46008A3P03C@`01<H<00C65003CA80000X00C6
3004aP`00d`=00<A1P024@d00d`=00C63004aRT0000Y00C63004aP`00dd<008A1`034@/00dd=00C6
3004aRX0000P00=<1P04aP`01<H=00=<2`024@P00Q4:00=<3P04aP`01<H600=<8@00020014d600?6
3@03aPh00dd900<A20024@T00dd?00?63@03aPH014dQ00008005C0D01<H<00C63P03C0P00Q4900<A
1`03C0l01<H<00C61@05C240000Q00E=10000lI=C@03C@X000?6CDd014d<00==1P034@X00Q4600==
3@05C@;62@05C@;61005CB80000R00E<0P02aPa<0P02aPe<1P03C0D00Q4;008A1@03C0L034`3aP03
04a<00Y<0lH200E<8`0002<01Dd5aP802Dd5aP03C@00019=10024@/00a4300==00<0CDd03Dd00`1=
C@0=C@<01LH5CB@0000T00E<0lH:0003C<K600?62D`200i<0a4<008A3d`00`1<C00=C0/01LH3C2D0
000U00E=00?600002@05aP803dd200M=0Q46C@801Dd24@Q=00<0CDd03Dd300G62`05aP03C@0002@0
000U0003aTa<00=<2P05aPX04D`24@e<0a4@C0/01LH:0003C<K600?69P0002<000A=a/K61Dd70003
CLK600?64P09C@<A3Td24@U=4`05aP03C@0000D00dd5aP03C@000280000Q00=<1<H5C0@00d`4aQX0
0T`24@=<2@03C08A0T`K00C60d`400E<1<H3C280000O00E=0lH200E=00<0CDd00dd3aQl01Dd500E=
8003aPE=00<0CDd00dd200?61DdP00007@0:C0<03D`Q00E<00<0C4`00d`R00e<0`0:C1h0000K00]=
1@0;CB@01ddU00]=1@0;CA`0000I00Q<00<0C4`00T`300Q<00<0C4`00T`T00M<9@04C00304a<00I<
0`04C00304a<00I<6P0001L024d200A=0P0>CB<01Dd00`1=C@03CB@03Td200A=0P08CAP0000E00Q<
100<C00304a<00E<8@05C0D01D`R00M<00<0C4`02T`400Q<5P0001<024d500]=1005CB001Dd900E=
8@05C@@02dd500Q=500001403D`200U<1`05C1d01D`=00E<7P05C0L02D`200e<4P0000l064d800M=
6P05CA401DdK00M=200HCA00000=00Q<0P0FC08024`G00E<5@05C1P024`201I<0P08C0h0000;00Q=
200MCA@01DdI00E=5@0MC@P024d<00002@08C0P02D`2019<1<H@00E<7@05C1401<HBC0802D`800Q<
2P0000P01dd900U=2P0;C@K63005CB401Dd=00K62dd:00U=2@07C@T0000800E<2`09C0`014`200=<
2<H800E<9@05C0T02<H3C08014`<00U<2`05C0T0000800==3@03C@0304e=009=3004C@P01lH500E=
:@05C@H01lH800A=3004C@0404e=C@d00dd900007004C0`014`:00O600<0C4`00d`]00E<0P07aPX0
14`<00A<7@0001/014d<00A=3@04aPE=<@05C@G63@04C@`014dL00006`04C0`014`>00;614`e00A<
0lH>00A<3004C1`0000J00A=3004CA400Td00lH0000f009=00?600003`04C@`014dK00006P04C0`0
14`A00?6>003aQ4014`<00A<6`0001T014d<00A=4P03aSP00lHB00A=3004CAX0000I00A<3004C180
0lHh00?64P04C0`014`J00006004C@`014dB00C6>004aQ8014d<00A=6@0001P014`<00A<4P04aSP0
1<HB00A<3004C1T0000G00A=3004CA<00lHj00?64`04C@`014dH00005`04C0`014`C00?6>P03aQ<0
14`<00A<600001H014d<00A=5003aSX00lHD00A=3004CAL0000F00A<3004C1@00lHj00?65004C0`0
14`G00005P03C@d00ddD0004CLK6aSX00lH00dd0000B00==3@03CAL0000m00A<>P04C3h0000l00I=
>006CCd0000l00I<>006C3d0000k00M=>007CC`0000k00M<>007C3`0000j00A=00@0CDe=>003C@03
04e=009=>`0003X014`0101<C4`h00=<00<0C4`00T`k0000>@04C@8014df00A=0P04CCX0000i00A<
0P04C3H014`200A<>P0003P014d400===P03C@@014di0000>004C0@00d`f00=<1004C3T0000g00A=
1@03CCH00dd500A=>00003L014`500=<=P03C0D014`h0000=P04C@H014dd00A=1P04CCL0000f00A<
1P04C3@014`600A<=`0003D014d800===003C@P014df0000=@04C0P00d`d00=<2004C3H0000d00A=
2@03CC@00dd900A==@0003@014`900=<=003C0T014`e0000<`04C@X00ddd00==2P04CC@0000c00A<
2P04C38014`:00A<=000038014d;00A=<P04C@/014dc0000<P04C0`00d`b00=<3004C3<0000a00A=
3@03CC800dd=00A=<P00034014`=00=<<P03C0d014`b0000<004C@h00ddb00==3P04CC40000`00A<
3P04C30014`>00A<<@0003000dd?00A=<004C@l00dda0000@`03C3000da40000@`03CC000de40000
@`03C3000da40000_@000;d0002m0000_@000;d0002m0000_@000001\
\>"],
  ImageRangeCache->{{{0, 188}, {147, 0}} -> {-0.0269894, 0.0879404, 
  0.00560627, 0.00560627}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0837567 0.952381 [
[ 0 0 0 0 ]
[ 1 .78487 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78487 L
0 .78487 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.79178 .57374 L
s
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.86468 .50084 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.81993 .21828 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.72807 .17148 L
s
P
p
0 .4 1 r
.016 w
.67673 .38579 m
.71605 .42511 L
s
P
p
0 .4 1 r
.016 w
.67673 .38579 m
.70197 .33624 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.18602 .17148 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.09415 .21828 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.0494 .50084 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.1223 .57374 L
s
P
p
0 .4 1 r
.016 w
.23736 .38579 m
.21211 .33624 L
s
P
p
0 .4 1 r
.016 w
.23736 .38579 m
.19804 .42511 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.63783 .74125 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.73966 .72512 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.86953 .47022 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.82273 .37836 L
s
P
p
0 .4 1 r
.016 w
.65522 .52156 m
.66392 .57648 L
s
P
p
0 .4 1 r
.016 w
.65522 .52156 m
.70477 .49632 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.3842 .05975 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.28237 .04362 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.08008 .24591 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.09621 .34774 L
s
P
p
0 .4 1 r
.016 w
.29976 .26331 m
.30846 .20838 L
s
P
p
0 .4 1 r
.016 w
.29976 .26331 m
.24484 .272 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.67673 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.23736 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.65522 .52156 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.29976 .26331 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.90379 .34774 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.91992 .24591 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.71763 .04362 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.6158 .05975 L
s
P
p
0 .4 1 r
.016 w
.70024 .26331 m
.75516 .272 L
s
P
p
0 .4 1 r
.016 w
.70024 .26331 m
.69154 .20838 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.17727 .37836 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.13047 .47022 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.26034 .72512 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.36217 .74125 L
s
P
p
0 .4 1 r
.016 w
.34478 .52156 m
.29523 .49632 L
s
P
p
0 .4 1 r
.016 w
.34478 .52156 m
.33608 .57648 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.8777 .57374 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.9506 .50084 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.90585 .21828 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.81398 .17148 L
s
P
p
0 .4 1 r
.016 w
.76264 .38579 m
.80196 .42511 L
s
P
p
0 .4 1 r
.016 w
.76264 .38579 m
.78789 .33624 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.27193 .17148 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.18007 .21828 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.13532 .50084 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.20822 .57374 L
s
P
p
0 .4 1 r
.016 w
.32327 .38579 m
.29803 .33624 L
s
P
p
0 .4 1 r
.016 w
.32327 .38579 m
.28395 .42511 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.70024 .26331 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.34478 .52156 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.76264 .38579 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.32327 .38579 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.45704 .42058 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.54296 .42058 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0837567 0.952381 [
[ 0 0 0 0 ]
[ 1 .78487 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78487 L
0 .78487 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.79178 .57374 L
s
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.86468 .50084 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.81993 .21828 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.72807 .17148 L
s
P
p
.2 0 1 r
.018 w
.67673 .38579 m
.71605 .42511 L
s
P
p
.2 0 1 r
.018 w
.67673 .38579 m
.70197 .33624 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.18602 .17148 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.09415 .21828 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.0494 .50084 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.1223 .57374 L
s
P
p
.2 0 1 r
.018 w
.23736 .38579 m
.21211 .33624 L
s
P
p
.2 0 1 r
.018 w
.23736 .38579 m
.19804 .42511 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.63783 .74125 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.73966 .72512 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.86953 .47022 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.82273 .37836 L
s
P
p
.2 0 1 r
.018 w
.65522 .52156 m
.66392 .57648 L
s
P
p
.2 0 1 r
.018 w
.65522 .52156 m
.70477 .49632 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.3842 .05975 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.28237 .04362 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.08008 .24591 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.09621 .34774 L
s
P
p
.2 0 1 r
.018 w
.29976 .26331 m
.30846 .20838 L
s
P
p
.2 0 1 r
.018 w
.29976 .26331 m
.24484 .272 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.67673 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.23736 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.65522 .52156 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.29976 .26331 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.90379 .34774 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.91992 .24591 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.71763 .04362 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.6158 .05975 L
s
P
p
.2 0 1 r
.018 w
.70024 .26331 m
.75516 .272 L
s
P
p
.2 0 1 r
.018 w
.70024 .26331 m
.69154 .20838 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.17727 .37836 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.13047 .47022 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.26034 .72512 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.36217 .74125 L
s
P
p
.2 0 1 r
.018 w
.34478 .52156 m
.29523 .49632 L
s
P
p
.2 0 1 r
.018 w
.34478 .52156 m
.33608 .57648 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.8777 .57374 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.9506 .50084 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.90585 .21828 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.81398 .17148 L
s
P
p
.2 0 1 r
.018 w
.76264 .38579 m
.80196 .42511 L
s
P
p
.2 0 1 r
.018 w
.76264 .38579 m
.78789 .33624 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.27193 .17148 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.18007 .21828 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.13532 .50084 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.20822 .57374 L
s
P
p
.2 0 1 r
.018 w
.32327 .38579 m
.29803 .33624 L
s
P
p
.2 0 1 r
.018 w
.32327 .38579 m
.28395 .42511 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.70024 .26331 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.34478 .52156 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.76264 .38579 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.32327 .38579 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.45704 .42058 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.54296 .42058 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0568264 0.952381 [
[ 0 0 0 0 ]
[ 1 .83873 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .83873 L
0 .83873 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.73172 .45441 m
.85824 .58092 L
s
P
p
.2 0 1 r
.02 w
.71663 .3591 m
.79785 .19968 L
s
P
p
0 .4 1 r
.018 w
.68955 .41224 m
.73172 .45441 L
s
P
p
0 .4 1 r
.018 w
.68955 .41224 m
.71663 .3591 L
s
P
p
.2 0 1 r
.02 w
.19123 .3591 m
.11 .19968 L
s
P
p
.2 0 1 r
.02 w
.17613 .45441 m
.04961 .58092 L
s
P
p
0 .4 1 r
.018 w
.2183 .41224 m
.19123 .3591 L
s
P
p
0 .4 1 r
.018 w
.2183 .41224 m
.17613 .45441 L
s
P
p
.2 0 1 r
.02 w
.67581 .61677 m
.7038 .79348 L
s
P
p
.2 0 1 r
.02 w
.71962 .53078 m
.87904 .44956 L
s
P
p
0 .4 1 r
.018 w
.66648 .55786 m
.67581 .61677 L
s
P
p
0 .4 1 r
.018 w
.66648 .55786 m
.71962 .53078 L
s
P
p
.2 0 1 r
.02 w
.29457 .22196 m
.32256 .04524 L
s
P
p
.2 0 1 r
.02 w
.22633 .2902 m
.04961 .31819 L
s
P
p
0 .4 1 r
.018 w
.28524 .28087 m
.29457 .22196 L
s
P
p
0 .4 1 r
.018 w
.28524 .28087 m
.22633 .2902 L
s
P
p
.2 0 1 r
.016 w
.45393 .44956 m
.68955 .41224 L
s
P
p
.2 0 1 r
.016 w
.45393 .44956 m
.2183 .41224 L
s
P
p
.2 0 1 r
.016 w
.45393 .44956 m
.66648 .55786 L
s
P
p
.2 0 1 r
.016 w
.45393 .44956 m
.28524 .28087 L
s
P
p
.2 0 1 r
.02 w
.77367 .2902 m
.95039 .31819 L
s
P
p
.2 0 1 r
.02 w
.70543 .22196 m
.67744 .04524 L
s
P
p
0 .4 1 r
.018 w
.71476 .28087 m
.77367 .2902 L
s
P
p
0 .4 1 r
.018 w
.71476 .28087 m
.70543 .22196 L
s
P
p
.2 0 1 r
.02 w
.28038 .53078 m
.12096 .44956 L
s
P
p
.2 0 1 r
.02 w
.32419 .61677 m
.2962 .79348 L
s
P
p
0 .4 1 r
.018 w
.33352 .55786 m
.28038 .53078 L
s
P
p
0 .4 1 r
.018 w
.33352 .55786 m
.32419 .61677 L
s
P
p
.2 0 1 r
.02 w
.82387 .45441 m
.95039 .58092 L
s
P
p
.2 0 1 r
.02 w
.80877 .3591 m
.89 .19968 L
s
P
p
0 .4 1 r
.018 w
.7817 .41224 m
.82387 .45441 L
s
P
p
0 .4 1 r
.018 w
.7817 .41224 m
.80877 .3591 L
s
P
p
.2 0 1 r
.02 w
.28337 .3591 m
.20215 .19968 L
s
P
p
.2 0 1 r
.02 w
.26828 .45441 m
.14176 .58092 L
s
P
p
0 .4 1 r
.018 w
.31045 .41224 m
.28337 .3591 L
s
P
p
0 .4 1 r
.018 w
.31045 .41224 m
.26828 .45441 L
s
P
p
.2 0 1 r
.016 w
.54607 .44956 m
.71476 .28087 L
s
P
p
.2 0 1 r
.016 w
.54607 .44956 m
.33352 .55786 L
s
P
p
.2 0 1 r
.016 w
.54607 .44956 m
.7817 .41224 L
s
P
p
.2 0 1 r
.016 w
.54607 .44956 m
.31045 .41224 L
s
P
p
1 .6 0 r
.016 w
.5 .30775 m
.45393 .44956 L
s
P
p
1 .6 0 r
.016 w
.5 .30775 m
.54607 .44956 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0980909 0.952381 [
[ 0 0 0 0 ]
[ 1 .7562 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .7562 L
0 .7562 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.71138 .41007 m
.76181 .56529 L
s
P
p
.2 0 1 r
.02 w
.71138 .41007 m
.8666 .4605 L
s
P
p
.2 0 1 r
.02 w
.69761 .32312 m
.82965 .22719 L
s
P
p
.2 0 1 r
.02 w
.69761 .32312 m
.69761 .15991 L
s
P
p
0 .4 1 r
.018 w
.67291 .3716 m
.71138 .41007 L
s
P
p
0 .4 1 r
.018 w
.67291 .3716 m
.69761 .32312 L
s
P
p
.2 0 1 r
.02 w
.21833 .32312 m
.21833 .15991 L
s
P
p
.2 0 1 r
.02 w
.21833 .32312 m
.08629 .22719 L
s
P
p
.2 0 1 r
.02 w
.20456 .41007 m
.04934 .4605 L
s
P
p
.2 0 1 r
.02 w
.20456 .41007 m
.15413 .56529 L
s
P
p
0 .4 1 r
.018 w
.24303 .3716 m
.21833 .32312 L
s
P
p
0 .4 1 r
.018 w
.24303 .3716 m
.20456 .41007 L
s
P
p
.2 0 1 r
.02 w
.66038 .55817 m
.60994 .7134 L
s
P
p
.2 0 1 r
.02 w
.66038 .55817 m
.75631 .69021 L
s
P
p
.2 0 1 r
.02 w
.70034 .47974 m
.86356 .47974 L
s
P
p
.2 0 1 r
.02 w
.70034 .47974 m
.79628 .3477 L
s
P
p
0 .4 1 r
.018 w
.65187 .50444 m
.66038 .55817 L
s
P
p
0 .4 1 r
.018 w
.65187 .50444 m
.70034 .47974 L
s
P
p
.2 0 1 r
.02 w
.3126 .19803 m
.40854 .06598 L
s
P
p
.2 0 1 r
.02 w
.3126 .19803 m
.26217 .0428 L
s
P
p
.2 0 1 r
.02 w
.25036 .26027 m
.09513 .20984 L
s
P
p
.2 0 1 r
.02 w
.25036 .26027 m
.11831 .35621 L
s
P
p
0 .4 1 r
.018 w
.30409 .25176 m
.3126 .19803 L
s
P
p
0 .4 1 r
.018 w
.30409 .25176 m
.25036 .26027 L
s
P
p
.2 0 1 r
.016 w
.45797 .40564 m
.67291 .3716 L
s
P
p
.2 0 1 r
.016 w
.45797 .40564 m
.24303 .3716 L
s
P
p
.2 0 1 r
.016 w
.45797 .40564 m
.65187 .50444 L
s
P
p
.2 0 1 r
.016 w
.45797 .40564 m
.30409 .25176 L
s
P
p
.2 0 1 r
.02 w
.74964 .26027 m
.88169 .35621 L
s
P
p
.2 0 1 r
.02 w
.74964 .26027 m
.90487 .20984 L
s
P
p
.2 0 1 r
.02 w
.6874 .19803 m
.73783 .0428 L
s
P
p
.2 0 1 r
.02 w
.6874 .19803 m
.59146 .06598 L
s
P
p
0 .4 1 r
.018 w
.69591 .25176 m
.74964 .26027 L
s
P
p
0 .4 1 r
.018 w
.69591 .25176 m
.6874 .19803 L
s
P
p
.2 0 1 r
.02 w
.29966 .47974 m
.20372 .3477 L
s
P
p
.2 0 1 r
.02 w
.29966 .47974 m
.13644 .47974 L
s
P
p
.2 0 1 r
.02 w
.33962 .55817 m
.24369 .69021 L
s
P
p
.2 0 1 r
.02 w
.33962 .55817 m
.39006 .7134 L
s
P
p
0 .4 1 r
.018 w
.34813 .50444 m
.29966 .47974 L
s
P
p
0 .4 1 r
.018 w
.34813 .50444 m
.33962 .55817 L
s
P
p
.2 0 1 r
.02 w
.79544 .41007 m
.84587 .56529 L
s
P
p
.2 0 1 r
.02 w
.79544 .41007 m
.95066 .4605 L
s
P
p
.2 0 1 r
.02 w
.78167 .32312 m
.91371 .22719 L
s
P
p
.2 0 1 r
.02 w
.78167 .32312 m
.78167 .15991 L
s
P
p
0 .4 1 r
.018 w
.75697 .3716 m
.79544 .41007 L
s
P
p
0 .4 1 r
.018 w
.75697 .3716 m
.78167 .32312 L
s
P
p
.2 0 1 r
.02 w
.30239 .32312 m
.30239 .15991 L
s
P
p
.2 0 1 r
.02 w
.30239 .32312 m
.17035 .22719 L
s
P
p
.2 0 1 r
.02 w
.28862 .41007 m
.1334 .4605 L
s
P
p
.2 0 1 r
.02 w
.28862 .41007 m
.23819 .56529 L
s
P
p
0 .4 1 r
.018 w
.32709 .3716 m
.30239 .32312 L
s
P
p
0 .4 1 r
.018 w
.32709 .3716 m
.28862 .41007 L
s
P
p
.2 0 1 r
.016 w
.54203 .40564 m
.69591 .25176 L
s
P
p
.2 0 1 r
.016 w
.54203 .40564 m
.34813 .50444 L
s
P
p
.2 0 1 r
.016 w
.54203 .40564 m
.75697 .3716 L
s
P
p
.2 0 1 r
.016 w
.54203 .40564 m
.32709 .3716 L
s
P
p
1 .6 0 r
.016 w
.5 .27629 m
.45797 .40564 L
s
P
p
1 .6 0 r
.016 w
.5 .27629 m
.54203 .40564 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0754585 0.952381 [
[ 0 0 0 0 ]
[ 1 .80146 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .80146 L
0 .80146 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.70486 .43171 m
.78864 .59614 L
s
P
p
.2 0 1 r
.02 w
.70486 .43171 m
.86929 .51549 L
s
P
p
.2 0 1 r
.02 w
.69151 .34745 m
.822 .21696 L
s
P
p
.2 0 1 r
.02 w
.69151 .34745 m
.72038 .16518 L
s
P
p
0 .4 1 r
.018 w
.66757 .39443 m
.70486 .43171 L
s
P
p
0 .4 1 r
.018 w
.66757 .39443 m
.69151 .34745 L
s
P
p
.2 0 1 r
.02 w
.22702 .34745 m
.19815 .16518 L
s
P
p
.2 0 1 r
.02 w
.22702 .34745 m
.09653 .21696 L
s
P
p
.2 0 1 r
.02 w
.21368 .43171 m
.04925 .51549 L
s
P
p
.2 0 1 r
.02 w
.21368 .43171 m
.1299 .59614 L
s
P
p
0 .4 1 r
.018 w
.25096 .39443 m
.22702 .34745 L
s
P
p
0 .4 1 r
.018 w
.25096 .39443 m
.21368 .43171 L
s
P
p
.2 0 1 r
.02 w
.65543 .57525 m
.62656 .75752 L
s
P
p
.2 0 1 r
.02 w
.65543 .57525 m
.73921 .73968 L
s
P
p
.2 0 1 r
.02 w
.69416 .49924 m
.87643 .47037 L
s
P
p
.2 0 1 r
.02 w
.69416 .49924 m
.82465 .36874 L
s
P
p
0 .4 1 r
.018 w
.64718 .52317 m
.65543 .57525 L
s
P
p
0 .4 1 r
.018 w
.64718 .52317 m
.69416 .49924 L
s
P
p
.2 0 1 r
.02 w
.31838 .22621 m
.40216 .06179 L
s
P
p
.2 0 1 r
.02 w
.31838 .22621 m
.28951 .04395 L
s
P
p
.2 0 1 r
.02 w
.25806 .28654 m
.07579 .25767 L
s
P
p
.2 0 1 r
.02 w
.25806 .28654 m
.09363 .37032 L
s
P
p
0 .4 1 r
.018 w
.31013 .27829 m
.31838 .22621 L
s
P
p
0 .4 1 r
.018 w
.31013 .27829 m
.25806 .28654 L
s
P
p
.2 0 1 r
.016 w
.45927 .42742 m
.66757 .39443 L
s
P
p
.2 0 1 r
.016 w
.45927 .42742 m
.25096 .39443 L
s
P
p
.2 0 1 r
.016 w
.45927 .42742 m
.64718 .52317 L
s
P
p
.2 0 1 r
.016 w
.45927 .42742 m
.31013 .27829 L
s
P
p
.2 0 1 r
.02 w
.74194 .28654 m
.90637 .37032 L
s
P
p
.2 0 1 r
.02 w
.74194 .28654 m
.92421 .25767 L
s
P
p
.2 0 1 r
.02 w
.68162 .22621 m
.71049 .04395 L
s
P
p
.2 0 1 r
.02 w
.68162 .22621 m
.59784 .06179 L
s
P
p
0 .4 1 r
.018 w
.68987 .27829 m
.74194 .28654 L
s
P
p
0 .4 1 r
.018 w
.68987 .27829 m
.68162 .22621 L
s
P
p
.2 0 1 r
.02 w
.30584 .49924 m
.17535 .36874 L
s
P
p
.2 0 1 r
.02 w
.30584 .49924 m
.12357 .47037 L
s
P
p
.2 0 1 r
.02 w
.34457 .57525 m
.26079 .73968 L
s
P
p
.2 0 1 r
.02 w
.34457 .57525 m
.37344 .75752 L
s
P
p
0 .4 1 r
.018 w
.35282 .52317 m
.30584 .49924 L
s
P
p
0 .4 1 r
.018 w
.35282 .52317 m
.34457 .57525 L
s
P
p
.2 0 1 r
.02 w
.78632 .43171 m
.8701 .59614 L
s
P
p
.2 0 1 r
.02 w
.78632 .43171 m
.95075 .51549 L
s
P
p
.2 0 1 r
.02 w
.77298 .34745 m
.90347 .21696 L
s
P
p
.2 0 1 r
.02 w
.77298 .34745 m
.80185 .16518 L
s
P
p
0 .4 1 r
.018 w
.74904 .39443 m
.78632 .43171 L
s
P
p
0 .4 1 r
.018 w
.74904 .39443 m
.77298 .34745 L
s
P
p
.2 0 1 r
.02 w
.30849 .34745 m
.27962 .16518 L
s
P
p
.2 0 1 r
.02 w
.30849 .34745 m
.178 .21696 L
s
P
p
.2 0 1 r
.02 w
.29514 .43171 m
.13071 .51549 L
s
P
p
.2 0 1 r
.02 w
.29514 .43171 m
.21136 .59614 L
s
P
p
0 .4 1 r
.018 w
.33243 .39443 m
.30849 .34745 L
s
P
p
0 .4 1 r
.018 w
.33243 .39443 m
.29514 .43171 L
s
P
p
.2 0 1 r
.016 w
.54073 .42742 m
.68987 .27829 L
s
P
p
.2 0 1 r
.016 w
.54073 .42742 m
.35282 .52317 L
s
P
p
.2 0 1 r
.016 w
.54073 .42742 m
.74904 .39443 L
s
P
p
.2 0 1 r
.016 w
.54073 .42742 m
.33243 .39443 L
s
P
p
1 .6 0 r
.016 w
.5 .30206 m
.45927 .42742 L
s
P
p
1 .6 0 r
.016 w
.5 .30206 m
.54073 .42742 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0837567 0.952381 [
[ 0 0 0 0 ]
[ 1 .78487 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78487 L
0 .78487 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.71605 .42511 m
.79178 .57374 L
s
P
p
.2 0 1 r
.002 w
.71605 .42511 m
.86468 .50084 L
s
P
p
.2 0 1 r
.002 w
.70197 .33624 m
.81993 .21828 L
s
P
p
.2 0 1 r
.002 w
.70197 .33624 m
.72807 .17148 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.71605 .42511 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.70197 .33624 L
s
P
p
.2 0 1 r
.002 w
.21211 .33624 m
.18602 .17148 L
s
P
p
.2 0 1 r
.002 w
.21211 .33624 m
.09415 .21828 L
s
P
p
.2 0 1 r
.002 w
.19804 .42511 m
.0494 .50084 L
s
P
p
.2 0 1 r
.002 w
.19804 .42511 m
.1223 .57374 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.21211 .33624 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.19804 .42511 L
s
P
p
.2 0 1 r
.002 w
.66392 .57648 m
.63783 .74125 L
s
P
p
.2 0 1 r
.002 w
.66392 .57648 m
.73966 .72512 L
s
P
p
.2 0 1 r
.002 w
.70477 .49632 m
.86953 .47022 L
s
P
p
.2 0 1 r
.002 w
.70477 .49632 m
.82273 .37836 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.66392 .57648 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.70477 .49632 L
s
P
p
.2 0 1 r
.002 w
.30846 .20838 m
.3842 .05975 L
s
P
p
.2 0 1 r
.002 w
.30846 .20838 m
.28237 .04362 L
s
P
p
.2 0 1 r
.002 w
.24484 .272 m
.08008 .24591 L
s
P
p
.2 0 1 r
.002 w
.24484 .272 m
.09621 .34774 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.30846 .20838 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.24484 .272 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.67673 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.23736 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.65522 .52156 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.29976 .26331 L
s
P
p
.2 0 1 r
.002 w
.75516 .272 m
.90379 .34774 L
s
P
p
.2 0 1 r
.002 w
.75516 .272 m
.91992 .24591 L
s
P
p
.2 0 1 r
.002 w
.69154 .20838 m
.71763 .04362 L
s
P
p
.2 0 1 r
.002 w
.69154 .20838 m
.6158 .05975 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.75516 .272 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.69154 .20838 L
s
P
p
.2 0 1 r
.002 w
.29523 .49632 m
.17727 .37836 L
s
P
p
.2 0 1 r
.002 w
.29523 .49632 m
.13047 .47022 L
s
P
p
.2 0 1 r
.002 w
.33608 .57648 m
.26034 .72512 L
s
P
p
.2 0 1 r
.002 w
.33608 .57648 m
.36217 .74125 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.29523 .49632 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.33608 .57648 L
s
P
p
.2 0 1 r
.002 w
.80196 .42511 m
.8777 .57374 L
s
P
p
.2 0 1 r
.002 w
.80196 .42511 m
.9506 .50084 L
s
P
p
.2 0 1 r
.002 w
.78789 .33624 m
.90585 .21828 L
s
P
p
.2 0 1 r
.002 w
.78789 .33624 m
.81398 .17148 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.80196 .42511 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.78789 .33624 L
s
P
p
.2 0 1 r
.002 w
.29803 .33624 m
.27193 .17148 L
s
P
p
.2 0 1 r
.002 w
.29803 .33624 m
.18007 .21828 L
s
P
p
.2 0 1 r
.002 w
.28395 .42511 m
.13532 .50084 L
s
P
p
.2 0 1 r
.002 w
.28395 .42511 m
.20822 .57374 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.29803 .33624 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.28395 .42511 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.70024 .26331 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.34478 .52156 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.76264 .38579 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.32327 .38579 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.45704 .42058 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.54296 .42058 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0837567 0.952381 [
[ 0 0 0 0 ]
[ 1 .78487 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78487 L
0 .78487 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.02 w
.71605 .42511 m
.79178 .57374 L
s
P
p
0 .4 1 r
.02 w
.71605 .42511 m
.86468 .50084 L
s
P
p
0 .4 1 r
.02 w
.70197 .33624 m
.81993 .21828 L
s
P
p
0 .4 1 r
.02 w
.70197 .33624 m
.72807 .17148 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.71605 .42511 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.70197 .33624 L
s
P
p
0 .4 1 r
.02 w
.21211 .33624 m
.18602 .17148 L
s
P
p
0 .4 1 r
.02 w
.21211 .33624 m
.09415 .21828 L
s
P
p
0 .4 1 r
.02 w
.19804 .42511 m
.0494 .50084 L
s
P
p
0 .4 1 r
.02 w
.19804 .42511 m
.1223 .57374 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.21211 .33624 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.19804 .42511 L
s
P
p
0 .4 1 r
.02 w
.66392 .57648 m
.63783 .74125 L
s
P
p
0 .4 1 r
.02 w
.66392 .57648 m
.73966 .72512 L
s
P
p
0 .4 1 r
.02 w
.70477 .49632 m
.86953 .47022 L
s
P
p
0 .4 1 r
.02 w
.70477 .49632 m
.82273 .37836 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.66392 .57648 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.70477 .49632 L
s
P
p
0 .4 1 r
.02 w
.30846 .20838 m
.3842 .05975 L
s
P
p
0 .4 1 r
.02 w
.30846 .20838 m
.28237 .04362 L
s
P
p
0 .4 1 r
.02 w
.24484 .272 m
.08008 .24591 L
s
P
p
0 .4 1 r
.02 w
.24484 .272 m
.09621 .34774 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.30846 .20838 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.24484 .272 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.67673 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.23736 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.65522 .52156 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.29976 .26331 L
s
P
p
0 .4 1 r
.02 w
.75516 .272 m
.90379 .34774 L
s
P
p
0 .4 1 r
.02 w
.75516 .272 m
.91992 .24591 L
s
P
p
0 .4 1 r
.02 w
.69154 .20838 m
.71763 .04362 L
s
P
p
0 .4 1 r
.02 w
.69154 .20838 m
.6158 .05975 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.75516 .272 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.69154 .20838 L
s
P
p
0 .4 1 r
.02 w
.29523 .49632 m
.17727 .37836 L
s
P
p
0 .4 1 r
.02 w
.29523 .49632 m
.13047 .47022 L
s
P
p
0 .4 1 r
.02 w
.33608 .57648 m
.26034 .72512 L
s
P
p
0 .4 1 r
.02 w
.33608 .57648 m
.36217 .74125 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.29523 .49632 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.33608 .57648 L
s
P
p
0 .4 1 r
.02 w
.80196 .42511 m
.8777 .57374 L
s
P
p
0 .4 1 r
.02 w
.80196 .42511 m
.9506 .50084 L
s
P
p
0 .4 1 r
.02 w
.78789 .33624 m
.90585 .21828 L
s
P
p
0 .4 1 r
.02 w
.78789 .33624 m
.81398 .17148 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.80196 .42511 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.78789 .33624 L
s
P
p
0 .4 1 r
.02 w
.29803 .33624 m
.27193 .17148 L
s
P
p
0 .4 1 r
.02 w
.29803 .33624 m
.18007 .21828 L
s
P
p
0 .4 1 r
.02 w
.28395 .42511 m
.13532 .50084 L
s
P
p
0 .4 1 r
.02 w
.28395 .42511 m
.20822 .57374 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.29803 .33624 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.28395 .42511 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.70024 .26331 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.34478 .52156 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.76264 .38579 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.32327 .38579 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.45704 .42058 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.54296 .42058 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.152578 0.952381 [
[ 0 0 0 0 ]
[ 1 .64722 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .64722 L
0 .64722 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.68273 .44324 m
.68273 .60733 L
s
P
p
.2 0 1 r
.02 w
.68273 .44324 m
.77918 .57599 L
s
P
p
.2 0 1 r
.02 w
.71008 .35907 m
.86614 .30836 L
s
P
p
.2 0 1 r
.02 w
.71008 .35907 m
.80653 .22632 L
s
P
p
0 .4 1 r
.018 w
.66582 .39122 m
.68273 .44324 L
s
P
p
0 .4 1 r
.018 w
.66582 .39122 m
.71008 .35907 L
s
P
p
.2 0 1 r
.02 w
.23276 .20398 m
.23276 .03989 L
s
P
p
.2 0 1 r
.02 w
.23276 .20398 m
.13631 .07123 L
s
P
p
.2 0 1 r
.02 w
.20541 .28815 m
.04935 .33886 L
s
P
p
.2 0 1 r
.02 w
.20541 .28815 m
.10896 .42091 L
s
P
p
0 .4 1 r
.018 w
.24966 .256 m
.23276 .20398 L
s
P
p
0 .4 1 r
.018 w
.24966 .256 m
.20541 .28815 L
s
P
p
.2 0 1 r
.016 w
.45774 .32361 m
.66582 .39122 L
s
P
p
.2 0 1 r
.016 w
.45774 .32361 m
.24966 .256 L
s
P
p
.2 0 1 r
.02 w
.79459 .28815 m
.89104 .42091 L
s
P
p
.2 0 1 r
.02 w
.79459 .28815 m
.95065 .33886 L
s
P
p
.2 0 1 r
.02 w
.76724 .20398 m
.86369 .07123 L
s
P
p
.2 0 1 r
.02 w
.76724 .20398 m
.76724 .03989 L
s
P
p
0 .4 1 r
.018 w
.75034 .256 m
.79459 .28815 L
s
P
p
0 .4 1 r
.018 w
.75034 .256 m
.76724 .20398 L
s
P
p
.2 0 1 r
.02 w
.28992 .35907 m
.19347 .22632 L
s
P
p
.2 0 1 r
.02 w
.28992 .35907 m
.13386 .30836 L
s
P
p
.2 0 1 r
.02 w
.31727 .44324 m
.22082 .57599 L
s
P
p
.2 0 1 r
.02 w
.31727 .44324 m
.31727 .60733 L
s
P
p
0 .4 1 r
.018 w
.33418 .39122 m
.28992 .35907 L
s
P
p
0 .4 1 r
.018 w
.33418 .39122 m
.31727 .44324 L
s
P
p
.2 0 1 r
.016 w
.54226 .32361 m
.75034 .256 L
s
P
p
.2 0 1 r
.016 w
.54226 .32361 m
.33418 .39122 L
s
P
p
1 .6 0 r
.016 w
.5 .19356 m
.45774 .32361 L
s
P
p
1 .6 0 r
.016 w
.5 .19356 m
.54226 .32361 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0779985 0.952381 [
[ 0 0 0 0 ]
[ 1 .79638 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79638 L
0 .79638 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.70074 .43386 m
.78136 .59207 L
s
P
p
.2 0 1 r
.02 w
.70074 .43386 m
.85896 .51447 L
s
P
p
.2 0 1 r
.02 w
.68576 .33926 m
.81132 .2137 L
s
P
p
.2 0 1 r
.02 w
.68576 .33926 m
.71354 .16388 L
s
P
p
0 .4 1 r
.018 w
.65889 .392 m
.70074 .43386 L
s
P
p
0 .4 1 r
.018 w
.65889 .392 m
.68576 .33926 L
s
P
p
.2 0 1 r
.02 w
.22279 .33926 m
.19501 .16388 L
s
P
p
.2 0 1 r
.02 w
.22279 .33926 m
.09723 .2137 L
s
P
p
.2 0 1 r
.02 w
.20781 .43386 m
.04959 .51447 L
s
P
p
.2 0 1 r
.02 w
.20781 .43386 m
.12719 .59207 L
s
P
p
0 .4 1 r
.018 w
.24966 .392 m
.22279 .33926 L
s
P
p
0 .4 1 r
.018 w
.24966 .392 m
.20781 .43386 L
s
P
p
.2 0 1 r
.02 w
.64812 .57692 m
.62034 .75231 L
s
P
p
.2 0 1 r
.02 w
.64812 .57692 m
.72873 .73514 L
s
P
p
.2 0 1 r
.02 w
.6916 .49159 m
.86698 .46381 L
s
P
p
.2 0 1 r
.02 w
.6916 .49159 m
.81716 .36603 L
s
P
p
0 .4 1 r
.018 w
.63886 .51846 m
.64812 .57692 L
s
P
p
0 .4 1 r
.018 w
.63886 .51846 m
.6916 .49159 L
s
P
p
.2 0 1 r
.02 w
.31704 .21946 m
.39766 .06125 L
s
P
p
.2 0 1 r
.02 w
.31704 .21946 m
.28927 .04408 L
s
P
p
.2 0 1 r
.02 w
.24932 .28718 m
.07394 .2594 L
s
P
p
.2 0 1 r
.02 w
.24932 .28718 m
.09111 .3678 L
s
P
p
0 .4 1 r
.018 w
.30779 .27792 m
.31704 .21946 L
s
P
p
0 .4 1 r
.018 w
.30779 .27792 m
.24932 .28718 L
s
P
p
.2 0 1 r
.016 w
.45427 .42441 m
.65889 .392 L
s
P
p
.2 0 1 r
.016 w
.45427 .42441 m
.24966 .392 L
s
P
p
.2 0 1 r
.016 w
.45427 .42441 m
.63886 .51846 L
s
P
p
.2 0 1 r
.016 w
.45427 .42441 m
.30779 .27792 L
s
P
p
.2 0 1 r
.02 w
.75068 .28718 m
.90889 .3678 L
s
P
p
.2 0 1 r
.02 w
.75068 .28718 m
.92606 .2594 L
s
P
p
.2 0 1 r
.02 w
.68296 .21946 m
.71073 .04408 L
s
P
p
.2 0 1 r
.02 w
.68296 .21946 m
.60234 .06125 L
s
P
p
0 .4 1 r
.018 w
.69221 .27792 m
.75068 .28718 L
s
P
p
0 .4 1 r
.018 w
.69221 .27792 m
.68296 .21946 L
s
P
p
.2 0 1 r
.02 w
.3084 .49159 m
.18284 .36603 L
s
P
p
.2 0 1 r
.02 w
.3084 .49159 m
.13302 .46381 L
s
P
p
.2 0 1 r
.02 w
.35188 .57692 m
.27127 .73514 L
s
P
p
.2 0 1 r
.02 w
.35188 .57692 m
.37966 .75231 L
s
P
p
0 .4 1 r
.018 w
.36114 .51846 m
.3084 .49159 L
s
P
p
0 .4 1 r
.018 w
.36114 .51846 m
.35188 .57692 L
s
P
p
.2 0 1 r
.02 w
.79219 .43386 m
.87281 .59207 L
s
P
p
.2 0 1 r
.02 w
.79219 .43386 m
.95041 .51447 L
s
P
p
.2 0 1 r
.02 w
.77721 .33926 m
.90277 .2137 L
s
P
p
.2 0 1 r
.02 w
.77721 .33926 m
.80499 .16388 L
s
P
p
0 .4 1 r
.018 w
.75034 .392 m
.79219 .43386 L
s
P
p
0 .4 1 r
.018 w
.75034 .392 m
.77721 .33926 L
s
P
p
.2 0 1 r
.02 w
.31424 .33926 m
.28646 .16388 L
s
P
p
.2 0 1 r
.02 w
.31424 .33926 m
.18868 .2137 L
s
P
p
.2 0 1 r
.02 w
.29926 .43386 m
.14104 .51447 L
s
P
p
.2 0 1 r
.02 w
.29926 .43386 m
.21864 .59207 L
s
P
p
0 .4 1 r
.018 w
.34111 .392 m
.31424 .33926 L
s
P
p
0 .4 1 r
.018 w
.34111 .392 m
.29926 .43386 L
s
P
p
.2 0 1 r
.016 w
.54573 .42441 m
.69221 .27792 L
s
P
p
.2 0 1 r
.016 w
.54573 .42441 m
.36114 .51846 L
s
P
p
.2 0 1 r
.016 w
.54573 .42441 m
.75034 .392 L
s
P
p
.2 0 1 r
.016 w
.54573 .42441 m
.34111 .392 L
s
P
p
1 .6 0 r
.016 w
.5 .28368 m
.45427 .42441 L
s
P
p
1 .6 0 r
.016 w
.5 .28368 m
.54573 .42441 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0837567 0.952381 [
[ 0 0 0 0 ]
[ 1 .78487 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78487 L
0 .78487 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.79178 .57374 L
s
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.86468 .50084 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.81993 .21828 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.72807 .17148 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.71605 .42511 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.70197 .33624 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.18602 .17148 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.09415 .21828 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.0494 .50084 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.1223 .57374 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.21211 .33624 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.19804 .42511 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.63783 .74125 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.73966 .72512 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.86953 .47022 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.82273 .37836 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.66392 .57648 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.70477 .49632 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.3842 .05975 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.28237 .04362 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.08008 .24591 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.09621 .34774 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.30846 .20838 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.24484 .272 L
s
P
p
.2 0 1 r
.014 w
.45704 .42058 m
.67673 .38579 L
s
P
p
.2 0 1 r
.014 w
.45704 .42058 m
.23736 .38579 L
s
P
p
.2 0 1 r
.014 w
.45704 .42058 m
.65522 .52156 L
s
P
p
.2 0 1 r
.014 w
.45704 .42058 m
.29976 .26331 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.90379 .34774 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.91992 .24591 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.71763 .04362 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.6158 .05975 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.75516 .272 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.69154 .20838 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.17727 .37836 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.13047 .47022 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.26034 .72512 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.36217 .74125 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.29523 .49632 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.33608 .57648 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.8777 .57374 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.9506 .50084 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.90585 .21828 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.81398 .17148 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.80196 .42511 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.78789 .33624 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.27193 .17148 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.18007 .21828 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.13532 .50084 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.20822 .57374 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.29803 .33624 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.28395 .42511 L
s
P
p
.2 0 1 r
.014 w
.54296 .42058 m
.70024 .26331 L
s
P
p
.2 0 1 r
.014 w
.54296 .42058 m
.34478 .52156 L
s
P
p
.2 0 1 r
.014 w
.54296 .42058 m
.76264 .38579 L
s
P
p
.2 0 1 r
.014 w
.54296 .42058 m
.32327 .38579 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.45704 .42058 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.54296 .42058 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0837567 0.952381 [
[ 0 0 0 0 ]
[ 1 .78487 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78487 L
0 .78487 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.79178 .57374 L
s
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.86468 .50084 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.81993 .21828 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.72807 .17148 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.71605 .42511 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.70197 .33624 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.18602 .17148 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.09415 .21828 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.0494 .50084 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.1223 .57374 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.21211 .33624 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.19804 .42511 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.63783 .74125 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.73966 .72512 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.86953 .47022 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.82273 .37836 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.66392 .57648 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.70477 .49632 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.3842 .05975 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.28237 .04362 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.08008 .24591 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.09621 .34774 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.30846 .20838 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.24484 .272 L
s
P
p
0 .4 1 r
.016 w
.45704 .42058 m
.67673 .38579 L
s
P
p
0 .4 1 r
.016 w
.45704 .42058 m
.23736 .38579 L
s
P
p
0 .4 1 r
.016 w
.45704 .42058 m
.65522 .52156 L
s
P
p
0 .4 1 r
.016 w
.45704 .42058 m
.29976 .26331 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.90379 .34774 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.91992 .24591 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.71763 .04362 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.6158 .05975 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.75516 .272 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.69154 .20838 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.17727 .37836 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.13047 .47022 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.26034 .72512 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.36217 .74125 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.29523 .49632 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.33608 .57648 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.8777 .57374 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.9506 .50084 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.90585 .21828 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.81398 .17148 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.80196 .42511 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.78789 .33624 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.27193 .17148 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.18007 .21828 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.13532 .50084 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.20822 .57374 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.29803 .33624 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.28395 .42511 L
s
P
p
0 .4 1 r
.016 w
.54296 .42058 m
.70024 .26331 L
s
P
p
0 .4 1 r
.016 w
.54296 .42058 m
.34478 .52156 L
s
P
p
0 .4 1 r
.016 w
.54296 .42058 m
.76264 .38579 L
s
P
p
0 .4 1 r
.016 w
.54296 .42058 m
.32327 .38579 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.45704 .42058 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.54296 .42058 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.161425 0.952381 [
[ 0 0 0 0 ]
[ 1 .62953 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .62953 L
0 .62953 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.7165 .32134 m
.87049 .34573 L
s
P
p
.2 0 1 r
.02 w
.7165 .32134 m
.85542 .25056 L
s
P
p
0 .4 1 r
.018 w
.66517 .32947 m
.7165 .32134 L
s
P
p
.2 0 1 r
.02 w
.2032 .32134 m
.06428 .25056 L
s
P
p
.2 0 1 r
.02 w
.2032 .32134 m
.04921 .34573 L
s
P
p
0 .4 1 r
.018 w
.25453 .32947 m
.2032 .32134 L
s
P
p
.2 0 1 r
.02 w
.69138 .47996 m
.80162 .5902 L
s
P
p
.2 0 1 r
.02 w
.69138 .47996 m
.84537 .50435 L
s
P
p
0 .4 1 r
.018 w
.64507 .45636 m
.69138 .47996 L
s
P
p
.2 0 1 r
.02 w
.27611 .17825 m
.20533 .03933 L
s
P
p
.2 0 1 r
.02 w
.27611 .17825 m
.13719 .10746 L
s
P
p
0 .4 1 r
.018 w
.31286 .21499 m
.27611 .17825 L
s
P
p
.2 0 1 r
.016 w
.45985 .36199 m
.66517 .32947 L
s
P
p
.2 0 1 r
.016 w
.45985 .36199 m
.25453 .32947 L
s
P
p
.2 0 1 r
.016 w
.45985 .36199 m
.64507 .45636 L
s
P
p
.2 0 1 r
.016 w
.45985 .36199 m
.31286 .21499 L
s
P
p
.2 0 1 r
.02 w
.72389 .17825 m
.86281 .10746 L
s
P
p
.2 0 1 r
.02 w
.72389 .17825 m
.79467 .03933 L
s
P
p
0 .4 1 r
.018 w
.68714 .21499 m
.72389 .17825 L
s
P
p
.2 0 1 r
.02 w
.30862 .47996 m
.15463 .50435 L
s
P
p
.2 0 1 r
.02 w
.30862 .47996 m
.19838 .5902 L
s
P
p
0 .4 1 r
.018 w
.35493 .45636 m
.30862 .47996 L
s
P
p
.2 0 1 r
.02 w
.7968 .32134 m
.95079 .34573 L
s
P
p
.2 0 1 r
.02 w
.7968 .32134 m
.93572 .25056 L
s
P
p
0 .4 1 r
.018 w
.74547 .32947 m
.7968 .32134 L
s
P
p
.2 0 1 r
.02 w
.2835 .32134 m
.14458 .25056 L
s
P
p
.2 0 1 r
.02 w
.2835 .32134 m
.12951 .34573 L
s
P
p
0 .4 1 r
.018 w
.33483 .32947 m
.2835 .32134 L
s
P
p
.2 0 1 r
.016 w
.54015 .36199 m
.68714 .21499 L
s
P
p
.2 0 1 r
.016 w
.54015 .36199 m
.35493 .45636 L
s
P
p
.2 0 1 r
.016 w
.54015 .36199 m
.74547 .32947 L
s
P
p
.2 0 1 r
.016 w
.54015 .36199 m
.33483 .32947 L
s
P
p
1 .6 0 r
.016 w
.5 .23842 m
.45985 .36199 L
s
P
p
1 .6 0 r
.016 w
.5 .23842 m
.54015 .36199 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0693485 0.952381 [
[ 0 0 0 0 ]
[ 1 .81368 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .81368 L
0 .81368 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.71923 .44983 m
.7732 .61592 L
s
P
p
.2 0 1 r
.02 w
.71923 .44983 m
.86052 .55248 L
s
P
p
.2 0 1 r
.02 w
.703 .34737 m
.80565 .20608 L
s
P
p
.2 0 1 r
.02 w
.703 .34737 m
.703 .17273 L
s
P
p
0 .4 1 r
.018 w
.68501 .40273 m
.71923 .44983 L
s
P
p
0 .4 1 r
.018 w
.68501 .40273 m
.703 .34737 L
s
P
p
.2 0 1 r
.02 w
.20705 .34737 m
.20705 .17273 L
s
P
p
.2 0 1 r
.02 w
.20705 .34737 m
.1044 .20608 L
s
P
p
.2 0 1 r
.02 w
.19082 .44983 m
.04954 .55248 L
s
P
p
.2 0 1 r
.02 w
.19082 .44983 m
.13686 .61592 L
s
P
p
0 .4 1 r
.018 w
.22504 .40273 m
.20705 .34737 L
s
P
p
0 .4 1 r
.018 w
.22504 .40273 m
.19082 .44983 L
s
P
p
.2 0 1 r
.02 w
.6625 .60309 m
.60853 .76918 L
s
P
p
.2 0 1 r
.02 w
.6625 .60309 m
.71647 .76918 L
s
P
p
.2 0 1 r
.02 w
.7096 .51066 m
.87569 .45669 L
s
P
p
.2 0 1 r
.02 w
.7096 .51066 m
.81225 .36937 L
s
P
p
0 .4 1 r
.018 w
.6625 .54487 m
.6625 .60309 L
s
P
p
0 .4 1 r
.018 w
.6625 .54487 m
.7096 .51066 L
s
P
p
.2 0 1 r
.02 w
.30836 .21914 m
.41102 .07786 L
s
P
p
.2 0 1 r
.02 w
.30836 .21914 m
.30836 .0445 L
s
P
p
.2 0 1 r
.02 w
.23501 .2925 m
.06037 .2925 L
s
P
p
.2 0 1 r
.02 w
.23501 .2925 m
.09372 .39515 L
s
P
p
0 .4 1 r
.018 w
.29038 .27451 m
.30836 .21914 L
s
P
p
0 .4 1 r
.018 w
.29038 .27451 m
.23501 .2925 L
s
P
p
.2 0 1 r
.016 w
.45503 .43916 m
.68501 .40273 L
s
P
p
.2 0 1 r
.016 w
.45503 .43916 m
.22504 .40273 L
s
P
p
.2 0 1 r
.016 w
.45503 .43916 m
.6625 .54487 L
s
P
p
.2 0 1 r
.016 w
.45503 .43916 m
.29038 .27451 L
s
P
p
.2 0 1 r
.02 w
.76499 .2925 m
.90628 .39515 L
s
P
p
.2 0 1 r
.02 w
.76499 .2925 m
.93963 .2925 L
s
P
p
.2 0 1 r
.02 w
.69164 .21914 m
.69164 .0445 L
s
P
p
.2 0 1 r
.02 w
.69164 .21914 m
.58898 .07786 L
s
P
p
0 .4 1 r
.018 w
.70962 .27451 m
.76499 .2925 L
s
P
p
0 .4 1 r
.018 w
.70962 .27451 m
.69164 .21914 L
s
P
p
.2 0 1 r
.02 w
.2904 .51066 m
.18775 .36937 L
s
P
p
.2 0 1 r
.02 w
.2904 .51066 m
.12431 .45669 L
s
P
p
.2 0 1 r
.02 w
.3375 .60309 m
.28353 .76918 L
s
P
p
.2 0 1 r
.02 w
.3375 .60309 m
.39147 .76918 L
s
P
p
0 .4 1 r
.018 w
.3375 .54487 m
.2904 .51066 L
s
P
p
0 .4 1 r
.018 w
.3375 .54487 m
.3375 .60309 L
s
P
p
.2 0 1 r
.02 w
.80918 .44983 m
.86314 .61592 L
s
P
p
.2 0 1 r
.02 w
.80918 .44983 m
.95046 .55248 L
s
P
p
.2 0 1 r
.02 w
.79295 .34737 m
.8956 .20608 L
s
P
p
.2 0 1 r
.02 w
.79295 .34737 m
.79295 .17273 L
s
P
p
0 .4 1 r
.018 w
.77496 .40273 m
.80918 .44983 L
s
P
p
0 .4 1 r
.018 w
.77496 .40273 m
.79295 .34737 L
s
P
p
.2 0 1 r
.02 w
.297 .34737 m
.297 .17273 L
s
P
p
.2 0 1 r
.02 w
.297 .34737 m
.19435 .20608 L
s
P
p
.2 0 1 r
.02 w
.28077 .44983 m
.13948 .55248 L
s
P
p
.2 0 1 r
.02 w
.28077 .44983 m
.2268 .61592 L
s
P
p
0 .4 1 r
.018 w
.31499 .40273 m
.297 .34737 L
s
P
p
0 .4 1 r
.018 w
.31499 .40273 m
.28077 .44983 L
s
P
p
.2 0 1 r
.016 w
.54497 .43916 m
.70962 .27451 L
s
P
p
.2 0 1 r
.016 w
.54497 .43916 m
.3375 .54487 L
s
P
p
.2 0 1 r
.016 w
.54497 .43916 m
.77496 .40273 L
s
P
p
.2 0 1 r
.016 w
.54497 .43916 m
.31499 .40273 L
s
P
p
1 .6 0 r
.016 w
.5 .30075 m
.45503 .43916 L
s
P
p
1 .6 0 r
.016 w
.5 .30075 m
.54497 .43916 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0972841 0.952381 [
[ 0 0 0 0 ]
[ 1 .75781 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .75781 L
0 .75781 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.70529 .39251 m
.78445 .54788 L
s
P
p
.2 0 1 r
.02 w
.70529 .39251 m
.86066 .47168 L
s
P
p
.2 0 1 r
.02 w
.69793 .34606 m
.82123 .22276 L
s
P
p
.2 0 1 r
.02 w
.69793 .34606 m
.72521 .17383 L
s
P
p
0 .4 1 r
.018 w
.68474 .37196 m
.70529 .39251 L
s
P
p
0 .4 1 r
.018 w
.68474 .37196 m
.69793 .34606 L
s
P
p
.2 0 1 r
.02 w
.21226 .34606 m
.18498 .17383 L
s
P
p
.2 0 1 r
.02 w
.21226 .34606 m
.08896 .22276 L
s
P
p
.2 0 1 r
.02 w
.2049 .39251 m
.04953 .47168 L
s
P
p
.2 0 1 r
.02 w
.2049 .39251 m
.12574 .54788 L
s
P
p
0 .4 1 r
.018 w
.22545 .37196 m
.21226 .34606 L
s
P
p
0 .4 1 r
.018 w
.22545 .37196 m
.2049 .39251 L
s
P
p
.2 0 1 r
.02 w
.6668 .54259 m
.63952 .71482 L
s
P
p
.2 0 1 r
.02 w
.6668 .54259 m
.74597 .69796 L
s
P
p
.2 0 1 r
.02 w
.68815 .50069 m
.86038 .47341 L
s
P
p
.2 0 1 r
.02 w
.68815 .50069 m
.81146 .37739 L
s
P
p
0 .4 1 r
.018 w
.66226 .51389 m
.6668 .54259 L
s
P
p
0 .4 1 r
.018 w
.66226 .51389 m
.68815 .50069 L
s
P
p
.2 0 1 r
.02 w
.29524 .21522 m
.3744 .05985 L
s
P
p
.2 0 1 r
.02 w
.29524 .21522 m
.26796 .04299 L
s
P
p
.2 0 1 r
.02 w
.26199 .24847 m
.08976 .22119 L
s
P
p
.2 0 1 r
.02 w
.26199 .24847 m
.10661 .32764 L
s
P
p
0 .4 1 r
.018 w
.29069 .24393 m
.29524 .21522 L
s
P
p
0 .4 1 r
.018 w
.29069 .24393 m
.26199 .24847 L
s
P
p
.2 0 1 r
.016 w
.4551 .40833 m
.68474 .37196 L
s
P
p
.2 0 1 r
.016 w
.4551 .40833 m
.22545 .37196 L
s
P
p
.2 0 1 r
.016 w
.4551 .40833 m
.66226 .51389 L
s
P
p
.2 0 1 r
.016 w
.4551 .40833 m
.29069 .24393 L
s
P
p
.2 0 1 r
.02 w
.73801 .24847 m
.89339 .32764 L
s
P
p
.2 0 1 r
.02 w
.73801 .24847 m
.91024 .22119 L
s
P
p
.2 0 1 r
.02 w
.70476 .21522 m
.73204 .04299 L
s
P
p
.2 0 1 r
.02 w
.70476 .21522 m
.6256 .05985 L
s
P
p
0 .4 1 r
.018 w
.70931 .24393 m
.73801 .24847 L
s
P
p
0 .4 1 r
.018 w
.70931 .24393 m
.70476 .21522 L
s
P
p
.2 0 1 r
.02 w
.31185 .50069 m
.18854 .37739 L
s
P
p
.2 0 1 r
.02 w
.31185 .50069 m
.13962 .47341 L
s
P
p
.2 0 1 r
.02 w
.3332 .54259 m
.25403 .69796 L
s
P
p
.2 0 1 r
.02 w
.3332 .54259 m
.36048 .71482 L
s
P
p
0 .4 1 r
.018 w
.33774 .51389 m
.31185 .50069 L
s
P
p
0 .4 1 r
.018 w
.33774 .51389 m
.3332 .54259 L
s
P
p
.2 0 1 r
.02 w
.7951 .39251 m
.87426 .54788 L
s
P
p
.2 0 1 r
.02 w
.7951 .39251 m
.95047 .47168 L
s
P
p
.2 0 1 r
.02 w
.78774 .34606 m
.91104 .22276 L
s
P
p
.2 0 1 r
.02 w
.78774 .34606 m
.81502 .17383 L
s
P
p
0 .4 1 r
.018 w
.77455 .37196 m
.7951 .39251 L
s
P
p
0 .4 1 r
.018 w
.77455 .37196 m
.78774 .34606 L
s
P
p
.2 0 1 r
.02 w
.30207 .34606 m
.27479 .17383 L
s
P
p
.2 0 1 r
.02 w
.30207 .34606 m
.17877 .22276 L
s
P
p
.2 0 1 r
.02 w
.29471 .39251 m
.13934 .47168 L
s
P
p
.2 0 1 r
.02 w
.29471 .39251 m
.21555 .54788 L
s
P
p
0 .4 1 r
.018 w
.31526 .37196 m
.30207 .34606 L
s
P
p
0 .4 1 r
.018 w
.31526 .37196 m
.29471 .39251 L
s
P
p
.2 0 1 r
.016 w
.5449 .40833 m
.70931 .24393 L
s
P
p
.2 0 1 r
.016 w
.5449 .40833 m
.33774 .51389 L
s
P
p
.2 0 1 r
.016 w
.5449 .40833 m
.77455 .37196 L
s
P
p
.2 0 1 r
.016 w
.5449 .40833 m
.31526 .37196 L
s
P
p
1 .6 0 r
.016 w
.5 .27013 m
.4551 .40833 L
s
P
p
1 .6 0 r
.016 w
.5 .27013 m
.5449 .40833 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.162138 0.952381 [
[ 0 0 0 0 ]
[ 1 .6281 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .6281 L
0 .6281 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.76288 .30417 m
.82137 .36265 L
s
P
p
0 .4 1 r
.018 w
.76288 .30417 m
.80043 .23047 L
s
P
p
0 .4 1 r
.018 w
.10932 .30417 m
.07177 .23047 L
s
P
p
0 .4 1 r
.018 w
.10932 .30417 m
.05083 .36265 L
s
P
p
0 .4 1 r
.018 w
.73089 .50613 m
.74383 .58782 L
s
P
p
0 .4 1 r
.018 w
.73089 .50613 m
.80459 .46858 L
s
P
p
0 .4 1 r
.018 w
.20215 .12198 m
.21509 .04028 L
s
P
p
0 .4 1 r
.018 w
.20215 .12198 m
.12046 .13492 L
s
P
p
.2 0 1 r
.016 w
.4361 .35592 m
.76288 .30417 L
s
P
p
.2 0 1 r
.016 w
.4361 .35592 m
.10932 .30417 L
s
P
p
.2 0 1 r
.016 w
.4361 .35592 m
.73089 .50613 L
s
P
p
.2 0 1 r
.016 w
.4361 .35592 m
.20215 .12198 L
s
P
p
0 .4 1 r
.018 w
.79785 .12198 m
.87954 .13492 L
s
P
p
0 .4 1 r
.018 w
.79785 .12198 m
.78491 .04028 L
s
P
p
0 .4 1 r
.018 w
.26911 .50613 m
.19541 .46858 L
s
P
p
0 .4 1 r
.018 w
.26911 .50613 m
.25617 .58782 L
s
P
p
0 .4 1 r
.018 w
.89068 .30417 m
.94917 .36265 L
s
P
p
0 .4 1 r
.018 w
.89068 .30417 m
.92823 .23047 L
s
P
p
0 .4 1 r
.018 w
.23712 .30417 m
.19957 .23047 L
s
P
p
0 .4 1 r
.018 w
.23712 .30417 m
.17863 .36265 L
s
P
p
.2 0 1 r
.016 w
.5639 .35592 m
.79785 .12198 L
s
P
p
.2 0 1 r
.016 w
.5639 .35592 m
.26911 .50613 L
s
P
p
.2 0 1 r
.016 w
.5639 .35592 m
.89068 .30417 L
s
P
p
.2 0 1 r
.016 w
.5639 .35592 m
.23712 .30417 L
s
P
p
1 .6 0 r
.016 w
.5 .15926 m
.4361 .35592 L
s
P
p
1 .6 0 r
.016 w
.5 .15926 m
.5639 .35592 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0720399 0.952381 [
[ 0 0 0 0 ]
[ 1 .8083 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8083 L
0 .8083 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.67271 .64761 L
s
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.75652 .60491 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.79734 .34714 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.73084 .28063 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.6489 .4973 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.66174 .41623 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.26053 .12782 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.16763 .14253 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.04914 .37507 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.09184 .45888 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.23672 .27813 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.19946 .35126 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.49191 .74954 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.58481 .76426 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.76936 .57971 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.75464 .48681 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.561 .61394 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.61904 .5559 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.46398 .08674 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.38017 .04404 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.14763 .16253 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.13292 .25543 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.35636 .19436 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.28323 .23162 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.62587 .4521 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.24466 .32823 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.56894 .56384 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.33333 .23956 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.83361 .4831 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.87631 .39929 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.75783 .16675 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.66493 .15204 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.726 .37549 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.68874 .30235 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.19462 .30485 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.12811 .37136 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.16894 .62913 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.25274 .67183 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.26371 .44045 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.27655 .52152 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.74726 .67183 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.83106 .62913 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.87189 .37136 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.80538 .30485 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.72345 .52152 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.73629 .44045 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.33507 .15204 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.24217 .16675 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.12369 .39929 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.16639 .4831 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.31126 .30235 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.274 .37549 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.6808 .35246 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.29958 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.70042 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.3192 .35246 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.86708 .25543 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.85237 .16253 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.61983 .04404 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.53602 .08674 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.71677 .23162 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.64364 .19436 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.24536 .48681 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.23064 .57971 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.41519 .76426 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.50809 .74954 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.38096 .5559 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.439 .61394 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.90816 .45888 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.95086 .37507 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.83237 .14253 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.73947 .12782 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.80054 .35126 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.76328 .27813 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.26916 .28063 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.20266 .34714 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.24348 .60491 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.32729 .64761 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.33826 .41623 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.3511 .4973 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.66667 .23956 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.43106 .56384 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.75534 .32823 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.37413 .4521 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.42546 .42036 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.5 .44458 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.57454 .42036 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0944803 0.952381 [
[ 0 0 0 0 ]
[ 1 .76342 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .76342 L
0 .76342 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.75094 .37341 m
.85574 .51766 L
s
P
p
.2 0 1 r
.02 w
.75094 .37341 m
.92051 .42851 L
s
P
p
.2 0 1 r
.02 w
.72122 .28195 m
.82602 .1377 L
s
P
p
.2 0 1 r
.02 w
.72122 .28195 m
.72122 .10365 L
s
P
p
0 .4 1 r
.018 w
.70285 .33847 m
.75094 .37341 L
s
P
p
0 .4 1 r
.018 w
.70285 .33847 m
.72122 .28195 L
s
P
p
.2 0 1 r
.02 w
.20409 .36385 m
.14899 .19428 L
s
P
p
.2 0 1 r
.02 w
.20409 .36385 m
.05984 .25905 L
s
P
p
.2 0 1 r
.02 w
.20409 .46002 m
.05984 .56482 L
s
P
p
.2 0 1 r
.02 w
.20409 .46002 m
.14899 .62959 L
s
P
p
0 .4 1 r
.018 w
.23902 .41194 m
.20409 .36385 L
s
P
p
0 .4 1 r
.018 w
.23902 .41194 m
.20409 .46002 L
s
P
p
.2 0 1 r
.02 w
.72122 .54193 m
.72122 .72023 L
s
P
p
.2 0 1 r
.02 w
.72122 .54193 m
.82602 .68617 L
s
P
p
.2 0 1 r
.02 w
.75094 .45047 m
.92051 .39537 L
s
P
p
.2 0 1 r
.02 w
.75094 .45047 m
.85574 .30622 L
s
P
p
0 .4 1 r
.018 w
.70285 .4854 m
.72122 .54193 L
s
P
p
0 .4 1 r
.018 w
.70285 .4854 m
.75094 .45047 L
s
P
p
.2 0 1 r
.02 w
.28443 .21277 m
.33952 .0432 L
s
P
p
.2 0 1 r
.02 w
.28443 .21277 m
.22933 .0432 L
s
P
p
.2 0 1 r
.02 w
.2279 .29057 m
.0496 .29057 L
s
P
p
.2 0 1 r
.02 w
.2279 .29057 m
.08365 .39537 L
s
P
p
0 .4 1 r
.018 w
.28443 .2722 m
.28443 .21277 L
s
P
p
0 .4 1 r
.018 w
.28443 .2722 m
.2279 .29057 L
s
P
p
.2 0 1 r
.016 w
.47676 .41194 m
.70285 .33847 L
s
P
p
.2 0 1 r
.016 w
.47676 .41194 m
.23902 .41194 L
s
P
p
.2 0 1 r
.016 w
.47676 .41194 m
.70285 .4854 L
s
P
p
.2 0 1 r
.016 w
.47676 .41194 m
.28443 .2722 L
s
P
p
.2 0 1 r
.02 w
.7721 .29057 m
.91635 .39537 L
s
P
p
.2 0 1 r
.02 w
.7721 .29057 m
.9504 .29057 L
s
P
p
.2 0 1 r
.02 w
.71557 .21277 m
.77067 .0432 L
s
P
p
.2 0 1 r
.02 w
.71557 .21277 m
.66048 .0432 L
s
P
p
0 .4 1 r
.018 w
.71557 .2722 m
.7721 .29057 L
s
P
p
0 .4 1 r
.018 w
.71557 .2722 m
.71557 .21277 L
s
P
p
.2 0 1 r
.02 w
.24906 .45047 m
.14426 .30622 L
s
P
p
.2 0 1 r
.02 w
.24906 .45047 m
.07949 .39537 L
s
P
p
.2 0 1 r
.02 w
.27878 .54193 m
.17398 .68617 L
s
P
p
.2 0 1 r
.02 w
.27878 .54193 m
.27878 .72023 L
s
P
p
0 .4 1 r
.018 w
.29715 .4854 m
.24906 .45047 L
s
P
p
0 .4 1 r
.018 w
.29715 .4854 m
.27878 .54193 L
s
P
p
.2 0 1 r
.02 w
.79591 .46002 m
.85101 .62959 L
s
P
p
.2 0 1 r
.02 w
.79591 .46002 m
.94016 .56482 L
s
P
p
.2 0 1 r
.02 w
.79591 .36385 m
.94016 .25905 L
s
P
p
.2 0 1 r
.02 w
.79591 .36385 m
.85101 .19428 L
s
P
p
0 .4 1 r
.018 w
.76098 .41194 m
.79591 .46002 L
s
P
p
0 .4 1 r
.018 w
.76098 .41194 m
.79591 .36385 L
s
P
p
.2 0 1 r
.02 w
.27878 .28195 m
.27878 .10365 L
s
P
p
.2 0 1 r
.02 w
.27878 .28195 m
.17398 .1377 L
s
P
p
.2 0 1 r
.02 w
.24906 .37341 m
.07949 .42851 L
s
P
p
.2 0 1 r
.02 w
.24906 .37341 m
.14426 .51766 L
s
P
p
0 .4 1 r
.018 w
.29715 .33847 m
.27878 .28195 L
s
P
p
0 .4 1 r
.018 w
.29715 .33847 m
.24906 .37341 L
s
P
p
.2 0 1 r
.016 w
.52324 .41194 m
.71557 .2722 L
s
P
p
.2 0 1 r
.016 w
.52324 .41194 m
.29715 .4854 L
s
P
p
.2 0 1 r
.016 w
.52324 .41194 m
.76098 .41194 L
s
P
p
.2 0 1 r
.016 w
.52324 .41194 m
.29715 .33847 L
s
P
p
1 .6 0 r
.016 w
.5 .26518 m
.47676 .41194 L
s
P
p
1 .6 0 r
.016 w
.5 .26518 m
.52324 .41194 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0906538 0.952381 [
[ 0 0 0 0 ]
[ 1 .77107 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .77107 L
0 .77107 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.7036 .4176 m
.77792 .56348 L
s
P
p
.2 0 1 r
.02 w
.7036 .4176 m
.84947 .49193 L
s
P
p
.2 0 1 r
.02 w
.68979 .33039 m
.80555 .21463 L
s
P
p
.2 0 1 r
.02 w
.68979 .33039 m
.7154 .16869 L
s
P
p
0 .4 1 r
.018 w
.66501 .37902 m
.7036 .4176 L
s
P
p
0 .4 1 r
.018 w
.66501 .37902 m
.68979 .33039 L
s
P
p
.2 0 1 r
.02 w
.20903 .33039 m
.18342 .16869 L
s
P
p
.2 0 1 r
.02 w
.20903 .33039 m
.09327 .21463 L
s
P
p
.2 0 1 r
.02 w
.19522 .4176 m
.04935 .49193 L
s
P
p
.2 0 1 r
.02 w
.19522 .4176 m
.12089 .56348 L
s
P
p
0 .4 1 r
.018 w
.23381 .37902 m
.20903 .33039 L
s
P
p
0 .4 1 r
.018 w
.23381 .37902 m
.19522 .4176 L
s
P
p
.2 0 1 r
.02 w
.65244 .56616 m
.62683 .72787 L
s
P
p
.2 0 1 r
.02 w
.65244 .56616 m
.72677 .71204 L
s
P
p
.2 0 1 r
.02 w
.69253 .48749 m
.85423 .46188 L
s
P
p
.2 0 1 r
.02 w
.69253 .48749 m
.8083 .37172 L
s
P
p
0 .4 1 r
.018 w
.64391 .51226 m
.65244 .56616 L
s
P
p
0 .4 1 r
.018 w
.64391 .51226 m
.69253 .48749 L
s
P
p
.2 0 1 r
.02 w
.30359 .20491 m
.37792 .05904 L
s
P
p
.2 0 1 r
.02 w
.30359 .20491 m
.27798 .04321 L
s
P
p
.2 0 1 r
.02 w
.24115 .26735 m
.07945 .24174 L
s
P
p
.2 0 1 r
.02 w
.24115 .26735 m
.09528 .34167 L
s
P
p
0 .4 1 r
.018 w
.29505 .25881 m
.30359 .20491 L
s
P
p
0 .4 1 r
.018 w
.29505 .25881 m
.24115 .26735 L
s
P
p
.2 0 1 r
.016 w
.44941 .41316 m
.66501 .37902 L
s
P
p
.2 0 1 r
.016 w
.44941 .41316 m
.23381 .37902 L
s
P
p
.2 0 1 r
.016 w
.44941 .41316 m
.64391 .51226 L
s
P
p
.2 0 1 r
.016 w
.44941 .41316 m
.29505 .25881 L
s
P
p
.2 0 1 r
.02 w
.75885 .26735 m
.90472 .34167 L
s
P
p
.2 0 1 r
.02 w
.75885 .26735 m
.92055 .24174 L
s
P
p
.2 0 1 r
.02 w
.69641 .20491 m
.72202 .04321 L
s
P
p
.2 0 1 r
.02 w
.69641 .20491 m
.62208 .05904 L
s
P
p
0 .4 1 r
.018 w
.70495 .25881 m
.75885 .26735 L
s
P
p
0 .4 1 r
.018 w
.70495 .25881 m
.69641 .20491 L
s
P
p
.2 0 1 r
.02 w
.30747 .48749 m
.1917 .37172 L
s
P
p
.2 0 1 r
.02 w
.30747 .48749 m
.14577 .46188 L
s
P
p
.2 0 1 r
.02 w
.34756 .56616 m
.27323 .71204 L
s
P
p
.2 0 1 r
.02 w
.34756 .56616 m
.37317 .72787 L
s
P
p
0 .4 1 r
.018 w
.35609 .51226 m
.30747 .48749 L
s
P
p
0 .4 1 r
.018 w
.35609 .51226 m
.34756 .56616 L
s
P
p
.2 0 1 r
.02 w
.80478 .4176 m
.87911 .56348 L
s
P
p
.2 0 1 r
.02 w
.80478 .4176 m
.95065 .49193 L
s
P
p
.2 0 1 r
.02 w
.79097 .33039 m
.90673 .21463 L
s
P
p
.2 0 1 r
.02 w
.79097 .33039 m
.81658 .16869 L
s
P
p
0 .4 1 r
.018 w
.76619 .37902 m
.80478 .4176 L
s
P
p
0 .4 1 r
.018 w
.76619 .37902 m
.79097 .33039 L
s
P
p
.2 0 1 r
.02 w
.31021 .33039 m
.2846 .16869 L
s
P
p
.2 0 1 r
.02 w
.31021 .33039 m
.19445 .21463 L
s
P
p
.2 0 1 r
.02 w
.2964 .4176 m
.15053 .49193 L
s
P
p
.2 0 1 r
.02 w
.2964 .4176 m
.22208 .56348 L
s
P
p
0 .4 1 r
.018 w
.33499 .37902 m
.31021 .33039 L
s
P
p
0 .4 1 r
.018 w
.33499 .37902 m
.2964 .4176 L
s
P
p
.2 0 1 r
.016 w
.55059 .41316 m
.70495 .25881 L
s
P
p
.2 0 1 r
.016 w
.55059 .41316 m
.35609 .51226 L
s
P
p
.2 0 1 r
.016 w
.55059 .41316 m
.76619 .37902 L
s
P
p
.2 0 1 r
.016 w
.55059 .41316 m
.33499 .37902 L
s
P
p
1 .6 0 r
.016 w
.5 .25746 m
.44941 .41316 L
s
P
p
1 .6 0 r
.016 w
.5 .25746 m
.55059 .41316 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0837567 0.952381 [
[ 0 0 0 0 ]
[ 1 .78487 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78487 L
0 .78487 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.79178 .57374 L
s
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.86468 .50084 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.81993 .21828 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.72807 .17148 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.71605 .42511 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.70197 .33624 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.18602 .17148 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.09415 .21828 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.0494 .50084 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.1223 .57374 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.21211 .33624 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.19804 .42511 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.63783 .74125 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.73966 .72512 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.86953 .47022 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.82273 .37836 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.66392 .57648 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.70477 .49632 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.3842 .05975 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.28237 .04362 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.08008 .24591 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.09621 .34774 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.30846 .20838 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.24484 .272 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.67673 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.23736 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.65522 .52156 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.29976 .26331 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.90379 .34774 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.91992 .24591 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.71763 .04362 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.6158 .05975 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.75516 .272 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.69154 .20838 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.17727 .37836 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.13047 .47022 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.26034 .72512 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.36217 .74125 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.29523 .49632 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.33608 .57648 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.8777 .57374 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.9506 .50084 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.90585 .21828 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.81398 .17148 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.80196 .42511 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.78789 .33624 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.27193 .17148 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.18007 .21828 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.13532 .50084 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.20822 .57374 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.29803 .33624 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.28395 .42511 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.70024 .26331 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.34478 .52156 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.76264 .38579 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.32327 .38579 L
s
P
p
1 .6 0 r
.018 w
.5 .28837 m
.45704 .42058 L
s
P
p
1 .6 0 r
.018 w
.5 .28837 m
.54296 .42058 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0837567 0.952381 [
[ 0 0 0 0 ]
[ 1 .78487 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78487 L
0 .78487 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.79178 .57374 L
s
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.86468 .50084 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.81993 .21828 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.72807 .17148 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.71605 .42511 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.70197 .33624 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.18602 .17148 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.09415 .21828 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.0494 .50084 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.1223 .57374 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.21211 .33624 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.19804 .42511 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.63783 .74125 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.73966 .72512 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.86953 .47022 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.82273 .37836 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.66392 .57648 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.70477 .49632 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.3842 .05975 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.28237 .04362 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.08008 .24591 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.09621 .34774 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.30846 .20838 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.24484 .272 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.67673 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.23736 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.65522 .52156 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.29976 .26331 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.90379 .34774 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.91992 .24591 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.71763 .04362 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.6158 .05975 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.75516 .272 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.69154 .20838 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.17727 .37836 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.13047 .47022 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.26034 .72512 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.36217 .74125 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.29523 .49632 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.33608 .57648 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.8777 .57374 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.9506 .50084 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.90585 .21828 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.81398 .17148 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.80196 .42511 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.78789 .33624 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.27193 .17148 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.18007 .21828 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.13532 .50084 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.20822 .57374 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.29803 .33624 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.28395 .42511 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.70024 .26331 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.34478 .52156 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.76264 .38579 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.32327 .38579 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.45704 .42058 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.54296 .42058 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0790991 1.1582 0.028955 1.1582 [
[ 0 0 0 0 ]
[ 1 1.21611 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.21611 L
0 1.21611 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.50273 .25473 m
.71597 .18544 L
s
P
p
.2 0 1 r
.02 w
.50273 .25473 m
.63452 .07333 L
s
P
p
.2 0 1 r
.02 w
.38179 .25473 m
.25 .07333 L
s
P
p
.2 0 1 r
.02 w
.38179 .25473 m
.16855 .18544 L
s
P
p
0 .4 1 r
.018 w
.44226 .29866 m
.50273 .25473 L
s
P
p
0 .4 1 r
.018 w
.44226 .29866 m
.38179 .25473 L
s
P
p
.2 0 1 r
.02 w
.27879 .90504 m
.05457 .90504 L
s
P
p
.2 0 1 r
.02 w
.27879 .90504 m
.0974 1.03683 L
s
P
p
.2 0 1 r
.02 w
.39381 .94241 m
.4631 1.15566 L
s
P
p
.2 0 1 r
.02 w
.39381 .94241 m
.57521 1.0742 L
s
P
p
0 .4 1 r
.018 w
.34988 .88194 m
.27879 .90504 L
s
P
p
0 .4 1 r
.018 w
.34988 .88194 m
.39381 .94241 L
s
P
p
.2 0 1 r
.02 w
.69272 .35575 m
.90597 .42504 L
s
P
p
.2 0 1 r
.02 w
.69272 .35575 m
.90597 .28647 L
s
P
p
.2 0 1 r
.02 w
.59489 .28467 m
.59489 .06045 L
s
P
p
.2 0 1 r
.02 w
.59489 .28467 m
.4631 .10327 L
s
P
p
0 .4 1 r
.018 w
.61798 .35575 m
.69272 .35575 L
s
P
p
0 .4 1 r
.018 w
.61798 .35575 m
.59489 .28467 L
s
P
p
.2 0 1 r
.016 w
.44226 .59762 m
.44226 .29866 L
s
P
p
.2 0 1 r
.016 w
.44226 .59762 m
.34988 .88194 L
s
P
p
.2 0 1 r
.016 w
.44226 .59762 m
.61798 .35575 L
s
P
p
.2 0 1 r
.02 w
.40511 .28467 m
.5369 .10327 L
s
P
p
.2 0 1 r
.02 w
.40511 .28467 m
.40511 .06045 L
s
P
p
.2 0 1 r
.02 w
.30728 .35575 m
.09403 .28647 L
s
P
p
.2 0 1 r
.02 w
.30728 .35575 m
.09403 .42504 L
s
P
p
0 .4 1 r
.018 w
.38202 .35575 m
.40511 .28467 L
s
P
p
0 .4 1 r
.018 w
.38202 .35575 m
.30728 .35575 L
s
P
p
.2 0 1 r
.02 w
.60619 .94241 m
.42479 1.0742 L
s
P
p
.2 0 1 r
.02 w
.60619 .94241 m
.5369 1.15566 L
s
P
p
.2 0 1 r
.02 w
.72121 .90504 m
.9026 1.03683 L
s
P
p
.2 0 1 r
.02 w
.72121 .90504 m
.94543 .90504 L
s
P
p
0 .4 1 r
.018 w
.65012 .88194 m
.60619 .94241 L
s
P
p
0 .4 1 r
.018 w
.65012 .88194 m
.72121 .90504 L
s
P
p
.2 0 1 r
.02 w
.61821 .25473 m
.83145 .18544 L
s
P
p
.2 0 1 r
.02 w
.61821 .25473 m
.75 .07333 L
s
P
p
.2 0 1 r
.02 w
.49727 .25473 m
.36548 .07333 L
s
P
p
.2 0 1 r
.02 w
.49727 .25473 m
.28403 .18544 L
s
P
p
0 .4 1 r
.018 w
.55774 .29866 m
.61821 .25473 L
s
P
p
0 .4 1 r
.018 w
.55774 .29866 m
.49727 .25473 L
s
P
p
.2 0 1 r
.016 w
.55774 .59762 m
.38202 .35575 L
s
P
p
.2 0 1 r
.016 w
.55774 .59762 m
.65012 .88194 L
s
P
p
.2 0 1 r
.016 w
.55774 .59762 m
.55774 .29866 L
s
P
p
1 .6 0 r
.016 w
.5 .41991 m
.44226 .59762 L
s
P
p
1 .6 0 r
.016 w
.5 .41991 m
.55774 .59762 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`0005L000==00002@000dd0002L0000400014`004`70004C000C1@000A<001<
1`0014`004`E0003C00000T000=<00004P000d`0000=0003C000014000E<0000C0050005C00004`0
500014`004`70004C000C1@000C600361`001<H00<HA0000400014d004d70004C@00CA@000A=001=
1`0014d004dE0003C@0000T000==00004P000dd000020003C@0000<000==00000P000dd0000A0005
C@0004d01@001Dd0001=01@000A=001=1`0014d004dD0004aP00aPL000C600364@00010000=<04`0
2@000d`0C00D0003C01<00T000=<04`05@000d`000090003C00001<000E<0000C0050005C00004`0
500014`004`70004C000C1@000=<04`02@000d`0C00D0003aP3600T000?60<H04@0001400Td9009=
5P02C@T00TdE0003C@0000X000==00004`0014d004d70004C@00CA4000==00000dd900==0P000dd0
000@009=2@02CAH00/H900;64P0000d000=<00000d`900=<0P000d`0000<0003C00000=<2@03C080
00=<00002P000d`0C0020003C00000X000A<001<0P000d`0000;0003C01<009<2@03C00304`000h0
00=<00000d`900=<0P000d`0000<0003C00000=<2@03C08000=<000030000lH00003aPT00lH20003
aP0000`0000:0004C@00C@8000==aP002P001LI=001=008000==00001P0014d004d2009=2`02C@80
00A=001=2@000dd0C@020003aP0000X000C6001=0P000dd0000;0004C@00C@/000C6001=300014d0
04d20003CLH000X000G6C@00C@020003C@0000H000A=001=0P000dg6000:0005aTd004d00P000dd0
00060004aP00aP800/H;00;60P001<H00<H;00002@05C08000=<aP002P000lI<0005C0P014`2009<
2`02C00304a<00=<2P001D`0C03600`000?604`00P000d`0000800E<0P000d`000090003aP0000E<
1`06C00304c600/000?6C0001T`700E<00<0C<H02`000lI<0005C0P01LH00`36aP0;00;60P04aP/0
000<00==00?6CDd02`000dg6aP03C@`000==04d00dd;00I=3002C@03aTe=00H000<A00000`02C@;6
0dd;0006C@1=CLI=2`000dg6aP03C@`014d00lI=000:0003CLK600==30001Td0CDg6C@/000==a/H0
0dd<0003aP3600?62`000dg6aP03aPd0000<00E<00<0C0000`000a40000200=<00@0C4a<3005C003
04`000<000<A00000P03C00404a<C0T014`20003C01<00D000<A00000P0014`004`20004C01<C0X0
0T`0101<C4`400034@0000800d`00`1<C00=00=<00@0C4a<10000a40000200=<00@0C4a<3003C004
04a<C0@000<A00000P03C00404a<C0`00lH01036aT`400034@00008000=<0<H01<H=00002`001Td0
0<H0aP8000E=00004@030003C@36008000C6001=2P001Td004d0C@8000E=00004@030003C@1=0080
00A=001=30001/H00<H0C@<00Q430004C@00aP8000?600002`000dd0aP020003aP1=00<000LA0000
C@36008000?604d02`0014d00<H20003aP1=00<000LA0000C@36008000C6001=2P0014d00<H20003
aP1=00<000LA0000C@36008000C6001=2P001<H00<H20003aP1=00<000DA0000C@020003aP360080
00?600002P0000X000M<0000aP3600<000A<000A0P0014`00<H20005aP0004`020001d`0001<04`0
0`0014`001420004C000C08000E<0000C00;0004aP00aP8000Q<000A0140C0<000C60036300014`0
04`20004aP00C08000@A001<0P001<H00<H20003C00000L000E<001<aP020004aP00C08000@A001<
0P001LH00<I<008000=<00001P001D`00036008000C6001<0P00114004`20004aP00aP<000=<0000
1P001LH00036008000C6001<0P00114004`30003aP3600<000?600002@0000d000==aTd01Td00a40
4@07C@03aTd000d02Dd00a404@09C@l024d00a404@08CA0024d00a404@08CA000dd00lI=C@02C@03
4@0A00Q=3`09C@034@0A00M=00?6C@003@02aPM=00<A01401dd2aPh0000<0005C<I<C<H00`02C003
4D`A00=<0P001LI<0<I<00`01D`3009<00<AC1400d`2009<00<0C4`02`02C004aP00aP800T`0115<
C143C08000C600360T`<0004C<I<aP<00T`00a5<4@03C08000C6C<I<3P0014c6C<H3009<00<AC140
0d`20004aTc6C0d000E<aP1<aP03009<00<AC1400d`20005aTa<aT`03002aP030<K600<00T`00a5<
4@03C0801LH=00002P07C@@00Td00`1=C@040003C@1=00A=2007C@@00Td00`1=C@040003C@1=00A=
2P04C@D01Dd500A=2P05C@0304d000<00Td00`1=C@040003C@1=00A=2@04C@0304d000<00Td00`1=
C@040003C@1=00==2@05C@0304d000<00Td00`1=C@0400M=2005aP030<H000<00Td00`1=C@0400O6
2`0000T000A<04a<0P0014c6aP02C0D00T`01036C4`2009<00<0C0001@0014`0C4`200=<00<0C4`0
1@02C00404a<C0800T`00`1<00070003C000009<0`02C0D00T`3009<0P000d`000060003C01<00E<
00C604a<1@02C0030<I<00E<00<0C0001P001D`0C4`0009<00C604a<1@02C0050<I<C0000T`00`1<
00060004C01<C0800T`01<H0C4`5009<00<0a/H00T`01@1<C01<00H000C60<K60P03aP0304a<00D0
0T`00`36aP02aP050<K60<H02P0000`000A=001=0P000dd000070004C@00C@8000==00002P0014d0
04d20003C@0000L000A=001=0P000dd000080004C@00C@800/H00dd000070003CLK6008000A=001=
2`000dd0C@020003C@0000L000I=001=04d:0004C@1=C@8000A=001=2@0014d004d2009=00<0C@00
200014d004d20003C@0000L000A=001=0P000dd0000:0004aP00aP8000==00001`0014d00<H20003
aP0000/0000<0004C000C08000?600001`001<H004`20003C00000X000A<001<0P000d`000070004
C000C08000=<00001`0014`004`50003aP0000L000?600000`0014`004`:0003C01<008000?60000
1`001/H004`0C0d000A<001<0P000lH000070004aP00C08000=<00002P0014`004`20003aP0000L0
00C6001<0P000d`0000:0004aP00aP8000?600001`001<H00<H20003aP0000/0000;0004C@00C@<0
00?600001`001LH0001=008000==0000200014d004d30003C@0000L000E=0000C@020003C@0000h0
00?600002@000lH0000?0004C@00C@8000?600001`001<H004d20003C@0000T000A=001=0`000lH0
00070005aP0004d00P000dd000080004C@00C@<000?600001`001LH0001=008000==000020001<H0
0<H30003aP0000L000G60000aP020003aP0000X0000B0003C00000L000=<00005P000d`000070003
C00001D000=<00002@000d`0000E0003C00000L000=<00005P000d`000070003C00001H000=<0000
1`000d`0000F0003aP0000L000?600004@0001400Td9009=5P02C@T00TdF0003C@0000T000==0000
5002C@P000==04d05P02C@T00TdF009=2@02CAH00/H900;64P00010000=<04`0200014`004`D0004
C000C0L000A<001<5@000d`000090003C00001<000A<001<1`0014`004`D0004C000C0L000A<001<
500014`004`70004C000C1@000C600361`001<H00<HA000040000dd0C@080004C@00CA@000A=001=
1`0014d004dD0003C@0000X000==00004P001Dd0001=00L000E=0000C@0C0004C@00C@L000A=001=
500014d004d70004C@00CA@000C600361`001<H00<HA00003`0014`004`80005C00004`04P001D`0
001<00L000E<0000C00C0003C00000X000=<00005P000d`000040003C00001D000E<0000C0070005
C00004`04P001D`0001<00L000E<0000C00B0005aP000<H01`001LH000360100001F0003C@0000X0
00==0000W0000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`0003<000E=0000C@050005C@0004d0500014d004d70004C@00CA@000A=001=
1`0014d004dh0003C@0000T000==00004`000dd0000;0003C@0000l0000c0005C00004`01@001D`0
001<01@000A<001<1`0014`004`D0004C000C0L000A<001<>00014`004`50004C000C1D000A<001<
1`0014`004`A00003P000dd0000>0003C@00014000A=001=1`0014d004dD0003C@1=00T000==04d0
50000dd0C@090003C@1=018000==00003`000dd0000A0004C@00C@D000A=001=5@0014d004d70004
C@00CA40000;0004C000C10000A<001<4@02C0T00T`F009<2@02C1H00T`9009<4`000d`0000?0003
C000014000=<04`01`000d`0C00E0003C01<00T000=<04`04@0000/000A=001=400014d004d=0003
C@0000==2@03C@8000==000030000dd00003C@T00dd20003C@0000`000==00000dd900==0P000dd0
000:009=0P000dd0000=0003C@00009=3@000dd00002C@T00Td20003C@0000d000==00000dd:009=
0P000dd0000<000030000d`0C00@0003C01<00/000A<001<0P000dc6000:0005aT`004`00P000d`0
00060004C000C08000=<aP002P001LI<001<008000=<00001P0014`004`20003C<H000X000G6C000
C0020003C00000T00d`?00=<2`000d`00002C08000=<00002@000lH00002C08000=<00002@000d`0
0003C0X00T`20003C00000`0000=009=4002C@d000M=04e=04g600/000?6C@000Td00`1=000800E=
00<0CLH02`000lI=0005C@P01Dd00`1=aP0;0003aTd000E=3@000dd0000=0003C@0000`000A=001=
0P000dd000090004aP00C@8000==00001`04C@8000==aP002`000lH00004C@/0000>0003aP0000H0
00<A00001@000lH0000:00M<00?6C00010000a4000030003C<K600E<2P001T`0C4c6C0/000=<a/H0
0d`<0006C01<C<I<2`03aP=<40000lH0000;0003aP0000/02D`;009<00?6C4`014`80005C01<C<H0
0T`;009<00G6C4`0C00<00003@000dg6000700034@0000D000?604d03@03C@0304e=00D000<A0000
0P03C@0404e=C@`00dd0101=CDd400034@0000800dd0101=CDd<00==00@0CDg610000a4000020004
aTe=00==4@000dd000090003C@0001000Td0101=CDd400034@0000800dd00`1=C@0=00A=00<0CDd0
10000a400002009=00<0CDd00dd<00003@000dc6C002C0D000<A00000`03C00304`000/000A<0036
0P000lI<0002008A0`000d`0aP020004aP00C0X000A<00360P000lH0C00300074@0004`0aP020004
aP00C0X000A<00360P000lH0aP0300074@000<H0aP020004aP00C0P00T`00`1<C0040003C0000080
00<A00000P000d`00002009<00<0C4`02@000d`0aP020003aP1<00<000LA0000C036008000?604`0
2`001D`0C4`0009<00<0C0000P001Q40001<009<00<0C4`00P000d`00009000030000dg6C@0300==
00D04@0A0003C@<000?6C@002P001Dd004g6008000?604d00P001A404@1=008000G60036C@020003
C@0000H000E=0000aP020004aP00C@8000@A001=0P001<H00<H30003C@0000H000E=0000aP020004
aP00aP8000@A00360P001<H00<H30003C@0000L01Dd30005C@0001400`0014d00005C@X000A=04g6
0P001<H004d200044@00C@8000O60036C@1=00d000C600360P0014d001420004C@00aP8000?60000
3@0000X01T`50005C15<4D`01@06C0`024`00a404@08C0l000=<aT`01T`00a404@07C003aT`000d0
00=<a/H01/H00a404@08aP03C00000/014`2aP=<0P000a400006C004aTa<C0T000=<00002D`00a40
4@09C08000=<00002@09C0034@0A00U<3P0000T000A=001=0P000dg6aP0200==0P03C@030<K600==
0`000dd000080006CLI=CLH00Td0115=CA43C@060<I=CLI=3@001Dg6CDg600<00Td00a5=4@03C@80
00G6C@36C@0<0005CLI=CLH00`02aP034LHA00?60P001LI=0<I=00T01Dd400A=00<ACA4014d500A=
2P001<I=0<H200==00<ACA400dd20004aTe=aP`00Td01P1=C@1=00==00<ACA400dd20003C@1=00==
300000/000=<00001002C0P000=<00000`000d`0000900M<0`04C0@01d`900M<1002C00304a<00@0
00=<04`014`800M<1002aP030<K600@000=<04`014`C0005C15<4D`05006C0@00T`00`1<C00400I<
2@001D`004`0009<1002C00304a<00D000I<04a<04`;00002P000dd000050003aP0000L000?60000
10000dd000070005C@1=C@000Td01<H0CDd4009=00<0a/H00Td01@1=001=00L000==04d014d2aP03
04e=00D00Td00`36C@05C@0304d000D000==04d014d2aP030<K600D00/H00`36C@05C@0304d00140
0Td00`1=C@0D009=00<0CDd00/H00`1=C@05009=00<0a/H01Dd80003C@0000E=0P02C@D00Td200I=
00<0C@002@00014000?600002@000lH0000<0004C01<C08000A<001<20001D`0001<008000A<001<
2@0014`004`20003C00000L000A<001<0P000d`0000:0004C000C08000?600001`001<H004`20003
C00001400T`5009<4@001T`0C4`0C08000=<00001`0014`004`20003C01<00X000=<00000T`00lI<
00080004C<I<C08000=<00002`00014000==00002@000dd0000?0004C@00C@8000?600001P001LH0
001=008000==00002P0014d004d20003aP0000L000C6001=0P000dd0000:0004C@00C@8000?60000
1`001<H004d20003C@0000d00Td00lI=00080003CLI=009=2`0014d004d20004C@00aPT000C6001=
0P02C@0304d000L000A=001=0`000lH000070005aP0004d00P000dd0000:00004002C0/00T`?0004
C000C0<000?600001`001LH0001<008000=<0000200014`004`30003aP0000L000G60000C0020003
C00000P000A<001<0`000lH000070005aP0004`00P000d`0000900=<00<0C00030000d`00002C0/0
00A<001<0`000lH000070005aP0004`00P000d`0000?0003C00000L000=<00004@0000l000==04d0
2`000dd0C@0E0003C@0000L000==00005P000dd000070003C@0001H000==00001`000dd0000C0003
C@0000d000==0000300014d004d30003C@0000L000E=0000C@020003C@0000h00Td9009=4P0000h0
00A<001<2`0014`004`C009<2@02C1H00T`9009<5P02C0T00T`C0003C00000l000=<00004@000d`0
C0070003C01<01D000=<04`02@000d`0C00A00004@000dd000090003C@0001@000==04d01`000dd0
C@0E0004C@00C@L000A=001=500014d004d70004C@00CA4000==00004@000dd0000@0003C@1=00L0
00==04d05@0014d004d80003C@1=0140000d0003C01<00L000=<04`05@0014`004`70004C000C1@0
00A<001<1`0014`004`h0003C01<00L000=<04`050001D`0001<00P000A<001<400003<000A=001=
1`0014d004dC0005C@0004d01`001Dd0001=018000E=0000C@070005C@0004d0=P001Dd0001=00D0
00E=0000C@0G0003C@0000H000==00004@000;l000E<0000C0050005C00004`0=0000?l00`000?l0
0`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000><000==00000Td4009=0P000dd0
000?0000h`000d`00003C00304`0009<0P000d`0000?0000i0000dd00002C@0404d0C@8000==0000
400003H000=<00001@000d`0000C0005C00004`02@001D`0001<018000=<00002`000d`0000B0004
C000C0L000A<001<500014`004`70004C000C1801T`01@1<C4`0009<00@0C4`00T`?0000=P001Td0
CDd0C@8000==00004`001Dd0001=00T000E=0000C@0B0004C@00C@L000A=001=500014d004d70004
C@00CA@000A=001=1`0014d004dE00I=00<0CDd01DdA00003P000lH0000?0003aP0000l000A<0000
0T`40003C01<00<000=<00004003C0/00d`C0004C000C0L000A<001<50000d`0C0090003C01<01@0
00=<04`02@000d`0C00H0003aTa<00;600=<aT`0500000h000?600003`000lH0000<009=00@0C@00
0Td600==0P0014d0CDd=0003C@1=009=2`03C@0304d001400Td9009=5P02C@T00TdF009=2@02CA40
14d50006aTd004g61004C@d0000=0003aP00010000?60000300014`0C4`20003C00000H000C6C000
0d`>0003C01<009<2`03C00304`000d000=<00000d`900=<0P000d`0000<0003C00000=<2@03C080
00=<000030000d`00003C0T00d`20003C00000l00T`2aP03C01<00800T`2aP9<4@0000/00/H2CA40
00A=a/K630000dd0C@020003C@0000H000C6C@000Td>0005C@1=04d03@001Dd0C@1=00d000E=001=
aP0;0005aTd004d03P001Dd004g600/000G6C@00C@0>0005C@00CLH02`001LI=001=00l00dd30003
C@1=00800Td400==3P0000l000=<00001@000a4000050003C00000`024`90003C<K600E<2`000d`0
0002C0d000G6C000C00:00E<00<0C<H02`000lI<0005C0P01D`00`1<aP0;0003aT`000E<2005C003
04c600/000?6C0001D`:009<1`02C0034@1<00P000=<00002`00010000==000010000a4000040003
C@00014000C6CDe=2@03C@03aP0000X00Td20004C@1=C@H000<A000010001<I=04d2009=2@000dd0
C@03C@D000<A00000`000dg6aP03C@`000I=04e=aTd;0003CLK600==30001Td0CDg6C@/000==a/H0
0ddF0004CA40CAH000090005aP000<H00`000d`0000200034@0A00@000A<003610000lH000080007
C036C<H0C003000;4@0004`0aTc604`02P05C0?600=<00000`000a400003009<0/H5C0T00d`00`1<
C00500034@0000<00T`0101<C4`<00=<00@0C4a<10000a40000200=<00@0C4a<3003C00404a<C0@0
00<A00000P03C00404a<C1H000A<4A5<5P0000T000G60000aP040007C@0001404@030005C@000<H0
10000lH0000600U=0`0011400005C@04aTe=C@/00Td20003aP1=00@000<A00000P000dd0aP02009=
2`0014d00<H20003aTd0008000<A01400`001Dg60036008000==0000200014d00<H20003aP1=00<0
00LA0000C@36008000C6001=2P0014d00<H20003aP1=00<000LA0000C@36008000C6001=5@00115=
4DdF00002P001LH0003600@000I<000A01420005C0000<H010000lH0000500a<00D04A4A0004C003
aTa<00E<2002C0030<H000E<00D04@0A0004C004aP36009<2@001D`00036008000?604`00P000a40
4@020003C036008000G60000C0080005C0000<H00P001<H004`200044@00C08000C600360`000d`0
00060005C0000<H00P001<H004`200044@00C08000C600360`000d`0000B00044D`AC1H0000:00]=
00DA00004@0:C@X01Dd20004aTe=C@<A0dd00lH00005C@T00Td0101=CLH300==00<A01400Td400;6
00A=04e=2`04C@03aTe=009=00<A01401dd00lI=000=0003CLI=00I=00<A01401dd00lI=000=00U=
00<A01401dd00lI=000F00044@004AH0000:0005aP000<H00P04C0054Da<C14014`20005aP000<H0
2@0014`004`2aP0@0<H0C15<4D`AC0360<H0C08000=<0000200;C0034D`A00]<2`001Dc604c60080
0T`01A5<C4`A009<00L0aTa<0<I<00`000E<aTa<aP03009<00<AC1400d`20005aTa<aT`030001Dc6
04c600<00T`00a5<4@03C08000G6C4c6C00F0004C000C1H000090005aP000<H02003C@P000G60000
aP070004C@00C@<01Td00`1=C@04C@<000A=001=20001Td0001=aP8014d300==0P02aP05C@0004d0
2007C@@01Dd300Q=2@000dd0C@03C@@00Td00`1=C@0400A=00<0C@002@001Td0CDd0C@@00Td00`1=
C@0400A=00<0C@004`001Dd0001=01H0000D009<0`02C1@000=<00000T`2aP@000=<00000P02aP9<
0P000d`0000;0003C<H0009<2P02C08000?6C0002@0014`004`2009<00C604a<1@02C0040<I<C080
00A<001<1`06C0;600<0C4`01@02C0030<K600I<2007C004aP1<C0D00T`00`36aP06C1<000=<0000
0P000d`0000C00004`000dd000050003C@0001@000A=aTe=0`000dd0C@03009=00?600003@02C@04
04d0aP`000G6001=0002C@/000A=001=0P000dd000070004C@00C@8000==00001`0014d0CDd20004
C@00C@T000A=001=0P02C@0304d000D000A=04e=0P0014d004d90004C@00C@800Td00`1=000@0003
C@0000<000==00004`0000d00lH00`1<C009009<0P02aPl000=<04`00T`2aP05C00004`00/H4C0d0
00A<001<0P000lH0000;0004aP00C08000=<0000200014`004`20003aP0000L000C6001<0P000d`0
000:0004C000C08000?600001`001<H004`20003C00000X000A<001<0P000lH000070004aP00C080
00=<00004P000d`000030003C00001<0000@0003C@0000/000==aP003`05C@<000G60000aP020003
C@1=009=2`001Dd0001=008000==00002`0014d004d30003C@0000H000A=001=0`000lH000070005
aP0004d00P000dd000080004C@00C@<000?600001`001LH0001=008000==0000200014d004d30003
aP0000L000G60000C@020003C@00014000==000010000dd0000B000040000lH0000;0003aP0000h0
00I<001<04`30005aP000<H00P001T`004`0C0h000A<04a<3@02C00304`0018000=<00001`000d`0
000F0003C00000L000=<00005P000d`000070003C00001H000?6C0001P000dc6000B00003`000lH0
000=0003aP00010000==04d00`001Dd0001=008000A=001=3`001Dd0C@1=00d000E=04d0C@0A009=
2@02CAH00Td9009=5P02C@T00Td@00I=00?60<H01`000lH0aP06C@`0000?0003aP0000d000?60000
40000d`00003009<00<0C4`01@000d`0000?0003C01<00d000=<04`04`000d`0C0070003C01<01D0
00A<001<1`0014`004`D0004C000C0L000A<001<4`000d`000020003aT`0008000=<aP000`02C0l0
000g0007C@1=04d0C@0E0004C@00C@d000A=001=4@0014d004d70004C@00CA@000A=001=1`0014d0
04dD0004C@00C@L000A=001=4P000dd000030003C@1=009=00<0C@001@000dd0000<0000=`0014`0
04`20003C00001H000=<00002`000d`0000E0003C00000D000=<000050001D`0001<00L000E<0000
C00B0005C00004`01`001D`0001<010000=<00001@02C00304a<00P000=<00002`0003L000==0000
0`000dd0002W0005C@0004d05P000>L000E<0000C00F0000j0000dd0C@0G0000o`030000o`030000
o`030000o`030000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.109417,
   0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110614, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.109417, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.74027, -0.110615, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.10942, 0.0329415, 0.0329415},
   {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277, -0.110614, 
  0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} -> {-7.1939,
   -0.109417, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 37.5625}} ->
   {-0.270008, -1.2634, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {69.375, 
  37.5625}} -> {-1.42777, -1.26687, 0.0330062, 0.0330062}, {{77.5, 109.375}, {
  69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415}, {{112.562, 
  144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26686, 0.0330062, 0.0330062},
   {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.88594, -1.2634, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277, -1.26687, 
  0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} -> {-7.1939,
   -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 2.5}} ->
   {-0.270008, -2.41738, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {34.375, 
  2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 109.375}, {
  34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{112.562, 
  144.375}, {34.375, 2.5}} -> {-3.74027, -2.42312, 0.0330062, 0.0330062}, {{
  147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277, -2.42311, 
  0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} -> {-7.1939,
   -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .8083 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0720399 0.952381 [
[ 0 0 0 0 ]
[ 1 .8083 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .8083 L
0 .8083 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.67271 .64761 L
s
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.75652 .60491 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.79734 .34714 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.73084 .28063 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.6489 .4973 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.66174 .41623 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.26053 .12782 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.16763 .14253 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.04914 .37507 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.09184 .45888 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.23672 .27813 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.19946 .35126 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.49191 .74954 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.58481 .76426 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.76936 .57971 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.75464 .48681 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.561 .61394 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.61904 .5559 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.46398 .08674 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.38017 .04404 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.14763 .16253 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.13292 .25543 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.35636 .19436 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.28323 .23162 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.62587 .4521 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.24466 .32823 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.56894 .56384 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.33333 .23956 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.83361 .4831 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.87631 .39929 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.75783 .16675 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.66493 .15204 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.726 .37549 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.68874 .30235 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.19462 .30485 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.12811 .37136 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.16894 .62913 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.25274 .67183 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.26371 .44045 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.27655 .52152 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.74726 .67183 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.83106 .62913 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.87189 .37136 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.80538 .30485 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.72345 .52152 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.73629 .44045 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.33507 .15204 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.24217 .16675 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.12369 .39929 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.16639 .4831 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.31126 .30235 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.274 .37549 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.6808 .35246 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.29958 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.70042 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.3192 .35246 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.86708 .25543 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.85237 .16253 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.61983 .04404 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.53602 .08674 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.71677 .23162 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.64364 .19436 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.24536 .48681 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.23064 .57971 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.41519 .76426 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.50809 .74954 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.38096 .5559 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.439 .61394 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.90816 .45888 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.95086 .37507 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.83237 .14253 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.73947 .12782 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.80054 .35126 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.76328 .27813 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.26916 .28063 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.20266 .34714 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.24348 .60491 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.32729 .64761 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.33826 .41623 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.3511 .4973 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.66667 .23956 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.43106 .56384 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.75534 .32823 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.37413 .4521 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.42546 .42036 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.5 .44458 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.57454 .42036 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{187, 151},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002k0000U`P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000;/0002k0000^`000;/0002k0000^`000;/0
002k0000A@03CBX00de60000A@03C2X00da60000A@03CBX00de60000A@03C2X00da60000A004CBX0
14e50000A004C2X014a50000A003CB`00de50000A003C2`00da50000A003C@h00dd:00==3P03CDD0
001400=<3@04C0X014`=00=<A@0004@00dd<00E=2P05C@`00de50000@`04C0/01D`<00E<2`04C4@0
001300A=2P05C@h01Dd:00A=A00004<00d`:00E<4005C0X00da40000@`03C@T01DdB00E=2@03CD@0
000_00=<4@03C0P01D`D00E<2003C1400d``0000;`03CA400dd700E=5P05C@L00ddA00==<00002l0
0d`A00=<1P05C1P01D`600=<4@03C300000N00==3P03CA0014d500E=6P05C@D014d@00==3P03CAl0
000N00=<3@04C10014`400E<7005C0@014`@00A<3@03C1l0000N00A=3004C@/00dd200==1005CAh0
1Dd400==0P03C@/014d<00A=7`0001h014`<00=<3003C0800d`300E<8005C0<00d`200=<3003C0`0
14`O00006P04C@0304e=009=2@05C@`00dd200==0P05CB801Dd200==0P03C@`01Dd900A=00<0CDd0
0TdK00006P09C0T01D`<00=<0P03C00304a<00=<9005C00404a<C0800d`<00E<2@09C1/0000J00Y=
2005C@/014d200Q=9P08C@8014d;00E=200:CA/0000L00Q<2005C0/014`00`1<C006C2P024`00`1<
C002C0/01D`800Q<7@0001h024d700A=2`03C@801ddZ00M=0P03C@/014d700Q=7`00020024`500A<
2`03C0801T`/00I<0P03C0/014`500Q<8@0002802Dd200E=2P03C@800lH2CBh00Td3aP800dd:00E=
0P09CB<0000R011<2@04C0800lH00d`0000^0004C<K6aP8014`9011<8`0002<03dd900A=00<0a/H0
0/Hb00C600<0CDd00Td900m=900002<01D`00`1<C008C0P00d`200C6<P04aP800d`800Y<00<0C4`0
0d`T00009004C@<024d800==00<0a/H00/Hd00C600@0CDe=2008C@<014dU00009@04C0<02D`600=<
00<0a/H00/Hd00C600@0C4a<1P09C0<014`V00009@04C@<024d5aP800dd4aSH01<H3C@<01LH7C@<0
14dV00009P04C00304a<00Q<1LH4C0C6=P04aP03C<K600S624`00`1<C002C2L0000U011=1LH4C@?6
>00>aPi=9P0001l05d`01036a/H5C0;6>0000lI<C008aQM<800001X05Dd300A=1005C@03aP0003P0
0Td3aP03C@00008014d301E=6`0001L044`00`1<C005C0@014`300I<>@03C00404a<C0<014`400M<
00<0C4`03T`H00005`0:C@L01dd400A=0`03C@0304e=03T00Td200==0`04C@@01dd700Y=600001L0
1D`=00I<1@04C00304a<009<00@0C4a<=`03C08014`00`1<C002C0D01T`=00E<600002T01Dd600A=
00<0CDd00Td2009==`02C@<014d00`1=C@02C@H01DdZ0000:P0014c6a/H700=<00@0C4a<0`03C3D0
0d`400=<00@0C4a<1`03aP03C00002T0000Z0004CLK6aP<00dd00`1=C@05C@@00Tde009=1@07C@04
04e=C@<00lH00dd0000Y0000:`03aP<00d`00`1<C005C0@00d`c00=<1@07C00404a<C0<00lH/0000
:`03aP<014d00`1=C@04C@D00Tdc009=1P06C@0304e=009=0`03aR`0000[00?60`04C00304a<00A<
1@03C3400d`600I<00<0C4`00T`300?6;00002<00dd500C60`04C@0304g600;61`02CC400Td800?6
00==04d00dd300C61@03CB@0000S00=<1@04aP<014`00`1<aP02aPL00d`_00=<2003aP03C01<00=<
0`04aPD00d`T00008`04C@D00lH400A=00@0a/K62002CBl00Td900?600<0CDd00Td400?61@04CB@0
000S00A<1@03aP@014`00`36aP02aPL00d`F008A5@03C0P01<H00`1<C002C0@00lH500A<900002@0
14d300C61@04C@C62002CAH00Q4E009=2@04aPA=1@04aP<014dU00009004C0800/H3C0D014`01036
a/H800=<50044A<00d`900?600<0C4`00T`400=<0lH200A<9@0002D014d3aPE=1004C@?62@02CA<0
1Q4B009=2P03aPA=0`05C@G60ddV00009@04C0C600<0C4`00d`200A<0lH900=<4P064A400d`:00?6
14`00`1<C003C0801lH00d`0000T00009006C@;61005C@0304e=009=0lH9009=4@084A000Td:00C6
24d500O600==00008`0002402D`800Q<0lH900=<3`034@04014A00<A3P03C0X01<H6C0T01/H4C240
000J019=2009C@X00Td>00<A0P024@800Q4>009=2P03C@;614d900A=1<H;CAX0000C015<0/H8C0L0
0/H8C0P00d`=008A0`024@800a4<00=<2009C0;61`07C0?64T`C0000300JC@8024d300C62Td7009=
30034@<00Q4300<A2`02C@L02Td5aP<024d201]=300000P054`400E<0`0:C0K62d`500=<2P034@@0
0Q44008A2P03C0D02d`7aPY<0`05C0@054`90000200=C@0304e=00I=00<0CDd00dd500]=0lH00`1=
C@0;C@@00Td:008A1@024@@00a49009=100>C@030<K600?62Dd500E=00<0CDd01Td200a=2@0000P0
1T`:00]<00<0C4`03d`400i<0P03C0P00a45008A1@024@P00d`200Y<00<0C4`00T`400?63T`00`1<
C009C0/01D`900006P0MC@8014d200Y=00<0CDd01`034@H00Q4500<A1`02C@0304e=00Q=0`04C@80
7DdK00006@0PC00304a<009<0`0<C0H00Q47008A1P034@D034`400A<00<0C4`07T`J00005P0@C@D0
1dd00`1=C@09C@D02Td500<A1`024@L00Q4500Y=1P0;C@0304e=00E=1@0@CAL0000F019<1005C0@0
2T`600A<00<0C4`00d`200<A20024@L00a4300A<00<0C4`00T`700Y<1005C0@04T`G00005P08C@@0
24d00`1=C@03C@L024d800A=00<0CDd00Td34@T00Q4800<A14d00`1=C@02C@T024d700E=00<0CDd0
1Td400Q=5`0001P01D`700e<2004C0C61`08C08A00=<00001`024@T00Q48C0P01<H4C0P03D`700E<
6@0001L01Dd:00]=2P02C@G62005C@<A0dd7008A1`02C@<A1Dd900G60Td:00]=2P05CAP0000F00E<
3@0:C0/01/H9009<0a46C0D00Q4500E<0a42C0X01/H;00Y<3@05C1L0000E00E=3@0;C@d01LH:008A
2dd00`0A4@0;C@8A2`05aPd02dd=00E=5P0001@01D`=00E<00<0C4`00T`3aPd01LH:00=<00<0C4`0
1d`24@Q<00@0C4a<2`05aPd00lH4C00304a<00=<3@05C1D0000C00E=3@05C@@00Td3aPh01LH900e=
0Q4<C@X01LH>00?60Td400E=3@05CA@0000B00E<3@05C0L01<H>00G600<0C4`03D`200=<0Q43C003
04a<00e<0P05aPh01<H700E<3@05C1<0000A00E=3@05C@P01LH>0003aTe=00Y=0P0:C@8A2Dd200a=
0/H>00G62005C@d01DdB00004005C0d01D`:00G63@000lI<C003C0<03T`600e<0`05C0;63@05aPX0
1D`=00E<4@00010014d=00E=3005aP`01<H<C@0404e=C@/00dd00`1=C@0<C@?63005aP`01Dd=00A=
4@0001000d`=00E<3P05aPL00d`4aPM<2003C0T00d`800i<2005aPh01D`=00=<4@0001l01Dd@00G6
2Dd4aP03C@0000d00dd700==400=C@030<K600?64005CB00000N00E<4P000lI<C008C0800lHB00=<
1@03C1<00lH00`1<C008C0;64P05C1l0000N00A=2P04C@D000?6CDd00Td700C64`03C@<00ddD00C6
1P04C@;61@04C@X014dO00007P03C0/01T`300C62004aQ@00d`0101<C4`E00C62004aP<01T`;00=<
7`0002`024d4aPP01<HF00E=5`04aPP01<H8CBd0000^00Q<0/H70003C<K600;65`03C1P01<H00d`0
000500C61T`_0000<008C@H00Td3aQL01DdH00?60Td60003CLK600;60dda0000<P08C0<01T`F00=<
00@0C4a<5`06C0<00d`4aP03C0000340000b00;63ddE00==0`03CAH03Dd4aS<0000a0003C<K600;6
3D`D00=<1@03C1D03D`4aP03C0000300000`009=0lH300Y=5003C@L00ddE00Y=0`03aP9=<@0002l0
1T`400U<4`03C0T00d`D00U<1006C300000^00M=0`0;CA400dd;00==4P0;C@<01dd_0000;@08C080
1D`00`1<C006C0h00d`=00=<3`08C00304a<00=<0P08C2h0000/00Q=0P05C@<02Dd;00==3`03C@`0
2Dd300E=0P08CBd0000[00E<00D0C4a<0005C0@01d`8aP@00d`A00=<1@08aPM<1005C00504a<C000
1D`/0000:P05C@8024d200Y=2lH3CA<00dd<aPY=0P08C@801Dd[0000:@05C0<054`:aP=<5@03C0_6
54`300E<:P0002P074d700C60Td00lH0000D009=1LH701a=:@0002L06T`>00?65P03aPh06T`X0000
9P0@C@L014d>00?65P03aPh014d7011=9`0002D03d`900=<3`04aQ@01<H?00=<2@0?C2H0000T00E=
1@05C@X00dd?00C65004aPl00dd:00E=1@05CBD0000S00E<1@06C0X00d`@00?65003aQ000d`:00I<
1@05C2@0000R00E=1@07C@X00dd@00?65003aQ000dd:00M=1@05CB<0000Q00E<1P07C0T014`@00?6
5003aQ0014`900M<1P05C280000P00E=1`07C@T014d@00?65003aQ0014d900M=1`05CB40000O00E<
2`04C0T00d`A00?600=<0000400014c6a/HA00=<2@04C0/01D`P00007P05C@`00dd:00==4@04CA80
14dA00==2P03C@`01DdO00007P04C0d00d`:00=<4006C1001T`@00=<2P03C0d014`O00007P03C@h0
0dd900A=4006CA001Td@00A=2@03C@h00ddO0000;`03C0T014`@00M<3P07C10014`900=<<00002l0
0dd900==4@07C@h01ddA00==2@03CC00000^00A<2@03C1400d`00`1<C002C0`014`0101<C4`A00=<
2@04C2l0000^00A=2@03CA400dd00`1=C@02C@`014d0101=CDdA00==2@04CBl0000^00=<7P03C080
14`:00A<0P03C1h00d`_0000;P03CAd014d200A=2P04C@8014dM00==;`0002h00d`M00A<0`04C0P0
14`300A<7@03C2l0000^00==7@03C@@014d800A=1003CAd00dd_0000CP03C0D014`600A<1@03C4l0
001>00==1@04C@H014d500==C`0004h00d`600A<1004C0H00da?0000CP03C@H014d400A=1P03CDl0
001=00A<1`04C08014`700A<CP0004d014d700A=0P04C@L014e>0000C@03C0T024`900=<CP0004d0
0dd900Q=2@03CDh0001=00=<2P06C0X00da>0000C@03C@X01Td:00==CP0004d00d`;00A<2`03C4h0
001<00A=2`04C@/014e=0000C004C0X01T`:00A<C@0004`00dd;00I=2`03CDd0001<00=<2`06C0/0
0da=0000C003CA`00de=0000C003C1`00da=0000^`000;/0002k0000^`000;/0002k0000^`000001
\
\>"],
  ImageRangeCache->{{{0, 186}, {150, 0}} -> {-0.0262085, 0.0756376, 
  0.00565816, 0.00565816}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0720399 0.952381 [
[ 0 0 0 0 ]
[ 1 .8083 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8083 L
0 .8083 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.67271 .64761 L
s
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.75652 .60491 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.79734 .34714 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.73084 .28063 L
s
P
p
0 .4 1 r
.016 w
.62587 .4521 m
.6489 .4973 L
s
P
p
0 .4 1 r
.016 w
.62587 .4521 m
.66174 .41623 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.26053 .12782 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.16763 .14253 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.04914 .37507 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.09184 .45888 L
s
P
p
0 .4 1 r
.016 w
.24466 .32823 m
.23672 .27813 L
s
P
p
0 .4 1 r
.016 w
.24466 .32823 m
.19946 .35126 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.49191 .74954 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.58481 .76426 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.76936 .57971 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.75464 .48681 L
s
P
p
0 .4 1 r
.016 w
.56894 .56384 m
.561 .61394 L
s
P
p
0 .4 1 r
.016 w
.56894 .56384 m
.61904 .5559 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.46398 .08674 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.38017 .04404 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.14763 .16253 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.13292 .25543 L
s
P
p
0 .4 1 r
.016 w
.33333 .23956 m
.35636 .19436 L
s
P
p
0 .4 1 r
.016 w
.33333 .23956 m
.28323 .23162 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.62587 .4521 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.24466 .32823 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.56894 .56384 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.33333 .23956 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.83361 .4831 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.87631 .39929 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.75783 .16675 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.66493 .15204 L
s
P
p
0 .4 1 r
.016 w
.6808 .35246 m
.726 .37549 L
s
P
p
0 .4 1 r
.016 w
.6808 .35246 m
.68874 .30235 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.19462 .30485 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.12811 .37136 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.16894 .62913 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.25274 .67183 L
s
P
p
0 .4 1 r
.016 w
.29958 .47632 m
.26371 .44045 L
s
P
p
0 .4 1 r
.016 w
.29958 .47632 m
.27655 .52152 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.74726 .67183 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.83106 .62913 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.87189 .37136 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.80538 .30485 L
s
P
p
0 .4 1 r
.016 w
.70042 .47632 m
.72345 .52152 L
s
P
p
0 .4 1 r
.016 w
.70042 .47632 m
.73629 .44045 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.33507 .15204 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.24217 .16675 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.12369 .39929 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.16639 .4831 L
s
P
p
0 .4 1 r
.016 w
.3192 .35246 m
.31126 .30235 L
s
P
p
0 .4 1 r
.016 w
.3192 .35246 m
.274 .37549 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.6808 .35246 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.29958 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.70042 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.3192 .35246 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.86708 .25543 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.85237 .16253 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.61983 .04404 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.53602 .08674 L
s
P
p
0 .4 1 r
.016 w
.66667 .23956 m
.71677 .23162 L
s
P
p
0 .4 1 r
.016 w
.66667 .23956 m
.64364 .19436 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.24536 .48681 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.23064 .57971 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.41519 .76426 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.50809 .74954 L
s
P
p
0 .4 1 r
.016 w
.43106 .56384 m
.38096 .5559 L
s
P
p
0 .4 1 r
.016 w
.43106 .56384 m
.439 .61394 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.90816 .45888 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.95086 .37507 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.83237 .14253 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.73947 .12782 L
s
P
p
0 .4 1 r
.016 w
.75534 .32823 m
.80054 .35126 L
s
P
p
0 .4 1 r
.016 w
.75534 .32823 m
.76328 .27813 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.26916 .28063 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.20266 .34714 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.24348 .60491 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.32729 .64761 L
s
P
p
0 .4 1 r
.016 w
.37413 .4521 m
.33826 .41623 L
s
P
p
0 .4 1 r
.016 w
.37413 .4521 m
.3511 .4973 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.66667 .23956 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.43106 .56384 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.75534 .32823 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.37413 .4521 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.42546 .42036 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.5 .44458 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.57454 .42036 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0720399 0.952381 [
[ 0 0 0 0 ]
[ 1 .8083 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8083 L
0 .8083 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.67271 .64761 L
s
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.75652 .60491 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.79734 .34714 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.73084 .28063 L
s
P
p
.2 0 1 r
.018 w
.62587 .4521 m
.6489 .4973 L
s
P
p
.2 0 1 r
.018 w
.62587 .4521 m
.66174 .41623 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.26053 .12782 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.16763 .14253 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.04914 .37507 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.09184 .45888 L
s
P
p
.2 0 1 r
.018 w
.24466 .32823 m
.23672 .27813 L
s
P
p
.2 0 1 r
.018 w
.24466 .32823 m
.19946 .35126 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.49191 .74954 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.58481 .76426 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.76936 .57971 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.75464 .48681 L
s
P
p
.2 0 1 r
.018 w
.56894 .56384 m
.561 .61394 L
s
P
p
.2 0 1 r
.018 w
.56894 .56384 m
.61904 .5559 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.46398 .08674 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.38017 .04404 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.14763 .16253 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.13292 .25543 L
s
P
p
.2 0 1 r
.018 w
.33333 .23956 m
.35636 .19436 L
s
P
p
.2 0 1 r
.018 w
.33333 .23956 m
.28323 .23162 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.62587 .4521 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.24466 .32823 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.56894 .56384 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.33333 .23956 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.83361 .4831 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.87631 .39929 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.75783 .16675 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.66493 .15204 L
s
P
p
.2 0 1 r
.018 w
.6808 .35246 m
.726 .37549 L
s
P
p
.2 0 1 r
.018 w
.6808 .35246 m
.68874 .30235 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.19462 .30485 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.12811 .37136 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.16894 .62913 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.25274 .67183 L
s
P
p
.2 0 1 r
.018 w
.29958 .47632 m
.26371 .44045 L
s
P
p
.2 0 1 r
.018 w
.29958 .47632 m
.27655 .52152 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.74726 .67183 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.83106 .62913 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.87189 .37136 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.80538 .30485 L
s
P
p
.2 0 1 r
.018 w
.70042 .47632 m
.72345 .52152 L
s
P
p
.2 0 1 r
.018 w
.70042 .47632 m
.73629 .44045 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.33507 .15204 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.24217 .16675 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.12369 .39929 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.16639 .4831 L
s
P
p
.2 0 1 r
.018 w
.3192 .35246 m
.31126 .30235 L
s
P
p
.2 0 1 r
.018 w
.3192 .35246 m
.274 .37549 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.6808 .35246 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.29958 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.70042 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.3192 .35246 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.86708 .25543 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.85237 .16253 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.61983 .04404 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.53602 .08674 L
s
P
p
.2 0 1 r
.018 w
.66667 .23956 m
.71677 .23162 L
s
P
p
.2 0 1 r
.018 w
.66667 .23956 m
.64364 .19436 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.24536 .48681 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.23064 .57971 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.41519 .76426 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.50809 .74954 L
s
P
p
.2 0 1 r
.018 w
.43106 .56384 m
.38096 .5559 L
s
P
p
.2 0 1 r
.018 w
.43106 .56384 m
.439 .61394 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.90816 .45888 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.95086 .37507 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.83237 .14253 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.73947 .12782 L
s
P
p
.2 0 1 r
.018 w
.75534 .32823 m
.80054 .35126 L
s
P
p
.2 0 1 r
.018 w
.75534 .32823 m
.76328 .27813 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.26916 .28063 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.20266 .34714 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.24348 .60491 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.32729 .64761 L
s
P
p
.2 0 1 r
.018 w
.37413 .4521 m
.33826 .41623 L
s
P
p
.2 0 1 r
.018 w
.37413 .4521 m
.3511 .4973 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.66667 .23956 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.43106 .56384 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.75534 .32823 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.37413 .4521 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.42546 .42036 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.5 .44458 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.57454 .42036 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0720399 0.952381 [
[ 0 0 0 0 ]
[ 1 .8083 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8083 L
0 .8083 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.6251 .64761 L
s
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.718 .6329 L
s
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.7845 .56639 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.81206 .39242 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.76936 .30862 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.68555 .26592 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.6489 .4973 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.66174 .41623 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.30581 .14253 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.21291 .12782 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.12911 .17052 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.04914 .32746 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.06386 .42036 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.13036 .48686 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.23672 .27813 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.19946 .35126 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.45339 .72156 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.5372 .76426 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.63009 .74954 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.75464 .625 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.76936 .5321 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.72666 .44829 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.561 .61394 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.61904 .5559 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.49196 .12527 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.42546 .05876 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.33256 .04404 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.17562 .12401 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.13292 .20781 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.14763 .30071 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.35636 .19436 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.28323 .23162 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.62587 .4521 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.24466 .32823 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.56894 .56384 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.33333 .23956 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.79509 .51109 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.8616 .44458 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.87631 .35168 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.79635 .19474 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.71254 .15204 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.61964 .16675 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.726 .37549 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.68874 .30235 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.2399 .29014 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.1561 .33284 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.1134 .41664 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.14095 .59061 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.20746 .65712 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.30036 .67183 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.26371 .44045 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.27655 .52152 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.69964 .67183 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.79254 .65712 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.85905 .59061 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.8866 .41664 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.8439 .33284 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.7601 .29014 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.72345 .52152 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.73629 .44045 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.38036 .16675 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.28746 .15204 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.20365 .19474 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.12369 .35168 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.1384 .44458 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.20491 .51109 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.31126 .30235 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.274 .37549 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.6808 .35246 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.29958 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.70042 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.3192 .35246 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.85237 .30071 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.86708 .20781 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.82438 .12401 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.66744 .04404 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.57454 .05876 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.50804 .12527 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.71677 .23162 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.64364 .19436 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.27334 .44829 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.23064 .5321 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.24536 .625 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.36991 .74954 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.4628 .76426 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.54661 .72156 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.38096 .5559 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.439 .61394 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.86964 .48686 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.93614 .42036 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.95086 .32746 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.87089 .17052 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.78709 .12782 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.69419 .14253 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.80054 .35126 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.76328 .27813 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.31445 .26592 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.23064 .30862 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.18794 .39242 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.2155 .56639 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.282 .6329 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.3749 .64761 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.33826 .41623 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.3511 .4973 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.66667 .23956 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.43106 .56384 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.75534 .32823 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.37413 .4521 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.42546 .42036 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.5 .44458 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.57454 .42036 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0755605 0.952381 [
[ 0 0 0 0 ]
[ 1 .80126 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .80126 L
0 .80126 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.64829 .4971 m
.64829 .64867 L
s
P
p
.2 0 1 r
.02 w
.64829 .4971 m
.77091 .58619 L
s
P
p
.2 0 1 r
.02 w
.66108 .41637 m
.80522 .36953 L
s
P
p
.2 0 1 r
.02 w
.66108 .41637 m
.70791 .27222 L
s
P
p
0 .4 1 r
.018 w
.62536 .45209 m
.64829 .4971 L
s
P
p
0 .4 1 r
.018 w
.62536 .45209 m
.66108 .41637 L
s
P
p
.2 0 1 r
.02 w
.2378 .27884 m
.28464 .13469 L
s
P
p
.2 0 1 r
.02 w
.2378 .27884 m
.14872 .15622 L
s
P
p
.2 0 1 r
.02 w
.20069 .35167 m
.04913 .35167 L
s
P
p
.2 0 1 r
.02 w
.20069 .35167 m
.11161 .47429 L
s
P
p
0 .4 1 r
.018 w
.24571 .32874 m
.2378 .27884 L
s
P
p
0 .4 1 r
.018 w
.24571 .32874 m
.20069 .35167 L
s
P
p
.2 0 1 r
.02 w
.56075 .61327 m
.47167 .73588 L
s
P
p
.2 0 1 r
.02 w
.56075 .61327 m
.60759 .75741 L
s
P
p
.2 0 1 r
.02 w
.61855 .55547 m
.7627 .6023 L
s
P
p
.2 0 1 r
.02 w
.61855 .55547 m
.74117 .46638 L
s
P
p
0 .4 1 r
.018 w
.56866 .56337 m
.56075 .61327 L
s
P
p
0 .4 1 r
.018 w
.56866 .56337 m
.61855 .55547 L
s
P
p
.2 0 1 r
.02 w
.35696 .19541 m
.47957 .10632 L
s
P
p
.2 0 1 r
.02 w
.35696 .19541 m
.35696 .04385 L
s
P
p
.2 0 1 r
.02 w
.28412 .23252 m
.16151 .14343 L
s
P
p
.2 0 1 r
.02 w
.28412 .23252 m
.13998 .27935 L
s
P
p
0 .4 1 r
.018 w
.33402 .24042 m
.35696 .19541 L
s
P
p
0 .4 1 r
.018 w
.33402 .24042 m
.28412 .23252 L
s
P
p
.2 0 1 r
.016 w
.42576 .42048 m
.62536 .45209 L
s
P
p
.2 0 1 r
.016 w
.42576 .42048 m
.24571 .32874 L
s
P
p
.2 0 1 r
.016 w
.42576 .42048 m
.56866 .56337 L
s
P
p
.2 0 1 r
.016 w
.42576 .42048 m
.33402 .24042 L
s
P
p
.2 0 1 r
.02 w
.72507 .37579 m
.81415 .49841 L
s
P
p
.2 0 1 r
.02 w
.72507 .37579 m
.87663 .37579 L
s
P
p
.2 0 1 r
.02 w
.68796 .30296 m
.77704 .18034 L
s
P
p
.2 0 1 r
.02 w
.68796 .30296 m
.64112 .15882 L
s
P
p
0 .4 1 r
.018 w
.68006 .35286 m
.72507 .37579 L
s
P
p
0 .4 1 r
.018 w
.68006 .35286 m
.68796 .30296 L
s
P
p
.2 0 1 r
.02 w
.26468 .44049 m
.21785 .29635 L
s
P
p
.2 0 1 r
.02 w
.26468 .44049 m
.12054 .39365 L
s
P
p
.2 0 1 r
.02 w
.27747 .52123 m
.15486 .61031 L
s
P
p
.2 0 1 r
.02 w
.27747 .52123 m
.27747 .67279 L
s
P
p
0 .4 1 r
.018 w
.30041 .47621 m
.26468 .44049 L
s
P
p
0 .4 1 r
.018 w
.30041 .47621 m
.27747 .52123 L
s
P
p
.2 0 1 r
.02 w
.72253 .52123 m
.72253 .67279 L
s
P
p
.2 0 1 r
.02 w
.72253 .52123 m
.84514 .61031 L
s
P
p
.2 0 1 r
.02 w
.73532 .44049 m
.87946 .39365 L
s
P
p
.2 0 1 r
.02 w
.73532 .44049 m
.78215 .29635 L
s
P
p
0 .4 1 r
.018 w
.69959 .47621 m
.72253 .52123 L
s
P
p
0 .4 1 r
.018 w
.69959 .47621 m
.73532 .44049 L
s
P
p
.2 0 1 r
.02 w
.31204 .30296 m
.35888 .15882 L
s
P
p
.2 0 1 r
.02 w
.31204 .30296 m
.22296 .18034 L
s
P
p
.2 0 1 r
.02 w
.27493 .37579 m
.12337 .37579 L
s
P
p
.2 0 1 r
.02 w
.27493 .37579 m
.18585 .49841 L
s
P
p
0 .4 1 r
.018 w
.31994 .35286 m
.31204 .30296 L
s
P
p
0 .4 1 r
.018 w
.31994 .35286 m
.27493 .37579 L
s
P
p
.2 0 1 r
.016 w
.5 .4446 m
.68006 .35286 L
s
P
p
.2 0 1 r
.016 w
.5 .4446 m
.30041 .47621 L
s
P
p
.2 0 1 r
.016 w
.5 .4446 m
.69959 .47621 L
s
P
p
.2 0 1 r
.016 w
.5 .4446 m
.31994 .35286 L
s
P
p
.2 0 1 r
.02 w
.71588 .23252 m
.86002 .27935 L
s
P
p
.2 0 1 r
.02 w
.71588 .23252 m
.83849 .14343 L
s
P
p
.2 0 1 r
.02 w
.64304 .19541 m
.64304 .04385 L
s
P
p
.2 0 1 r
.02 w
.64304 .19541 m
.52043 .10632 L
s
P
p
0 .4 1 r
.018 w
.66598 .24042 m
.71588 .23252 L
s
P
p
0 .4 1 r
.018 w
.66598 .24042 m
.64304 .19541 L
s
P
p
.2 0 1 r
.02 w
.38145 .55547 m
.25883 .46638 L
s
P
p
.2 0 1 r
.02 w
.38145 .55547 m
.2373 .6023 L
s
P
p
.2 0 1 r
.02 w
.43925 .61327 m
.39241 .75741 L
s
P
p
.2 0 1 r
.02 w
.43925 .61327 m
.52833 .73588 L
s
P
p
0 .4 1 r
.018 w
.43134 .56337 m
.38145 .55547 L
s
P
p
0 .4 1 r
.018 w
.43134 .56337 m
.43925 .61327 L
s
P
p
.2 0 1 r
.02 w
.79931 .35167 m
.88839 .47429 L
s
P
p
.2 0 1 r
.02 w
.79931 .35167 m
.95087 .35167 L
s
P
p
.2 0 1 r
.02 w
.7622 .27884 m
.85128 .15622 L
s
P
p
.2 0 1 r
.02 w
.7622 .27884 m
.71536 .13469 L
s
P
p
0 .4 1 r
.018 w
.75429 .32874 m
.79931 .35167 L
s
P
p
0 .4 1 r
.018 w
.75429 .32874 m
.7622 .27884 L
s
P
p
.2 0 1 r
.02 w
.33892 .41637 m
.29209 .27222 L
s
P
p
.2 0 1 r
.02 w
.33892 .41637 m
.19478 .36953 L
s
P
p
.2 0 1 r
.02 w
.35171 .4971 m
.22909 .58619 L
s
P
p
.2 0 1 r
.02 w
.35171 .4971 m
.35171 .64867 L
s
P
p
0 .4 1 r
.018 w
.37464 .45209 m
.33892 .41637 L
s
P
p
0 .4 1 r
.018 w
.37464 .45209 m
.35171 .4971 L
s
P
p
.2 0 1 r
.016 w
.57424 .42048 m
.66598 .24042 L
s
P
p
.2 0 1 r
.016 w
.57424 .42048 m
.43134 .56337 L
s
P
p
.2 0 1 r
.016 w
.57424 .42048 m
.75429 .32874 L
s
P
p
.2 0 1 r
.016 w
.57424 .42048 m
.37464 .45209 L
s
P
p
1 .6 0 r
.016 w
.5 .3183 m
.42576 .42048 L
s
P
p
1 .6 0 r
.016 w
.5 .3183 m
.5 .4446 L
s
P
p
1 .6 0 r
.016 w
.5 .3183 m
.57424 .42048 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0669943 0.952381 [
[ 0 0 0 0 ]
[ 1 .81839 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .81839 L
0 .81839 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.64111 .49747 m
.66743 .66365 L
s
P
p
.2 0 1 r
.02 w
.64111 .49747 m
.76009 .61644 L
s
P
p
.2 0 1 r
.02 w
.65328 .42064 m
.8032 .34425 L
s
P
p
.2 0 1 r
.02 w
.65328 .42064 m
.72966 .27072 L
s
P
p
0 .4 1 r
.018 w
.61928 .45464 m
.64111 .49747 L
s
P
p
0 .4 1 r
.018 w
.61928 .45464 m
.65328 .42064 L
s
P
p
.2 0 1 r
.02 w
.2505 .28977 m
.27682 .12359 L
s
P
p
.2 0 1 r
.02 w
.2505 .28977 m
.17412 .13985 L
s
P
p
.2 0 1 r
.02 w
.21519 .35908 m
.049 .3854 L
s
P
p
.2 0 1 r
.02 w
.21519 .35908 m
.09621 .47805 L
s
P
p
0 .4 1 r
.018 w
.25802 .33725 m
.2505 .28977 L
s
P
p
0 .4 1 r
.018 w
.25802 .33725 m
.21519 .35908 L
s
P
p
.2 0 1 r
.02 w
.55781 .60801 m
.48142 .75793 L
s
P
p
.2 0 1 r
.02 w
.55781 .60801 m
.58413 .77419 L
s
P
p
.2 0 1 r
.02 w
.61281 .55301 m
.779 .57933 L
s
P
p
.2 0 1 r
.02 w
.61281 .55301 m
.76273 .47662 L
s
P
p
0 .4 1 r
.018 w
.56533 .56053 m
.55781 .60801 L
s
P
p
0 .4 1 r
.018 w
.56533 .56053 m
.61281 .55301 L
s
P
p
.2 0 1 r
.02 w
.36388 .21038 m
.48286 .09141 L
s
P
p
.2 0 1 r
.02 w
.36388 .21038 m
.3902 .0442 L
s
P
p
.2 0 1 r
.02 w
.29458 .2457 m
.14466 .16931 L
s
P
p
.2 0 1 r
.02 w
.29458 .2457 m
.12839 .27202 L
s
P
p
0 .4 1 r
.018 w
.34206 .25322 m
.36388 .21038 L
s
P
p
0 .4 1 r
.018 w
.34206 .25322 m
.29458 .2457 L
s
P
p
.2 0 1 r
.016 w
.42936 .42455 m
.61928 .45464 L
s
P
p
.2 0 1 r
.016 w
.42936 .42455 m
.25802 .33725 L
s
P
p
.2 0 1 r
.016 w
.42936 .42455 m
.56533 .56053 L
s
P
p
.2 0 1 r
.016 w
.42936 .42455 m
.34206 .25322 L
s
P
p
.2 0 1 r
.02 w
.71417 .38203 m
.83314 .50101 L
s
P
p
.2 0 1 r
.02 w
.71417 .38203 m
.88035 .40835 L
s
P
p
.2 0 1 r
.02 w
.67886 .31273 m
.75524 .16281 L
s
P
p
.2 0 1 r
.02 w
.67886 .31273 m
.65253 .14654 L
s
P
p
0 .4 1 r
.018 w
.67134 .36021 m
.71417 .38203 L
s
P
p
0 .4 1 r
.018 w
.67134 .36021 m
.67886 .31273 L
s
P
p
.2 0 1 r
.02 w
.27608 .4436 m
.19969 .29368 L
s
P
p
.2 0 1 r
.02 w
.27608 .4436 m
.12616 .36721 L
s
P
p
.2 0 1 r
.02 w
.28825 .52042 m
.16927 .6394 L
s
P
p
.2 0 1 r
.02 w
.28825 .52042 m
.26193 .68661 L
s
P
p
0 .4 1 r
.018 w
.31007 .47759 m
.27608 .4436 L
s
P
p
0 .4 1 r
.018 w
.31007 .47759 m
.28825 .52042 L
s
P
p
.2 0 1 r
.02 w
.71175 .52042 m
.73807 .68661 L
s
P
p
.2 0 1 r
.02 w
.71175 .52042 m
.83073 .6394 L
s
P
p
.2 0 1 r
.02 w
.72392 .4436 m
.87384 .36721 L
s
P
p
.2 0 1 r
.02 w
.72392 .4436 m
.80031 .29368 L
s
P
p
0 .4 1 r
.018 w
.68993 .47759 m
.71175 .52042 L
s
P
p
0 .4 1 r
.018 w
.68993 .47759 m
.72392 .4436 L
s
P
p
.2 0 1 r
.02 w
.32114 .31273 m
.34747 .14654 L
s
P
p
.2 0 1 r
.02 w
.32114 .31273 m
.24476 .16281 L
s
P
p
.2 0 1 r
.02 w
.28583 .38203 m
.11965 .40835 L
s
P
p
.2 0 1 r
.02 w
.28583 .38203 m
.16686 .50101 L
s
P
p
0 .4 1 r
.018 w
.32866 .36021 m
.32114 .31273 L
s
P
p
0 .4 1 r
.018 w
.32866 .36021 m
.28583 .38203 L
s
P
p
.2 0 1 r
.016 w
.5 .44751 m
.67134 .36021 L
s
P
p
.2 0 1 r
.016 w
.5 .44751 m
.31007 .47759 L
s
P
p
.2 0 1 r
.016 w
.5 .44751 m
.68993 .47759 L
s
P
p
.2 0 1 r
.016 w
.5 .44751 m
.32866 .36021 L
s
P
p
.2 0 1 r
.02 w
.70542 .2457 m
.87161 .27202 L
s
P
p
.2 0 1 r
.02 w
.70542 .2457 m
.85534 .16931 L
s
P
p
.2 0 1 r
.02 w
.63612 .21038 m
.6098 .0442 L
s
P
p
.2 0 1 r
.02 w
.63612 .21038 m
.51714 .09141 L
s
P
p
0 .4 1 r
.018 w
.65794 .25322 m
.70542 .2457 L
s
P
p
0 .4 1 r
.018 w
.65794 .25322 m
.63612 .21038 L
s
P
p
.2 0 1 r
.02 w
.38719 .55301 m
.23727 .47662 L
s
P
p
.2 0 1 r
.02 w
.38719 .55301 m
.221 .57933 L
s
P
p
.2 0 1 r
.02 w
.44219 .60801 m
.41587 .77419 L
s
P
p
.2 0 1 r
.02 w
.44219 .60801 m
.51858 .75793 L
s
P
p
0 .4 1 r
.018 w
.43467 .56053 m
.38719 .55301 L
s
P
p
0 .4 1 r
.018 w
.43467 .56053 m
.44219 .60801 L
s
P
p
.2 0 1 r
.02 w
.78481 .35908 m
.90379 .47805 L
s
P
p
.2 0 1 r
.02 w
.78481 .35908 m
.951 .3854 L
s
P
p
.2 0 1 r
.02 w
.7495 .28977 m
.82588 .13985 L
s
P
p
.2 0 1 r
.02 w
.7495 .28977 m
.72318 .12359 L
s
P
p
0 .4 1 r
.018 w
.74198 .33725 m
.78481 .35908 L
s
P
p
0 .4 1 r
.018 w
.74198 .33725 m
.7495 .28977 L
s
P
p
.2 0 1 r
.02 w
.34672 .42064 m
.27034 .27072 L
s
P
p
.2 0 1 r
.02 w
.34672 .42064 m
.1968 .34425 L
s
P
p
.2 0 1 r
.02 w
.35889 .49747 m
.23991 .61644 L
s
P
p
.2 0 1 r
.02 w
.35889 .49747 m
.33257 .66365 L
s
P
p
0 .4 1 r
.018 w
.38072 .45464 m
.34672 .42064 L
s
P
p
0 .4 1 r
.018 w
.38072 .45464 m
.35889 .49747 L
s
P
p
.2 0 1 r
.016 w
.57064 .42455 m
.65794 .25322 L
s
P
p
.2 0 1 r
.016 w
.57064 .42455 m
.43467 .56053 L
s
P
p
.2 0 1 r
.016 w
.57064 .42455 m
.74198 .33725 L
s
P
p
.2 0 1 r
.016 w
.57064 .42455 m
.38072 .45464 L
s
P
p
1 .6 0 r
.016 w
.5 .32732 m
.42936 .42455 L
s
P
p
1 .6 0 r
.016 w
.5 .32732 m
.5 .44751 L
s
P
p
1 .6 0 r
.016 w
.5 .32732 m
.57064 .42455 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0720399 0.952381 [
[ 0 0 0 0 ]
[ 1 .8083 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8083 L
0 .8083 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.018 w
.6489 .4973 m
.67271 .64761 L
s
P
p
.2 0 1 r
.018 w
.6489 .4973 m
.75652 .60491 L
s
P
p
.2 0 1 r
.018 w
.66174 .41623 m
.79734 .34714 L
s
P
p
.2 0 1 r
.018 w
.66174 .41623 m
.73084 .28063 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.6489 .4973 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.66174 .41623 L
s
P
p
.2 0 1 r
.018 w
.23672 .27813 m
.26053 .12782 L
s
P
p
.2 0 1 r
.018 w
.23672 .27813 m
.16763 .14253 L
s
P
p
.2 0 1 r
.018 w
.19946 .35126 m
.04914 .37507 L
s
P
p
.2 0 1 r
.018 w
.19946 .35126 m
.09184 .45888 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.23672 .27813 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.19946 .35126 L
s
P
p
.2 0 1 r
.018 w
.561 .61394 m
.49191 .74954 L
s
P
p
.2 0 1 r
.018 w
.561 .61394 m
.58481 .76426 L
s
P
p
.2 0 1 r
.018 w
.61904 .5559 m
.76936 .57971 L
s
P
p
.2 0 1 r
.018 w
.61904 .5559 m
.75464 .48681 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.561 .61394 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.61904 .5559 L
s
P
p
.2 0 1 r
.018 w
.35636 .19436 m
.46398 .08674 L
s
P
p
.2 0 1 r
.018 w
.35636 .19436 m
.38017 .04404 L
s
P
p
.2 0 1 r
.018 w
.28323 .23162 m
.14763 .16253 L
s
P
p
.2 0 1 r
.018 w
.28323 .23162 m
.13292 .25543 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.35636 .19436 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.28323 .23162 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.62587 .4521 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.24466 .32823 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.56894 .56384 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.33333 .23956 L
s
P
p
.2 0 1 r
.018 w
.726 .37549 m
.83361 .4831 L
s
P
p
.2 0 1 r
.018 w
.726 .37549 m
.87631 .39929 L
s
P
p
.2 0 1 r
.018 w
.68874 .30235 m
.75783 .16675 L
s
P
p
.2 0 1 r
.018 w
.68874 .30235 m
.66493 .15204 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.726 .37549 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.68874 .30235 L
s
P
p
.2 0 1 r
.018 w
.26371 .44045 m
.19462 .30485 L
s
P
p
.2 0 1 r
.018 w
.26371 .44045 m
.12811 .37136 L
s
P
p
.2 0 1 r
.018 w
.27655 .52152 m
.16894 .62913 L
s
P
p
.2 0 1 r
.018 w
.27655 .52152 m
.25274 .67183 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.26371 .44045 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.27655 .52152 L
s
P
p
.2 0 1 r
.018 w
.72345 .52152 m
.74726 .67183 L
s
P
p
.2 0 1 r
.018 w
.72345 .52152 m
.83106 .62913 L
s
P
p
.2 0 1 r
.018 w
.73629 .44045 m
.87189 .37136 L
s
P
p
.2 0 1 r
.018 w
.73629 .44045 m
.80538 .30485 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.72345 .52152 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.73629 .44045 L
s
P
p
.2 0 1 r
.018 w
.31126 .30235 m
.33507 .15204 L
s
P
p
.2 0 1 r
.018 w
.31126 .30235 m
.24217 .16675 L
s
P
p
.2 0 1 r
.018 w
.274 .37549 m
.12369 .39929 L
s
P
p
.2 0 1 r
.018 w
.274 .37549 m
.16639 .4831 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.31126 .30235 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.274 .37549 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.6808 .35246 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.29958 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.70042 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.3192 .35246 L
s
P
p
.2 0 1 r
.018 w
.71677 .23162 m
.86708 .25543 L
s
P
p
.2 0 1 r
.018 w
.71677 .23162 m
.85237 .16253 L
s
P
p
.2 0 1 r
.018 w
.64364 .19436 m
.61983 .04404 L
s
P
p
.2 0 1 r
.018 w
.64364 .19436 m
.53602 .08674 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.71677 .23162 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.64364 .19436 L
s
P
p
.2 0 1 r
.018 w
.38096 .5559 m
.24536 .48681 L
s
P
p
.2 0 1 r
.018 w
.38096 .5559 m
.23064 .57971 L
s
P
p
.2 0 1 r
.018 w
.439 .61394 m
.41519 .76426 L
s
P
p
.2 0 1 r
.018 w
.439 .61394 m
.50809 .74954 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.38096 .5559 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.439 .61394 L
s
P
p
.2 0 1 r
.018 w
.80054 .35126 m
.90816 .45888 L
s
P
p
.2 0 1 r
.018 w
.80054 .35126 m
.95086 .37507 L
s
P
p
.2 0 1 r
.018 w
.76328 .27813 m
.83237 .14253 L
s
P
p
.2 0 1 r
.018 w
.76328 .27813 m
.73947 .12782 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.80054 .35126 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.76328 .27813 L
s
P
p
.2 0 1 r
.018 w
.33826 .41623 m
.26916 .28063 L
s
P
p
.2 0 1 r
.018 w
.33826 .41623 m
.20266 .34714 L
s
P
p
.2 0 1 r
.018 w
.3511 .4973 m
.24348 .60491 L
s
P
p
.2 0 1 r
.018 w
.3511 .4973 m
.32729 .64761 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.33826 .41623 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.3511 .4973 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.66667 .23956 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.43106 .56384 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.75534 .32823 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.37413 .4521 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.42546 .42036 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.5 .44458 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.57454 .42036 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0720399 0.952381 [
[ 0 0 0 0 ]
[ 1 .8083 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8083 L
0 .8083 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.02 w
.6489 .4973 m
.67271 .64761 L
s
P
p
0 .4 1 r
.02 w
.6489 .4973 m
.75652 .60491 L
s
P
p
0 .4 1 r
.02 w
.66174 .41623 m
.79734 .34714 L
s
P
p
0 .4 1 r
.02 w
.66174 .41623 m
.73084 .28063 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.6489 .4973 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.66174 .41623 L
s
P
p
0 .4 1 r
.02 w
.23672 .27813 m
.26053 .12782 L
s
P
p
0 .4 1 r
.02 w
.23672 .27813 m
.16763 .14253 L
s
P
p
0 .4 1 r
.02 w
.19946 .35126 m
.04914 .37507 L
s
P
p
0 .4 1 r
.02 w
.19946 .35126 m
.09184 .45888 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.23672 .27813 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.19946 .35126 L
s
P
p
0 .4 1 r
.02 w
.561 .61394 m
.49191 .74954 L
s
P
p
0 .4 1 r
.02 w
.561 .61394 m
.58481 .76426 L
s
P
p
0 .4 1 r
.02 w
.61904 .5559 m
.76936 .57971 L
s
P
p
0 .4 1 r
.02 w
.61904 .5559 m
.75464 .48681 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.561 .61394 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.61904 .5559 L
s
P
p
0 .4 1 r
.02 w
.35636 .19436 m
.46398 .08674 L
s
P
p
0 .4 1 r
.02 w
.35636 .19436 m
.38017 .04404 L
s
P
p
0 .4 1 r
.02 w
.28323 .23162 m
.14763 .16253 L
s
P
p
0 .4 1 r
.02 w
.28323 .23162 m
.13292 .25543 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.35636 .19436 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.28323 .23162 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.62587 .4521 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.24466 .32823 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.56894 .56384 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.33333 .23956 L
s
P
p
0 .4 1 r
.02 w
.726 .37549 m
.83361 .4831 L
s
P
p
0 .4 1 r
.02 w
.726 .37549 m
.87631 .39929 L
s
P
p
0 .4 1 r
.02 w
.68874 .30235 m
.75783 .16675 L
s
P
p
0 .4 1 r
.02 w
.68874 .30235 m
.66493 .15204 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.726 .37549 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.68874 .30235 L
s
P
p
0 .4 1 r
.02 w
.26371 .44045 m
.19462 .30485 L
s
P
p
0 .4 1 r
.02 w
.26371 .44045 m
.12811 .37136 L
s
P
p
0 .4 1 r
.02 w
.27655 .52152 m
.16894 .62913 L
s
P
p
0 .4 1 r
.02 w
.27655 .52152 m
.25274 .67183 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.26371 .44045 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.27655 .52152 L
s
P
p
0 .4 1 r
.02 w
.72345 .52152 m
.74726 .67183 L
s
P
p
0 .4 1 r
.02 w
.72345 .52152 m
.83106 .62913 L
s
P
p
0 .4 1 r
.02 w
.73629 .44045 m
.87189 .37136 L
s
P
p
0 .4 1 r
.02 w
.73629 .44045 m
.80538 .30485 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.72345 .52152 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.73629 .44045 L
s
P
p
0 .4 1 r
.02 w
.31126 .30235 m
.33507 .15204 L
s
P
p
0 .4 1 r
.02 w
.31126 .30235 m
.24217 .16675 L
s
P
p
0 .4 1 r
.02 w
.274 .37549 m
.12369 .39929 L
s
P
p
0 .4 1 r
.02 w
.274 .37549 m
.16639 .4831 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.31126 .30235 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.274 .37549 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.6808 .35246 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.29958 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.70042 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.3192 .35246 L
s
P
p
0 .4 1 r
.02 w
.71677 .23162 m
.86708 .25543 L
s
P
p
0 .4 1 r
.02 w
.71677 .23162 m
.85237 .16253 L
s
P
p
0 .4 1 r
.02 w
.64364 .19436 m
.61983 .04404 L
s
P
p
0 .4 1 r
.02 w
.64364 .19436 m
.53602 .08674 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.71677 .23162 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.64364 .19436 L
s
P
p
0 .4 1 r
.02 w
.38096 .5559 m
.24536 .48681 L
s
P
p
0 .4 1 r
.02 w
.38096 .5559 m
.23064 .57971 L
s
P
p
0 .4 1 r
.02 w
.439 .61394 m
.41519 .76426 L
s
P
p
0 .4 1 r
.02 w
.439 .61394 m
.50809 .74954 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.38096 .5559 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.439 .61394 L
s
P
p
0 .4 1 r
.02 w
.80054 .35126 m
.90816 .45888 L
s
P
p
0 .4 1 r
.02 w
.80054 .35126 m
.95086 .37507 L
s
P
p
0 .4 1 r
.02 w
.76328 .27813 m
.83237 .14253 L
s
P
p
0 .4 1 r
.02 w
.76328 .27813 m
.73947 .12782 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.80054 .35126 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.76328 .27813 L
s
P
p
0 .4 1 r
.02 w
.33826 .41623 m
.26916 .28063 L
s
P
p
0 .4 1 r
.02 w
.33826 .41623 m
.20266 .34714 L
s
P
p
0 .4 1 r
.02 w
.3511 .4973 m
.24348 .60491 L
s
P
p
0 .4 1 r
.02 w
.3511 .4973 m
.32729 .64761 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.33826 .41623 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.3511 .4973 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.66667 .23956 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.43106 .56384 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.75534 .32823 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.37413 .4521 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.42546 .42036 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.5 .44458 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.57454 .42036 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.111088 0.952381 [
[ 0 0 0 0 ]
[ 1 .73021 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .73021 L
0 .73021 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.59199 .53961 m
.54372 .68819 L
s
P
p
.2 0 1 r
.02 w
.59199 .53961 m
.64027 .68819 L
s
P
p
.2 0 1 r
.02 w
.64152 .47144 m
.79774 .47144 L
s
P
p
.2 0 1 r
.02 w
.64152 .47144 m
.76791 .37962 L
s
P
p
0 .4 1 r
.018 w
.59199 .48754 m
.59199 .53961 L
s
P
p
0 .4 1 r
.018 w
.59199 .48754 m
.64152 .47144 L
s
P
p
.2 0 1 r
.02 w
.25496 .19059 m
.30324 .04202 L
s
P
p
.2 0 1 r
.02 w
.25496 .19059 m
.20669 .04202 L
s
P
p
.2 0 1 r
.02 w
.20544 .25876 m
.04921 .25876 L
s
P
p
.2 0 1 r
.02 w
.20544 .25876 m
.07905 .35059 L
s
P
p
0 .4 1 r
.018 w
.25496 .24267 m
.25496 .19059 L
s
P
p
0 .4 1 r
.018 w
.25496 .24267 m
.20544 .25876 L
s
P
p
.2 0 1 r
.016 w
.42348 .3651 m
.59199 .48754 L
s
P
p
.2 0 1 r
.016 w
.42348 .3651 m
.25496 .24267 L
s
P
p
.2 0 1 r
.02 w
.73891 .43209 m
.78718 .58067 L
s
P
p
.2 0 1 r
.02 w
.73891 .43209 m
.86529 .52392 L
s
P
p
.2 0 1 r
.02 w
.73891 .34784 m
.86529 .25601 L
s
P
p
.2 0 1 r
.02 w
.73891 .34784 m
.78718 .19926 L
s
P
p
0 .4 1 r
.018 w
.7083 .38997 m
.73891 .43209 L
s
P
p
0 .4 1 r
.018 w
.7083 .38997 m
.73891 .34784 L
s
P
p
.2 0 1 r
.02 w
.26109 .34784 m
.21282 .19926 L
s
P
p
.2 0 1 r
.02 w
.26109 .34784 m
.13471 .25601 L
s
P
p
.2 0 1 r
.02 w
.26109 .43209 m
.13471 .52392 L
s
P
p
.2 0 1 r
.02 w
.26109 .43209 m
.21282 .58067 L
s
P
p
0 .4 1 r
.018 w
.2917 .38997 m
.26109 .34784 L
s
P
p
0 .4 1 r
.018 w
.2917 .38997 m
.26109 .43209 L
s
P
p
.2 0 1 r
.016 w
.5 .38997 m
.7083 .38997 L
s
P
p
.2 0 1 r
.016 w
.5 .38997 m
.2917 .38997 L
s
P
p
.2 0 1 r
.02 w
.79456 .25876 m
.92095 .35059 L
s
P
p
.2 0 1 r
.02 w
.79456 .25876 m
.95079 .25876 L
s
P
p
.2 0 1 r
.02 w
.74504 .19059 m
.79331 .04202 L
s
P
p
.2 0 1 r
.02 w
.74504 .19059 m
.69676 .04202 L
s
P
p
0 .4 1 r
.018 w
.74504 .24267 m
.79456 .25876 L
s
P
p
0 .4 1 r
.018 w
.74504 .24267 m
.74504 .19059 L
s
P
p
.2 0 1 r
.02 w
.35848 .47144 m
.23209 .37962 L
s
P
p
.2 0 1 r
.02 w
.35848 .47144 m
.20226 .47144 L
s
P
p
.2 0 1 r
.02 w
.40801 .53961 m
.35973 .68819 L
s
P
p
.2 0 1 r
.02 w
.40801 .53961 m
.45628 .68819 L
s
P
p
0 .4 1 r
.018 w
.40801 .48754 m
.35848 .47144 L
s
P
p
0 .4 1 r
.018 w
.40801 .48754 m
.40801 .53961 L
s
P
p
.2 0 1 r
.016 w
.57652 .3651 m
.74504 .24267 L
s
P
p
.2 0 1 r
.016 w
.57652 .3651 m
.40801 .48754 L
s
P
p
1 .6 0 r
.016 w
.5 .25978 m
.42348 .3651 L
s
P
p
1 .6 0 r
.016 w
.5 .25978 m
.5 .38997 L
s
P
p
1 .6 0 r
.016 w
.5 .25978 m
.57652 .3651 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0745047 0.952381 [
[ 0 0 0 0 ]
[ 1 .80337 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .80337 L
0 .80337 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.63035 .49309 m
.6554 .65129 L
s
P
p
.2 0 1 r
.02 w
.63035 .49309 m
.7436 .60635 L
s
P
p
.2 0 1 r
.02 w
.64386 .40777 m
.78657 .33505 L
s
P
p
.2 0 1 r
.02 w
.64386 .40777 m
.71658 .26506 L
s
P
p
0 .4 1 r
.018 w
.60611 .44552 m
.63035 .49309 L
s
P
p
0 .4 1 r
.018 w
.60611 .44552 m
.64386 .40777 L
s
P
p
.2 0 1 r
.02 w
.2467 .27872 m
.27175 .12052 L
s
P
p
.2 0 1 r
.02 w
.2467 .27872 m
.17398 .13601 L
s
P
p
.2 0 1 r
.02 w
.20748 .35569 m
.04928 .38075 L
s
P
p
.2 0 1 r
.02 w
.20748 .35569 m
.09422 .46895 L
s
P
p
0 .4 1 r
.018 w
.25505 .33145 m
.2467 .27872 L
s
P
p
0 .4 1 r
.018 w
.25505 .33145 m
.20748 .35569 L
s
P
p
.2 0 1 r
.02 w
.54533 .60115 m
.47261 .74386 L
s
P
p
.2 0 1 r
.02 w
.54533 .60115 m
.57038 .75935 L
s
P
p
.2 0 1 r
.02 w
.60641 .54007 m
.76461 .56512 L
s
P
p
.2 0 1 r
.02 w
.60641 .54007 m
.74912 .46735 L
s
P
p
0 .4 1 r
.018 w
.55368 .54842 m
.54533 .60115 L
s
P
p
0 .4 1 r
.018 w
.55368 .54842 m
.60641 .54007 L
s
P
p
.2 0 1 r
.02 w
.36095 .20222 m
.47421 .08896 L
s
P
p
.2 0 1 r
.02 w
.36095 .20222 m
.38601 .04402 L
s
P
p
.2 0 1 r
.02 w
.28398 .24144 m
.14127 .16872 L
s
P
p
.2 0 1 r
.02 w
.28398 .24144 m
.12578 .26649 L
s
P
p
0 .4 1 r
.018 w
.33671 .24979 m
.36095 .20222 L
s
P
p
0 .4 1 r
.018 w
.33671 .24979 m
.28398 .24144 L
s
P
p
.2 0 1 r
.016 w
.42155 .41629 m
.60611 .44552 L
s
P
p
.2 0 1 r
.016 w
.42155 .41629 m
.25505 .33145 L
s
P
p
.2 0 1 r
.016 w
.42155 .41629 m
.55368 .54842 L
s
P
p
.2 0 1 r
.016 w
.42155 .41629 m
.33671 .24979 L
s
P
p
.2 0 1 r
.02 w
.71407 .38118 m
.82732 .49444 L
s
P
p
.2 0 1 r
.02 w
.71407 .38118 m
.87226 .40624 L
s
P
p
.2 0 1 r
.02 w
.67485 .30421 m
.74756 .1615 L
s
P
p
.2 0 1 r
.02 w
.67485 .30421 m
.64979 .14602 L
s
P
p
0 .4 1 r
.018 w
.6665 .35694 m
.71407 .38118 L
s
P
p
0 .4 1 r
.018 w
.6665 .35694 m
.67485 .30421 L
s
P
p
.2 0 1 r
.02 w
.27769 .43326 m
.20497 .29055 L
s
P
p
.2 0 1 r
.02 w
.27769 .43326 m
.13497 .36054 L
s
P
p
.2 0 1 r
.02 w
.2912 .51858 m
.17794 .63184 L
s
P
p
.2 0 1 r
.02 w
.2912 .51858 m
.26614 .67678 L
s
P
p
0 .4 1 r
.018 w
.31544 .47101 m
.27769 .43326 L
s
P
p
0 .4 1 r
.018 w
.31544 .47101 m
.2912 .51858 L
s
P
p
.2 0 1 r
.02 w
.7088 .51858 m
.73386 .67678 L
s
P
p
.2 0 1 r
.02 w
.7088 .51858 m
.82206 .63184 L
s
P
p
.2 0 1 r
.02 w
.72231 .43326 m
.86503 .36054 L
s
P
p
.2 0 1 r
.02 w
.72231 .43326 m
.79503 .29055 L
s
P
p
0 .4 1 r
.018 w
.68456 .47101 m
.7088 .51858 L
s
P
p
0 .4 1 r
.018 w
.68456 .47101 m
.72231 .43326 L
s
P
p
.2 0 1 r
.02 w
.32515 .30421 m
.35021 .14602 L
s
P
p
.2 0 1 r
.02 w
.32515 .30421 m
.25244 .1615 L
s
P
p
.2 0 1 r
.02 w
.28593 .38118 m
.12774 .40624 L
s
P
p
.2 0 1 r
.02 w
.28593 .38118 m
.17268 .49444 L
s
P
p
0 .4 1 r
.018 w
.3335 .35694 m
.32515 .30421 L
s
P
p
0 .4 1 r
.018 w
.3335 .35694 m
.28593 .38118 L
s
P
p
.2 0 1 r
.016 w
.5 .44178 m
.6665 .35694 L
s
P
p
.2 0 1 r
.016 w
.5 .44178 m
.31544 .47101 L
s
P
p
.2 0 1 r
.016 w
.5 .44178 m
.68456 .47101 L
s
P
p
.2 0 1 r
.016 w
.5 .44178 m
.3335 .35694 L
s
P
p
.2 0 1 r
.02 w
.71602 .24144 m
.87422 .26649 L
s
P
p
.2 0 1 r
.02 w
.71602 .24144 m
.85873 .16872 L
s
P
p
.2 0 1 r
.02 w
.63905 .20222 m
.61399 .04402 L
s
P
p
.2 0 1 r
.02 w
.63905 .20222 m
.52579 .08896 L
s
P
p
0 .4 1 r
.018 w
.66329 .24979 m
.71602 .24144 L
s
P
p
0 .4 1 r
.018 w
.66329 .24979 m
.63905 .20222 L
s
P
p
.2 0 1 r
.02 w
.39359 .54007 m
.25088 .46735 L
s
P
p
.2 0 1 r
.02 w
.39359 .54007 m
.23539 .56512 L
s
P
p
.2 0 1 r
.02 w
.45467 .60115 m
.42962 .75935 L
s
P
p
.2 0 1 r
.02 w
.45467 .60115 m
.52739 .74386 L
s
P
p
0 .4 1 r
.018 w
.44632 .54842 m
.39359 .54007 L
s
P
p
0 .4 1 r
.018 w
.44632 .54842 m
.45467 .60115 L
s
P
p
.2 0 1 r
.02 w
.79252 .35569 m
.90578 .46895 L
s
P
p
.2 0 1 r
.02 w
.79252 .35569 m
.95072 .38075 L
s
P
p
.2 0 1 r
.02 w
.7533 .27872 m
.82602 .13601 L
s
P
p
.2 0 1 r
.02 w
.7533 .27872 m
.72825 .12052 L
s
P
p
0 .4 1 r
.018 w
.74495 .33145 m
.79252 .35569 L
s
P
p
0 .4 1 r
.018 w
.74495 .33145 m
.7533 .27872 L
s
P
p
.2 0 1 r
.02 w
.35614 .40777 m
.28342 .26506 L
s
P
p
.2 0 1 r
.02 w
.35614 .40777 m
.21343 .33505 L
s
P
p
.2 0 1 r
.02 w
.36965 .49309 m
.2564 .60635 L
s
P
p
.2 0 1 r
.02 w
.36965 .49309 m
.3446 .65129 L
s
P
p
0 .4 1 r
.018 w
.39389 .44552 m
.35614 .40777 L
s
P
p
0 .4 1 r
.018 w
.39389 .44552 m
.36965 .49309 L
s
P
p
.2 0 1 r
.016 w
.57845 .41629 m
.66329 .24979 L
s
P
p
.2 0 1 r
.016 w
.57845 .41629 m
.44632 .54842 L
s
P
p
.2 0 1 r
.016 w
.57845 .41629 m
.74495 .33145 L
s
P
p
.2 0 1 r
.016 w
.57845 .41629 m
.39389 .44552 L
s
P
p
1 .6 0 r
.016 w
.5 .3083 m
.42155 .41629 L
s
P
p
1 .6 0 r
.016 w
.5 .3083 m
.5 .44178 L
s
P
p
1 .6 0 r
.016 w
.5 .3083 m
.57845 .41629 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0720399 0.952381 [
[ 0 0 0 0 ]
[ 1 .8083 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8083 L
0 .8083 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.67271 .64761 L
s
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.75652 .60491 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.79734 .34714 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.73084 .28063 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.6489 .4973 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.66174 .41623 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.26053 .12782 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.16763 .14253 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.04914 .37507 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.09184 .45888 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.23672 .27813 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.19946 .35126 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.49191 .74954 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.58481 .76426 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.76936 .57971 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.75464 .48681 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.561 .61394 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.61904 .5559 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.46398 .08674 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.38017 .04404 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.14763 .16253 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.13292 .25543 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.35636 .19436 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.28323 .23162 L
s
P
p
.2 0 1 r
.014 w
.42546 .42036 m
.62587 .4521 L
s
P
p
.2 0 1 r
.014 w
.42546 .42036 m
.24466 .32823 L
s
P
p
.2 0 1 r
.014 w
.42546 .42036 m
.56894 .56384 L
s
P
p
.2 0 1 r
.014 w
.42546 .42036 m
.33333 .23956 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.83361 .4831 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.87631 .39929 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.75783 .16675 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.66493 .15204 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.726 .37549 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.68874 .30235 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.19462 .30485 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.12811 .37136 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.16894 .62913 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.25274 .67183 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.26371 .44045 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.27655 .52152 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.74726 .67183 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.83106 .62913 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.87189 .37136 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.80538 .30485 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.72345 .52152 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.73629 .44045 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.33507 .15204 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.24217 .16675 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.12369 .39929 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.16639 .4831 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.31126 .30235 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.274 .37549 L
s
P
p
.2 0 1 r
.014 w
.5 .44458 m
.6808 .35246 L
s
P
p
.2 0 1 r
.014 w
.5 .44458 m
.29958 .47632 L
s
P
p
.2 0 1 r
.014 w
.5 .44458 m
.70042 .47632 L
s
P
p
.2 0 1 r
.014 w
.5 .44458 m
.3192 .35246 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.86708 .25543 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.85237 .16253 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.61983 .04404 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.53602 .08674 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.71677 .23162 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.64364 .19436 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.24536 .48681 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.23064 .57971 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.41519 .76426 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.50809 .74954 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.38096 .5559 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.439 .61394 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.90816 .45888 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.95086 .37507 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.83237 .14253 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.73947 .12782 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.80054 .35126 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.76328 .27813 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.26916 .28063 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.20266 .34714 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.24348 .60491 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.32729 .64761 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.33826 .41623 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.3511 .4973 L
s
P
p
.2 0 1 r
.014 w
.57454 .42036 m
.66667 .23956 L
s
P
p
.2 0 1 r
.014 w
.57454 .42036 m
.43106 .56384 L
s
P
p
.2 0 1 r
.014 w
.57454 .42036 m
.75534 .32823 L
s
P
p
.2 0 1 r
.014 w
.57454 .42036 m
.37413 .4521 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.42546 .42036 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.5 .44458 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.57454 .42036 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0720399 0.952381 [
[ 0 0 0 0 ]
[ 1 .8083 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8083 L
0 .8083 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.67271 .64761 L
s
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.75652 .60491 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.79734 .34714 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.73084 .28063 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.6489 .4973 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.66174 .41623 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.26053 .12782 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.16763 .14253 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.04914 .37507 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.09184 .45888 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.23672 .27813 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.19946 .35126 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.49191 .74954 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.58481 .76426 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.76936 .57971 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.75464 .48681 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.561 .61394 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.61904 .5559 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.46398 .08674 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.38017 .04404 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.14763 .16253 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.13292 .25543 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.35636 .19436 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.28323 .23162 L
s
P
p
.8 0 1 r
.016 w
.42546 .42036 m
.62587 .4521 L
s
P
p
.8 0 1 r
.016 w
.42546 .42036 m
.24466 .32823 L
s
P
p
.8 0 1 r
.016 w
.42546 .42036 m
.56894 .56384 L
s
P
p
.8 0 1 r
.016 w
.42546 .42036 m
.33333 .23956 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.83361 .4831 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.87631 .39929 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.75783 .16675 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.66493 .15204 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.726 .37549 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.68874 .30235 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.19462 .30485 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.12811 .37136 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.16894 .62913 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.25274 .67183 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.26371 .44045 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.27655 .52152 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.74726 .67183 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.83106 .62913 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.87189 .37136 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.80538 .30485 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.72345 .52152 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.73629 .44045 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.33507 .15204 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.24217 .16675 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.12369 .39929 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.16639 .4831 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.31126 .30235 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.274 .37549 L
s
P
p
.8 0 1 r
.016 w
.5 .44458 m
.6808 .35246 L
s
P
p
.8 0 1 r
.016 w
.5 .44458 m
.29958 .47632 L
s
P
p
.8 0 1 r
.016 w
.5 .44458 m
.70042 .47632 L
s
P
p
.8 0 1 r
.016 w
.5 .44458 m
.3192 .35246 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.86708 .25543 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.85237 .16253 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.61983 .04404 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.53602 .08674 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.71677 .23162 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.64364 .19436 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.24536 .48681 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.23064 .57971 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.41519 .76426 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.50809 .74954 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.38096 .5559 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.439 .61394 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.90816 .45888 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.95086 .37507 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.83237 .14253 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.73947 .12782 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.80054 .35126 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.76328 .27813 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.26916 .28063 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.20266 .34714 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.24348 .60491 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.32729 .64761 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.33826 .41623 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.3511 .4973 L
s
P
p
.8 0 1 r
.016 w
.57454 .42036 m
.66667 .23956 L
s
P
p
.8 0 1 r
.016 w
.57454 .42036 m
.43106 .56384 L
s
P
p
.8 0 1 r
.016 w
.57454 .42036 m
.75534 .32823 L
s
P
p
.8 0 1 r
.016 w
.57454 .42036 m
.37413 .4521 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.42546 .42036 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.5 .44458 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.57454 .42036 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0873268 0.952381 [
[ 0 0 0 0 ]
[ 1 .77773 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .77773 L
0 .77773 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.67598 .45922 m
.81158 .52831 L
s
P
p
.2 0 1 r
.02 w
.67598 .45922 m
.82629 .43541 L
s
P
p
0 .4 1 r
.018 w
.62587 .45129 m
.67598 .45922 L
s
P
p
.2 0 1 r
.02 w
.19946 .30439 m
.09184 .19678 L
s
P
p
.2 0 1 r
.02 w
.19946 .30439 m
.04914 .28058 L
s
P
p
0 .4 1 r
.018 w
.24466 .32742 m
.19946 .30439 L
s
P
p
.2 0 1 r
.02 w
.60481 .5989 m
.6739 .7345 L
s
P
p
.2 0 1 r
.02 w
.60481 .5989 m
.74041 .66799 L
s
P
p
0 .4 1 r
.018 w
.56894 .56303 m
.60481 .5989 L
s
P
p
.2 0 1 r
.02 w
.3103 .19354 m
.2865 .04323 L
s
P
p
.2 0 1 r
.02 w
.3103 .19354 m
.20269 .08593 L
s
P
p
0 .4 1 r
.018 w
.33333 .23874 m
.3103 .19354 L
s
P
p
.2 0 1 r
.016 w
.42546 .41954 m
.62587 .45129 L
s
P
p
.2 0 1 r
.016 w
.42546 .41954 m
.24466 .32742 L
s
P
p
.2 0 1 r
.016 w
.42546 .41954 m
.56894 .56303 L
s
P
p
.2 0 1 r
.016 w
.42546 .41954 m
.33333 .23874 L
s
P
p
.2 0 1 r
.02 w
.726 .32861 m
.87631 .3048 L
s
P
p
.2 0 1 r
.02 w
.726 .32861 m
.83361 .221 L
s
P
p
0 .4 1 r
.018 w
.6808 .35164 m
.726 .32861 L
s
P
p
.2 0 1 r
.02 w
.24948 .48344 m
.09916 .45964 L
s
P
p
.2 0 1 r
.02 w
.24948 .48344 m
.11388 .55253 L
s
P
p
0 .4 1 r
.018 w
.29958 .47551 m
.24948 .48344 L
s
P
p
.2 0 1 r
.02 w
.75052 .48344 m
.88612 .55253 L
s
P
p
.2 0 1 r
.02 w
.75052 .48344 m
.90084 .45964 L
s
P
p
0 .4 1 r
.018 w
.70042 .47551 m
.75052 .48344 L
s
P
p
.2 0 1 r
.02 w
.274 .32861 m
.16639 .221 L
s
P
p
.2 0 1 r
.02 w
.274 .32861 m
.12369 .3048 L
s
P
p
0 .4 1 r
.018 w
.3192 .35164 m
.274 .32861 L
s
P
p
.2 0 1 r
.016 w
.5 .44376 m
.6808 .35164 L
s
P
p
.2 0 1 r
.016 w
.5 .44376 m
.29958 .47551 L
s
P
p
.2 0 1 r
.016 w
.5 .44376 m
.70042 .47551 L
s
P
p
.2 0 1 r
.016 w
.5 .44376 m
.3192 .35164 L
s
P
p
.2 0 1 r
.02 w
.6897 .19354 m
.79731 .08593 L
s
P
p
.2 0 1 r
.02 w
.6897 .19354 m
.7135 .04323 L
s
P
p
0 .4 1 r
.018 w
.66667 .23874 m
.6897 .19354 L
s
P
p
.2 0 1 r
.02 w
.39519 .5989 m
.25959 .66799 L
s
P
p
.2 0 1 r
.02 w
.39519 .5989 m
.3261 .7345 L
s
P
p
0 .4 1 r
.018 w
.43106 .56303 m
.39519 .5989 L
s
P
p
.2 0 1 r
.02 w
.80054 .30439 m
.95086 .28058 L
s
P
p
.2 0 1 r
.02 w
.80054 .30439 m
.90816 .19678 L
s
P
p
0 .4 1 r
.018 w
.75534 .32742 m
.80054 .30439 L
s
P
p
.2 0 1 r
.02 w
.32402 .45922 m
.17371 .43541 L
s
P
p
.2 0 1 r
.02 w
.32402 .45922 m
.18842 .52831 L
s
P
p
0 .4 1 r
.018 w
.37413 .45129 m
.32402 .45922 L
s
P
p
.2 0 1 r
.016 w
.57454 .41954 m
.66667 .23874 L
s
P
p
.2 0 1 r
.016 w
.57454 .41954 m
.43106 .56303 L
s
P
p
.2 0 1 r
.016 w
.57454 .41954 m
.75534 .32742 L
s
P
p
.2 0 1 r
.016 w
.57454 .41954 m
.37413 .45129 L
s
P
p
1 .6 0 r
.016 w
.5 .31694 m
.42546 .41954 L
s
P
p
1 .6 0 r
.016 w
.5 .31694 m
.5 .44376 L
s
P
p
1 .6 0 r
.016 w
.5 .31694 m
.57454 .41954 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0688927 0.952381 [
[ 0 0 0 0 ]
[ 1 .8146 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8146 L
0 .8146 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.64465 .50062 m
.64465 .65615 L
s
P
p
.2 0 1 r
.02 w
.64465 .50062 m
.73607 .62644 L
s
P
p
.2 0 1 r
.02 w
.65911 .40938 m
.78493 .31796 L
s
P
p
.2 0 1 r
.02 w
.65911 .40938 m
.70717 .26146 L
s
P
p
0 .4 1 r
.018 w
.62863 .45132 m
.64465 .50062 L
s
P
p
0 .4 1 r
.018 w
.62863 .45132 m
.65911 .40938 L
s
P
p
.2 0 1 r
.02 w
.23906 .27289 m
.28712 .12498 L
s
P
p
.2 0 1 r
.02 w
.23906 .27289 m
.191 .12498 L
s
P
p
.2 0 1 r
.02 w
.19711 .35521 m
.0492 .40327 L
s
P
p
.2 0 1 r
.02 w
.19711 .35521 m
.1057 .48103 L
s
P
p
0 .4 1 r
.018 w
.23906 .32473 m
.23906 .27289 L
s
P
p
0 .4 1 r
.018 w
.23906 .32473 m
.19711 .35521 L
s
P
p
.2 0 1 r
.02 w
.55443 .61481 m
.46302 .74063 L
s
P
p
.2 0 1 r
.02 w
.55443 .61481 m
.55443 .77034 L
s
P
p
.2 0 1 r
.02 w
.61976 .54949 m
.77528 .54949 L
s
P
p
.2 0 1 r
.02 w
.61976 .54949 m
.74558 .45807 L
s
P
p
0 .4 1 r
.018 w
.57045 .56551 m
.55443 .61481 L
s
P
p
0 .4 1 r
.018 w
.57045 .56551 m
.61976 .54949 L
s
P
p
.2 0 1 r
.02 w
.36015 .19217 m
.48597 .10076 L
s
P
p
.2 0 1 r
.02 w
.36015 .19217 m
.40821 .04426 L
s
P
p
.2 0 1 r
.02 w
.27784 .23411 m
.12992 .18605 L
s
P
p
.2 0 1 r
.02 w
.27784 .23411 m
.12992 .28217 L
s
P
p
0 .4 1 r
.018 w
.32968 .23411 m
.36015 .19217 L
s
P
p
0 .4 1 r
.018 w
.32968 .23411 m
.27784 .23411 L
s
P
p
.2 0 1 r
.016 w
.42382 .41888 m
.62863 .45132 L
s
P
p
.2 0 1 r
.016 w
.42382 .41888 m
.23906 .32473 L
s
P
p
.2 0 1 r
.016 w
.42382 .41888 m
.57045 .56551 L
s
P
p
.2 0 1 r
.016 w
.42382 .41888 m
.32968 .23411 L
s
P
p
.2 0 1 r
.02 w
.72671 .37996 m
.81812 .50578 L
s
P
p
.2 0 1 r
.02 w
.72671 .37996 m
.87462 .42802 L
s
P
p
.2 0 1 r
.02 w
.68477 .29765 m
.73282 .14973 L
s
P
p
.2 0 1 r
.02 w
.68477 .29765 m
.63671 .14973 L
s
P
p
0 .4 1 r
.018 w
.68477 .34949 m
.72671 .37996 L
s
P
p
0 .4 1 r
.018 w
.68477 .34949 m
.68477 .29765 L
s
P
p
.2 0 1 r
.02 w
.26471 .43413 m
.21665 .28621 L
s
P
p
.2 0 1 r
.02 w
.26471 .43413 m
.13889 .34271 L
s
P
p
.2 0 1 r
.02 w
.27917 .52537 m
.18775 .6512 L
s
P
p
.2 0 1 r
.02 w
.27917 .52537 m
.27917 .6809 L
s
P
p
0 .4 1 r
.018 w
.29519 .47607 m
.26471 .43413 L
s
P
p
0 .4 1 r
.018 w
.29519 .47607 m
.27917 .52537 L
s
P
p
.2 0 1 r
.02 w
.72083 .52537 m
.72083 .6809 L
s
P
p
.2 0 1 r
.02 w
.72083 .52537 m
.81225 .6512 L
s
P
p
.2 0 1 r
.02 w
.73529 .43413 m
.86111 .34271 L
s
P
p
.2 0 1 r
.02 w
.73529 .43413 m
.78335 .28621 L
s
P
p
0 .4 1 r
.018 w
.70481 .47607 m
.72083 .52537 L
s
P
p
0 .4 1 r
.018 w
.70481 .47607 m
.73529 .43413 L
s
P
p
.2 0 1 r
.02 w
.31523 .29765 m
.36329 .14973 L
s
P
p
.2 0 1 r
.02 w
.31523 .29765 m
.26718 .14973 L
s
P
p
.2 0 1 r
.02 w
.27329 .37996 m
.12538 .42802 L
s
P
p
.2 0 1 r
.02 w
.27329 .37996 m
.18188 .50578 L
s
P
p
0 .4 1 r
.018 w
.31523 .34949 m
.31523 .29765 L
s
P
p
0 .4 1 r
.018 w
.31523 .34949 m
.27329 .37996 L
s
P
p
.2 0 1 r
.016 w
.5 .44363 m
.68477 .34949 L
s
P
p
.2 0 1 r
.016 w
.5 .44363 m
.29519 .47607 L
s
P
p
.2 0 1 r
.016 w
.5 .44363 m
.70481 .47607 L
s
P
p
.2 0 1 r
.016 w
.5 .44363 m
.31523 .34949 L
s
P
p
.2 0 1 r
.02 w
.72216 .23411 m
.87008 .28217 L
s
P
p
.2 0 1 r
.02 w
.72216 .23411 m
.87008 .18605 L
s
P
p
.2 0 1 r
.02 w
.63985 .19217 m
.59179 .04426 L
s
P
p
.2 0 1 r
.02 w
.63985 .19217 m
.51403 .10076 L
s
P
p
0 .4 1 r
.018 w
.67032 .23411 m
.72216 .23411 L
s
P
p
0 .4 1 r
.018 w
.67032 .23411 m
.63985 .19217 L
s
P
p
.2 0 1 r
.02 w
.38024 .54949 m
.25442 .45807 L
s
P
p
.2 0 1 r
.02 w
.38024 .54949 m
.22472 .54949 L
s
P
p
.2 0 1 r
.02 w
.44557 .61481 m
.44557 .77034 L
s
P
p
.2 0 1 r
.02 w
.44557 .61481 m
.53698 .74063 L
s
P
p
0 .4 1 r
.018 w
.42955 .56551 m
.38024 .54949 L
s
P
p
0 .4 1 r
.018 w
.42955 .56551 m
.44557 .61481 L
s
P
p
.2 0 1 r
.02 w
.80289 .35521 m
.8943 .48103 L
s
P
p
.2 0 1 r
.02 w
.80289 .35521 m
.9508 .40327 L
s
P
p
.2 0 1 r
.02 w
.76094 .27289 m
.809 .12498 L
s
P
p
.2 0 1 r
.02 w
.76094 .27289 m
.71288 .12498 L
s
P
p
0 .4 1 r
.018 w
.76094 .32473 m
.80289 .35521 L
s
P
p
0 .4 1 r
.018 w
.76094 .32473 m
.76094 .27289 L
s
P
p
.2 0 1 r
.02 w
.34089 .40938 m
.29283 .26146 L
s
P
p
.2 0 1 r
.02 w
.34089 .40938 m
.21507 .31796 L
s
P
p
.2 0 1 r
.02 w
.35535 .50062 m
.26393 .62644 L
s
P
p
.2 0 1 r
.02 w
.35535 .50062 m
.35535 .65615 L
s
P
p
0 .4 1 r
.018 w
.37137 .45132 m
.34089 .40938 L
s
P
p
0 .4 1 r
.018 w
.37137 .45132 m
.35535 .50062 L
s
P
p
.2 0 1 r
.016 w
.57618 .41888 m
.67032 .23411 L
s
P
p
.2 0 1 r
.016 w
.57618 .41888 m
.42955 .56551 L
s
P
p
.2 0 1 r
.016 w
.57618 .41888 m
.76094 .32473 L
s
P
p
.2 0 1 r
.016 w
.57618 .41888 m
.37137 .45132 L
s
P
p
1 .6 0 r
.016 w
.5 .31403 m
.42382 .41888 L
s
P
p
1 .6 0 r
.016 w
.5 .31403 m
.5 .44363 L
s
P
p
1 .6 0 r
.016 w
.5 .31403 m
.57618 .41888 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0784614 0.952381 [
[ 0 0 0 0 ]
[ 1 .79546 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79546 L
0 .79546 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.64459 .47327 m
.66965 .63146 L
s
P
p
.2 0 1 r
.02 w
.64459 .47327 m
.75785 .58652 L
s
P
p
.2 0 1 r
.02 w
.65135 .43061 m
.79406 .35789 L
s
P
p
.2 0 1 r
.02 w
.65135 .43061 m
.72407 .2879 L
s
P
p
0 .4 1 r
.018 w
.63247 .44948 m
.64459 .47327 L
s
P
p
0 .4 1 r
.018 w
.63247 .44948 m
.65135 .43061 L
s
P
p
.2 0 1 r
.02 w
.22709 .29276 m
.25214 .13456 L
s
P
p
.2 0 1 r
.02 w
.22709 .29276 m
.15437 .15004 L
s
P
p
.2 0 1 r
.02 w
.20748 .33124 m
.04928 .3563 L
s
P
p
.2 0 1 r
.02 w
.20748 .33124 m
.09422 .4445 L
s
P
p
0 .4 1 r
.018 w
.23126 .31912 m
.22709 .29276 L
s
P
p
0 .4 1 r
.018 w
.23126 .31912 m
.20748 .33124 L
s
P
p
.2 0 1 r
.02 w
.56838 .59345 m
.49566 .73616 L
s
P
p
.2 0 1 r
.02 w
.56838 .59345 m
.59343 .75165 L
s
P
p
.2 0 1 r
.02 w
.59892 .56291 m
.75712 .58796 L
s
P
p
.2 0 1 r
.02 w
.59892 .56291 m
.74163 .49019 L
s
P
p
0 .4 1 r
.018 w
.57255 .56708 m
.56838 .59345 L
s
P
p
0 .4 1 r
.018 w
.57255 .56708 m
.59892 .56291 L
s
P
p
.2 0 1 r
.02 w
.33671 .20201 m
.44997 .08875 L
s
P
p
.2 0 1 r
.02 w
.33671 .20201 m
.36177 .04381 L
s
P
p
.2 0 1 r
.02 w
.29823 .22162 m
.15552 .1489 L
s
P
p
.2 0 1 r
.02 w
.29823 .22162 m
.14003 .24667 L
s
P
p
0 .4 1 r
.018 w
.32459 .22579 m
.33671 .20201 L
s
P
p
0 .4 1 r
.018 w
.32459 .22579 m
.29823 .22162 L
s
P
p
.2 0 1 r
.016 w
.42155 .41608 m
.63247 .44948 L
s
P
p
.2 0 1 r
.016 w
.42155 .41608 m
.23126 .31912 L
s
P
p
.2 0 1 r
.016 w
.42155 .41608 m
.57255 .56708 L
s
P
p
.2 0 1 r
.016 w
.42155 .41608 m
.32459 .22579 L
s
P
p
.2 0 1 r
.02 w
.71407 .35673 m
.82732 .46999 L
s
P
p
.2 0 1 r
.02 w
.71407 .35673 m
.87226 .38179 L
s
P
p
.2 0 1 r
.02 w
.69446 .31825 m
.76717 .17554 L
s
P
p
.2 0 1 r
.02 w
.69446 .31825 m
.6694 .16005 L
s
P
p
0 .4 1 r
.018 w
.69028 .34461 m
.71407 .35673 L
s
P
p
0 .4 1 r
.018 w
.69028 .34461 m
.69446 .31825 L
s
P
p
.2 0 1 r
.02 w
.2702 .4561 m
.19748 .31339 L
s
P
p
.2 0 1 r
.02 w
.2702 .4561 m
.12748 .38338 L
s
P
p
.2 0 1 r
.02 w
.27695 .49876 m
.1637 .61202 L
s
P
p
.2 0 1 r
.02 w
.27695 .49876 m
.2519 .65696 L
s
P
p
0 .4 1 r
.018 w
.28907 .47497 m
.2702 .4561 L
s
P
p
0 .4 1 r
.018 w
.28907 .47497 m
.27695 .49876 L
s
P
p
.2 0 1 r
.02 w
.72305 .49876 m
.7481 .65696 L
s
P
p
.2 0 1 r
.02 w
.72305 .49876 m
.8363 .61202 L
s
P
p
.2 0 1 r
.02 w
.7298 .4561 m
.87252 .38338 L
s
P
p
.2 0 1 r
.02 w
.7298 .4561 m
.80252 .31339 L
s
P
p
0 .4 1 r
.018 w
.71093 .47497 m
.72305 .49876 L
s
P
p
0 .4 1 r
.018 w
.71093 .47497 m
.7298 .4561 L
s
P
p
.2 0 1 r
.02 w
.30554 .31825 m
.3306 .16005 L
s
P
p
.2 0 1 r
.02 w
.30554 .31825 m
.23283 .17554 L
s
P
p
.2 0 1 r
.02 w
.28593 .35673 m
.12774 .38179 L
s
P
p
.2 0 1 r
.02 w
.28593 .35673 m
.17268 .46999 L
s
P
p
0 .4 1 r
.018 w
.30972 .34461 m
.30554 .31825 L
s
P
p
0 .4 1 r
.018 w
.30972 .34461 m
.28593 .35673 L
s
P
p
.2 0 1 r
.016 w
.5 .44157 m
.69028 .34461 L
s
P
p
.2 0 1 r
.016 w
.5 .44157 m
.28907 .47497 L
s
P
p
.2 0 1 r
.016 w
.5 .44157 m
.71093 .47497 L
s
P
p
.2 0 1 r
.016 w
.5 .44157 m
.30972 .34461 L
s
P
p
.2 0 1 r
.02 w
.70177 .22162 m
.85997 .24667 L
s
P
p
.2 0 1 r
.02 w
.70177 .22162 m
.84448 .1489 L
s
P
p
.2 0 1 r
.02 w
.66329 .20201 m
.63823 .04381 L
s
P
p
.2 0 1 r
.02 w
.66329 .20201 m
.55003 .08875 L
s
P
p
0 .4 1 r
.018 w
.67541 .22579 m
.70177 .22162 L
s
P
p
0 .4 1 r
.018 w
.67541 .22579 m
.66329 .20201 L
s
P
p
.2 0 1 r
.02 w
.40108 .56291 m
.25837 .49019 L
s
P
p
.2 0 1 r
.02 w
.40108 .56291 m
.24288 .58796 L
s
P
p
.2 0 1 r
.02 w
.43162 .59345 m
.40657 .75165 L
s
P
p
.2 0 1 r
.02 w
.43162 .59345 m
.50434 .73616 L
s
P
p
0 .4 1 r
.018 w
.42745 .56708 m
.40108 .56291 L
s
P
p
0 .4 1 r
.018 w
.42745 .56708 m
.43162 .59345 L
s
P
p
.2 0 1 r
.02 w
.79252 .33124 m
.90578 .4445 L
s
P
p
.2 0 1 r
.02 w
.79252 .33124 m
.95072 .3563 L
s
P
p
.2 0 1 r
.02 w
.77291 .29276 m
.84563 .15004 L
s
P
p
.2 0 1 r
.02 w
.77291 .29276 m
.74786 .13456 L
s
P
p
0 .4 1 r
.018 w
.76874 .31912 m
.79252 .33124 L
s
P
p
0 .4 1 r
.018 w
.76874 .31912 m
.77291 .29276 L
s
P
p
.2 0 1 r
.02 w
.34865 .43061 m
.27593 .2879 L
s
P
p
.2 0 1 r
.02 w
.34865 .43061 m
.20594 .35789 L
s
P
p
.2 0 1 r
.02 w
.35541 .47327 m
.24215 .58652 L
s
P
p
.2 0 1 r
.02 w
.35541 .47327 m
.33035 .63146 L
s
P
p
0 .4 1 r
.018 w
.36753 .44948 m
.34865 .43061 L
s
P
p
0 .4 1 r
.018 w
.36753 .44948 m
.35541 .47327 L
s
P
p
.2 0 1 r
.016 w
.57845 .41608 m
.67541 .22579 L
s
P
p
.2 0 1 r
.016 w
.57845 .41608 m
.42745 .56708 L
s
P
p
.2 0 1 r
.016 w
.57845 .41608 m
.76874 .31912 L
s
P
p
.2 0 1 r
.016 w
.57845 .41608 m
.36753 .44948 L
s
P
p
1 .6 0 r
.016 w
.5 .30809 m
.42155 .41608 L
s
P
p
1 .6 0 r
.016 w
.5 .30809 m
.5 .44157 L
s
P
p
1 .6 0 r
.016 w
.5 .30809 m
.57845 .41608 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0473091 0.952381 [
[ 0 0 0 0 ]
[ 1 .85776 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85776 L
0 .85776 L
closepath
clip
newpath
p
P
p
1 .6 0 r
.016 w
.5 .05677 m
.06256 .65886 L
s
P
p
1 .6 0 r
.016 w
.5 .05677 m
.5 .80099 L
s
P
p
1 .6 0 r
.016 w
.5 .05677 m
.93744 .65886 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0534067 0.952381 [
[ 0 0 0 0 ]
[ 1 .84557 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .84557 L
0 .84557 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.58697 .56416 m
.56293 .71593 L
s
P
p
.2 0 1 r
.02 w
.58697 .56416 m
.65673 .70107 L
s
P
p
.2 0 1 r
.02 w
.62459 .49031 m
.77636 .46627 L
s
P
p
.2 0 1 r
.02 w
.62459 .49031 m
.73325 .38166 L
s
P
p
0 .4 1 r
.018 w
.57896 .51357 m
.58697 .56416 L
s
P
p
0 .4 1 r
.018 w
.57896 .51357 m
.62459 .49031 L
s
P
p
.2 0 1 r
.02 w
.25954 .22509 m
.3293 .08817 L
s
P
p
.2 0 1 r
.02 w
.25954 .22509 m
.2355 .07332 L
s
P
p
.2 0 1 r
.02 w
.20094 .28369 m
.04917 .25965 L
s
P
p
.2 0 1 r
.02 w
.20094 .28369 m
.06403 .35345 L
s
P
p
0 .4 1 r
.018 w
.25153 .27568 m
.25954 .22509 L
s
P
p
0 .4 1 r
.018 w
.25153 .27568 m
.20094 .28369 L
s
P
p
.2 0 1 r
.02 w
.46617 .64874 m
.35751 .7574 L
s
P
p
.2 0 1 r
.02 w
.46617 .64874 m
.44213 .80051 L
s
P
p
.2 0 1 r
.02 w
.54001 .61112 m
.67692 .68088 L
s
P
p
.2 0 1 r
.02 w
.54001 .61112 m
.69178 .58708 L
s
P
p
0 .4 1 r
.018 w
.48942 .6031 m
.46617 .64874 L
s
P
p
0 .4 1 r
.018 w
.48942 .6031 m
.54001 .61112 L
s
P
p
.2 0 1 r
.02 w
.40057 .18197 m
.53749 .11221 L
s
P
p
.2 0 1 r
.02 w
.40057 .18197 m
.47033 .04506 L
s
P
p
.2 0 1 r
.02 w
.31871 .19494 m
.21006 .08628 L
s
P
p
.2 0 1 r
.02 w
.31871 .19494 m
.16694 .1709 L
s
P
p
0 .4 1 r
.018 w
.36435 .21819 m
.40057 .18197 L
s
P
p
0 .4 1 r
.018 w
.36435 .21819 m
.31871 .19494 L
s
P
p
.2 0 1 r
.016 w
.3964 .42055 m
.57896 .51357 L
s
P
p
.2 0 1 r
.016 w
.3964 .42055 m
.25153 .27568 L
s
P
p
.2 0 1 r
.016 w
.3964 .42055 m
.48942 .6031 L
s
P
p
.2 0 1 r
.016 w
.3964 .42055 m
.36435 .21819 L
s
P
p
.2 0 1 r
.02 w
.69901 .47124 m
.76877 .60815 L
s
P
p
.2 0 1 r
.02 w
.69901 .47124 m
.83592 .541 L
s
P
p
.2 0 1 r
.02 w
.68604 .38938 m
.7947 .28072 L
s
P
p
.2 0 1 r
.02 w
.68604 .38938 m
.71008 .23761 L
s
P
p
0 .4 1 r
.018 w
.66279 .43502 m
.69901 .47124 L
s
P
p
0 .4 1 r
.018 w
.66279 .43502 m
.68604 .38938 L
s
P
p
.2 0 1 r
.02 w
.23482 .38938 m
.21078 .23761 L
s
P
p
.2 0 1 r
.02 w
.23482 .38938 m
.12616 .28072 L
s
P
p
.2 0 1 r
.02 w
.22185 .47124 m
.08494 .541 L
s
P
p
.2 0 1 r
.02 w
.22185 .47124 m
.15209 .60815 L
s
P
p
0 .4 1 r
.018 w
.25807 .43502 m
.23482 .38938 L
s
P
p
0 .4 1 r
.018 w
.25807 .43502 m
.22185 .47124 L
s
P
p
.2 0 1 r
.02 w
.65099 .61067 m
.62696 .76244 L
s
P
p
.2 0 1 r
.02 w
.65099 .61067 m
.72076 .74759 L
s
P
p
.2 0 1 r
.02 w
.68862 .53683 m
.84039 .51279 L
s
P
p
.2 0 1 r
.02 w
.68862 .53683 m
.79728 .42817 L
s
P
p
0 .4 1 r
.018 w
.64298 .56008 m
.65099 .61067 L
s
P
p
0 .4 1 r
.018 w
.64298 .56008 m
.68862 .53683 L
s
P
p
.2 0 1 r
.02 w
.32357 .2716 m
.39333 .13469 L
s
P
p
.2 0 1 r
.02 w
.32357 .2716 m
.29953 .11983 L
s
P
p
.2 0 1 r
.02 w
.26497 .33021 m
.11319 .30617 L
s
P
p
.2 0 1 r
.02 w
.26497 .33021 m
.12805 .39997 L
s
P
p
0 .4 1 r
.018 w
.31556 .32219 m
.32357 .2716 L
s
P
p
0 .4 1 r
.018 w
.31556 .32219 m
.26497 .33021 L
s
P
p
.2 0 1 r
.016 w
.46043 .46707 m
.66279 .43502 L
s
P
p
.2 0 1 r
.016 w
.46043 .46707 m
.25807 .43502 L
s
P
p
.2 0 1 r
.016 w
.46043 .46707 m
.64298 .56008 L
s
P
p
.2 0 1 r
.016 w
.46043 .46707 m
.31556 .32219 L
s
P
p
.2 0 1 r
.02 w
.73503 .33021 m
.87195 .39997 L
s
P
p
.2 0 1 r
.02 w
.73503 .33021 m
.88681 .30617 L
s
P
p
.2 0 1 r
.02 w
.67643 .2716 m
.70047 .11983 L
s
P
p
.2 0 1 r
.02 w
.67643 .2716 m
.60667 .13469 L
s
P
p
0 .4 1 r
.018 w
.68444 .32219 m
.73503 .33021 L
s
P
p
0 .4 1 r
.018 w
.68444 .32219 m
.67643 .2716 L
s
P
p
.2 0 1 r
.02 w
.31138 .53683 m
.20272 .42817 L
s
P
p
.2 0 1 r
.02 w
.31138 .53683 m
.15961 .51279 L
s
P
p
.2 0 1 r
.02 w
.34901 .61067 m
.27924 .74759 L
s
P
p
.2 0 1 r
.02 w
.34901 .61067 m
.37304 .76244 L
s
P
p
0 .4 1 r
.018 w
.35702 .56008 m
.31138 .53683 L
s
P
p
0 .4 1 r
.018 w
.35702 .56008 m
.34901 .61067 L
s
P
p
.2 0 1 r
.02 w
.77815 .47124 m
.84791 .60815 L
s
P
p
.2 0 1 r
.02 w
.77815 .47124 m
.91506 .541 L
s
P
p
.2 0 1 r
.02 w
.76518 .38938 m
.87384 .28072 L
s
P
p
.2 0 1 r
.02 w
.76518 .38938 m
.78922 .23761 L
s
P
p
0 .4 1 r
.018 w
.74193 .43502 m
.77815 .47124 L
s
P
p
0 .4 1 r
.018 w
.74193 .43502 m
.76518 .38938 L
s
P
p
.2 0 1 r
.02 w
.31396 .38938 m
.28992 .23761 L
s
P
p
.2 0 1 r
.02 w
.31396 .38938 m
.2053 .28072 L
s
P
p
.2 0 1 r
.02 w
.30099 .47124 m
.16408 .541 L
s
P
p
.2 0 1 r
.02 w
.30099 .47124 m
.23123 .60815 L
s
P
p
0 .4 1 r
.018 w
.33721 .43502 m
.31396 .38938 L
s
P
p
0 .4 1 r
.018 w
.33721 .43502 m
.30099 .47124 L
s
P
p
.2 0 1 r
.016 w
.53957 .46707 m
.68444 .32219 L
s
P
p
.2 0 1 r
.016 w
.53957 .46707 m
.35702 .56008 L
s
P
p
.2 0 1 r
.016 w
.53957 .46707 m
.74193 .43502 L
s
P
p
.2 0 1 r
.016 w
.53957 .46707 m
.33721 .43502 L
s
P
p
.2 0 1 r
.02 w
.68129 .19494 m
.83306 .1709 L
s
P
p
.2 0 1 r
.02 w
.68129 .19494 m
.78994 .08628 L
s
P
p
.2 0 1 r
.02 w
.59943 .18197 m
.52967 .04506 L
s
P
p
.2 0 1 r
.02 w
.59943 .18197 m
.46251 .11221 L
s
P
p
0 .4 1 r
.018 w
.63565 .21819 m
.68129 .19494 L
s
P
p
0 .4 1 r
.018 w
.63565 .21819 m
.59943 .18197 L
s
P
p
.2 0 1 r
.02 w
.45999 .61112 m
.30822 .58708 L
s
P
p
.2 0 1 r
.02 w
.45999 .61112 m
.32308 .68088 L
s
P
p
.2 0 1 r
.02 w
.53383 .64874 m
.55787 .80051 L
s
P
p
.2 0 1 r
.02 w
.53383 .64874 m
.64249 .7574 L
s
P
p
0 .4 1 r
.018 w
.51058 .6031 m
.45999 .61112 L
s
P
p
0 .4 1 r
.018 w
.51058 .6031 m
.53383 .64874 L
s
P
p
.2 0 1 r
.02 w
.79906 .28369 m
.93597 .35345 L
s
P
p
.2 0 1 r
.02 w
.79906 .28369 m
.95083 .25965 L
s
P
p
.2 0 1 r
.02 w
.74046 .22509 m
.7645 .07332 L
s
P
p
.2 0 1 r
.02 w
.74046 .22509 m
.6707 .08817 L
s
P
p
0 .4 1 r
.018 w
.74847 .27568 m
.79906 .28369 L
s
P
p
0 .4 1 r
.018 w
.74847 .27568 m
.74046 .22509 L
s
P
p
.2 0 1 r
.02 w
.37541 .49031 m
.26675 .38166 L
s
P
p
.2 0 1 r
.02 w
.37541 .49031 m
.22364 .46627 L
s
P
p
.2 0 1 r
.02 w
.41303 .56416 m
.34327 .70107 L
s
P
p
.2 0 1 r
.02 w
.41303 .56416 m
.43707 .71593 L
s
P
p
0 .4 1 r
.018 w
.42104 .51357 m
.37541 .49031 L
s
P
p
0 .4 1 r
.018 w
.42104 .51357 m
.41303 .56416 L
s
P
p
.2 0 1 r
.016 w
.6036 .42055 m
.63565 .21819 L
s
P
p
.2 0 1 r
.016 w
.6036 .42055 m
.51058 .6031 L
s
P
p
.2 0 1 r
.016 w
.6036 .42055 m
.74847 .27568 L
s
P
p
.2 0 1 r
.016 w
.6036 .42055 m
.42104 .51357 L
s
P
p
1 .6 0 r
.016 w
.5 .34528 m
.3964 .42055 L
s
P
p
1 .6 0 r
.016 w
.5 .34528 m
.46043 .46707 L
s
P
p
1 .6 0 r
.016 w
.5 .34528 m
.53957 .46707 L
s
P
p
1 .6 0 r
.016 w
.5 .34528 m
.6036 .42055 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0837567 0.952381 [
[ 0 0 0 0 ]
[ 1 .78487 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78487 L
0 .78487 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.79178 .57374 L
s
P
p
.2 0 1 r
.02 w
.71605 .42511 m
.86468 .50084 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.81993 .21828 L
s
P
p
.2 0 1 r
.02 w
.70197 .33624 m
.72807 .17148 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.71605 .42511 L
s
P
p
0 .4 1 r
.018 w
.67673 .38579 m
.70197 .33624 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.18602 .17148 L
s
P
p
.2 0 1 r
.02 w
.21211 .33624 m
.09415 .21828 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.0494 .50084 L
s
P
p
.2 0 1 r
.02 w
.19804 .42511 m
.1223 .57374 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.21211 .33624 L
s
P
p
0 .4 1 r
.018 w
.23736 .38579 m
.19804 .42511 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.63783 .74125 L
s
P
p
.2 0 1 r
.02 w
.66392 .57648 m
.73966 .72512 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.86953 .47022 L
s
P
p
.2 0 1 r
.02 w
.70477 .49632 m
.82273 .37836 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.66392 .57648 L
s
P
p
0 .4 1 r
.018 w
.65522 .52156 m
.70477 .49632 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.3842 .05975 L
s
P
p
.2 0 1 r
.02 w
.30846 .20838 m
.28237 .04362 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.08008 .24591 L
s
P
p
.2 0 1 r
.02 w
.24484 .272 m
.09621 .34774 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.30846 .20838 L
s
P
p
0 .4 1 r
.018 w
.29976 .26331 m
.24484 .272 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.67673 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.23736 .38579 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.65522 .52156 L
s
P
p
.2 0 1 r
.016 w
.45704 .42058 m
.29976 .26331 L
s
P
p
.2 0 1 r
.02 w
.74773 .35165 m
.86569 .46961 L
s
P
p
.2 0 1 r
.02 w
.74773 .35165 m
.91249 .37775 L
s
P
p
.2 0 1 r
.02 w
.70688 .27149 m
.78261 .12285 L
s
P
p
.2 0 1 r
.02 w
.70688 .27149 m
.68078 .10672 L
s
P
p
0 .4 1 r
.018 w
.69818 .32641 m
.74773 .35165 L
s
P
p
0 .4 1 r
.018 w
.69818 .32641 m
.70688 .27149 L
s
P
p
.2 0 1 r
.02 w
.24099 .42286 m
.16526 .27423 L
s
P
p
.2 0 1 r
.02 w
.24099 .42286 m
.09236 .34713 L
s
P
p
.2 0 1 r
.02 w
.25507 .51173 m
.13711 .62969 L
s
P
p
.2 0 1 r
.02 w
.25507 .51173 m
.22897 .67649 L
s
P
p
0 .4 1 r
.018 w
.28031 .46218 m
.24099 .42286 L
s
P
p
0 .4 1 r
.018 w
.28031 .46218 m
.25507 .51173 L
s
P
p
.2 0 1 r
.02 w
.74493 .51173 m
.77103 .67649 L
s
P
p
.2 0 1 r
.02 w
.74493 .51173 m
.86289 .62969 L
s
P
p
.2 0 1 r
.02 w
.75901 .42286 m
.90764 .34713 L
s
P
p
.2 0 1 r
.02 w
.75901 .42286 m
.83474 .27423 L
s
P
p
0 .4 1 r
.018 w
.71969 .46218 m
.74493 .51173 L
s
P
p
0 .4 1 r
.018 w
.71969 .46218 m
.75901 .42286 L
s
P
p
.2 0 1 r
.02 w
.29312 .27149 m
.31922 .10672 L
s
P
p
.2 0 1 r
.02 w
.29312 .27149 m
.21739 .12285 L
s
P
p
.2 0 1 r
.02 w
.25227 .35165 m
.08751 .37775 L
s
P
p
.2 0 1 r
.02 w
.25227 .35165 m
.13431 .46961 L
s
P
p
0 .4 1 r
.018 w
.30182 .32641 m
.29312 .27149 L
s
P
p
0 .4 1 r
.018 w
.30182 .32641 m
.25227 .35165 L
s
P
p
.2 0 1 r
.016 w
.5 .42739 m
.69818 .32641 L
s
P
p
.2 0 1 r
.016 w
.5 .42739 m
.28031 .46218 L
s
P
p
.2 0 1 r
.016 w
.5 .42739 m
.71969 .46218 L
s
P
p
.2 0 1 r
.016 w
.5 .42739 m
.30182 .32641 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.90379 .34774 L
s
P
p
.2 0 1 r
.02 w
.75516 .272 m
.91992 .24591 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.71763 .04362 L
s
P
p
.2 0 1 r
.02 w
.69154 .20838 m
.6158 .05975 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.75516 .272 L
s
P
p
0 .4 1 r
.018 w
.70024 .26331 m
.69154 .20838 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.17727 .37836 L
s
P
p
.2 0 1 r
.02 w
.29523 .49632 m
.13047 .47022 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.26034 .72512 L
s
P
p
.2 0 1 r
.02 w
.33608 .57648 m
.36217 .74125 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.29523 .49632 L
s
P
p
0 .4 1 r
.018 w
.34478 .52156 m
.33608 .57648 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.8777 .57374 L
s
P
p
.2 0 1 r
.02 w
.80196 .42511 m
.9506 .50084 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.90585 .21828 L
s
P
p
.2 0 1 r
.02 w
.78789 .33624 m
.81398 .17148 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.80196 .42511 L
s
P
p
0 .4 1 r
.018 w
.76264 .38579 m
.78789 .33624 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.27193 .17148 L
s
P
p
.2 0 1 r
.02 w
.29803 .33624 m
.18007 .21828 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.13532 .50084 L
s
P
p
.2 0 1 r
.02 w
.28395 .42511 m
.20822 .57374 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.29803 .33624 L
s
P
p
0 .4 1 r
.018 w
.32327 .38579 m
.28395 .42511 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.70024 .26331 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.34478 .52156 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.76264 .38579 L
s
P
p
.2 0 1 r
.016 w
.54296 .42058 m
.32327 .38579 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.45704 .42058 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.5 .42739 L
s
P
p
1 .6 0 r
.016 w
.5 .28837 m
.54296 .42058 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0842144 0.952381 [
[ 0 0 0 0 ]
[ 1 .78395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78395 L
0 .78395 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.62973 .48216 m
.65278 .62769 L
s
P
p
.2 0 1 r
.02 w
.62973 .48216 m
.73392 .58635 L
s
P
p
.2 0 1 r
.02 w
.64216 .40367 m
.77345 .33678 L
s
P
p
.2 0 1 r
.02 w
.64216 .40367 m
.70905 .27239 L
s
P
p
0 .4 1 r
.018 w
.60743 .4384 m
.62973 .48216 L
s
P
p
0 .4 1 r
.018 w
.60743 .4384 m
.64216 .40367 L
s
P
p
.2 0 1 r
.02 w
.23067 .26997 m
.25371 .12444 L
s
P
p
.2 0 1 r
.02 w
.23067 .26997 m
.16377 .13868 L
s
P
p
.2 0 1 r
.02 w
.19459 .34077 m
.04906 .36382 L
s
P
p
.2 0 1 r
.02 w
.19459 .34077 m
.0904 .44496 L
s
P
p
0 .4 1 r
.018 w
.23835 .31848 m
.23067 .26997 L
s
P
p
0 .4 1 r
.018 w
.23835 .31848 m
.19459 .34077 L
s
P
p
.2 0 1 r
.02 w
.54463 .59509 m
.47773 .72638 L
s
P
p
.2 0 1 r
.02 w
.54463 .59509 m
.56768 .74062 L
s
P
p
.2 0 1 r
.02 w
.60082 .5389 m
.74635 .56195 L
s
P
p
.2 0 1 r
.02 w
.60082 .5389 m
.7321 .47201 L
s
P
p
0 .4 1 r
.018 w
.55231 .54658 m
.54463 .59509 L
s
P
p
0 .4 1 r
.018 w
.55231 .54658 m
.60082 .5389 L
s
P
p
.2 0 1 r
.02 w
.3465 .18886 m
.45069 .08467 L
s
P
p
.2 0 1 r
.02 w
.3465 .18886 m
.36955 .04333 L
s
P
p
.2 0 1 r
.02 w
.27569 .22494 m
.14441 .15805 L
s
P
p
.2 0 1 r
.02 w
.27569 .22494 m
.13016 .24799 L
s
P
p
0 .4 1 r
.018 w
.3242 .23262 m
.3465 .18886 L
s
P
p
0 .4 1 r
.018 w
.3242 .23262 m
.27569 .22494 L
s
P
p
.2 0 1 r
.016 w
.41339 .40767 m
.60743 .4384 L
s
P
p
.2 0 1 r
.016 w
.41339 .40767 m
.23835 .31848 L
s
P
p
.2 0 1 r
.016 w
.41339 .40767 m
.55231 .54658 L
s
P
p
.2 0 1 r
.016 w
.41339 .40767 m
.3242 .23262 L
s
P
p
.2 0 1 r
.02 w
.71881 .36891 m
.82299 .4731 L
s
P
p
.2 0 1 r
.02 w
.71881 .36891 m
.86434 .39196 L
s
P
p
.2 0 1 r
.02 w
.68273 .29811 m
.74962 .16682 L
s
P
p
.2 0 1 r
.02 w
.68273 .29811 m
.65968 .15258 L
s
P
p
0 .4 1 r
.018 w
.67505 .34662 m
.71881 .36891 L
s
P
p
0 .4 1 r
.018 w
.67505 .34662 m
.68273 .29811 L
s
P
p
.2 0 1 r
.02 w
.27123 .43181 m
.20434 .30053 L
s
P
p
.2 0 1 r
.02 w
.27123 .43181 m
.13995 .36492 L
s
P
p
.2 0 1 r
.02 w
.28366 .5103 m
.17948 .61449 L
s
P
p
.2 0 1 r
.02 w
.28366 .5103 m
.26061 .65583 L
s
P
p
0 .4 1 r
.018 w
.30596 .46654 m
.27123 .43181 L
s
P
p
0 .4 1 r
.018 w
.30596 .46654 m
.28366 .5103 L
s
P
p
.2 0 1 r
.02 w
.71634 .5103 m
.73939 .65583 L
s
P
p
.2 0 1 r
.02 w
.71634 .5103 m
.82052 .61449 L
s
P
p
.2 0 1 r
.02 w
.72877 .43181 m
.86005 .36492 L
s
P
p
.2 0 1 r
.02 w
.72877 .43181 m
.79566 .30053 L
s
P
p
0 .4 1 r
.018 w
.69404 .46654 m
.71634 .5103 L
s
P
p
0 .4 1 r
.018 w
.69404 .46654 m
.72877 .43181 L
s
P
p
.2 0 1 r
.02 w
.31727 .29811 m
.34032 .15258 L
s
P
p
.2 0 1 r
.02 w
.31727 .29811 m
.25038 .16682 L
s
P
p
.2 0 1 r
.02 w
.28119 .36891 m
.13566 .39196 L
s
P
p
.2 0 1 r
.02 w
.28119 .36891 m
.17701 .4731 L
s
P
p
0 .4 1 r
.018 w
.32495 .34662 m
.31727 .29811 L
s
P
p
0 .4 1 r
.018 w
.32495 .34662 m
.28119 .36891 L
s
P
p
.2 0 1 r
.016 w
.5 .43581 m
.67505 .34662 L
s
P
p
.2 0 1 r
.016 w
.5 .43581 m
.30596 .46654 L
s
P
p
.2 0 1 r
.016 w
.5 .43581 m
.69404 .46654 L
s
P
p
.2 0 1 r
.016 w
.5 .43581 m
.32495 .34662 L
s
P
p
.2 0 1 r
.02 w
.72431 .22494 m
.86984 .24799 L
s
P
p
.2 0 1 r
.02 w
.72431 .22494 m
.85559 .15805 L
s
P
p
.2 0 1 r
.02 w
.6535 .18886 m
.63045 .04333 L
s
P
p
.2 0 1 r
.02 w
.6535 .18886 m
.54931 .08467 L
s
P
p
0 .4 1 r
.018 w
.6758 .23262 m
.72431 .22494 L
s
P
p
0 .4 1 r
.018 w
.6758 .23262 m
.6535 .18886 L
s
P
p
.2 0 1 r
.02 w
.39918 .5389 m
.2679 .47201 L
s
P
p
.2 0 1 r
.02 w
.39918 .5389 m
.25365 .56195 L
s
P
p
.2 0 1 r
.02 w
.45537 .59509 m
.43232 .74062 L
s
P
p
.2 0 1 r
.02 w
.45537 .59509 m
.52227 .72638 L
s
P
p
0 .4 1 r
.018 w
.44769 .54658 m
.39918 .5389 L
s
P
p
0 .4 1 r
.018 w
.44769 .54658 m
.45537 .59509 L
s
P
p
.2 0 1 r
.02 w
.80541 .34077 m
.9096 .44496 L
s
P
p
.2 0 1 r
.02 w
.80541 .34077 m
.95094 .36382 L
s
P
p
.2 0 1 r
.02 w
.76933 .26997 m
.83623 .13868 L
s
P
p
.2 0 1 r
.02 w
.76933 .26997 m
.74629 .12444 L
s
P
p
0 .4 1 r
.018 w
.76165 .31848 m
.80541 .34077 L
s
P
p
0 .4 1 r
.018 w
.76165 .31848 m
.76933 .26997 L
s
P
p
.2 0 1 r
.02 w
.35784 .40367 m
.29095 .27239 L
s
P
p
.2 0 1 r
.02 w
.35784 .40367 m
.22655 .33678 L
s
P
p
.2 0 1 r
.02 w
.37027 .48216 m
.26608 .58635 L
s
P
p
.2 0 1 r
.02 w
.37027 .48216 m
.34722 .62769 L
s
P
p
0 .4 1 r
.018 w
.39257 .4384 m
.35784 .40367 L
s
P
p
0 .4 1 r
.018 w
.39257 .4384 m
.37027 .48216 L
s
P
p
.2 0 1 r
.016 w
.58661 .40767 m
.6758 .23262 L
s
P
p
.2 0 1 r
.016 w
.58661 .40767 m
.44769 .54658 L
s
P
p
.2 0 1 r
.016 w
.58661 .40767 m
.76165 .31848 L
s
P
p
.2 0 1 r
.016 w
.58661 .40767 m
.39257 .4384 L
s
P
p
1 .6 0 r
.016 w
.5 .28846 m
.41339 .40767 L
s
P
p
1 .6 0 r
.016 w
.5 .28846 m
.5 .43581 L
s
P
p
1 .6 0 r
.016 w
.5 .28846 m
.58661 .40767 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0720399 0.952381 [
[ 0 0 0 0 ]
[ 1 .8083 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8083 L
0 .8083 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.67271 .64761 L
s
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.75652 .60491 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.79734 .34714 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.73084 .28063 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.6489 .4973 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.66174 .41623 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.26053 .12782 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.16763 .14253 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.04914 .37507 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.09184 .45888 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.23672 .27813 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.19946 .35126 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.49191 .74954 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.58481 .76426 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.76936 .57971 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.75464 .48681 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.561 .61394 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.61904 .5559 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.46398 .08674 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.38017 .04404 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.14763 .16253 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.13292 .25543 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.35636 .19436 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.28323 .23162 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.62587 .4521 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.24466 .32823 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.56894 .56384 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.33333 .23956 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.83361 .4831 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.87631 .39929 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.75783 .16675 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.66493 .15204 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.726 .37549 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.68874 .30235 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.19462 .30485 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.12811 .37136 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.16894 .62913 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.25274 .67183 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.26371 .44045 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.27655 .52152 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.74726 .67183 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.83106 .62913 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.87189 .37136 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.80538 .30485 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.72345 .52152 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.73629 .44045 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.33507 .15204 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.24217 .16675 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.12369 .39929 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.16639 .4831 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.31126 .30235 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.274 .37549 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.6808 .35246 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.29958 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.70042 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.3192 .35246 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.86708 .25543 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.85237 .16253 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.61983 .04404 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.53602 .08674 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.71677 .23162 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.64364 .19436 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.24536 .48681 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.23064 .57971 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.41519 .76426 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.50809 .74954 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.38096 .5559 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.439 .61394 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.90816 .45888 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.95086 .37507 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.83237 .14253 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.73947 .12782 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.80054 .35126 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.76328 .27813 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.26916 .28063 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.20266 .34714 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.24348 .60491 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.32729 .64761 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.33826 .41623 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.3511 .4973 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.66667 .23956 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.43106 .56384 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.75534 .32823 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.37413 .4521 L
s
P
p
1 .6 0 r
.014 w
.5 .31775 m
.42546 .42036 L
s
P
p
1 .6 0 r
.014 w
.5 .31775 m
.5 .44458 L
s
P
p
1 .6 0 r
.014 w
.5 .31775 m
.57454 .42036 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0720399 0.952381 [
[ 0 0 0 0 ]
[ 1 .8083 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8083 L
0 .8083 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.67271 .64761 L
s
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.75652 .60491 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.79734 .34714 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.73084 .28063 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.6489 .4973 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.66174 .41623 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.26053 .12782 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.16763 .14253 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.04914 .37507 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.09184 .45888 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.23672 .27813 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.19946 .35126 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.49191 .74954 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.58481 .76426 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.76936 .57971 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.75464 .48681 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.561 .61394 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.61904 .5559 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.46398 .08674 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.38017 .04404 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.14763 .16253 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.13292 .25543 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.35636 .19436 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.28323 .23162 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.62587 .4521 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.24466 .32823 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.56894 .56384 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.33333 .23956 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.83361 .4831 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.87631 .39929 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.75783 .16675 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.66493 .15204 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.726 .37549 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.68874 .30235 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.19462 .30485 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.12811 .37136 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.16894 .62913 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.25274 .67183 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.26371 .44045 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.27655 .52152 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.74726 .67183 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.83106 .62913 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.87189 .37136 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.80538 .30485 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.72345 .52152 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.73629 .44045 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.33507 .15204 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.24217 .16675 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.12369 .39929 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.16639 .4831 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.31126 .30235 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.274 .37549 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.6808 .35246 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.29958 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.70042 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.3192 .35246 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.86708 .25543 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.85237 .16253 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.61983 .04404 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.53602 .08674 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.71677 .23162 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.64364 .19436 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.24536 .48681 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.23064 .57971 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.41519 .76426 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.50809 .74954 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.38096 .5559 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.439 .61394 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.90816 .45888 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.95086 .37507 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.83237 .14253 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.73947 .12782 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.80054 .35126 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.76328 .27813 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.26916 .28063 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.20266 .34714 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.24348 .60491 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.32729 .64761 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.33826 .41623 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.3511 .4973 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.66667 .23956 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.43106 .56384 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.75534 .32823 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.37413 .4521 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.42546 .42036 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.5 .44458 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.57454 .42036 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0492176 0.952381 [
[ 0 0 0 0 ]
[ 1 .85395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85395 L
0 .85395 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.24108 .70023 L
s
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.29606 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.55565 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.61064 .70023 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.38504 .65346 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.46668 .65346 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.68758 .21443 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.65867 .12546 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.41179 .04525 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.33611 .10023 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.53621 .21443 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.45857 .18921 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .53848 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .63203 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.32282 .78461 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.41179 .7557 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.25677 .58525 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.32282 .63324 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.75958 .40791 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.78849 .31894 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.63591 .10893 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.54236 .10893 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.63712 .31894 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.58914 .25289 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.10412 .33222 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.04913 .40791 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.12934 .65479 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.21832 .6837 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.19309 .45468 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.21832 .53233 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.42586 .6238 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.48822 .23003 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.30723 .58525 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.58914 .30334 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.23391 .48434 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.51407 .77979 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.60304 .8087 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .65612 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .56257 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.60304 .65733 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.66909 .60934 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.58975 .12432 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.51407 .06934 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.26719 .14955 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.23828 .23853 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.46729 .2133 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.38965 .23853 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.31522 .72432 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.37021 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.62979 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.68478 .72432 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.45918 .67755 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.54082 .67755 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.76172 .23853 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.73281 .14955 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.48593 .06934 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.41025 .12432 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.61035 .23853 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.53271 .2133 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .56257 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .65612 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.39696 .8087 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.48593 .77979 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.33091 .60934 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.39696 .65733 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.61863 .60934 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.43763 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.5 .64789 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.56237 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.38137 .60934 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.78168 .6837 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.87066 .65479 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.95087 .40791 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.89588 .33222 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.78168 .53233 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.80691 .45468 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.45764 .10893 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.36409 .10893 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.21151 .31894 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.24042 .40791 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.41086 .25289 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.36288 .31894 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.58821 .7557 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.67718 .78461 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .63203 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .53848 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.67718 .63324 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.74323 .58525 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.66389 .10023 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.58821 .04525 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.34133 .12546 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.31242 .21443 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.54143 .18921 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.46379 .21443 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.38936 .70023 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.44435 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.70394 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.75892 .70023 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.53332 .65346 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.61496 .65346 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.76609 .48434 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.41086 .30334 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.69277 .58525 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.51178 .23003 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.57414 .6238 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.42586 .42197 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.5 .44606 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.57414 .42197 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`000:0000==000010000dd0001H00004`000d`000050003C00001P000=<0000
1@000d`0000G0004C000C0<000A<001<60000d`000070003C00001P000=<000010000d`0000H0003
C00000D000=<000060000lH000050003aP000180000C0006C@1=C@1=0P000dd0000H0006C@1=C@1=
0P000dd0000G0004C@00C@<000A=001=60000dd000070003C@0001P000E=04d0C@020003C@0001P0
00E=04e=0002C@0304d001T000G60<K60002aP030<H001<0000?0004C000009<10000d`0C0030003
C000010000A<00000T`40003C01<00<000=<00003P02C0<000A<04`00d`0101<04`3009<4`000d`0
0002C00304a<008000=<00004@0014`004`30005C01<04`00P0014`004`20003C00000h000A<0000
0T`5009<0`000d`0000@0004aP0000;61@02aP<000?600003P0000`00Td0101=0002C@H00dd20004
C@1=C@`00Td0101=0002C@H00dd20004C@1=C@h000==04d01Dd300I=00<0C@003@02C@8000==04d0
0Td500==00@0C@000Td<009=00@0CDd00Td00`1=00020005C@1=C@000Td00`1=C@0<009=00@0C@00
0Td7009=0P0014d0CDd<00;600@0aP000/H700;60P001<H0a/H=0000300014`0C4`20003C00000H0
00C6C0000d`=0004C01<C08000=<00001P02C0800d`<00M<00?6C0001P000dc6C003C00304a<00/0
00M<04`0C01<00P000Q<aP1<04`0C0h00d`0101<C4`500=<00@0C4a<3P0014`0C4`20003C00000L0
00?600000T`00`1<000;0004aP36aP8000?600001`000lH00002aP030<H000`0000=00A=00?6C@00
1`001<I=a/H3C@h000I=04e=04d8009=00@0CDe=3@06C@03aTd000P00/H6C@`014d00`1=00080003
aP1=00==3`03C@0304g600L000?6C@000dd?0006C@1=C@1=2@001/H0CDd0C@h01/H900K63P0000/0
14`0101<C4`900E<00<0C4`02P08C0T024`=00E<2@05C1000T`00lI<C0090003C<K6009<4005C0T0
00=<a/H00d`<00Q<2@000dc6aP05C0X01lH00d`000070003C<K600;600<0a/H0300000h000?604d0
0Td900==00?600004004C@T014d@0003C@1=00==2@03C@03aP1=00d00Td00`36C@02C@T000E=04g6
0002C@/00dd00`36C@02C@T00dd00lH0C@02C@h000C6CDe=2@03C@03aP0001000lH00dd000070004
CLK6aQ00000=0007C<H0C<H0C003000;4@0004`0aTc604`03P000d`0C002C00304`0008000HA0000
C003C00304`000`000Q<04a<04`0C0<000`A0000C0360<I<04`>0006C<I<aP1<0`002Q40001<0<I<
aT`?0007C036C<H0C003000;4@0004`0aTc604`03P001d`0aTc604`00`002a40001<0<I<aP1<00h0
00?60<H00/H00`1<000200064@0004`00lH00`36000=00002`09C@<000@A00001Dd01<I=CDd:00U=
0`0011400009C@P02dd300044@0000E=0/H4C@H014d00lI=C@04C@<000@A00001Dd00lI=C@03C@T0
2Dd200034@0000==00C6CDg60dd:00U=0`0011400005C@;60Td:00G600A=aTe=0`0011400005C@C6
300000T034`01@0A4A4000A<00?6C4`01D`600a<00D04A4A000<C0P000I<04`0C<H4C005014A4@00
24`00`1<000900Y<00D04A4A0004C003aTa<00=<200=C0<A1D`00lI<C005C0H034`01@0A4A4000A<
00?6C4`01D`600W60d`01@0A4A4000A<2<H:00002`05C@8000C6CDe=0a43C@03aP0000E=2P05C@80
14d34@A=0P05C@T024d01<I=CDd34@==00?6CDd01Td900==00D0CDe=aP03C@<A0dd01LI=CDd000==
2P05C@8000_6000ACA5=4Dd0aP0200E=2P05C@8000C6CDe=0a43C@03aP0000E=2P05aP8000C6CDe=
0a43C@03aP0000G6300000/000E<001<aP02000?aP1<4D`AC15<0<H0aP1<008000=<000020000d`0
0003C00@04`0C15<4D`AC01<04`0C08000=<00001P001D`0C4`000=<00h0aP1<4D`AC15<0<H0aP9<
00D0C000C009000CC01<C<H0aP1<4D`AC15<0<H0aP02C00304`000X000I<001<0<H200A<00<AC4`0
0T`20003aP1<008000=<000020004d`004`0aP3604`AC15<4D`0aP000/H014`004`:000CaP00aP36
0<H0C15<4D`AC0360003aP8000?600002P0000X000A=001=0P07C@0304e=00A=0`0014d004d80004
C@00C@<01Td00`1=C@04C@<000A=001=2P000dd00008C@0304e=00I=0P000dd000090003C@0000U=
00<0CDd01dd20003C@0000L000E=001=0004C@06aP00C@1=0P05C@0504d004d0200014d004d300I=
00<0CDd014d30004C@00C@P000C600360`06C@0304e=00A=0`001<H00<H;000030000d`00002C003
0<H000<000=<00000P02aP9<0P000d`0000:0003C00000A<10000d`0000200A<0P000d`000090004
C000C08000=<aP000`000d`0000200;60P0014`004`<0006C00004c610000d`0000200;60`000d`0
000;0003C000008000=<0<H00`001d`000360<H010000d`0000:0003C000009<0/H40003C0000080
0/H2C08000=<00002P000lH00004aP@000=<00000P04aP8000?600002`0000l000A=aTe=0`000dd0
C@03009=00?600004@04C@<000==04d00`03CA801Dd30003C@1=00<000==0<H00TdA009=00<0C@00
0P000dd0C@030004C@36CA8000==aP000Td20003C@1=00800Td00`36C@0C0003aTe=00<000==04d0
0`02C@03aTd001800lH30003C@1=00<01<H@00003P000d`0C002C0;600E<0000C002aPA<4@000d`0
C005C0<01d`?00=<00@0C4a<0/H01D`0001<00;60d`00`1<C00?00E<0/H01D`0001<00;61D`@00I<
00?6C0000P000dc6aP05C14014`2aP05C00004`00/H3C00304`001001/H01D`0001<00G600<0aP00
3P0000d01Dd30005aP000<H00P000dd0C@02C@l01Dd30005C@0004d00P000dd0C@02C@d000A=0000
0dd0101=0<H30004aP1=00==0P000dd0000;00A=00D0C@00aP030005aP00C@0014d>0006C@00C@1=
0P001LH00036008000==04d00P000dd0000=00==00D0C@00aP030004aP0000E=3`03aP050<H00<H0
0`001<H00005aPh0000<0006C000C01<0`001LH00036008000I<001<04`=0006C000C01<0`001D`0
001<008000I<001<04`@00=<00@0C0360P001Dc604`000=<3`001d`0001<04`00P001LH000360080
00=<04`00`000d`0000:0004C000C08000A<001<0`0014`004`20004C000C0d000=<04`00P0014`0
0<H30007aP0004`0C0020003C00000/000?60<H00P001<H00<H30007aP000<H0aP020003aP0000/0
000?0003C@1=00<000E=0000C@020004C@00CA8000==04d00`001Dd0001=008000A=001=4@001dd0
04d0C@000dd01P1=04d0C@8000==000040000dd0C@020005C@0004d00P000dd0C@0C0004C@00C@80
0Td00`1=C@020004C@00CA8000A=001=0P001Dd0001=00<000==04d04P001<H00<H20005aP000<H0
0`000lH0aP0@00003`000d`00003009<00<0C4`01@000d`0000@0003C00000<00T`00`1<C0050003
C000018000=<000014`00`1<C0020003C00001<000=<00000P02C00304a<00@000=<00004@000d`0
00030005C01<04`01@000d`0000@0003C00000<00T`00`1<C0050003C000010000?600000`02aP03
0<K600D000?600003P0001@000M=04d0C@1=01`000M=04d0C@1=01`00dd0101=04dL0004C@00C@80
00==00006P0014d004d20003C@0001X000M=04d0C@1=01`000O60<H0aP3601D0000D0004C000C080
00=<00006P0014`004`20003C00001T000I<001<04`20003C00001T000M<04`0C01<01`000M<04`0
C01<01`000A<001<0P000d`0000J0004aP00aP8000?600004`000:0000==00000`000dd0001I0000
o`030000o`030000o`030000o`030000o`030000o`030000o`030000o`030000o`030000o`030000
``000d`000030003C00003H0000f0003C@0000D000==000060000dd000050003C@0001P000==0000
1@000dd0000E0003C@0000/000==00005P000dd000030003C@0001T000==00001@000dd0000B0000
3P0014`004`;0004C000C1D000I<001<04`20003C00001P000E<04a<0002C00304`001T000E<04a<
0002C00304`001@000=<04`03@000d`0C00F0003C01<009<00<0C0006P000d`0C0030003C01<01@0
000>0004C@00C@/000A=001=4P001Td004d0C@8000A=001=0P000dd0000A0004C@00009=1@02C@<0
00==0000400014d00002C@D00Td30003C@0000l000==04d03@000dd0C@0?0004C@00C@8000==04d0
0`000dd0C@020004C@00CA@000==04d00`000dd0C@0D00003P000d`0C00=0003C01<00l000Q<04a<
04`0C0@000E<04a<0002C00304`000`00T`0101<0002C0L00T`20004C01<C0`00T`0101<0002C0L0
0T`20004C01<C0l000=<04`02`000d`0C00@0004C000C0800T`5009<0P0014`004`=009<00L0C000
C01<00D000=<04`00P0014`0C4`=00003`02C@d00Td>00==00@0CDd00Td600==00@0CDd00Td<0004
C@1=C@8000==00001`000lH00002C@0304d000/000A=04e=0P000dd000070003aP00009=00<0C@00
3`02C@/00Td?009=00@0C@1=0P000dd000050007aP00C@1=0002C@/000==04d00Td00`1=C@07009=
00H0CDe=04d=00003`000lH0000=0003aP0000h014`00`1<00070003aT`000=<3`001T`0C4`0C0T0
00K604a<04`>0006C01<C01<2@001/H0C4`0C0/000=<000010000lH000090003aP0000@000=<0000
2@04C00304c600L000?6C00014`>0006C01<C<I<2@02aPA<3P0000h000==aP003P000lI=000?00E=
2@000dg6aP03C@`024d90003CLK600E=2P07C@03@P0000L000=2a/H01Dd:00==10000dd000070003
C@0000800dd=00E=2@000dg6aP03C@d00dd00`1=C@0;0003C@1=00A=300000h00d`=00=<3@04C004
aTa<C0T00d`00lI<0002C0h000C6C4a<2@03C003aP00010000C6C4a22@00149<C<H?0003C01<00<0
00=<00001`001d`0001<04`02`04C004aTa<C0T00d`00lI<0002C0`00T`00`1<C00;009<00<0C4`0
3P0000T014d01LI=001=00D000<A00000`0014d0CLH5C@/000I=aTg604d3000:4@0004g604g6C@l0
00M=0<I=aP1=00<000/A0000C@36CLH0C@0>0007C@36CLH0@P03000;4@000480aTg604d02P07C@<0
00==00001@001Dd0001=00;614d;00A=00<0C@000P001a40001=0<H00Td00lH0000=0006CLH0CLI=
10000a4000020006CLI=0<I=3P0000/000=<04`00T`20004C000008A0`02C08014`>00A<00@0C000
0Q420003C03600A<3@09C0<000@A00001D`2aP9<2P05C004@Ta2@P<000@A00001D82aP9<3P001Dc6
001<00<000DA0000C00200=<3P02C00304a<009<00D0C0004@020003C01<009<00<0C<H00T`;00Q<
0`000a40000200Q<300000X000==00000P002<H0001=01400Q400`1=00020003aP00008000==0000
1P0;C@030140008A00<0CDd00Td00lI=aP05C@H034d01@0A4A4000A=00?6CDd01Dd600U=0d801@0A
4A4000A200?6CDd01Dd>009=00D0C@004@020004C@1=C@l00Td01`1=CDg6C@000Td01@0A4A40009=
00L0CLI=04d0009=1`03C@0504e=CLH014d01@0A4A40009=00<0CDd00dd2009=2P0000T000=<0000
0P02C0@000HAC00AC1440003aT`000<000=<00001`05C0800/H0215<C15<4Dc60P06C0X01D`20004
aTa<C0<A0d`00lH00005C0X01D`20004aT92@P<A0d800lH00005C1800T`01@0A4A40009<40000d`0
0005C0090<H0015<4D`A008000?604`014`20003C00000H00d`01@1<C4`000=<0Q400d`A0005C080
0T`<00004007C@034De=00E=3`001Td004d0aP<00dd0115=CDd30003aTd0008000==0000200014d0
04d2aP0@0<H0CA5=4DdAC@360<H0C@8000==0000200014d004d2aP0@0<H0@Q524D8A@P360<H0C@80
00==00004P001A5=4DdA01@000I=0000CLH200A=00<ACDd00Td30005aP0004d02P000dd0C@02C@80
00K604dACA42C@034Dg600800dd00`1=000;00003P0014c604`400=<0`0014`0aT`=0005C000C000
1D`01lH0C01<0<H01T`30003C00000H000A<001<0`06C00304a<00A<0`0014`004`80004C000C0<0
1T800`12@P04@P<000A<001<2007C0;614`00a5<C002C0;61d`80004C00000E<00K6001<04`20003
aTa<00=<0`000d`000060004C000C0800T`00lI<C002C00304a<00E<0P0014`004`;00003@05C@;6
00<0C@000P000dd0aP06C@d000==00000P02C@05aP0004d00`02C@05aP0004d03@000dd00002C@;6
10000dd0000200;60Td20003C@0000X000==00000Td2aP@000=200000P02aP9=0P000dd0000<009=
00C6CDe=0P000dd0C@0200==0/H2C@h000I=0000CLH40003C@00008000?6CLH00P000dd0000>009=
00<0C@000`000dd000020004C@36CA00000<0004C000C0@000=<00000`000d`000020004C000C100
00_6C4a<aP1<04`0aP03C003aP00014000A<aTa<0`000d`0C003009<00?600004@0014c6C4`30003
@P1200<00T`00lI<000>009<2@000d`00007009<40000lH0C0030003C01<00<000=<0<H04`05C080
00=<04`00P05C100000;0004C@00C@D000?600000`000lH000020005C@0004d03@04C@0404d0C@<0
00A=04d00ddA0003C@1=009=0/H01Dd0001=00;614dA0003C@1=009=0/H01D80001200;60dd00`1=
000<0003C@0000P000==04d02P000dd0000;00E=0/H01Dd0001=00;61Dd@0004C@1=009=00?6C@00
0P000dg6C@03C@0304d000h0000>0003C00000<000?600000`000lH000020003C00000l000E<04`0
C0020004aP00aP<000E<04`0C00?00E<0`001LH00036008000=<04`00T`?00E<0`001LH000360080
00=<04`00d`F0005C00004`06004C08000G60000aP020004C01<C10000=<04`00d`20005aP000<H0
0P001T`0C4`0C0h0000>0003C@0000<000==00000`000dd000030003C@0000d000==04d00P0014d0
04d20006C@0004d00Td00`1=000<0006C@00C@1=0`001LH00036008000I=001=04d=0006C@00C@1=
0`001LH00036008000A=001=0P000dd0000A0003CLH000@000?6C@0050001Dd0C@1=008000G60000
aP020003C@1=009=3P0014d004d20004C@00C@<000A=001=0P0014d004d=00004`02C0@00T`G0004
C000C08014`30003C01<01<000=<04`00`001D`0001<008000A<001<4P000d`0C0030005C00004`0
0P0014`004`C00=<00<0C00010000d`0C002C14000I<001<04`20005C00004`00P000d`0C0020003
C00000h000=<00000`02C00304a<00D000=<00003P0001<000==04d00`000dd0C@0F0003C@0000<0
00E=04d0C@040003C@00014000==00000`02C@0304e=00D000==000040000dd00003009=00<0CDd0
1@000dd0000@0005C@0004d01`001Dd0001=01<000==00000P02C@0304e=00@000==00005P001dd0
C@1=04d05@00018000A<001<0P0014`004`L0005C01<04`07@001d`0C01<04`070001d`0C01<04`0
6P000d`000070003C00001T000E<04`0C00M0007C01<04`0C00E0000>002C@0304e=01d000A=001=
0P000dd0000J0004C@00C@8000==00005`000dd000090003C@0001P00Td00`1=C@0M0004C@00C@80
00==00004`0005X000=<00000`000d`0001Q0005C00004`0>@000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`0001L000<A00007`000dd0C@2Z0003
C@0000<000==00004`0001L000<A00005`0014`004`40003C01<00<000=<00000T`B0004C000C0L0
00A<001<5`000d`000050003C00001P000=<00001@000d`0000H0003C00000D000=<00006@000d`0
0002C00304`001@0000F00<A600014d004d300E=0P02C@0304e=018000A=001=1`0014d004dG0003
C@1=00<000==04d06P001Dd0CDd0009=00<0C@006@001Dd0CDd0009=00<0C@00600;CA<0000E0005
4@0A01405`04C0800d`0101<C4`20003C01<014000=<04`00T`900=<00<0C00050000d`0C0030003
C01<01H000A<00000T`5009<0`000d`0000@0004C000009<1@02C0<000=<00004@02C00304a<00M<
0P000d`0000?000050001140014200034@0001801Td20003C@0000<000?600001Td>0003C@00009=
2@02C@8000==0000300014d004d20003C@1=00D000==04d00P0014d004d<009=00@0C@000Td7009=
0P0014d0CDd<009=00@0C@000Td7009=0P0014d0CDdB009=00X0CLI=aTd0C@1=4P0001@000@A000A
0P000a40000E00=<00?6C<H01@001<I<a/H2C10000=<04`00d`900A<00<0C0003002C00404`0009<
1`02C08000A<04a<300014`0C4`20003C00000L000?600000T`00`1<000;0004C01<C08000=<0000
1`000lH00002C00304`001001D`00lH0aP05C180000C00054@0001400`000a40000C0003CLI=00==
1`04C@03aTd000h000E=04e=aP0;0005aTe=04d03P03C@8000==00001`000lH00003C@h000I=04e=
04d90006aP1=C@1=3P000dd0C@020003C@0000L000K6001=04d@00M=00C6CLI=0/H4CA00000B0003
4@00008000<A00000P000a40000=00=<0P03C003aP1<00L000=<0<H00d`200=<1`07C003aP0000T0
00?6C4`01D`900M<2`000dc6C004C0X024`90003C<K600E<2P08C0T000=<a/H01D`C0007aT`0C01<
aP0E00004@000a40000300034@0000<000<A00003P04C@0504g604d01`001Td0aTd0aP==2`001Td0
CDg6C@/000==a/H00dd>0004aP1=C@/00Td00`36000@0004aTe=C@T00dd00lH0000@0004aTe=C@T0
0dd00lH0000E00==00@0CDe=5@00014000<A00000`000a40000300034@0000d00d`0101<C<H3C0L0
0d`00lI<C004C0X00d`0101<C4`400034@0000800T`00lH0C002C0h000E<04c6C00400034@000080
00E<aT`0aP0?0007C036C<H0C003000;4@0004`0aTc604`03P001d`0aTc604`00`002a40001<0<I<
aP1<00/000A<00001D`01/H004`AC08000?6C4`00d`30003C00000T0000@00034@0000@000<A0000
10000a40000;0003C@0000==00<0CDd00dd01@0A4A4000U=0P000dd000060005C@1=aP000/H2C@<0
00@A00000dd01/H0aTd0C@X00Td00lI=C@03C@@000<A00000P0014g6CDd2aP9=2P09C@<000@A0000
1Dd2aP9=2P09C@<000@A00001Dd2aP9=2@000dd00003009=10000ddAC@04009=1@000dd000090000
3`000a40000500034@0000D000<A0000300014`00<H2C009aP1<C1404@0A009<00@0aTc60`000d`0
0007009<00L0C4c60<H0009<0P000a400002C0030<H000;614`7009<00<0C4`01T`200<A0P03C003
aTa<009<00<0C4`01P0<C005014A4@0014`00lI<C005C0H034`01@0A4A4000A<00?6C4`01D`600=<
0`000d`000030005C14A4D`01@0014`00003C0X0000?00034@0000D000<A00001@000a40000>0003
C@1=00A=00LACA404DdA00I=300<C@<A1dd00lI=C@02C@T01Td02@36CDdACA404@02C@800dd00`1=
C@0:00E=0P001<I=CDd34@==00?600001Dd:00E=0P001<I=CDd34@==00?600001Dd:009=1`001TdA
01404@9=1P02C@`0000>00034@0000H000<A00001P000a40000>00E<00H0C4`AC143C005aP1<aT`0
3P04C004aP00009<0a43C0800/H00`36C00;0006C00004c60P001LHAC4`A009<00HAaP00aT`30003
C00000P000A<001<0/H03@3604`AC15<4D`0aP000/H014`004`:000CC000C0360<H0C15<4D`AC036
0002aP04C000C0`00/H200=<00H0C00A04`200=<0P000lH0000<00003@000a40000700034@0000L0
00<A0000300024g6CDg6CLH00Td00`1=C@02aP06CLI=CLI=3009C@0404e=009=0P03C@0304e=009=
2@001Dd0001=00801Td00`1=C@04C@8000E=0000C@080004C@00C@<01Td00`1=C@04C@<000A=001=
200014d004d300I=00<0CDd014d30004C@00C@d00Td3009=00<0C@000Td4009=3`0000`000<A0000
20000a40000800034@0000T01d`0101<C4`3009<0P07C0T01T`2aP0304a<00D00T`00`36aP06C0/0
00=<00000T`00`3600020008C0000<H0aT`20003C00000/000=<00000T`2aP@000=<00000P02aP9<
0P000d`0000:0003C000009<0/H40003C00000800/H2C08000=<000030000lH000020003C01<00A<
00<0C0000`000lH0000=000030000a40000800034@0000P000<A0000200014d0CDd2000<CLI=0<H0
C@1=aP1=0/H2C@0504e=04d01`0014d0CDd20004C@00C@T000A=00360P02C@0304d000`000C604e=
0P000dd0C@02009=00<0aP004P0014g6CDd30003C@1=00<00Td00lI=000B0003aTe=00<000==04d0
0`02C@03aTd000d014d30008C@00C@1=04d20004C@0000A=300000/000<A00002@000a4000090003
4@0000X000A<04`00d`01/H0C01<00;60d`20003C00000/000A<04a<0P000lH000070003aP00009<
00<0C0003P05C003aT`0008000=<aT`014`A0003C01<009<0/H01D`0001<00;60d`00`1<000@00A<
0/H01D`0001<00;60d`00`1<000>00E<0P02C00304`0009<0P000dc6aP02C0h0000:00034@0000X0
00<A00002P000a4000080003C@1=00<000O604e=aTg6009=00D0aP00C@020003C@0000T000==04d0
0Td20003aP0000L000?600000dd00`1=000<0005C@1=04d00P001LH00036008000E=04d0C@0?00E=
0`001LH0003600<01Dd?00==00D0C@00aP030004aP0000E=3@03C@0=04e=aTg6C@1=04g6C@02aPE=
3@0000T000<A00002`000a40000;00034@0000d00d`01@360<H000=<4P000d`0C0030003C00000L0
00M<0000C01<00d000=<04`00P001d`000360<H00`001T`004`0C0d000I<001<04`30005aP000<H0
0`000d`0C0020003C00000/000=<04`00P0014`00<H30007aP0004`0C0020003C00000T000=<04`0
0T`00`36C002aP050<I<aP000/H014c60002C00304`000/0000G00034@0001X00dd0101=C@02C@04
04e=CA0000A=001=0P02C@T00Td20004C@00C@h000A=001=0`000dd0C@030004C@00CA8000==04d0
0`001Dd0001=00<000==04d04P0014d004d20005C@0004d00`000dd0C@0A0005C@1=C@0014d00`1=
C@02C@0504e=04d03`0001L000<A00006P06C00404a<00=<4`000d`0C0020003C00000D000I<001<
04`H00=<6@000d`00003009<00<0C4`01@000d`0000@0003C00000<00T`00`1<C0050003C0000100
00=<04`034`00`1<000?00005`000a40000I0006C@00C@1=0`03C@8000==00004P0014d004d70004
C@00CAT000E=04d0C@0M0007C@1=04d0C@0L0007C@1=04d0C@0I00I=00<0CDd00Td00`1=000A0000
5`000a40000K009<00<0C0000P000d`0C00F0005C00004`01`001D`0001<01P00T`00`1<C00M0004
C000C08000=<00006P0014`004`20003C00001L000=<00000T`00`1<C002C0800T`A00005`000a40
000N0005C@0004d0H`000dd000030003C@0001X000==00000`000dd0000I009=1@02CA@0003o00<0
003o00<0003o00<0003o00<0003o00<0003o00<00000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.109418,
   0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110616, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.109418, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.74027, -0.110615, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.109419, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277,
   -0.110616, 0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.1939, -0.109418, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.270008, -1.2634, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  69.375, 37.5625}} -> {-1.42777, -1.26687, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26686, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.88594, -1.2634, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277,
   -1.26686, 0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.1939, -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.270008, -2.41738, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.74027, -2.42311, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277,
   -2.42311, 0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1939, -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85395 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0492176 0.952381 [
[ 0 0 0 0 ]
[ 1 .85395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .85395 L
0 .85395 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.24108 .70023 L
s
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.29606 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.55565 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.61064 .70023 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.38504 .65346 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.46668 .65346 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.68758 .21443 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.65867 .12546 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.41179 .04525 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.33611 .10023 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.53621 .21443 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.45857 .18921 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .53848 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .63203 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.32282 .78461 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.41179 .7557 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.25677 .58525 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.32282 .63324 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.75958 .40791 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.78849 .31894 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.63591 .10893 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.54236 .10893 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.63712 .31894 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.58914 .25289 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.10412 .33222 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.04913 .40791 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.12934 .65479 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.21832 .6837 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.19309 .45468 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.21832 .53233 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.42586 .6238 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.48822 .23003 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.30723 .58525 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.58914 .30334 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.23391 .48434 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.51407 .77979 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.60304 .8087 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .65612 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .56257 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.60304 .65733 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.66909 .60934 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.58975 .12432 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.51407 .06934 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.26719 .14955 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.23828 .23853 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.46729 .2133 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.38965 .23853 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.31522 .72432 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.37021 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.62979 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.68478 .72432 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.45918 .67755 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.54082 .67755 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.76172 .23853 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.73281 .14955 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.48593 .06934 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.41025 .12432 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.61035 .23853 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.53271 .2133 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .56257 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .65612 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.39696 .8087 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.48593 .77979 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.33091 .60934 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.39696 .65733 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.61863 .60934 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.43763 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.5 .64789 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.56237 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.38137 .60934 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.78168 .6837 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.87066 .65479 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.95087 .40791 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.89588 .33222 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.78168 .53233 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.80691 .45468 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.45764 .10893 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.36409 .10893 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.21151 .31894 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.24042 .40791 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.41086 .25289 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.36288 .31894 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.58821 .7557 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.67718 .78461 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .63203 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .53848 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.67718 .63324 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.74323 .58525 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.66389 .10023 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.58821 .04525 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.34133 .12546 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.31242 .21443 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.54143 .18921 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.46379 .21443 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.38936 .70023 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.44435 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.70394 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.75892 .70023 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.53332 .65346 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.61496 .65346 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.76609 .48434 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.41086 .30334 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.69277 .58525 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.51178 .23003 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.57414 .6238 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.42586 .42197 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.5 .44606 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.57414 .42197 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{181, 154},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002e0000VPP10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000;D0002e0000]@000;D0002e0000]@000;D0
002e0000B@03C1`00da:0000B@03CA`00de:0000B@03C1`00da:0000B@04CAX014e:0000B@04C0T0
0d`200=<2@04C4X0001:00==2@03C@800dd900==B`0004X014`800=<0P03C0P014a;0000BP04C@P0
24d800A=B`0004/00d`800Q<2003C4`0000k00A=3004C@P01Td800A=3004CC`0000k00E<2`04C0P0
1T`800A<2`05C3`0000k00Q=2@03C@800dd300I=0`03C@800dd900Q=?00003d01T`900A<00@0C4a<
1004C0@00d`00`1<C002C0T01T`n0000?P06C@P014d0101=CDd400A=1003C@0304e=009=2006CCl0
000l00Y<0P04C00304a<00E<1004C0@01d`00`1<C002C0802T`m0000?00;C@0304e=00Y=1004C@@0
34d00`1=C@09CCd0000l01M<1006C0@05d`m0000?P0EC@@01Td401E=?`0002l014`<01A<1006C0@0
54`<00A<<00002l01Dd<01==1006C@@04dd<00E=<00002l01T`=019<0P08C0804T`=00I<<0000340
1Td<019=00<0CDd01Td00`1=C@0@C@`01Tdb0000<P06C0/05T`201I<2`06C3<0000c00M=2@0FC@80
5Td900M==00003D01T`901E<0P0EC0T01T`f0000=P06C@P014d00`1=C@06C@?600<0CDd024d01036
a/H8C@0304e=009=2006CCL0000h00I<1P04C0801d`3aPa<0lH7C08014`600I<>@0003T01Td600==
0`07C@;62dd4aPI=0`03C@H01Tdj0000>P06C0D014`300M<00?6C4`024`5aPE<0`04C0D01T`k0000
?006C@<014d3019=1<H6C@<014d300I=?@0003L06d`5aP03C000008000=<a/H00lHKC3P0000g01]=
2<H00`36aP05aQ]=>00003L06d`@aQ]<>00004403Dd301;60`0=CD80000Z01]<0/H7C0801/H2C0?6
0T`7aP801D`4aQ]<:`0002X06dd2aPI=0P05aP800Td2aP0404e=aP801LH20003CLK600G66dd[0000
:P0KC0?61D`6aP<00T`3009<100>aQ]<:`0004L000?6CLH00/H00dg6aP03aP<00dd300==100;aTP0
00180003C<K600;60T`2aP@00T`5009<1@000lI<C005aP03C00004L0001900?600@0CDg61@02C@D0
0Td6009=00?60<H00/I:0000B@03aP0404a<C0@00d`500=<1@02C0800lI:0000B@03aP800Td4009=
1`02C@@00dd200?6BP0004T00lH2009<1002C0L00T`4009<0`03aTX0001900?60P03C@800dd700==
0`02C@<00lI:0000B@03aP<00T`2009<2@02C0800d`300?6BP0004T00lH3009=0P02C@T00Td2009=
1003aTX0001800C60`06C0T00d`00`1<C00400G6B00004D01<H3C@@014d;00E=0`03C@K6A@000480
1lH4C0<014`;00A<0`04C0W6@P0002D06dd:aP0404e=C@8014d;00A=0P03C@<02LHKCBH0000U01]<
1lH500A<00<0C4`01P024@D01d`700K66d`V00004P03CA006dd4aPT01Td6008A1@06C@/00lHKCA00
0ddC00004P03C2H01T`>00E<10044@@014`?00I<9P03C1<0000B00A=9006CA0014d300HA0P04CA40
1TdT00A=4`0001801D`Q00M<4@05C003014A00HA1D`B00M<8@05C1<0000C00E=7`06CA801Td34@04
014A008A1TdC00I=7`05CA@0000D00A<7P06C1<00T`2009<0Q401D`04A5<00<A0T`00`1<C00D00I<
7P04C1D0000E00A=6`06CAD00Td20004CA4A4@9=0Q42C@<A0P02CAH01TdK00A=5P0001D01D`I00I<
5@03C0800a400`1<C0024@03C000008A0P03C1H01T`I00E<5P0001H014dH00I=5P02C@800a4014d0
CDd24@03C@1=00<A0P02CAL01TdH00A=5`0001L014`E00I<6002C0800Q45C08A14`34@0304a<01T0
1T`E00A<600001L01DdC00I=6003C@04014A4@A=00<04A4014d0100A4A43CAT01TdC00E=600001P0
1D`@00M<6@02C004014A4@A<0P024@0304a<009<00@04A400T`J00M<4005C1T0000I00A=3`06CA/0
0Td34@I=00@04A401Dd34@9=7006C@l014dJ00006P04C0d01T`K009<0a43C0800T`0100A4@02C004
04a<C0<A0T`L00I<3@04C1/0000800E=3@05C@/01DdM009=0Q42C@@00Td00`0A4@03C@<00Td24@9=
7P05C@/01Dd=00E=2@0000P024`;00E<2P04C1h000E<4A4AC00500=<0Q42C0D000E<4A4AC00O00A<
2P05C0/024`90000200;C@T014d:00==7P0014dA4A48009=0Q42C@L00a400dd0000M00==2P04C@T0
2dd900002`0;C0L014`X009<0a49009<0Q42C0P00a42C2T014`700]<300000h034d300E=9005C@8A
2P02C@8A00==000020024@E=9@05C@<034d?00004@0<C00304a<009<8@0:C0/000A<4A5<2P0:C280
14`00`1<C00:C180000D00m=7@07C@8014d;0004CA4AC@X014d200M=7P0?CAD0000H00a<6@07C0@0
1D`;0003C14A00/01D`400M<6P0<C1T0000K00M=1<HD00M=1`02C@0304e=00`00Q4;009=00<0CDd0
1`07CAD01<H7CA`0000N00A<1LH@00M<2@03C00304a<00/014`:009<00@0C4a<2@07C1401LH4C1l0
000Q0003CLK600G62`07C@/00dd2009=2P06C@T00Td200==2`07C@`01lH00dd0000P00009006aPL0
1d`>009<0`02C0T01d`9009<0`02C0h01d`800K69@0002D01/H300M=4003C@<00Td9009=00<0CDd0
0dd8009=0`03CA001dd400K69P0002L01<H7C1800d`4009<2003C00404a<00=<1`02C0@00d`B00M<
1LHX0000:0000lI=C@04CA@00dd5009=1`03C@800Td200==1P02C@D00ddD00I=0/HY0000:0001<I<
C4`G009<1P02C0H00d`3009<0`02C0H00T`6009<5`03C0;6:@0002P01<HF00==1P02C@H00Td4009=
0`03C@D00Td600==5`04aRT0000X00?65P03C0L00T`500=<1002C0@00d`4009<1`03C1L00lHY0000
9`04aQD00dd8009=1003C@D00Td5009=1002C@P00ddF00C6:00002L01<HE009<2@02C0@00T`6009<
1@03C0<00T`9009<5P04aRP0000W00?65@03C@T00Td300==1P02C@H00dd2009=2@03CAH00lHX0000
9P04aQ@00d`:009<0P03C0L00T`7009<0P02C0X00d`E00C69`0002H01<HD009=2`02C@0404e=C@P0
0Td700==00<0CDd02`02CAD01<HW00004`05C0h00lHD00=<2`02C00304a<00T00T`800E<2`03C1D0
0lH>00E<500001<024d:0004CLK6aQ<00dd<00E=2@02C@T014d<00==5003aP03C@0000P024dD0000
4`0;C0H01D`B00=<3@04C0X00T`:00=<3@03C1<01D`600]<500001H02dd200I=4P02C@h00dd;009=
2P03C@h00TdC00I=0P0;CAL0000I011<4@03C0h00T`<009<2`03C0d00d`B011<6P0001`03Dd@00==
3P03C@`00Td;00==3P03CA403DdM00007`0<C0h00T`>00A<3002C0/014`>009<3`0<C200000Q00e=
2P03C@d01Dd<009=2`05C@d00dd;00e=8P00020014`00`1<C009C0O60d`>009<00<0C4`03002C0/0
0T`00`1<C00>00=<2lH8C00304a<009<8@0001l01Dd200e=0lH3C@h00dd00`1=C@0<009=2`02C@04
04e=C@h00dd:aPM=0P05CB00000N00E<0`0BC0;63003C0800T`<009<2`02C0800d`=0003aTa<00[6
1d`300E<7`0001h014d00`1=C@0DC@03aP0000X00Td3009=3002C@/00Td300==3004aQ==00<0CDd0
0TdO00007@0>C0H02d`900=<0`02C0`00T`;009<1002C0X00T`3aPI<1P0>C1h0000L00e=2`06C@[6
0dd4009=3002C@/00Td400==3/H3C@/03DdM00006P0;C00404a<C0`01D`9aP=<1@02C0`00T`;009<
1@03C0g60T`<00=<00<0C4`02D`K00005`0;C@@00dd900Q=2LH2C@;60`000lI=C@02aPX00Td:0003
aTe=00;60`000lI=C@0<aPI=2@03C@@02ddH0000500;C0L00d`600]<0/H700C60P02aP9<0lH9009<
2@02aP9<0lH200C61`04aPU<1P03C0L02d`E00004`0;C@P00dd200a=00<0a/H00/H800?600@0a/K6
0Td4aPP00Td800?60Td4aP040<K6aPP01<H00`1=C@0:C@800dd800]=500001<02T`900i<1@03aPP0
2<H00`36aP04aPH00T`600K600<0a/H01/H800?61@0>C0T02T`D00004`03C@8014d900a=2003aP03
C@0000D01lH300K61@02C@D01/H300O61`0014g6a/H800a=2@04C@800ddD00005`05C0H02d`<00E<
1`05aPD01/H30003aTa<00;60P06aPD01LH700E<300;C0H01D`H00005P05C@D02Td?00I=0`02C@G6
2005aP03CLK6009=00?6CDd01LH800G60Td300I=3`0:C@D01DdG00005P04C0H02D`@00]<1LH900O6
1D`4aPT01LH;C1002D`600A<5`0001H00dd700A=0P03CA002dd5aP03C@0000L00lH8C@?62@000dg6
aP03aP]=4003C@8014d700==5`0002H00d`@019<1`000lI<C00<C003aP0000D04T`@00=<9`0002H0
0dd<01M=0`0AC@?60Td301M=3003CBL0000V00=<2@0CC00304a<015<0P04C0C62d`00`1<C00AC0T0
0d`W00009P03C@H03Dd200I=0P0JC@?62dd200I=0P0=C@H00ddW00009P03C0<02d`200=<0`05C080
3T`200Q<0P0>C0801D`300=<0P0;C0<00d`W0000:P0:C@D00dd301A=1006C@@054d300==1@0:CB/0
000Z00M<2003C08054`500I<1@0DC0800d`800M<:`0002X014d;011=0P06C@L014d700I=0P0@C@/0
14d[0000>@0@C0<01D`600I<1P05C0<044`j0000=`0:C@801Td300E=1@08C@D01Dd300I=0P0:CCP0
000g00Q<1@05C0801d`300Y<0`07C0801D`500Q<>00003L024d500E=00<0CDd01dd200A=0P04C@80
2Dd00`1=C@03C@D024dh0000>@05C0L02D`00`1<C007C0@02D`00`1<C007C0L01D`j0000>@04C@T0
1dd300Q=1008C@<01dd900A=>P0003P014`:00I<1@06C0H01T`500I<2P04C3T0000g00E=2P06C@D0
1Dd800E=1@06C@X01Ddh0000=`05C0X01T`500E<2005C0D01T`:00E<>00003H01Td:00I=1@06C@H0
1Td500I=2P06CCL0000e00M<2@04C0L024`400Q<1`04C0T01d`f0000=008C@P01Dd600Y=0P0:C@H0
1Dd800Q==@0003@014`0101<C4`800E<1P04C08014`200A<0P04C0H01D`800=<00<0C4`00T`e0000
=003C@800dd700I=1P03C@@00dd200==1003C@H01Td700==0P03CCD0000i00=<1P07C2801d`600=<
>P00044024dR00Q=@P00044014`0101<C4`R00=<00<0C4`00Ta20000@@03C@800ddR00==0P03CD80
001600=<8P03C4L0002e0000]@000;D0002e0000]@000;D0002e0000\
\>"],
  ImageRangeCache->{{{0, 180}, {153, 0}} -> {-0.027445, 0.051674, 0.0058605, 
  0.0058605}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0492176 0.952381 [
[ 0 0 0 0 ]
[ 1 .85395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85395 L
0 .85395 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.24108 .70023 L
s
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.29606 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.55565 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.61064 .70023 L
s
P
p
0 .4 1 r
.02 w
.42586 .6238 m
.38504 .65346 L
s
P
p
0 .4 1 r
.02 w
.42586 .6238 m
.46668 .65346 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.68758 .21443 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.65867 .12546 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.41179 .04525 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.33611 .10023 L
s
P
p
0 .4 1 r
.02 w
.48822 .23003 m
.53621 .21443 L
s
P
p
0 .4 1 r
.02 w
.48822 .23003 m
.45857 .18921 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .53848 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .63203 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.32282 .78461 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.41179 .7557 L
s
P
p
0 .4 1 r
.02 w
.30723 .58525 m
.25677 .58525 L
s
P
p
0 .4 1 r
.02 w
.30723 .58525 m
.32282 .63324 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.75958 .40791 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.78849 .31894 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.63591 .10893 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.54236 .10893 L
s
P
p
0 .4 1 r
.02 w
.58914 .30334 m
.63712 .31894 L
s
P
p
0 .4 1 r
.02 w
.58914 .30334 m
.58914 .25289 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.10412 .33222 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.04913 .40791 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.12934 .65479 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.21832 .6837 L
s
P
p
0 .4 1 r
.02 w
.23391 .48434 m
.19309 .45468 L
s
P
p
0 .4 1 r
.02 w
.23391 .48434 m
.21832 .53233 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.42586 .6238 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.48822 .23003 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.30723 .58525 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.58914 .30334 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.23391 .48434 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.51407 .77979 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.60304 .8087 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .65612 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .56257 L
s
P
p
0 .4 1 r
.02 w
.61863 .60934 m
.60304 .65733 L
s
P
p
0 .4 1 r
.02 w
.61863 .60934 m
.66909 .60934 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.58975 .12432 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.51407 .06934 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.26719 .14955 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.23828 .23853 L
s
P
p
0 .4 1 r
.02 w
.43763 .25412 m
.46729 .2133 L
s
P
p
0 .4 1 r
.02 w
.43763 .25412 m
.38965 .23853 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.31522 .72432 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.37021 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.62979 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.68478 .72432 L
s
P
p
0 .4 1 r
.02 w
.5 .64789 m
.45918 .67755 L
s
P
p
0 .4 1 r
.02 w
.5 .64789 m
.54082 .67755 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.76172 .23853 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.73281 .14955 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.48593 .06934 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.41025 .12432 L
s
P
p
0 .4 1 r
.02 w
.56237 .25412 m
.61035 .23853 L
s
P
p
0 .4 1 r
.02 w
.56237 .25412 m
.53271 .2133 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .56257 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .65612 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.39696 .8087 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.48593 .77979 L
s
P
p
0 .4 1 r
.02 w
.38137 .60934 m
.33091 .60934 L
s
P
p
0 .4 1 r
.02 w
.38137 .60934 m
.39696 .65733 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.61863 .60934 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.43763 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.5 .64789 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.56237 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.38137 .60934 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.78168 .6837 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.87066 .65479 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.95087 .40791 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.89588 .33222 L
s
P
p
0 .4 1 r
.02 w
.76609 .48434 m
.78168 .53233 L
s
P
p
0 .4 1 r
.02 w
.76609 .48434 m
.80691 .45468 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.45764 .10893 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.36409 .10893 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.21151 .31894 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.24042 .40791 L
s
P
p
0 .4 1 r
.02 w
.41086 .30334 m
.41086 .25289 L
s
P
p
0 .4 1 r
.02 w
.41086 .30334 m
.36288 .31894 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.58821 .7557 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.67718 .78461 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .63203 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .53848 L
s
P
p
0 .4 1 r
.02 w
.69277 .58525 m
.67718 .63324 L
s
P
p
0 .4 1 r
.02 w
.69277 .58525 m
.74323 .58525 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.66389 .10023 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.58821 .04525 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.34133 .12546 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.31242 .21443 L
s
P
p
0 .4 1 r
.02 w
.51178 .23003 m
.54143 .18921 L
s
P
p
0 .4 1 r
.02 w
.51178 .23003 m
.46379 .21443 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.38936 .70023 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.44435 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.70394 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.75892 .70023 L
s
P
p
0 .4 1 r
.02 w
.57414 .6238 m
.53332 .65346 L
s
P
p
0 .4 1 r
.02 w
.57414 .6238 m
.61496 .65346 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.76609 .48434 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.41086 .30334 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.69277 .58525 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.51178 .23003 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.57414 .6238 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.42586 .42197 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.5 .44606 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.57414 .42197 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0492176 0.952381 [
[ 0 0 0 0 ]
[ 1 .85395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85395 L
0 .85395 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.24108 .70023 L
s
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.29606 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.55565 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.61064 .70023 L
s
P
p
.2 0 1 r
.018 w
.42586 .6238 m
.38504 .65346 L
s
P
p
.2 0 1 r
.018 w
.42586 .6238 m
.46668 .65346 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.68758 .21443 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.65867 .12546 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.41179 .04525 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.33611 .10023 L
s
P
p
.2 0 1 r
.018 w
.48822 .23003 m
.53621 .21443 L
s
P
p
.2 0 1 r
.018 w
.48822 .23003 m
.45857 .18921 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .53848 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .63203 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.32282 .78461 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.41179 .7557 L
s
P
p
.2 0 1 r
.018 w
.30723 .58525 m
.25677 .58525 L
s
P
p
.2 0 1 r
.018 w
.30723 .58525 m
.32282 .63324 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.75958 .40791 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.78849 .31894 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.63591 .10893 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.54236 .10893 L
s
P
p
.2 0 1 r
.018 w
.58914 .30334 m
.63712 .31894 L
s
P
p
.2 0 1 r
.018 w
.58914 .30334 m
.58914 .25289 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.10412 .33222 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.04913 .40791 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.12934 .65479 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.21832 .6837 L
s
P
p
.2 0 1 r
.018 w
.23391 .48434 m
.19309 .45468 L
s
P
p
.2 0 1 r
.018 w
.23391 .48434 m
.21832 .53233 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.42586 .6238 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.48822 .23003 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.30723 .58525 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.58914 .30334 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.23391 .48434 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.51407 .77979 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.60304 .8087 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .65612 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .56257 L
s
P
p
.2 0 1 r
.018 w
.61863 .60934 m
.60304 .65733 L
s
P
p
.2 0 1 r
.018 w
.61863 .60934 m
.66909 .60934 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.58975 .12432 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.51407 .06934 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.26719 .14955 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.23828 .23853 L
s
P
p
.2 0 1 r
.018 w
.43763 .25412 m
.46729 .2133 L
s
P
p
.2 0 1 r
.018 w
.43763 .25412 m
.38965 .23853 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.31522 .72432 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.37021 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.62979 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.68478 .72432 L
s
P
p
.2 0 1 r
.018 w
.5 .64789 m
.45918 .67755 L
s
P
p
.2 0 1 r
.018 w
.5 .64789 m
.54082 .67755 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.76172 .23853 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.73281 .14955 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.48593 .06934 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.41025 .12432 L
s
P
p
.2 0 1 r
.018 w
.56237 .25412 m
.61035 .23853 L
s
P
p
.2 0 1 r
.018 w
.56237 .25412 m
.53271 .2133 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .56257 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .65612 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.39696 .8087 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.48593 .77979 L
s
P
p
.2 0 1 r
.018 w
.38137 .60934 m
.33091 .60934 L
s
P
p
.2 0 1 r
.018 w
.38137 .60934 m
.39696 .65733 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.61863 .60934 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.43763 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.5 .64789 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.56237 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.38137 .60934 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.78168 .6837 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.87066 .65479 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.95087 .40791 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.89588 .33222 L
s
P
p
.2 0 1 r
.018 w
.76609 .48434 m
.78168 .53233 L
s
P
p
.2 0 1 r
.018 w
.76609 .48434 m
.80691 .45468 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.45764 .10893 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.36409 .10893 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.21151 .31894 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.24042 .40791 L
s
P
p
.2 0 1 r
.018 w
.41086 .30334 m
.41086 .25289 L
s
P
p
.2 0 1 r
.018 w
.41086 .30334 m
.36288 .31894 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.58821 .7557 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.67718 .78461 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .63203 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .53848 L
s
P
p
.2 0 1 r
.018 w
.69277 .58525 m
.67718 .63324 L
s
P
p
.2 0 1 r
.018 w
.69277 .58525 m
.74323 .58525 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.66389 .10023 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.58821 .04525 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.34133 .12546 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.31242 .21443 L
s
P
p
.2 0 1 r
.018 w
.51178 .23003 m
.54143 .18921 L
s
P
p
.2 0 1 r
.018 w
.51178 .23003 m
.46379 .21443 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.38936 .70023 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.44435 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.70394 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.75892 .70023 L
s
P
p
.2 0 1 r
.018 w
.57414 .6238 m
.53332 .65346 L
s
P
p
.2 0 1 r
.018 w
.57414 .6238 m
.61496 .65346 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.76609 .48434 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.41086 .30334 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.69277 .58525 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.51178 .23003 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.57414 .6238 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.42586 .42197 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.5 .44606 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.57414 .42197 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0452321 0.952381 [
[ 0 0 0 0 ]
[ 1 .86192 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .86192 L
0 .86192 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.38688 .65115 m
.23795 .65115 L
s
P
p
.2 0 1 r
.02 w
.38688 .65115 m
.26639 .73869 L
s
P
p
.2 0 1 r
.02 w
.38688 .65115 m
.34086 .79279 L
s
P
p
.2 0 1 r
.02 w
.46721 .65115 m
.51324 .79279 L
s
P
p
.2 0 1 r
.02 w
.46721 .65115 m
.5877 .73869 L
s
P
p
.2 0 1 r
.02 w
.46721 .65115 m
.61615 .65115 L
s
P
p
0 .4 1 r
.018 w
.42705 .62196 m
.38688 .65115 L
s
P
p
0 .4 1 r
.018 w
.42705 .62196 m
.46721 .65115 L
s
P
p
.2 0 1 r
.02 w
.53563 .21918 m
.67728 .2652 L
s
P
p
.2 0 1 r
.02 w
.53563 .21918 m
.67728 .17316 L
s
P
p
.2 0 1 r
.02 w
.53563 .21918 m
.62317 .09869 L
s
P
p
.2 0 1 r
.02 w
.45923 .19436 m
.45923 .04542 L
s
P
p
.2 0 1 r
.02 w
.45923 .19436 m
.37169 .07387 L
s
P
p
.2 0 1 r
.02 w
.45923 .19436 m
.31759 .14833 L
s
P
p
0 .4 1 r
.018 w
.48841 .23452 m
.53563 .21918 L
s
P
p
0 .4 1 r
.018 w
.48841 .23452 m
.45923 .19436 L
s
P
p
.2 0 1 r
.02 w
.26068 .58404 m
.14019 .4965 L
s
P
p
.2 0 1 r
.02 w
.26068 .58404 m
.11174 .58404 L
s
P
p
.2 0 1 r
.02 w
.26068 .58404 m
.14019 .67158 L
s
P
p
.2 0 1 r
.02 w
.32567 .63125 m
.27964 .7729 L
s
P
p
.2 0 1 r
.02 w
.32567 .63125 m
.37169 .7729 L
s
P
p
.2 0 1 r
.02 w
.32567 .63125 m
.44616 .7188 L
s
P
p
0 .4 1 r
.018 w
.31032 .58404 m
.26068 .58404 L
s
P
p
0 .4 1 r
.018 w
.31032 .58404 m
.32567 .63125 L
s
P
p
.2 0 1 r
.02 w
.63492 .322 m
.72246 .44249 L
s
P
p
.2 0 1 r
.02 w
.63492 .322 m
.77657 .36803 L
s
P
p
.2 0 1 r
.02 w
.63492 .322 m
.77657 .27598 L
s
P
p
.2 0 1 r
.02 w
.5877 .25701 m
.67525 .13652 L
s
P
p
.2 0 1 r
.02 w
.5877 .25701 m
.5877 .10808 L
s
P
p
.2 0 1 r
.02 w
.5877 .25701 m
.50016 .13652 L
s
P
p
0 .4 1 r
.018 w
.5877 .30666 m
.63492 .322 L
s
P
p
0 .4 1 r
.018 w
.5877 .30666 m
.5877 .25701 L
s
P
p
.2 0 1 r
.02 w
.19802 .45557 m
.152 .31392 L
s
P
p
.2 0 1 r
.02 w
.19802 .45557 m
.07753 .36803 L
s
P
p
.2 0 1 r
.02 w
.19802 .45557 m
.04909 .45557 L
s
P
p
.2 0 1 r
.02 w
.22284 .53196 m
.10235 .61951 L
s
P
p
.2 0 1 r
.02 w
.22284 .53196 m
.17682 .67361 L
s
P
p
.2 0 1 r
.02 w
.22284 .53196 m
.26887 .67361 L
s
P
p
0 .4 1 r
.018 w
.23819 .48475 m
.19802 .45557 L
s
P
p
0 .4 1 r
.018 w
.23819 .48475 m
.22284 .53196 L
s
P
p
.2 0 1 r
.016 w
.42705 .42338 m
.42705 .62196 L
s
P
p
.2 0 1 r
.016 w
.42705 .42338 m
.48841 .23452 L
s
P
p
.2 0 1 r
.016 w
.42705 .42338 m
.31032 .58404 L
s
P
p
.2 0 1 r
.016 w
.42705 .42338 m
.5877 .30666 L
s
P
p
.2 0 1 r
.016 w
.42705 .42338 m
.23819 .48475 L
s
P
p
.2 0 1 r
.02 w
.60138 .65496 m
.48089 .7425 L
s
P
p
.2 0 1 r
.02 w
.60138 .65496 m
.55536 .7966 L
s
P
p
.2 0 1 r
.02 w
.60138 .65496 m
.64741 .7966 L
s
P
p
.2 0 1 r
.02 w
.66637 .60774 m
.78686 .69528 L
s
P
p
.2 0 1 r
.02 w
.66637 .60774 m
.8153 .60774 L
s
P
p
.2 0 1 r
.02 w
.66637 .60774 m
.78686 .5202 L
s
P
p
0 .4 1 r
.018 w
.61672 .60774 m
.60138 .65496 L
s
P
p
0 .4 1 r
.018 w
.61672 .60774 m
.66637 .60774 L
s
P
p
.2 0 1 r
.02 w
.46782 .21806 m
.60946 .17204 L
s
P
p
.2 0 1 r
.02 w
.46782 .21806 m
.55536 .09757 L
s
P
p
.2 0 1 r
.02 w
.46782 .21806 m
.46782 .06912 L
s
P
p
.2 0 1 r
.02 w
.39142 .24288 m
.30388 .12239 L
s
P
p
.2 0 1 r
.02 w
.39142 .24288 m
.24977 .19686 L
s
P
p
.2 0 1 r
.02 w
.39142 .24288 m
.24977 .28891 L
s
P
p
0 .4 1 r
.018 w
.43863 .25822 m
.46782 .21806 L
s
P
p
0 .4 1 r
.018 w
.43863 .25822 m
.39142 .24288 L
s
P
p
.2 0 1 r
.02 w
.45984 .67485 m
.3109 .67485 L
s
P
p
.2 0 1 r
.02 w
.45984 .67485 m
.33934 .76239 L
s
P
p
.2 0 1 r
.02 w
.45984 .67485 m
.41381 .8165 L
s
P
p
.2 0 1 r
.02 w
.54016 .67485 m
.58619 .8165 L
s
P
p
.2 0 1 r
.02 w
.54016 .67485 m
.66066 .76239 L
s
P
p
.2 0 1 r
.02 w
.54016 .67485 m
.6891 .67485 L
s
P
p
0 .4 1 r
.018 w
.5 .64567 m
.45984 .67485 L
s
P
p
0 .4 1 r
.018 w
.5 .64567 m
.54016 .67485 L
s
P
p
.2 0 1 r
.02 w
.60858 .24288 m
.75023 .28891 L
s
P
p
.2 0 1 r
.02 w
.60858 .24288 m
.75023 .19686 L
s
P
p
.2 0 1 r
.02 w
.60858 .24288 m
.69612 .12239 L
s
P
p
.2 0 1 r
.02 w
.53218 .21806 m
.53218 .06912 L
s
P
p
.2 0 1 r
.02 w
.53218 .21806 m
.44464 .09757 L
s
P
p
.2 0 1 r
.02 w
.53218 .21806 m
.39054 .17204 L
s
P
p
0 .4 1 r
.018 w
.56137 .25822 m
.60858 .24288 L
s
P
p
0 .4 1 r
.018 w
.56137 .25822 m
.53218 .21806 L
s
P
p
.2 0 1 r
.02 w
.33363 .60774 m
.21314 .5202 L
s
P
p
.2 0 1 r
.02 w
.33363 .60774 m
.1847 .60774 L
s
P
p
.2 0 1 r
.02 w
.33363 .60774 m
.21314 .69528 L
s
P
p
.2 0 1 r
.02 w
.39862 .65496 m
.35259 .7966 L
s
P
p
.2 0 1 r
.02 w
.39862 .65496 m
.44464 .7966 L
s
P
p
.2 0 1 r
.02 w
.39862 .65496 m
.51911 .7425 L
s
P
p
0 .4 1 r
.018 w
.38328 .60774 m
.33363 .60774 L
s
P
p
0 .4 1 r
.018 w
.38328 .60774 m
.39862 .65496 L
s
P
p
.2 0 1 r
.016 w
.5 .44709 m
.61672 .60774 L
s
P
p
.2 0 1 r
.016 w
.5 .44709 m
.43863 .25822 L
s
P
p
.2 0 1 r
.016 w
.5 .44709 m
.5 .64567 L
s
P
p
.2 0 1 r
.016 w
.5 .44709 m
.56137 .25822 L
s
P
p
.2 0 1 r
.016 w
.5 .44709 m
.38328 .60774 L
s
P
p
.2 0 1 r
.02 w
.77716 .53196 m
.73113 .67361 L
s
P
p
.2 0 1 r
.02 w
.77716 .53196 m
.82318 .67361 L
s
P
p
.2 0 1 r
.02 w
.77716 .53196 m
.89765 .61951 L
s
P
p
.2 0 1 r
.02 w
.80198 .45557 m
.95091 .45557 L
s
P
p
.2 0 1 r
.02 w
.80198 .45557 m
.92247 .36803 L
s
P
p
.2 0 1 r
.02 w
.80198 .45557 m
.848 .31392 L
s
P
p
0 .4 1 r
.018 w
.76181 .48475 m
.77716 .53196 L
s
P
p
0 .4 1 r
.018 w
.76181 .48475 m
.80198 .45557 L
s
P
p
.2 0 1 r
.02 w
.4123 .25701 m
.49984 .13652 L
s
P
p
.2 0 1 r
.02 w
.4123 .25701 m
.4123 .10808 L
s
P
p
.2 0 1 r
.02 w
.4123 .25701 m
.32475 .13652 L
s
P
p
.2 0 1 r
.02 w
.36508 .322 m
.22343 .27598 L
s
P
p
.2 0 1 r
.02 w
.36508 .322 m
.22343 .36803 L
s
P
p
.2 0 1 r
.02 w
.36508 .322 m
.27754 .44249 L
s
P
p
0 .4 1 r
.018 w
.4123 .30666 m
.4123 .25701 L
s
P
p
0 .4 1 r
.018 w
.4123 .30666 m
.36508 .322 L
s
P
p
.2 0 1 r
.02 w
.67433 .63125 m
.55384 .7188 L
s
P
p
.2 0 1 r
.02 w
.67433 .63125 m
.62831 .7729 L
s
P
p
.2 0 1 r
.02 w
.67433 .63125 m
.72036 .7729 L
s
P
p
.2 0 1 r
.02 w
.73932 .58404 m
.85981 .67158 L
s
P
p
.2 0 1 r
.02 w
.73932 .58404 m
.88826 .58404 L
s
P
p
.2 0 1 r
.02 w
.73932 .58404 m
.85981 .4965 L
s
P
p
0 .4 1 r
.018 w
.68968 .58404 m
.67433 .63125 L
s
P
p
0 .4 1 r
.018 w
.68968 .58404 m
.73932 .58404 L
s
P
p
.2 0 1 r
.02 w
.54077 .19436 m
.68241 .14833 L
s
P
p
.2 0 1 r
.02 w
.54077 .19436 m
.62831 .07387 L
s
P
p
.2 0 1 r
.02 w
.54077 .19436 m
.54077 .04542 L
s
P
p
.2 0 1 r
.02 w
.46437 .21918 m
.37683 .09869 L
s
P
p
.2 0 1 r
.02 w
.46437 .21918 m
.32272 .17316 L
s
P
p
.2 0 1 r
.02 w
.46437 .21918 m
.32272 .2652 L
s
P
p
0 .4 1 r
.018 w
.51159 .23452 m
.54077 .19436 L
s
P
p
0 .4 1 r
.018 w
.51159 .23452 m
.46437 .21918 L
s
P
p
.2 0 1 r
.02 w
.53279 .65115 m
.38385 .65115 L
s
P
p
.2 0 1 r
.02 w
.53279 .65115 m
.4123 .73869 L
s
P
p
.2 0 1 r
.02 w
.53279 .65115 m
.48676 .79279 L
s
P
p
.2 0 1 r
.02 w
.61312 .65115 m
.65914 .79279 L
s
P
p
.2 0 1 r
.02 w
.61312 .65115 m
.73361 .73869 L
s
P
p
.2 0 1 r
.02 w
.61312 .65115 m
.76205 .65115 L
s
P
p
0 .4 1 r
.018 w
.57295 .62196 m
.53279 .65115 L
s
P
p
0 .4 1 r
.018 w
.57295 .62196 m
.61312 .65115 L
s
P
p
.2 0 1 r
.016 w
.57295 .42338 m
.76181 .48475 L
s
P
p
.2 0 1 r
.016 w
.57295 .42338 m
.4123 .30666 L
s
P
p
.2 0 1 r
.016 w
.57295 .42338 m
.68968 .58404 L
s
P
p
.2 0 1 r
.016 w
.57295 .42338 m
.51159 .23452 L
s
P
p
.2 0 1 r
.016 w
.57295 .42338 m
.57295 .62196 L
s
P
p
1 .6 0 r
.016 w
.5 .32297 m
.42705 .42338 L
s
P
p
1 .6 0 r
.016 w
.5 .32297 m
.5 .44709 L
s
P
p
1 .6 0 r
.016 w
.5 .32297 m
.57295 .42338 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0468257 0.952381 [
[ 0 0 0 0 ]
[ 1 .85873 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85873 L
0 .85873 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.38269 .65679 m
.24506 .72692 L
s
P
p
.2 0 1 r
.02 w
.38269 .65679 m
.27346 .76602 L
s
P
p
.2 0 1 r
.02 w
.46599 .65679 m
.57522 .76602 L
s
P
p
.2 0 1 r
.02 w
.46599 .65679 m
.60362 .72692 L
s
P
p
0 .4 1 r
.018 w
.42434 .62653 m
.38269 .65679 L
s
P
p
0 .4 1 r
.018 w
.42434 .62653 m
.46599 .65679 L
s
P
p
.2 0 1 r
.02 w
.53695 .20879 m
.68951 .18463 L
s
P
p
.2 0 1 r
.02 w
.53695 .20879 m
.67458 .13867 L
s
P
p
.2 0 1 r
.02 w
.45772 .18305 m
.38759 .04542 L
s
P
p
.2 0 1 r
.02 w
.45772 .18305 m
.3485 .07383 L
s
P
p
0 .4 1 r
.018 w
.48798 .2247 m
.53695 .20879 L
s
P
p
0 .4 1 r
.018 w
.48798 .2247 m
.45772 .18305 L
s
P
p
.2 0 1 r
.02 w
.2518 .5872 m
.09923 .56303 L
s
P
p
.2 0 1 r
.02 w
.2518 .5872 m
.09923 .61136 L
s
P
p
.2 0 1 r
.02 w
.31919 .63616 m
.34336 .78873 L
s
P
p
.2 0 1 r
.02 w
.31919 .63616 m
.38932 .77379 L
s
P
p
0 .4 1 r
.018 w
.30328 .5872 m
.2518 .5872 L
s
P
p
0 .4 1 r
.018 w
.30328 .5872 m
.31919 .63616 L
s
P
p
.2 0 1 r
.02 w
.63993 .31543 m
.77756 .38556 L
s
P
p
.2 0 1 r
.02 w
.63993 .31543 m
.79249 .33959 L
s
P
p
.2 0 1 r
.02 w
.59096 .24803 m
.61512 .09547 L
s
P
p
.2 0 1 r
.02 w
.59096 .24803 m
.5668 .09547 L
s
P
p
0 .4 1 r
.018 w
.59096 .29952 m
.63993 .31543 L
s
P
p
0 .4 1 r
.018 w
.59096 .29952 m
.59096 .24803 L
s
P
p
.2 0 1 r
.02 w
.18681 .45396 m
.07759 .34473 L
s
P
p
.2 0 1 r
.02 w
.18681 .45396 m
.04918 .38383 L
s
P
p
.2 0 1 r
.02 w
.21256 .53319 m
.14243 .67082 L
s
P
p
.2 0 1 r
.02 w
.21256 .53319 m
.18839 .68575 L
s
P
p
0 .4 1 r
.018 w
.22847 .48422 m
.18681 .45396 L
s
P
p
0 .4 1 r
.018 w
.22847 .48422 m
.21256 .53319 L
s
P
p
.2 0 1 r
.016 w
.42434 .42058 m
.42434 .62653 L
s
P
p
.2 0 1 r
.016 w
.42434 .42058 m
.48798 .2247 L
s
P
p
.2 0 1 r
.016 w
.42434 .42058 m
.30328 .5872 L
s
P
p
.2 0 1 r
.016 w
.42434 .42058 m
.59096 .29952 L
s
P
p
.2 0 1 r
.016 w
.42434 .42058 m
.22847 .48422 L
s
P
p
.2 0 1 r
.02 w
.60515 .66075 m
.53502 .79838 L
s
P
p
.2 0 1 r
.02 w
.60515 .66075 m
.58098 .81331 L
s
P
p
.2 0 1 r
.02 w
.67254 .61178 m
.82511 .63594 L
s
P
p
.2 0 1 r
.02 w
.67254 .61178 m
.82511 .58762 L
s
P
p
0 .4 1 r
.018 w
.62106 .61178 m
.60515 .66075 L
s
P
p
0 .4 1 r
.018 w
.62106 .61178 m
.67254 .61178 L
s
P
p
.2 0 1 r
.02 w
.46662 .20763 m
.57584 .09841 L
s
P
p
.2 0 1 r
.02 w
.46662 .20763 m
.53675 .07 L
s
P
p
.2 0 1 r
.02 w
.38739 .23338 m
.24976 .16325 L
s
P
p
.2 0 1 r
.02 w
.38739 .23338 m
.23483 .20921 L
s
P
p
0 .4 1 r
.018 w
.43636 .24929 m
.46662 .20763 L
s
P
p
0 .4 1 r
.018 w
.43636 .24929 m
.38739 .23338 L
s
P
p
.2 0 1 r
.02 w
.45835 .68138 m
.32072 .7515 L
s
P
p
.2 0 1 r
.02 w
.45835 .68138 m
.34912 .7906 L
s
P
p
.2 0 1 r
.02 w
.54165 .68138 m
.65088 .7906 L
s
P
p
.2 0 1 r
.02 w
.54165 .68138 m
.67928 .7515 L
s
P
p
0 .4 1 r
.018 w
.5 .65111 m
.45835 .68138 L
s
P
p
0 .4 1 r
.018 w
.5 .65111 m
.54165 .68138 L
s
P
p
.2 0 1 r
.02 w
.61261 .23338 m
.76517 .20921 L
s
P
p
.2 0 1 r
.02 w
.61261 .23338 m
.75024 .16325 L
s
P
p
.2 0 1 r
.02 w
.53338 .20763 m
.46325 .07 L
s
P
p
.2 0 1 r
.02 w
.53338 .20763 m
.42416 .09841 L
s
P
p
0 .4 1 r
.018 w
.56364 .24929 m
.61261 .23338 L
s
P
p
0 .4 1 r
.018 w
.56364 .24929 m
.53338 .20763 L
s
P
p
.2 0 1 r
.02 w
.32746 .61178 m
.17489 .58762 L
s
P
p
.2 0 1 r
.02 w
.32746 .61178 m
.17489 .63594 L
s
P
p
.2 0 1 r
.02 w
.39485 .66075 m
.41902 .81331 L
s
P
p
.2 0 1 r
.02 w
.39485 .66075 m
.46498 .79838 L
s
P
p
0 .4 1 r
.018 w
.37894 .61178 m
.32746 .61178 L
s
P
p
0 .4 1 r
.018 w
.37894 .61178 m
.39485 .66075 L
s
P
p
.2 0 1 r
.016 w
.5 .44516 m
.62106 .61178 L
s
P
p
.2 0 1 r
.016 w
.5 .44516 m
.43636 .24929 L
s
P
p
.2 0 1 r
.016 w
.5 .44516 m
.5 .65111 L
s
P
p
.2 0 1 r
.016 w
.5 .44516 m
.56364 .24929 L
s
P
p
.2 0 1 r
.016 w
.5 .44516 m
.37894 .61178 L
s
P
p
.2 0 1 r
.02 w
.78744 .53319 m
.81161 .68575 L
s
P
p
.2 0 1 r
.02 w
.78744 .53319 m
.85757 .67082 L
s
P
p
.2 0 1 r
.02 w
.81319 .45396 m
.95082 .38383 L
s
P
p
.2 0 1 r
.02 w
.81319 .45396 m
.92241 .34473 L
s
P
p
0 .4 1 r
.018 w
.77153 .48422 m
.78744 .53319 L
s
P
p
0 .4 1 r
.018 w
.77153 .48422 m
.81319 .45396 L
s
P
p
.2 0 1 r
.02 w
.40904 .24803 m
.4332 .09547 L
s
P
p
.2 0 1 r
.02 w
.40904 .24803 m
.38488 .09547 L
s
P
p
.2 0 1 r
.02 w
.36007 .31543 m
.20751 .33959 L
s
P
p
.2 0 1 r
.02 w
.36007 .31543 m
.22244 .38556 L
s
P
p
0 .4 1 r
.018 w
.40904 .29952 m
.40904 .24803 L
s
P
p
0 .4 1 r
.018 w
.40904 .29952 m
.36007 .31543 L
s
P
p
.2 0 1 r
.02 w
.68081 .63616 m
.61068 .77379 L
s
P
p
.2 0 1 r
.02 w
.68081 .63616 m
.65664 .78873 L
s
P
p
.2 0 1 r
.02 w
.7482 .5872 m
.90077 .61136 L
s
P
p
.2 0 1 r
.02 w
.7482 .5872 m
.90077 .56303 L
s
P
p
0 .4 1 r
.018 w
.69672 .5872 m
.68081 .63616 L
s
P
p
0 .4 1 r
.018 w
.69672 .5872 m
.7482 .5872 L
s
P
p
.2 0 1 r
.02 w
.54228 .18305 m
.6515 .07383 L
s
P
p
.2 0 1 r
.02 w
.54228 .18305 m
.61241 .04542 L
s
P
p
.2 0 1 r
.02 w
.46305 .20879 m
.32542 .13867 L
s
P
p
.2 0 1 r
.02 w
.46305 .20879 m
.31049 .18463 L
s
P
p
0 .4 1 r
.018 w
.51202 .2247 m
.54228 .18305 L
s
P
p
0 .4 1 r
.018 w
.51202 .2247 m
.46305 .20879 L
s
P
p
.2 0 1 r
.02 w
.53401 .65679 m
.39638 .72692 L
s
P
p
.2 0 1 r
.02 w
.53401 .65679 m
.42478 .76602 L
s
P
p
.2 0 1 r
.02 w
.61731 .65679 m
.72654 .76602 L
s
P
p
.2 0 1 r
.02 w
.61731 .65679 m
.75494 .72692 L
s
P
p
0 .4 1 r
.018 w
.57566 .62653 m
.53401 .65679 L
s
P
p
0 .4 1 r
.018 w
.57566 .62653 m
.61731 .65679 L
s
P
p
.2 0 1 r
.016 w
.57566 .42058 m
.77153 .48422 L
s
P
p
.2 0 1 r
.016 w
.57566 .42058 m
.40904 .29952 L
s
P
p
.2 0 1 r
.016 w
.57566 .42058 m
.69672 .5872 L
s
P
p
.2 0 1 r
.016 w
.57566 .42058 m
.51202 .2247 L
s
P
p
.2 0 1 r
.016 w
.57566 .42058 m
.57566 .62653 L
s
P
p
1 .6 0 r
.016 w
.5 .31644 m
.42434 .42058 L
s
P
p
1 .6 0 r
.016 w
.5 .31644 m
.5 .44516 L
s
P
p
1 .6 0 r
.016 w
.5 .31644 m
.57566 .42058 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0449087 0.952381 [
[ 0 0 0 0 ]
[ 1 .86256 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .86256 L
0 .86256 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39081 .6458 m
.2313 .69763 L
s
P
p
.2 0 1 r
.02 w
.39081 .6458 m
.29223 .78149 L
s
P
p
.2 0 1 r
.02 w
.46835 .6458 m
.56694 .78149 L
s
P
p
.2 0 1 r
.02 w
.46835 .6458 m
.62787 .69763 L
s
P
p
0 .4 1 r
.018 w
.42958 .61763 m
.39081 .6458 L
s
P
p
0 .4 1 r
.018 w
.42958 .61763 m
.46835 .6458 L
s
P
p
.2 0 1 r
.02 w
.53439 .22884 m
.70212 .22884 L
s
P
p
.2 0 1 r
.02 w
.53439 .22884 m
.67008 .13025 L
s
P
p
.2 0 1 r
.02 w
.46065 .20488 m
.40882 .04536 L
s
P
p
.2 0 1 r
.02 w
.46065 .20488 m
.32496 .10629 L
s
P
p
0 .4 1 r
.018 w
.48882 .24364 m
.53439 .22884 L
s
P
p
0 .4 1 r
.018 w
.48882 .24364 m
.46065 .20488 L
s
P
p
.2 0 1 r
.02 w
.26899 .58102 m
.10948 .52919 L
s
P
p
.2 0 1 r
.02 w
.26899 .58102 m
.10948 .63285 L
s
P
p
.2 0 1 r
.02 w
.33172 .6266 m
.33172 .79432 L
s
P
p
.2 0 1 r
.02 w
.33172 .6266 m
.43031 .76229 L
s
P
p
0 .4 1 r
.018 w
.31691 .58102 m
.26899 .58102 L
s
P
p
0 .4 1 r
.018 w
.31691 .58102 m
.33172 .6266 L
s
P
p
.2 0 1 r
.02 w
.63023 .32809 m
.76592 .42667 L
s
P
p
.2 0 1 r
.02 w
.63023 .32809 m
.79796 .32809 L
s
P
p
.2 0 1 r
.02 w
.58466 .26536 m
.63649 .10584 L
s
P
p
.2 0 1 r
.02 w
.58466 .26536 m
.53283 .10584 L
s
P
p
0 .4 1 r
.018 w
.58466 .31328 m
.63023 .32809 L
s
P
p
0 .4 1 r
.018 w
.58466 .31328 m
.58466 .26536 L
s
P
p
.2 0 1 r
.02 w
.20851 .45701 m
.10992 .32132 L
s
P
p
.2 0 1 r
.02 w
.20851 .45701 m
.049 .40518 L
s
P
p
.2 0 1 r
.02 w
.23247 .53076 m
.13388 .66645 L
s
P
p
.2 0 1 r
.02 w
.23247 .53076 m
.23247 .69848 L
s
P
p
0 .4 1 r
.018 w
.24728 .48518 m
.20851 .45701 L
s
P
p
0 .4 1 r
.018 w
.24728 .48518 m
.23247 .53076 L
s
P
p
.2 0 1 r
.016 w
.42958 .42595 m
.42958 .61763 L
s
P
p
.2 0 1 r
.016 w
.42958 .42595 m
.48882 .24364 L
s
P
p
.2 0 1 r
.016 w
.42958 .42595 m
.31691 .58102 L
s
P
p
.2 0 1 r
.016 w
.42958 .42595 m
.58466 .31328 L
s
P
p
.2 0 1 r
.016 w
.42958 .42595 m
.24728 .48518 L
s
P
p
.2 0 1 r
.02 w
.59786 .64948 m
.49928 .78517 L
s
P
p
.2 0 1 r
.02 w
.59786 .64948 m
.59786 .8172 L
s
P
p
.2 0 1 r
.02 w
.66059 .6039 m
.82011 .65573 L
s
P
p
.2 0 1 r
.02 w
.66059 .6039 m
.82011 .55207 L
s
P
p
0 .4 1 r
.018 w
.61267 .6039 m
.59786 .64948 L
s
P
p
0 .4 1 r
.018 w
.61267 .6039 m
.66059 .6039 L
s
P
p
.2 0 1 r
.02 w
.46893 .22776 m
.60463 .12917 L
s
P
p
.2 0 1 r
.02 w
.46893 .22776 m
.52076 .06824 L
s
P
p
.2 0 1 r
.02 w
.39519 .25172 m
.2595 .15313 L
s
P
p
.2 0 1 r
.02 w
.39519 .25172 m
.22747 .25172 L
s
P
p
0 .4 1 r
.018 w
.44077 .26652 m
.46893 .22776 L
s
P
p
0 .4 1 r
.018 w
.44077 .26652 m
.39519 .25172 L
s
P
p
.2 0 1 r
.02 w
.46123 .66868 m
.30172 .72051 L
s
P
p
.2 0 1 r
.02 w
.46123 .66868 m
.36265 .80437 L
s
P
p
.2 0 1 r
.02 w
.53877 .66868 m
.63735 .80437 L
s
P
p
.2 0 1 r
.02 w
.53877 .66868 m
.69828 .72051 L
s
P
p
0 .4 1 r
.018 w
.5 .64051 m
.46123 .66868 L
s
P
p
0 .4 1 r
.018 w
.5 .64051 m
.53877 .66868 L
s
P
p
.2 0 1 r
.02 w
.60481 .25172 m
.77253 .25172 L
s
P
p
.2 0 1 r
.02 w
.60481 .25172 m
.7405 .15313 L
s
P
p
.2 0 1 r
.02 w
.53107 .22776 m
.47924 .06824 L
s
P
p
.2 0 1 r
.02 w
.53107 .22776 m
.39537 .12917 L
s
P
p
0 .4 1 r
.018 w
.55923 .26652 m
.60481 .25172 L
s
P
p
0 .4 1 r
.018 w
.55923 .26652 m
.53107 .22776 L
s
P
p
.2 0 1 r
.02 w
.33941 .6039 m
.17989 .55207 L
s
P
p
.2 0 1 r
.02 w
.33941 .6039 m
.17989 .65573 L
s
P
p
.2 0 1 r
.02 w
.40214 .64948 m
.40214 .8172 L
s
P
p
.2 0 1 r
.02 w
.40214 .64948 m
.50072 .78517 L
s
P
p
0 .4 1 r
.018 w
.38733 .6039 m
.33941 .6039 L
s
P
p
0 .4 1 r
.018 w
.38733 .6039 m
.40214 .64948 L
s
P
p
.2 0 1 r
.016 w
.5 .44883 m
.61267 .6039 L
s
P
p
.2 0 1 r
.016 w
.5 .44883 m
.44077 .26652 L
s
P
p
.2 0 1 r
.016 w
.5 .44883 m
.5 .64051 L
s
P
p
.2 0 1 r
.016 w
.5 .44883 m
.55923 .26652 L
s
P
p
.2 0 1 r
.016 w
.5 .44883 m
.38733 .6039 L
s
P
p
.2 0 1 r
.02 w
.76753 .53076 m
.76753 .69848 L
s
P
p
.2 0 1 r
.02 w
.76753 .53076 m
.86612 .66645 L
s
P
p
.2 0 1 r
.02 w
.79149 .45701 m
.951 .40518 L
s
P
p
.2 0 1 r
.02 w
.79149 .45701 m
.89008 .32132 L
s
P
p
0 .4 1 r
.018 w
.75272 .48518 m
.76753 .53076 L
s
P
p
0 .4 1 r
.018 w
.75272 .48518 m
.79149 .45701 L
s
P
p
.2 0 1 r
.02 w
.41534 .26536 m
.46717 .10584 L
s
P
p
.2 0 1 r
.02 w
.41534 .26536 m
.36351 .10584 L
s
P
p
.2 0 1 r
.02 w
.36977 .32809 m
.20204 .32809 L
s
P
p
.2 0 1 r
.02 w
.36977 .32809 m
.23408 .42667 L
s
P
p
0 .4 1 r
.018 w
.41534 .31328 m
.41534 .26536 L
s
P
p
0 .4 1 r
.018 w
.41534 .31328 m
.36977 .32809 L
s
P
p
.2 0 1 r
.02 w
.66828 .6266 m
.56969 .76229 L
s
P
p
.2 0 1 r
.02 w
.66828 .6266 m
.66828 .79432 L
s
P
p
.2 0 1 r
.02 w
.73101 .58102 m
.89052 .63285 L
s
P
p
.2 0 1 r
.02 w
.73101 .58102 m
.89052 .52919 L
s
P
p
0 .4 1 r
.018 w
.68309 .58102 m
.66828 .6266 L
s
P
p
0 .4 1 r
.018 w
.68309 .58102 m
.73101 .58102 L
s
P
p
.2 0 1 r
.02 w
.53935 .20488 m
.67504 .10629 L
s
P
p
.2 0 1 r
.02 w
.53935 .20488 m
.59118 .04536 L
s
P
p
.2 0 1 r
.02 w
.46561 .22884 m
.32992 .13025 L
s
P
p
.2 0 1 r
.02 w
.46561 .22884 m
.29788 .22884 L
s
P
p
0 .4 1 r
.018 w
.51118 .24364 m
.53935 .20488 L
s
P
p
0 .4 1 r
.018 w
.51118 .24364 m
.46561 .22884 L
s
P
p
.2 0 1 r
.02 w
.53165 .6458 m
.37213 .69763 L
s
P
p
.2 0 1 r
.02 w
.53165 .6458 m
.43306 .78149 L
s
P
p
.2 0 1 r
.02 w
.60919 .6458 m
.70777 .78149 L
s
P
p
.2 0 1 r
.02 w
.60919 .6458 m
.7687 .69763 L
s
P
p
0 .4 1 r
.018 w
.57042 .61763 m
.53165 .6458 L
s
P
p
0 .4 1 r
.018 w
.57042 .61763 m
.60919 .6458 L
s
P
p
.2 0 1 r
.016 w
.57042 .42595 m
.75272 .48518 L
s
P
p
.2 0 1 r
.016 w
.57042 .42595 m
.41534 .31328 L
s
P
p
.2 0 1 r
.016 w
.57042 .42595 m
.68309 .58102 L
s
P
p
.2 0 1 r
.016 w
.57042 .42595 m
.51118 .24364 L
s
P
p
.2 0 1 r
.016 w
.57042 .42595 m
.57042 .61763 L
s
P
p
1 .6 0 r
.016 w
.5 .32902 m
.42958 .42595 L
s
P
p
1 .6 0 r
.016 w
.5 .32902 m
.5 .44883 L
s
P
p
1 .6 0 r
.016 w
.5 .32902 m
.57042 .42595 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0492176 0.952381 [
[ 0 0 0 0 ]
[ 1 .85395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85395 L
0 .85395 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.018 w
.38504 .65346 m
.24108 .70023 L
s
P
p
.2 0 1 r
.018 w
.38504 .65346 m
.29606 .77592 L
s
P
p
.2 0 1 r
.018 w
.46668 .65346 m
.55565 .77592 L
s
P
p
.2 0 1 r
.018 w
.46668 .65346 m
.61064 .70023 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.38504 .65346 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.46668 .65346 L
s
P
p
.2 0 1 r
.018 w
.53621 .21443 m
.68758 .21443 L
s
P
p
.2 0 1 r
.018 w
.53621 .21443 m
.65867 .12546 L
s
P
p
.2 0 1 r
.018 w
.45857 .18921 m
.41179 .04525 L
s
P
p
.2 0 1 r
.018 w
.45857 .18921 m
.33611 .10023 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.53621 .21443 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.45857 .18921 L
s
P
p
.2 0 1 r
.018 w
.25677 .58525 m
.11281 .53848 L
s
P
p
.2 0 1 r
.018 w
.25677 .58525 m
.11281 .63203 L
s
P
p
.2 0 1 r
.018 w
.32282 .63324 m
.32282 .78461 L
s
P
p
.2 0 1 r
.018 w
.32282 .63324 m
.41179 .7557 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.25677 .58525 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.32282 .63324 L
s
P
p
.2 0 1 r
.018 w
.63712 .31894 m
.75958 .40791 L
s
P
p
.2 0 1 r
.018 w
.63712 .31894 m
.78849 .31894 L
s
P
p
.2 0 1 r
.018 w
.58914 .25289 m
.63591 .10893 L
s
P
p
.2 0 1 r
.018 w
.58914 .25289 m
.54236 .10893 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.63712 .31894 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.58914 .25289 L
s
P
p
.2 0 1 r
.018 w
.19309 .45468 m
.10412 .33222 L
s
P
p
.2 0 1 r
.018 w
.19309 .45468 m
.04913 .40791 L
s
P
p
.2 0 1 r
.018 w
.21832 .53233 m
.12934 .65479 L
s
P
p
.2 0 1 r
.018 w
.21832 .53233 m
.21832 .6837 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.19309 .45468 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.21832 .53233 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.42586 .6238 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.48822 .23003 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.30723 .58525 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.58914 .30334 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.23391 .48434 L
s
P
p
.2 0 1 r
.018 w
.60304 .65733 m
.51407 .77979 L
s
P
p
.2 0 1 r
.018 w
.60304 .65733 m
.60304 .8087 L
s
P
p
.2 0 1 r
.018 w
.66909 .60934 m
.81305 .65612 L
s
P
p
.2 0 1 r
.018 w
.66909 .60934 m
.81305 .56257 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.60304 .65733 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.66909 .60934 L
s
P
p
.2 0 1 r
.018 w
.46729 .2133 m
.58975 .12432 L
s
P
p
.2 0 1 r
.018 w
.46729 .2133 m
.51407 .06934 L
s
P
p
.2 0 1 r
.018 w
.38965 .23853 m
.26719 .14955 L
s
P
p
.2 0 1 r
.018 w
.38965 .23853 m
.23828 .23853 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.46729 .2133 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.38965 .23853 L
s
P
p
.2 0 1 r
.018 w
.45918 .67755 m
.31522 .72432 L
s
P
p
.2 0 1 r
.018 w
.45918 .67755 m
.37021 .80001 L
s
P
p
.2 0 1 r
.018 w
.54082 .67755 m
.62979 .80001 L
s
P
p
.2 0 1 r
.018 w
.54082 .67755 m
.68478 .72432 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.45918 .67755 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.54082 .67755 L
s
P
p
.2 0 1 r
.018 w
.61035 .23853 m
.76172 .23853 L
s
P
p
.2 0 1 r
.018 w
.61035 .23853 m
.73281 .14955 L
s
P
p
.2 0 1 r
.018 w
.53271 .2133 m
.48593 .06934 L
s
P
p
.2 0 1 r
.018 w
.53271 .2133 m
.41025 .12432 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.61035 .23853 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.53271 .2133 L
s
P
p
.2 0 1 r
.018 w
.33091 .60934 m
.18695 .56257 L
s
P
p
.2 0 1 r
.018 w
.33091 .60934 m
.18695 .65612 L
s
P
p
.2 0 1 r
.018 w
.39696 .65733 m
.39696 .8087 L
s
P
p
.2 0 1 r
.018 w
.39696 .65733 m
.48593 .77979 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.33091 .60934 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.39696 .65733 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.61863 .60934 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.43763 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.5 .64789 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.56237 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.38137 .60934 L
s
P
p
.2 0 1 r
.018 w
.78168 .53233 m
.78168 .6837 L
s
P
p
.2 0 1 r
.018 w
.78168 .53233 m
.87066 .65479 L
s
P
p
.2 0 1 r
.018 w
.80691 .45468 m
.95087 .40791 L
s
P
p
.2 0 1 r
.018 w
.80691 .45468 m
.89588 .33222 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.78168 .53233 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.80691 .45468 L
s
P
p
.2 0 1 r
.018 w
.41086 .25289 m
.45764 .10893 L
s
P
p
.2 0 1 r
.018 w
.41086 .25289 m
.36409 .10893 L
s
P
p
.2 0 1 r
.018 w
.36288 .31894 m
.21151 .31894 L
s
P
p
.2 0 1 r
.018 w
.36288 .31894 m
.24042 .40791 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.41086 .25289 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.36288 .31894 L
s
P
p
.2 0 1 r
.018 w
.67718 .63324 m
.58821 .7557 L
s
P
p
.2 0 1 r
.018 w
.67718 .63324 m
.67718 .78461 L
s
P
p
.2 0 1 r
.018 w
.74323 .58525 m
.88719 .63203 L
s
P
p
.2 0 1 r
.018 w
.74323 .58525 m
.88719 .53848 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.67718 .63324 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.74323 .58525 L
s
P
p
.2 0 1 r
.018 w
.54143 .18921 m
.66389 .10023 L
s
P
p
.2 0 1 r
.018 w
.54143 .18921 m
.58821 .04525 L
s
P
p
.2 0 1 r
.018 w
.46379 .21443 m
.34133 .12546 L
s
P
p
.2 0 1 r
.018 w
.46379 .21443 m
.31242 .21443 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.54143 .18921 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.46379 .21443 L
s
P
p
.2 0 1 r
.018 w
.53332 .65346 m
.38936 .70023 L
s
P
p
.2 0 1 r
.018 w
.53332 .65346 m
.44435 .77592 L
s
P
p
.2 0 1 r
.018 w
.61496 .65346 m
.70394 .77592 L
s
P
p
.2 0 1 r
.018 w
.61496 .65346 m
.75892 .70023 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.53332 .65346 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.61496 .65346 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.76609 .48434 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.41086 .30334 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.69277 .58525 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.51178 .23003 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.57414 .6238 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.42586 .42197 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.5 .44606 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.57414 .42197 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0492176 0.952381 [
[ 0 0 0 0 ]
[ 1 .85395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85395 L
0 .85395 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.02 w
.38504 .65346 m
.24108 .70023 L
s
P
p
0 .4 1 r
.02 w
.38504 .65346 m
.29606 .77592 L
s
P
p
0 .4 1 r
.02 w
.46668 .65346 m
.55565 .77592 L
s
P
p
0 .4 1 r
.02 w
.46668 .65346 m
.61064 .70023 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.38504 .65346 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.46668 .65346 L
s
P
p
0 .4 1 r
.02 w
.53621 .21443 m
.68758 .21443 L
s
P
p
0 .4 1 r
.02 w
.53621 .21443 m
.65867 .12546 L
s
P
p
0 .4 1 r
.02 w
.45857 .18921 m
.41179 .04525 L
s
P
p
0 .4 1 r
.02 w
.45857 .18921 m
.33611 .10023 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.53621 .21443 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.45857 .18921 L
s
P
p
0 .4 1 r
.02 w
.25677 .58525 m
.11281 .53848 L
s
P
p
0 .4 1 r
.02 w
.25677 .58525 m
.11281 .63203 L
s
P
p
0 .4 1 r
.02 w
.32282 .63324 m
.32282 .78461 L
s
P
p
0 .4 1 r
.02 w
.32282 .63324 m
.41179 .7557 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.25677 .58525 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.32282 .63324 L
s
P
p
0 .4 1 r
.02 w
.63712 .31894 m
.75958 .40791 L
s
P
p
0 .4 1 r
.02 w
.63712 .31894 m
.78849 .31894 L
s
P
p
0 .4 1 r
.02 w
.58914 .25289 m
.63591 .10893 L
s
P
p
0 .4 1 r
.02 w
.58914 .25289 m
.54236 .10893 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.63712 .31894 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.58914 .25289 L
s
P
p
0 .4 1 r
.02 w
.19309 .45468 m
.10412 .33222 L
s
P
p
0 .4 1 r
.02 w
.19309 .45468 m
.04913 .40791 L
s
P
p
0 .4 1 r
.02 w
.21832 .53233 m
.12934 .65479 L
s
P
p
0 .4 1 r
.02 w
.21832 .53233 m
.21832 .6837 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.19309 .45468 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.21832 .53233 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.42586 .6238 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.48822 .23003 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.30723 .58525 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.58914 .30334 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.23391 .48434 L
s
P
p
0 .4 1 r
.02 w
.60304 .65733 m
.51407 .77979 L
s
P
p
0 .4 1 r
.02 w
.60304 .65733 m
.60304 .8087 L
s
P
p
0 .4 1 r
.02 w
.66909 .60934 m
.81305 .65612 L
s
P
p
0 .4 1 r
.02 w
.66909 .60934 m
.81305 .56257 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.60304 .65733 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.66909 .60934 L
s
P
p
0 .4 1 r
.02 w
.46729 .2133 m
.58975 .12432 L
s
P
p
0 .4 1 r
.02 w
.46729 .2133 m
.51407 .06934 L
s
P
p
0 .4 1 r
.02 w
.38965 .23853 m
.26719 .14955 L
s
P
p
0 .4 1 r
.02 w
.38965 .23853 m
.23828 .23853 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.46729 .2133 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.38965 .23853 L
s
P
p
0 .4 1 r
.02 w
.45918 .67755 m
.31522 .72432 L
s
P
p
0 .4 1 r
.02 w
.45918 .67755 m
.37021 .80001 L
s
P
p
0 .4 1 r
.02 w
.54082 .67755 m
.62979 .80001 L
s
P
p
0 .4 1 r
.02 w
.54082 .67755 m
.68478 .72432 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.45918 .67755 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.54082 .67755 L
s
P
p
0 .4 1 r
.02 w
.61035 .23853 m
.76172 .23853 L
s
P
p
0 .4 1 r
.02 w
.61035 .23853 m
.73281 .14955 L
s
P
p
0 .4 1 r
.02 w
.53271 .2133 m
.48593 .06934 L
s
P
p
0 .4 1 r
.02 w
.53271 .2133 m
.41025 .12432 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.61035 .23853 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.53271 .2133 L
s
P
p
0 .4 1 r
.02 w
.33091 .60934 m
.18695 .56257 L
s
P
p
0 .4 1 r
.02 w
.33091 .60934 m
.18695 .65612 L
s
P
p
0 .4 1 r
.02 w
.39696 .65733 m
.39696 .8087 L
s
P
p
0 .4 1 r
.02 w
.39696 .65733 m
.48593 .77979 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.33091 .60934 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.39696 .65733 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.61863 .60934 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.43763 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.5 .64789 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.56237 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.38137 .60934 L
s
P
p
0 .4 1 r
.02 w
.78168 .53233 m
.78168 .6837 L
s
P
p
0 .4 1 r
.02 w
.78168 .53233 m
.87066 .65479 L
s
P
p
0 .4 1 r
.02 w
.80691 .45468 m
.95087 .40791 L
s
P
p
0 .4 1 r
.02 w
.80691 .45468 m
.89588 .33222 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.78168 .53233 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.80691 .45468 L
s
P
p
0 .4 1 r
.02 w
.41086 .25289 m
.45764 .10893 L
s
P
p
0 .4 1 r
.02 w
.41086 .25289 m
.36409 .10893 L
s
P
p
0 .4 1 r
.02 w
.36288 .31894 m
.21151 .31894 L
s
P
p
0 .4 1 r
.02 w
.36288 .31894 m
.24042 .40791 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.41086 .25289 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.36288 .31894 L
s
P
p
0 .4 1 r
.02 w
.67718 .63324 m
.58821 .7557 L
s
P
p
0 .4 1 r
.02 w
.67718 .63324 m
.67718 .78461 L
s
P
p
0 .4 1 r
.02 w
.74323 .58525 m
.88719 .63203 L
s
P
p
0 .4 1 r
.02 w
.74323 .58525 m
.88719 .53848 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.67718 .63324 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.74323 .58525 L
s
P
p
0 .4 1 r
.02 w
.54143 .18921 m
.66389 .10023 L
s
P
p
0 .4 1 r
.02 w
.54143 .18921 m
.58821 .04525 L
s
P
p
0 .4 1 r
.02 w
.46379 .21443 m
.34133 .12546 L
s
P
p
0 .4 1 r
.02 w
.46379 .21443 m
.31242 .21443 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.54143 .18921 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.46379 .21443 L
s
P
p
0 .4 1 r
.02 w
.53332 .65346 m
.38936 .70023 L
s
P
p
0 .4 1 r
.02 w
.53332 .65346 m
.44435 .77592 L
s
P
p
0 .4 1 r
.02 w
.61496 .65346 m
.70394 .77592 L
s
P
p
0 .4 1 r
.02 w
.61496 .65346 m
.75892 .70023 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.53332 .65346 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.61496 .65346 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.76609 .48434 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.41086 .30334 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.69277 .58525 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.51178 .23003 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.57414 .6238 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.42586 .42197 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.5 .44606 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.57414 .42197 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0658404 0.952381 [
[ 0 0 0 0 ]
[ 1 .8207 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8207 L
0 .8207 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.52889 .60957 m
.43992 .73203 L
s
P
p
.2 0 1 r
.02 w
.52889 .60957 m
.52889 .76094 L
s
P
p
.2 0 1 r
.02 w
.59494 .56158 m
.7389 .60836 L
s
P
p
.2 0 1 r
.02 w
.59494 .56158 m
.7389 .51481 L
s
P
p
0 .4 1 r
.018 w
.54449 .56158 m
.52889 .60957 L
s
P
p
0 .4 1 r
.018 w
.54449 .56158 m
.59494 .56158 L
s
P
p
.2 0 1 r
.02 w
.46668 .16682 m
.61064 .12005 L
s
P
p
.2 0 1 r
.02 w
.46668 .16682 m
.55565 .04436 L
s
P
p
.2 0 1 r
.02 w
.38504 .16682 m
.29606 .04436 L
s
P
p
.2 0 1 r
.02 w
.38504 .16682 m
.24108 .12005 L
s
P
p
0 .4 1 r
.018 w
.42586 .19648 m
.46668 .16682 L
s
P
p
0 .4 1 r
.018 w
.42586 .19648 m
.38504 .16682 L
s
P
p
.2 0 1 r
.02 w
.25677 .56158 m
.11281 .51481 L
s
P
p
.2 0 1 r
.02 w
.25677 .56158 m
.11281 .60836 L
s
P
p
.2 0 1 r
.02 w
.32282 .60957 m
.32282 .76094 L
s
P
p
.2 0 1 r
.02 w
.32282 .60957 m
.41179 .73203 L
s
P
p
0 .4 1 r
.018 w
.30723 .56158 m
.25677 .56158 L
s
P
p
0 .4 1 r
.018 w
.30723 .56158 m
.32282 .60957 L
s
P
p
.2 0 1 r
.02 w
.65862 .36559 m
.7476 .48805 L
s
P
p
.2 0 1 r
.02 w
.65862 .36559 m
.80258 .41237 L
s
P
p
.2 0 1 r
.02 w
.6334 .28795 m
.72237 .16549 L
s
P
p
.2 0 1 r
.02 w
.6334 .28795 m
.6334 .13658 L
s
P
p
0 .4 1 r
.018 w
.6178 .33594 m
.65862 .36559 L
s
P
p
0 .4 1 r
.018 w
.6178 .33594 m
.6334 .28795 L
s
P
p
.2 0 1 r
.02 w
.21832 .28795 m
.21832 .13658 L
s
P
p
.2 0 1 r
.02 w
.21832 .28795 m
.12934 .16549 L
s
P
p
.2 0 1 r
.02 w
.19309 .36559 m
.04913 .41237 L
s
P
p
.2 0 1 r
.02 w
.19309 .36559 m
.10412 .48805 L
s
P
p
0 .4 1 r
.018 w
.23391 .33594 m
.21832 .28795 L
s
P
p
0 .4 1 r
.018 w
.23391 .33594 m
.19309 .36559 L
s
P
p
.2 0 1 r
.016 w
.42586 .3983 m
.54449 .56158 L
s
P
p
.2 0 1 r
.016 w
.42586 .3983 m
.42586 .19648 L
s
P
p
.2 0 1 r
.016 w
.42586 .3983 m
.30723 .56158 L
s
P
p
.2 0 1 r
.016 w
.42586 .3983 m
.6178 .33594 L
s
P
p
.2 0 1 r
.016 w
.42586 .3983 m
.23391 .33594 L
s
P
p
.2 0 1 r
.02 w
.70754 .53275 m
.70754 .68412 L
s
P
p
.2 0 1 r
.02 w
.70754 .53275 m
.79651 .65521 L
s
P
p
.2 0 1 r
.02 w
.73277 .45511 m
.87673 .40833 L
s
P
p
.2 0 1 r
.02 w
.73277 .45511 m
.82174 .33265 L
s
P
p
0 .4 1 r
.018 w
.69195 .48476 m
.70754 .53275 L
s
P
p
0 .4 1 r
.018 w
.69195 .48476 m
.73277 .45511 L
s
P
p
.2 0 1 r
.02 w
.39696 .21113 m
.48593 .08867 L
s
P
p
.2 0 1 r
.02 w
.39696 .21113 m
.39696 .05976 L
s
P
p
.2 0 1 r
.02 w
.33091 .25912 m
.18695 .21234 L
s
P
p
.2 0 1 r
.02 w
.33091 .25912 m
.18695 .30589 L
s
P
p
0 .4 1 r
.018 w
.38137 .25912 m
.39696 .21113 L
s
P
p
0 .4 1 r
.018 w
.38137 .25912 m
.33091 .25912 L
s
P
p
.2 0 1 r
.02 w
.45918 .65388 m
.31522 .70065 L
s
P
p
.2 0 1 r
.02 w
.45918 .65388 m
.37021 .77634 L
s
P
p
.2 0 1 r
.02 w
.54082 .65388 m
.62979 .77634 L
s
P
p
.2 0 1 r
.02 w
.54082 .65388 m
.68478 .70065 L
s
P
p
0 .4 1 r
.018 w
.5 .62422 m
.45918 .65388 L
s
P
p
0 .4 1 r
.018 w
.5 .62422 m
.54082 .65388 L
s
P
p
.2 0 1 r
.02 w
.66909 .25912 m
.81305 .30589 L
s
P
p
.2 0 1 r
.02 w
.66909 .25912 m
.81305 .21234 L
s
P
p
.2 0 1 r
.02 w
.60304 .21113 m
.60304 .05976 L
s
P
p
.2 0 1 r
.02 w
.60304 .21113 m
.51407 .08867 L
s
P
p
0 .4 1 r
.018 w
.61863 .25912 m
.66909 .25912 L
s
P
p
0 .4 1 r
.018 w
.61863 .25912 m
.60304 .21113 L
s
P
p
.2 0 1 r
.02 w
.26723 .45511 m
.17826 .33265 L
s
P
p
.2 0 1 r
.02 w
.26723 .45511 m
.12327 .40833 L
s
P
p
.2 0 1 r
.02 w
.29246 .53275 m
.20349 .65521 L
s
P
p
.2 0 1 r
.02 w
.29246 .53275 m
.29246 .68412 L
s
P
p
0 .4 1 r
.018 w
.30805 .48476 m
.26723 .45511 L
s
P
p
0 .4 1 r
.018 w
.30805 .48476 m
.29246 .53275 L
s
P
p
.2 0 1 r
.016 w
.5 .4224 m
.69195 .48476 L
s
P
p
.2 0 1 r
.016 w
.5 .4224 m
.38137 .25912 L
s
P
p
.2 0 1 r
.016 w
.5 .4224 m
.5 .62422 L
s
P
p
.2 0 1 r
.016 w
.5 .4224 m
.61863 .25912 L
s
P
p
.2 0 1 r
.016 w
.5 .4224 m
.30805 .48476 L
s
P
p
.2 0 1 r
.02 w
.80691 .36559 m
.89588 .48805 L
s
P
p
.2 0 1 r
.02 w
.80691 .36559 m
.95087 .41237 L
s
P
p
.2 0 1 r
.02 w
.78168 .28795 m
.87066 .16549 L
s
P
p
.2 0 1 r
.02 w
.78168 .28795 m
.78168 .13658 L
s
P
p
0 .4 1 r
.018 w
.76609 .33594 m
.80691 .36559 L
s
P
p
0 .4 1 r
.018 w
.76609 .33594 m
.78168 .28795 L
s
P
p
.2 0 1 r
.02 w
.3666 .28795 m
.3666 .13658 L
s
P
p
.2 0 1 r
.02 w
.3666 .28795 m
.27763 .16549 L
s
P
p
.2 0 1 r
.02 w
.34138 .36559 m
.19742 .41237 L
s
P
p
.2 0 1 r
.02 w
.34138 .36559 m
.2524 .48805 L
s
P
p
0 .4 1 r
.018 w
.3822 .33594 m
.3666 .28795 L
s
P
p
0 .4 1 r
.018 w
.3822 .33594 m
.34138 .36559 L
s
P
p
.2 0 1 r
.02 w
.67718 .60957 m
.58821 .73203 L
s
P
p
.2 0 1 r
.02 w
.67718 .60957 m
.67718 .76094 L
s
P
p
.2 0 1 r
.02 w
.74323 .56158 m
.88719 .60836 L
s
P
p
.2 0 1 r
.02 w
.74323 .56158 m
.88719 .51481 L
s
P
p
0 .4 1 r
.018 w
.69277 .56158 m
.67718 .60957 L
s
P
p
0 .4 1 r
.018 w
.69277 .56158 m
.74323 .56158 L
s
P
p
.2 0 1 r
.02 w
.61496 .16682 m
.75892 .12005 L
s
P
p
.2 0 1 r
.02 w
.61496 .16682 m
.70394 .04436 L
s
P
p
.2 0 1 r
.02 w
.53332 .16682 m
.44435 .04436 L
s
P
p
.2 0 1 r
.02 w
.53332 .16682 m
.38936 .12005 L
s
P
p
0 .4 1 r
.018 w
.57414 .19648 m
.61496 .16682 L
s
P
p
0 .4 1 r
.018 w
.57414 .19648 m
.53332 .16682 L
s
P
p
.2 0 1 r
.02 w
.40506 .56158 m
.2611 .51481 L
s
P
p
.2 0 1 r
.02 w
.40506 .56158 m
.2611 .60836 L
s
P
p
.2 0 1 r
.02 w
.47111 .60957 m
.47111 .76094 L
s
P
p
.2 0 1 r
.02 w
.47111 .60957 m
.56008 .73203 L
s
P
p
0 .4 1 r
.018 w
.45551 .56158 m
.40506 .56158 L
s
P
p
0 .4 1 r
.018 w
.45551 .56158 m
.47111 .60957 L
s
P
p
.2 0 1 r
.016 w
.57414 .3983 m
.76609 .33594 L
s
P
p
.2 0 1 r
.016 w
.57414 .3983 m
.3822 .33594 L
s
P
p
.2 0 1 r
.016 w
.57414 .3983 m
.69277 .56158 L
s
P
p
.2 0 1 r
.016 w
.57414 .3983 m
.57414 .19648 L
s
P
p
.2 0 1 r
.016 w
.57414 .3983 m
.45551 .56158 L
s
P
p
1 .6 0 r
.016 w
.5 .29625 m
.42586 .3983 L
s
P
p
1 .6 0 r
.016 w
.5 .29625 m
.5 .4224 L
s
P
p
1 .6 0 r
.016 w
.5 .29625 m
.57414 .3983 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0513235 0.952381 [
[ 0 0 0 0 ]
[ 1 .84973 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .84973 L
0 .84973 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.37861 .63547 m
.22661 .68486 L
s
P
p
.2 0 1 r
.02 w
.37861 .63547 m
.28467 .76477 L
s
P
p
.2 0 1 r
.02 w
.46481 .63547 m
.55876 .76477 L
s
P
p
.2 0 1 r
.02 w
.46481 .63547 m
.61682 .68486 L
s
P
p
0 .4 1 r
.018 w
.42171 .60416 m
.37861 .63547 L
s
P
p
0 .4 1 r
.018 w
.42171 .60416 m
.46481 .63547 L
s
P
p
.2 0 1 r
.02 w
.53 .2239 m
.68983 .2239 L
s
P
p
.2 0 1 r
.02 w
.53 .2239 m
.6593 .12996 L
s
P
p
.2 0 1 r
.02 w
.44802 .19726 m
.39863 .04526 L
s
P
p
.2 0 1 r
.02 w
.44802 .19726 m
.31872 .10332 L
s
P
p
0 .4 1 r
.018 w
.47933 .24036 m
.53 .2239 L
s
P
p
0 .4 1 r
.018 w
.47933 .24036 m
.44802 .19726 L
s
P
p
.2 0 1 r
.02 w
.25884 .56855 m
.10684 .51916 L
s
P
p
.2 0 1 r
.02 w
.25884 .56855 m
.10684 .61794 L
s
P
p
.2 0 1 r
.02 w
.32858 .61921 m
.32858 .77904 L
s
P
p
.2 0 1 r
.02 w
.32858 .61921 m
.42252 .74851 L
s
P
p
0 .4 1 r
.018 w
.31212 .56855 m
.25884 .56855 L
s
P
p
0 .4 1 r
.018 w
.31212 .56855 m
.32858 .61921 L
s
P
p
.2 0 1 r
.02 w
.62323 .32456 m
.75253 .4185 L
s
P
p
.2 0 1 r
.02 w
.62323 .32456 m
.78306 .32456 L
s
P
p
.2 0 1 r
.02 w
.57257 .25482 m
.62195 .10282 L
s
P
p
.2 0 1 r
.02 w
.57257 .25482 m
.52318 .10282 L
s
P
p
0 .4 1 r
.018 w
.57257 .3081 m
.62323 .32456 L
s
P
p
0 .4 1 r
.018 w
.57257 .3081 m
.57257 .25482 L
s
P
p
.2 0 1 r
.02 w
.20128 .444 m
.10734 .3147 L
s
P
p
.2 0 1 r
.02 w
.20128 .444 m
.04928 .39461 L
s
P
p
.2 0 1 r
.02 w
.22792 .52598 m
.13397 .65528 L
s
P
p
.2 0 1 r
.02 w
.22792 .52598 m
.22792 .68581 L
s
P
p
0 .4 1 r
.018 w
.24438 .47532 m
.20128 .444 L
s
P
p
0 .4 1 r
.018 w
.24438 .47532 m
.22792 .52598 L
s
P
p
.2 0 1 r
.016 w
.42171 .4177 m
.42171 .60416 L
s
P
p
.2 0 1 r
.016 w
.42171 .4177 m
.47933 .24036 L
s
P
p
.2 0 1 r
.016 w
.42171 .4177 m
.31212 .56855 L
s
P
p
.2 0 1 r
.016 w
.42171 .4177 m
.57257 .3081 L
s
P
p
.2 0 1 r
.016 w
.42171 .4177 m
.24438 .47532 L
s
P
p
.2 0 1 r
.02 w
.59314 .64465 m
.49919 .77395 L
s
P
p
.2 0 1 r
.02 w
.59314 .64465 m
.59314 .80448 L
s
P
p
.2 0 1 r
.02 w
.66287 .59398 m
.81488 .64337 L
s
P
p
.2 0 1 r
.02 w
.66287 .59398 m
.81488 .5446 L
s
P
p
0 .4 1 r
.018 w
.6096 .59398 m
.59314 .64465 L
s
P
p
0 .4 1 r
.018 w
.6096 .59398 m
.66287 .59398 L
s
P
p
.2 0 1 r
.02 w
.47369 .2227 m
.60299 .12875 L
s
P
p
.2 0 1 r
.02 w
.47369 .2227 m
.52308 .0707 L
s
P
p
.2 0 1 r
.02 w
.39171 .24933 m
.26241 .15539 L
s
P
p
.2 0 1 r
.02 w
.39171 .24933 m
.23189 .24933 L
s
P
p
0 .4 1 r
.018 w
.44238 .2658 m
.47369 .2227 L
s
P
p
0 .4 1 r
.018 w
.44238 .2658 m
.39171 .24933 L
s
P
p
.2 0 1 r
.02 w
.4569 .66091 m
.3049 .7103 L
s
P
p
.2 0 1 r
.02 w
.4569 .66091 m
.36296 .79021 L
s
P
p
.2 0 1 r
.02 w
.5431 .66091 m
.63704 .79021 L
s
P
p
.2 0 1 r
.02 w
.5431 .66091 m
.6951 .7103 L
s
P
p
0 .4 1 r
.018 w
.5 .62959 m
.4569 .66091 L
s
P
p
0 .4 1 r
.018 w
.5 .62959 m
.5431 .66091 L
s
P
p
.2 0 1 r
.02 w
.60829 .24933 m
.76811 .24933 L
s
P
p
.2 0 1 r
.02 w
.60829 .24933 m
.73759 .15539 L
s
P
p
.2 0 1 r
.02 w
.52631 .2227 m
.47692 .0707 L
s
P
p
.2 0 1 r
.02 w
.52631 .2227 m
.39701 .12875 L
s
P
p
0 .4 1 r
.018 w
.55762 .2658 m
.60829 .24933 L
s
P
p
0 .4 1 r
.018 w
.55762 .2658 m
.52631 .2227 L
s
P
p
.2 0 1 r
.02 w
.33713 .59398 m
.18512 .5446 L
s
P
p
.2 0 1 r
.02 w
.33713 .59398 m
.18512 .64337 L
s
P
p
.2 0 1 r
.02 w
.40686 .64465 m
.40686 .80448 L
s
P
p
.2 0 1 r
.02 w
.40686 .64465 m
.50081 .77395 L
s
P
p
0 .4 1 r
.018 w
.3904 .59398 m
.33713 .59398 L
s
P
p
0 .4 1 r
.018 w
.3904 .59398 m
.40686 .64465 L
s
P
p
.2 0 1 r
.016 w
.5 .44313 m
.6096 .59398 L
s
P
p
.2 0 1 r
.016 w
.5 .44313 m
.44238 .2658 L
s
P
p
.2 0 1 r
.016 w
.5 .44313 m
.5 .62959 L
s
P
p
.2 0 1 r
.016 w
.5 .44313 m
.55762 .2658 L
s
P
p
.2 0 1 r
.016 w
.5 .44313 m
.3904 .59398 L
s
P
p
.2 0 1 r
.02 w
.77208 .52598 m
.77208 .68581 L
s
P
p
.2 0 1 r
.02 w
.77208 .52598 m
.86603 .65528 L
s
P
p
.2 0 1 r
.02 w
.79872 .444 m
.95072 .39461 L
s
P
p
.2 0 1 r
.02 w
.79872 .444 m
.89266 .3147 L
s
P
p
0 .4 1 r
.018 w
.75562 .47532 m
.77208 .52598 L
s
P
p
0 .4 1 r
.018 w
.75562 .47532 m
.79872 .444 L
s
P
p
.2 0 1 r
.02 w
.42743 .25482 m
.47682 .10282 L
s
P
p
.2 0 1 r
.02 w
.42743 .25482 m
.37805 .10282 L
s
P
p
.2 0 1 r
.02 w
.37677 .32456 m
.21694 .32456 L
s
P
p
.2 0 1 r
.02 w
.37677 .32456 m
.24747 .4185 L
s
P
p
0 .4 1 r
.018 w
.42743 .3081 m
.42743 .25482 L
s
P
p
0 .4 1 r
.018 w
.42743 .3081 m
.37677 .32456 L
s
P
p
.2 0 1 r
.02 w
.67142 .61921 m
.57748 .74851 L
s
P
p
.2 0 1 r
.02 w
.67142 .61921 m
.67142 .77904 L
s
P
p
.2 0 1 r
.02 w
.74116 .56855 m
.89316 .61794 L
s
P
p
.2 0 1 r
.02 w
.74116 .56855 m
.89316 .51916 L
s
P
p
0 .4 1 r
.018 w
.68788 .56855 m
.67142 .61921 L
s
P
p
0 .4 1 r
.018 w
.68788 .56855 m
.74116 .56855 L
s
P
p
.2 0 1 r
.02 w
.55198 .19726 m
.68128 .10332 L
s
P
p
.2 0 1 r
.02 w
.55198 .19726 m
.60137 .04526 L
s
P
p
.2 0 1 r
.02 w
.47 .2239 m
.3407 .12996 L
s
P
p
.2 0 1 r
.02 w
.47 .2239 m
.31017 .2239 L
s
P
p
0 .4 1 r
.018 w
.52067 .24036 m
.55198 .19726 L
s
P
p
0 .4 1 r
.018 w
.52067 .24036 m
.47 .2239 L
s
P
p
.2 0 1 r
.02 w
.53519 .63547 m
.38318 .68486 L
s
P
p
.2 0 1 r
.02 w
.53519 .63547 m
.44124 .76477 L
s
P
p
.2 0 1 r
.02 w
.62139 .63547 m
.71533 .76477 L
s
P
p
.2 0 1 r
.02 w
.62139 .63547 m
.77339 .68486 L
s
P
p
0 .4 1 r
.018 w
.57829 .60416 m
.53519 .63547 L
s
P
p
0 .4 1 r
.018 w
.57829 .60416 m
.62139 .63547 L
s
P
p
.2 0 1 r
.016 w
.57829 .4177 m
.75562 .47532 L
s
P
p
.2 0 1 r
.016 w
.57829 .4177 m
.42743 .3081 L
s
P
p
.2 0 1 r
.016 w
.57829 .4177 m
.68788 .56855 L
s
P
p
.2 0 1 r
.016 w
.57829 .4177 m
.52067 .24036 L
s
P
p
.2 0 1 r
.016 w
.57829 .4177 m
.57829 .60416 L
s
P
p
1 .6 0 r
.016 w
.5 .30995 m
.42171 .4177 L
s
P
p
1 .6 0 r
.016 w
.5 .30995 m
.5 .44313 L
s
P
p
1 .6 0 r
.016 w
.5 .30995 m
.57829 .4177 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0492176 0.952381 [
[ 0 0 0 0 ]
[ 1 .85395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85395 L
0 .85395 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.24108 .70023 L
s
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.29606 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.55565 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.61064 .70023 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.38504 .65346 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.46668 .65346 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.68758 .21443 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.65867 .12546 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.41179 .04525 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.33611 .10023 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.53621 .21443 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.45857 .18921 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .53848 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .63203 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.32282 .78461 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.41179 .7557 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.25677 .58525 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.32282 .63324 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.75958 .40791 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.78849 .31894 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.63591 .10893 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.54236 .10893 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.63712 .31894 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.58914 .25289 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.10412 .33222 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.04913 .40791 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.12934 .65479 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.21832 .6837 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.19309 .45468 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.21832 .53233 L
s
P
p
.2 0 1 r
.014 w
.42586 .42197 m
.42586 .6238 L
s
P
p
.2 0 1 r
.014 w
.42586 .42197 m
.48822 .23003 L
s
P
p
.2 0 1 r
.014 w
.42586 .42197 m
.30723 .58525 L
s
P
p
.2 0 1 r
.014 w
.42586 .42197 m
.58914 .30334 L
s
P
p
.2 0 1 r
.014 w
.42586 .42197 m
.23391 .48434 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.51407 .77979 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.60304 .8087 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .65612 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .56257 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.60304 .65733 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.66909 .60934 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.58975 .12432 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.51407 .06934 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.26719 .14955 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.23828 .23853 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.46729 .2133 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.38965 .23853 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.31522 .72432 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.37021 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.62979 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.68478 .72432 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.45918 .67755 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.54082 .67755 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.76172 .23853 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.73281 .14955 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.48593 .06934 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.41025 .12432 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.61035 .23853 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.53271 .2133 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .56257 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .65612 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.39696 .8087 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.48593 .77979 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.33091 .60934 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.39696 .65733 L
s
P
p
.2 0 1 r
.014 w
.5 .44606 m
.61863 .60934 L
s
P
p
.2 0 1 r
.014 w
.5 .44606 m
.43763 .25412 L
s
P
p
.2 0 1 r
.014 w
.5 .44606 m
.5 .64789 L
s
P
p
.2 0 1 r
.014 w
.5 .44606 m
.56237 .25412 L
s
P
p
.2 0 1 r
.014 w
.5 .44606 m
.38137 .60934 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.78168 .6837 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.87066 .65479 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.95087 .40791 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.89588 .33222 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.78168 .53233 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.80691 .45468 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.45764 .10893 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.36409 .10893 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.21151 .31894 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.24042 .40791 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.41086 .25289 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.36288 .31894 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.58821 .7557 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.67718 .78461 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .63203 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .53848 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.67718 .63324 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.74323 .58525 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.66389 .10023 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.58821 .04525 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.34133 .12546 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.31242 .21443 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.54143 .18921 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.46379 .21443 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.38936 .70023 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.44435 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.70394 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.75892 .70023 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.53332 .65346 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.61496 .65346 L
s
P
p
.2 0 1 r
.014 w
.57414 .42197 m
.76609 .48434 L
s
P
p
.2 0 1 r
.014 w
.57414 .42197 m
.41086 .30334 L
s
P
p
.2 0 1 r
.014 w
.57414 .42197 m
.69277 .58525 L
s
P
p
.2 0 1 r
.014 w
.57414 .42197 m
.51178 .23003 L
s
P
p
.2 0 1 r
.014 w
.57414 .42197 m
.57414 .6238 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.42586 .42197 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.5 .44606 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.57414 .42197 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0492176 0.952381 [
[ 0 0 0 0 ]
[ 1 .85395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85395 L
0 .85395 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.24108 .70023 L
s
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.29606 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.55565 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.61064 .70023 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.38504 .65346 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.46668 .65346 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.68758 .21443 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.65867 .12546 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.41179 .04525 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.33611 .10023 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.53621 .21443 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.45857 .18921 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .53848 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .63203 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.32282 .78461 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.41179 .7557 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.25677 .58525 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.32282 .63324 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.75958 .40791 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.78849 .31894 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.63591 .10893 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.54236 .10893 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.63712 .31894 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.58914 .25289 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.10412 .33222 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.04913 .40791 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.12934 .65479 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.21832 .6837 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.19309 .45468 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.21832 .53233 L
s
P
p
.8 0 1 r
.016 w
.42586 .42197 m
.42586 .6238 L
s
P
p
.8 0 1 r
.016 w
.42586 .42197 m
.48822 .23003 L
s
P
p
.8 0 1 r
.016 w
.42586 .42197 m
.30723 .58525 L
s
P
p
.8 0 1 r
.016 w
.42586 .42197 m
.58914 .30334 L
s
P
p
.8 0 1 r
.016 w
.42586 .42197 m
.23391 .48434 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.51407 .77979 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.60304 .8087 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .65612 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .56257 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.60304 .65733 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.66909 .60934 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.58975 .12432 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.51407 .06934 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.26719 .14955 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.23828 .23853 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.46729 .2133 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.38965 .23853 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.31522 .72432 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.37021 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.62979 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.68478 .72432 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.45918 .67755 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.54082 .67755 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.76172 .23853 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.73281 .14955 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.48593 .06934 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.41025 .12432 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.61035 .23853 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.53271 .2133 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .56257 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .65612 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.39696 .8087 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.48593 .77979 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.33091 .60934 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.39696 .65733 L
s
P
p
.8 0 1 r
.016 w
.5 .44606 m
.61863 .60934 L
s
P
p
.8 0 1 r
.016 w
.5 .44606 m
.43763 .25412 L
s
P
p
.8 0 1 r
.016 w
.5 .44606 m
.5 .64789 L
s
P
p
.8 0 1 r
.016 w
.5 .44606 m
.56237 .25412 L
s
P
p
.8 0 1 r
.016 w
.5 .44606 m
.38137 .60934 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.78168 .6837 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.87066 .65479 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.95087 .40791 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.89588 .33222 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.78168 .53233 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.80691 .45468 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.45764 .10893 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.36409 .10893 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.21151 .31894 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.24042 .40791 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.41086 .25289 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.36288 .31894 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.58821 .7557 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.67718 .78461 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .63203 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .53848 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.67718 .63324 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.74323 .58525 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.66389 .10023 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.58821 .04525 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.34133 .12546 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.31242 .21443 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.54143 .18921 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.46379 .21443 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.38936 .70023 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.44435 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.70394 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.75892 .70023 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.53332 .65346 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.61496 .65346 L
s
P
p
.8 0 1 r
.016 w
.57414 .42197 m
.76609 .48434 L
s
P
p
.8 0 1 r
.016 w
.57414 .42197 m
.41086 .30334 L
s
P
p
.8 0 1 r
.016 w
.57414 .42197 m
.69277 .58525 L
s
P
p
.8 0 1 r
.016 w
.57414 .42197 m
.51178 .23003 L
s
P
p
.8 0 1 r
.016 w
.57414 .42197 m
.57414 .6238 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.42586 .42197 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.5 .44606 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.57414 .42197 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0371957 0.952381 [
[ 0 0 0 0 ]
[ 1 .87799 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .87799 L
0 .87799 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.38167 .60537 m
.26303 .51916 L
s
P
p
.2 0 1 r
.02 w
.38167 .60537 m
.23502 .60537 L
s
P
p
.2 0 1 r
.02 w
.42816 .66936 m
.38285 .80884 L
s
P
p
.2 0 1 r
.02 w
.42816 .66936 m
.47348 .80884 L
s
P
p
.2 0 1 r
.02 w
.47466 .60537 m
.62131 .60537 L
s
P
p
.2 0 1 r
.02 w
.47466 .60537 m
.5933 .51916 L
s
P
p
0 .4 1 r
.018 w
.42816 .62047 m
.38167 .60537 L
s
P
p
0 .4 1 r
.018 w
.42816 .62047 m
.42816 .66936 L
s
P
p
0 .4 1 r
.018 w
.42816 .62047 m
.47466 .60537 L
s
P
p
.2 0 1 r
.02 w
.52814 .2677 m
.61434 .38634 L
s
P
p
.2 0 1 r
.02 w
.52814 .2677 m
.66762 .31301 L
s
P
p
.2 0 1 r
.02 w
.5037 .19247 m
.5899 .07382 L
s
P
p
.2 0 1 r
.02 w
.5037 .19247 m
.5037 .04581 L
s
P
p
.2 0 1 r
.02 w
.43971 .23896 m
.30023 .19364 L
s
P
p
.2 0 1 r
.02 w
.43971 .23896 m
.30023 .28428 L
s
P
p
0 .4 1 r
.018 w
.48859 .23896 m
.52814 .2677 L
s
P
p
0 .4 1 r
.018 w
.48859 .23896 m
.5037 .19247 L
s
P
p
0 .4 1 r
.018 w
.48859 .23896 m
.43971 .23896 L
s
P
p
.2 0 1 r
.02 w
.28449 .54358 m
.23918 .4041 L
s
P
p
.2 0 1 r
.02 w
.28449 .54358 m
.16585 .45738 L
s
P
p
.2 0 1 r
.02 w
.28449 .62268 m
.16585 .70888 L
s
P
p
.2 0 1 r
.02 w
.28449 .62268 m
.23918 .76215 L
s
P
p
.2 0 1 r
.02 w
.35972 .59823 m
.47837 .68444 L
s
P
p
.2 0 1 r
.02 w
.35972 .59823 m
.50638 .59823 L
s
P
p
0 .4 1 r
.018 w
.31323 .58313 m
.28449 .54358 L
s
P
p
0 .4 1 r
.018 w
.31323 .58313 m
.28449 .62268 L
s
P
p
0 .4 1 r
.018 w
.31323 .58313 m
.35972 .59823 L
s
P
p
.2 0 1 r
.02 w
.60147 .35649 m
.60147 .50314 L
s
P
p
.2 0 1 r
.02 w
.60147 .35649 m
.68767 .47514 L
s
P
p
.2 0 1 r
.02 w
.62591 .28126 m
.76539 .23594 L
s
P
p
.2 0 1 r
.02 w
.62591 .28126 m
.71211 .16261 L
s
P
p
.2 0 1 r
.02 w
.54681 .28126 m
.46061 .16261 L
s
P
p
.2 0 1 r
.02 w
.54681 .28126 m
.40733 .23594 L
s
P
p
0 .4 1 r
.018 w
.58636 .31 m
.60147 .35649 L
s
P
p
0 .4 1 r
.018 w
.58636 .31 m
.62591 .28126 L
s
P
p
0 .4 1 r
.018 w
.58636 .31 m
.54681 .28126 L
s
P
p
.2 0 1 r
.02 w
.24219 .43647 m
.28751 .29699 L
s
P
p
.2 0 1 r
.02 w
.24219 .43647 m
.19688 .29699 L
s
P
p
.2 0 1 r
.02 w
.1957 .50046 m
.04905 .50046 L
s
P
p
.2 0 1 r
.02 w
.1957 .50046 m
.07705 .58667 L
s
P
p
.2 0 1 r
.02 w
.27093 .52491 m
.31625 .66438 L
s
P
p
.2 0 1 r
.02 w
.27093 .52491 m
.38958 .61111 L
s
P
p
0 .4 1 r
.018 w
.24219 .48536 m
.24219 .43647 L
s
P
p
0 .4 1 r
.018 w
.24219 .48536 m
.1957 .50046 L
s
P
p
0 .4 1 r
.018 w
.24219 .48536 m
.27093 .52491 L
s
P
p
.2 0 1 r
.016 w
.42816 .42493 m
.42816 .62047 L
s
P
p
.2 0 1 r
.016 w
.42816 .42493 m
.48859 .23896 L
s
P
p
.2 0 1 r
.016 w
.42816 .42493 m
.31323 .58313 L
s
P
p
.2 0 1 r
.016 w
.42816 .42493 m
.58636 .31 L
s
P
p
.2 0 1 r
.016 w
.42816 .42493 m
.24219 .48536 L
s
P
p
.2 0 1 r
.02 w
.56844 .62157 m
.42179 .62157 L
s
P
p
.2 0 1 r
.02 w
.56844 .62157 m
.4498 .70778 L
s
P
p
.2 0 1 r
.02 w
.64367 .64602 m
.68899 .7855 L
s
P
p
.2 0 1 r
.02 w
.64367 .64602 m
.76232 .73222 L
s
P
p
.2 0 1 r
.02 w
.64367 .56692 m
.76232 .48072 L
s
P
p
.2 0 1 r
.02 w
.64367 .56692 m
.68899 .42744 L
s
P
p
0 .4 1 r
.018 w
.61494 .60647 m
.56844 .62157 L
s
P
p
0 .4 1 r
.018 w
.61494 .60647 m
.64367 .64602 L
s
P
p
0 .4 1 r
.018 w
.61494 .60647 m
.64367 .56692 L
s
P
p
.2 0 1 r
.02 w
.48846 .2623 m
.62794 .30762 L
s
P
p
.2 0 1 r
.02 w
.48846 .2623 m
.62794 .21698 L
s
P
p
.2 0 1 r
.02 w
.42447 .21581 m
.42447 .06915 L
s
P
p
.2 0 1 r
.02 w
.42447 .21581 m
.33827 .09716 L
s
P
p
.2 0 1 r
.02 w
.40003 .29104 m
.26055 .33636 L
s
P
p
.2 0 1 r
.02 w
.40003 .29104 m
.31382 .40968 L
s
P
p
0 .4 1 r
.018 w
.43957 .2623 m
.48846 .2623 L
s
P
p
0 .4 1 r
.018 w
.43957 .2623 m
.42447 .21581 L
s
P
p
0 .4 1 r
.018 w
.43957 .2623 m
.40003 .29104 L
s
P
p
.2 0 1 r
.02 w
.45351 .62871 m
.33486 .54251 L
s
P
p
.2 0 1 r
.02 w
.45351 .62871 m
.30685 .62871 L
s
P
p
.2 0 1 r
.02 w
.5 .6927 m
.45468 .83218 L
s
P
p
.2 0 1 r
.02 w
.5 .6927 m
.54532 .83218 L
s
P
p
.2 0 1 r
.02 w
.54649 .62871 m
.69315 .62871 L
s
P
p
.2 0 1 r
.02 w
.54649 .62871 m
.66514 .54251 L
s
P
p
0 .4 1 r
.018 w
.5 .64381 m
.45351 .62871 L
s
P
p
0 .4 1 r
.018 w
.5 .64381 m
.5 .6927 L
s
P
p
0 .4 1 r
.018 w
.5 .64381 m
.54649 .62871 L
s
P
p
.2 0 1 r
.02 w
.59997 .29104 m
.68618 .40968 L
s
P
p
.2 0 1 r
.02 w
.59997 .29104 m
.73945 .33636 L
s
P
p
.2 0 1 r
.02 w
.57553 .21581 m
.66173 .09716 L
s
P
p
.2 0 1 r
.02 w
.57553 .21581 m
.57553 .06915 L
s
P
p
.2 0 1 r
.02 w
.51154 .2623 m
.37206 .21698 L
s
P
p
.2 0 1 r
.02 w
.51154 .2623 m
.37206 .30762 L
s
P
p
0 .4 1 r
.018 w
.56043 .2623 m
.59997 .29104 L
s
P
p
0 .4 1 r
.018 w
.56043 .2623 m
.57553 .21581 L
s
P
p
0 .4 1 r
.018 w
.56043 .2623 m
.51154 .2623 L
s
P
p
.2 0 1 r
.02 w
.35633 .56692 m
.31101 .42744 L
s
P
p
.2 0 1 r
.02 w
.35633 .56692 m
.23768 .48072 L
s
P
p
.2 0 1 r
.02 w
.35633 .64602 m
.23768 .73222 L
s
P
p
.2 0 1 r
.02 w
.35633 .64602 m
.31101 .7855 L
s
P
p
.2 0 1 r
.02 w
.43156 .62157 m
.5502 .70778 L
s
P
p
.2 0 1 r
.02 w
.43156 .62157 m
.57821 .62157 L
s
P
p
0 .4 1 r
.018 w
.38506 .60647 m
.35633 .56692 L
s
P
p
0 .4 1 r
.018 w
.38506 .60647 m
.35633 .64602 L
s
P
p
0 .4 1 r
.018 w
.38506 .60647 m
.43156 .62157 L
s
P
p
.2 0 1 r
.016 w
.5 .44827 m
.61494 .60647 L
s
P
p
.2 0 1 r
.016 w
.5 .44827 m
.43957 .2623 L
s
P
p
.2 0 1 r
.016 w
.5 .44827 m
.5 .64381 L
s
P
p
.2 0 1 r
.016 w
.5 .44827 m
.56043 .2623 L
s
P
p
.2 0 1 r
.016 w
.5 .44827 m
.38506 .60647 L
s
P
p
.2 0 1 r
.02 w
.72907 .52491 m
.61042 .61111 L
s
P
p
.2 0 1 r
.02 w
.72907 .52491 m
.68375 .66438 L
s
P
p
.2 0 1 r
.02 w
.8043 .50046 m
.92295 .58667 L
s
P
p
.2 0 1 r
.02 w
.8043 .50046 m
.95095 .50046 L
s
P
p
.2 0 1 r
.02 w
.75781 .43647 m
.80312 .29699 L
s
P
p
.2 0 1 r
.02 w
.75781 .43647 m
.71249 .29699 L
s
P
p
0 .4 1 r
.018 w
.75781 .48536 m
.72907 .52491 L
s
P
p
0 .4 1 r
.018 w
.75781 .48536 m
.8043 .50046 L
s
P
p
0 .4 1 r
.018 w
.75781 .48536 m
.75781 .43647 L
s
P
p
.2 0 1 r
.02 w
.45319 .28126 m
.59267 .23594 L
s
P
p
.2 0 1 r
.02 w
.45319 .28126 m
.53939 .16261 L
s
P
p
.2 0 1 r
.02 w
.37409 .28126 m
.28789 .16261 L
s
P
p
.2 0 1 r
.02 w
.37409 .28126 m
.23461 .23594 L
s
P
p
.2 0 1 r
.02 w
.39853 .35649 m
.31233 .47514 L
s
P
p
.2 0 1 r
.02 w
.39853 .35649 m
.39853 .50314 L
s
P
p
0 .4 1 r
.018 w
.41364 .31 m
.45319 .28126 L
s
P
p
0 .4 1 r
.018 w
.41364 .31 m
.37409 .28126 L
s
P
p
0 .4 1 r
.018 w
.41364 .31 m
.39853 .35649 L
s
P
p
.2 0 1 r
.02 w
.64028 .59823 m
.49362 .59823 L
s
P
p
.2 0 1 r
.02 w
.64028 .59823 m
.52163 .68444 L
s
P
p
.2 0 1 r
.02 w
.71551 .62268 m
.76082 .76215 L
s
P
p
.2 0 1 r
.02 w
.71551 .62268 m
.83415 .70888 L
s
P
p
.2 0 1 r
.02 w
.71551 .54358 m
.83415 .45738 L
s
P
p
.2 0 1 r
.02 w
.71551 .54358 m
.76082 .4041 L
s
P
p
0 .4 1 r
.018 w
.68677 .58313 m
.64028 .59823 L
s
P
p
0 .4 1 r
.018 w
.68677 .58313 m
.71551 .62268 L
s
P
p
0 .4 1 r
.018 w
.68677 .58313 m
.71551 .54358 L
s
P
p
.2 0 1 r
.02 w
.56029 .23896 m
.69977 .28428 L
s
P
p
.2 0 1 r
.02 w
.56029 .23896 m
.69977 .19364 L
s
P
p
.2 0 1 r
.02 w
.4963 .19247 m
.4963 .04581 L
s
P
p
.2 0 1 r
.02 w
.4963 .19247 m
.4101 .07382 L
s
P
p
.2 0 1 r
.02 w
.47186 .2677 m
.33238 .31301 L
s
P
p
.2 0 1 r
.02 w
.47186 .2677 m
.38566 .38634 L
s
P
p
0 .4 1 r
.018 w
.51141 .23896 m
.56029 .23896 L
s
P
p
0 .4 1 r
.018 w
.51141 .23896 m
.4963 .19247 L
s
P
p
0 .4 1 r
.018 w
.51141 .23896 m
.47186 .2677 L
s
P
p
.2 0 1 r
.02 w
.52534 .60537 m
.4067 .51916 L
s
P
p
.2 0 1 r
.02 w
.52534 .60537 m
.37869 .60537 L
s
P
p
.2 0 1 r
.02 w
.57184 .66936 m
.52652 .80884 L
s
P
p
.2 0 1 r
.02 w
.57184 .66936 m
.61715 .80884 L
s
P
p
.2 0 1 r
.02 w
.61833 .60537 m
.76498 .60537 L
s
P
p
.2 0 1 r
.02 w
.61833 .60537 m
.73697 .51916 L
s
P
p
0 .4 1 r
.018 w
.57184 .62047 m
.52534 .60537 L
s
P
p
0 .4 1 r
.018 w
.57184 .62047 m
.57184 .66936 L
s
P
p
0 .4 1 r
.018 w
.57184 .62047 m
.61833 .60537 L
s
P
p
.2 0 1 r
.016 w
.57184 .42493 m
.75781 .48536 L
s
P
p
.2 0 1 r
.016 w
.57184 .42493 m
.41364 .31 L
s
P
p
.2 0 1 r
.016 w
.57184 .42493 m
.68677 .58313 L
s
P
p
.2 0 1 r
.016 w
.57184 .42493 m
.51141 .23896 L
s
P
p
.2 0 1 r
.016 w
.57184 .42493 m
.57184 .62047 L
s
P
p
1 .6 0 r
.016 w
.5 .32606 m
.42816 .42493 L
s
P
p
1 .6 0 r
.016 w
.5 .32606 m
.5 .44827 L
s
P
p
1 .6 0 r
.016 w
.5 .32606 m
.57184 .42493 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0476533 0.952381 [
[ 0 0 0 0 ]
[ 1 .85707 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85707 L
0 .85707 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.39247 .65615 m
.26042 .72344 L
s
P
p
.2 0 1 r
.02 w
.39247 .65615 m
.32519 .78821 L
s
P
p
.2 0 1 r
.02 w
.46234 .65615 m
.52962 .78821 L
s
P
p
.2 0 1 r
.02 w
.46234 .65615 m
.59439 .72344 L
s
P
p
0 .4 1 r
.018 w
.42741 .62122 m
.39247 .65615 L
s
P
p
0 .4 1 r
.018 w
.42741 .62122 m
.46234 .65615 L
s
P
p
.2 0 1 r
.02 w
.53249 .21325 m
.67887 .19007 L
s
P
p
.2 0 1 r
.02 w
.53249 .21325 m
.63728 .10845 L
s
P
p
.2 0 1 r
.02 w
.46604 .19166 m
.44286 .04528 L
s
P
p
.2 0 1 r
.02 w
.46604 .19166 m
.36125 .08687 L
s
P
p
0 .4 1 r
.018 w
.48847 .23568 m
.53249 .21325 L
s
P
p
0 .4 1 r
.018 w
.48847 .23568 m
.46604 .19166 L
s
P
p
.2 0 1 r
.02 w
.26246 .59121 m
.11608 .56803 L
s
P
p
.2 0 1 r
.02 w
.26246 .59121 m
.13041 .65849 L
s
P
p
.2 0 1 r
.02 w
.31898 .63228 m
.2958 .77866 L
s
P
p
.2 0 1 r
.02 w
.31898 .63228 m
.38627 .76433 L
s
P
p
0 .4 1 r
.018 w
.31126 .58348 m
.26246 .59121 L
s
P
p
0 .4 1 r
.018 w
.31126 .58348 m
.31898 .63228 L
s
P
p
.2 0 1 r
.02 w
.63607 .31519 m
.76812 .38248 L
s
P
p
.2 0 1 r
.02 w
.63607 .31519 m
.78245 .29201 L
s
P
p
.2 0 1 r
.02 w
.595 .25867 m
.66229 .12662 L
s
P
p
.2 0 1 r
.02 w
.595 .25867 m
.57182 .11229 L
s
P
p
0 .4 1 r
.018 w
.58727 .30746 m
.63607 .31519 L
s
P
p
0 .4 1 r
.018 w
.58727 .30746 m
.595 .25867 L
s
P
p
.2 0 1 r
.02 w
.19545 .46225 m
.09066 .35745 L
s
P
p
.2 0 1 r
.02 w
.19545 .46225 m
.04907 .43907 L
s
P
p
.2 0 1 r
.02 w
.21704 .5287 m
.11225 .63349 L
s
P
p
.2 0 1 r
.02 w
.21704 .5287 m
.19386 .67508 L
s
P
p
0 .4 1 r
.018 w
.23947 .48468 m
.19545 .46225 L
s
P
p
0 .4 1 r
.018 w
.23947 .48468 m
.21704 .5287 L
s
P
p
.2 0 1 r
.016 w
.42741 .42361 m
.42741 .62122 L
s
P
p
.2 0 1 r
.016 w
.42741 .42361 m
.48847 .23568 L
s
P
p
.2 0 1 r
.016 w
.42741 .42361 m
.31126 .58348 L
s
P
p
.2 0 1 r
.016 w
.42741 .42361 m
.58727 .30746 L
s
P
p
.2 0 1 r
.016 w
.42741 .42361 m
.23947 .48468 L
s
P
p
.2 0 1 r
.02 w
.60842 .65586 m
.54114 .78791 L
s
P
p
.2 0 1 r
.02 w
.60842 .65586 m
.63161 .80224 L
s
P
p
.2 0 1 r
.02 w
.66494 .6148 m
.797 .68208 L
s
P
p
.2 0 1 r
.02 w
.66494 .6148 m
.81132 .59161 L
s
P
p
0 .4 1 r
.018 w
.61615 .60707 m
.60842 .65586 L
s
P
p
0 .4 1 r
.018 w
.61615 .60707 m
.66494 .6148 L
s
P
p
.2 0 1 r
.02 w
.46136 .21525 m
.56616 .11045 L
s
P
p
.2 0 1 r
.02 w
.46136 .21525 m
.48455 .06887 L
s
P
p
.2 0 1 r
.02 w
.39492 .23684 m
.29012 .13204 L
s
P
p
.2 0 1 r
.02 w
.39492 .23684 m
.24854 .21365 L
s
P
p
0 .4 1 r
.018 w
.43894 .25927 m
.46136 .21525 L
s
P
p
0 .4 1 r
.018 w
.43894 .25927 m
.39492 .23684 L
s
P
p
.2 0 1 r
.02 w
.46507 .67974 m
.33302 .74702 L
s
P
p
.2 0 1 r
.02 w
.46507 .67974 m
.39778 .81179 L
s
P
p
.2 0 1 r
.02 w
.53493 .67974 m
.60222 .81179 L
s
P
p
.2 0 1 r
.02 w
.53493 .67974 m
.66698 .74702 L
s
P
p
0 .4 1 r
.018 w
.5 .64481 m
.46507 .67974 L
s
P
p
0 .4 1 r
.018 w
.5 .64481 m
.53493 .67974 L
s
P
p
.2 0 1 r
.02 w
.60508 .23684 m
.75146 .21365 L
s
P
p
.2 0 1 r
.02 w
.60508 .23684 m
.70988 .13204 L
s
P
p
.2 0 1 r
.02 w
.53864 .21525 m
.51545 .06887 L
s
P
p
.2 0 1 r
.02 w
.53864 .21525 m
.43384 .11045 L
s
P
p
0 .4 1 r
.018 w
.56106 .25927 m
.60508 .23684 L
s
P
p
0 .4 1 r
.018 w
.56106 .25927 m
.53864 .21525 L
s
P
p
.2 0 1 r
.02 w
.33506 .6148 m
.18868 .59161 L
s
P
p
.2 0 1 r
.02 w
.33506 .6148 m
.203 .68208 L
s
P
p
.2 0 1 r
.02 w
.39158 .65586 m
.36839 .80224 L
s
P
p
.2 0 1 r
.02 w
.39158 .65586 m
.45886 .78791 L
s
P
p
0 .4 1 r
.018 w
.38385 .60707 m
.33506 .6148 L
s
P
p
0 .4 1 r
.018 w
.38385 .60707 m
.39158 .65586 L
s
P
p
.2 0 1 r
.016 w
.5 .4472 m
.61615 .60707 L
s
P
p
.2 0 1 r
.016 w
.5 .4472 m
.43894 .25927 L
s
P
p
.2 0 1 r
.016 w
.5 .4472 m
.5 .64481 L
s
P
p
.2 0 1 r
.016 w
.5 .4472 m
.56106 .25927 L
s
P
p
.2 0 1 r
.016 w
.5 .4472 m
.38385 .60707 L
s
P
p
.2 0 1 r
.02 w
.78296 .5287 m
.80614 .67508 L
s
P
p
.2 0 1 r
.02 w
.78296 .5287 m
.88775 .63349 L
s
P
p
.2 0 1 r
.02 w
.80455 .46225 m
.95093 .43907 L
s
P
p
.2 0 1 r
.02 w
.80455 .46225 m
.90934 .35745 L
s
P
p
0 .4 1 r
.018 w
.76053 .48468 m
.78296 .5287 L
s
P
p
0 .4 1 r
.018 w
.76053 .48468 m
.80455 .46225 L
s
P
p
.2 0 1 r
.02 w
.405 .25867 m
.42818 .11229 L
s
P
p
.2 0 1 r
.02 w
.405 .25867 m
.33771 .12662 L
s
P
p
.2 0 1 r
.02 w
.36393 .31519 m
.21755 .29201 L
s
P
p
.2 0 1 r
.02 w
.36393 .31519 m
.23188 .38248 L
s
P
p
0 .4 1 r
.018 w
.41273 .30746 m
.405 .25867 L
s
P
p
0 .4 1 r
.018 w
.41273 .30746 m
.36393 .31519 L
s
P
p
.2 0 1 r
.02 w
.68102 .63228 m
.61373 .76433 L
s
P
p
.2 0 1 r
.02 w
.68102 .63228 m
.7042 .77866 L
s
P
p
.2 0 1 r
.02 w
.73754 .59121 m
.86959 .65849 L
s
P
p
.2 0 1 r
.02 w
.73754 .59121 m
.88392 .56803 L
s
P
p
0 .4 1 r
.018 w
.68874 .58348 m
.68102 .63228 L
s
P
p
0 .4 1 r
.018 w
.68874 .58348 m
.73754 .59121 L
s
P
p
.2 0 1 r
.02 w
.53396 .19166 m
.63875 .08687 L
s
P
p
.2 0 1 r
.02 w
.53396 .19166 m
.55714 .04528 L
s
P
p
.2 0 1 r
.02 w
.46751 .21325 m
.36272 .10845 L
s
P
p
.2 0 1 r
.02 w
.46751 .21325 m
.32113 .19007 L
s
P
p
0 .4 1 r
.018 w
.51153 .23568 m
.53396 .19166 L
s
P
p
0 .4 1 r
.018 w
.51153 .23568 m
.46751 .21325 L
s
P
p
.2 0 1 r
.02 w
.53766 .65615 m
.40561 .72344 L
s
P
p
.2 0 1 r
.02 w
.53766 .65615 m
.47038 .78821 L
s
P
p
.2 0 1 r
.02 w
.60753 .65615 m
.67481 .78821 L
s
P
p
.2 0 1 r
.02 w
.60753 .65615 m
.73958 .72344 L
s
P
p
0 .4 1 r
.018 w
.57259 .62122 m
.53766 .65615 L
s
P
p
0 .4 1 r
.018 w
.57259 .62122 m
.60753 .65615 L
s
P
p
.2 0 1 r
.016 w
.57259 .42361 m
.76053 .48468 L
s
P
p
.2 0 1 r
.016 w
.57259 .42361 m
.41273 .30746 L
s
P
p
.2 0 1 r
.016 w
.57259 .42361 m
.68874 .58348 L
s
P
p
.2 0 1 r
.016 w
.57259 .42361 m
.51153 .23568 L
s
P
p
.2 0 1 r
.016 w
.57259 .42361 m
.57259 .62122 L
s
P
p
1 .6 0 r
.016 w
.5 .3237 m
.42741 .42361 L
s
P
p
1 .6 0 r
.016 w
.5 .3237 m
.5 .4472 L
s
P
p
1 .6 0 r
.016 w
.5 .3237 m
.57259 .42361 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0544013 0.952381 [
[ 0 0 0 0 ]
[ 1 .84358 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .84358 L
0 .84358 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.40099 .64505 m
.25025 .69403 L
s
P
p
.2 0 1 r
.02 w
.40099 .64505 m
.30783 .77328 L
s
P
p
.2 0 1 r
.02 w
.44373 .64505 m
.5369 .77328 L
s
P
p
.2 0 1 r
.02 w
.44373 .64505 m
.59448 .69403 L
s
P
p
0 .4 1 r
.018 w
.42236 .62952 m
.40099 .64505 L
s
P
p
0 .4 1 r
.018 w
.42236 .62952 m
.44373 .64505 L
s
P
p
.2 0 1 r
.02 w
.51279 .20903 m
.67129 .20903 L
s
P
p
.2 0 1 r
.02 w
.51279 .20903 m
.64102 .11586 L
s
P
p
.2 0 1 r
.02 w
.47214 .19582 m
.42316 .04507 L
s
P
p
.2 0 1 r
.02 w
.47214 .19582 m
.34391 .10265 L
s
P
p
0 .4 1 r
.018 w
.48767 .21719 m
.51279 .20903 L
s
P
p
0 .4 1 r
.018 w
.48767 .21719 m
.47214 .19582 L
s
P
p
.2 0 1 r
.02 w
.27173 .58916 m
.12098 .54018 L
s
P
p
.2 0 1 r
.02 w
.27173 .58916 m
.12098 .63814 L
s
P
p
.2 0 1 r
.02 w
.30631 .61428 m
.30631 .77278 L
s
P
p
.2 0 1 r
.02 w
.30631 .61428 m
.39947 .74251 L
s
P
p
0 .4 1 r
.018 w
.29814 .58916 m
.27173 .58916 L
s
P
p
0 .4 1 r
.018 w
.29814 .58916 m
.30631 .61428 L
s
P
p
.2 0 1 r
.02 w
.61846 .30213 m
.74669 .39529 L
s
P
p
.2 0 1 r
.02 w
.61846 .30213 m
.77696 .30213 L
s
P
p
.2 0 1 r
.02 w
.59334 .26755 m
.64232 .1168 L
s
P
p
.2 0 1 r
.02 w
.59334 .26755 m
.54436 .1168 L
s
P
p
0 .4 1 r
.018 w
.59334 .29396 m
.61846 .30213 L
s
P
p
0 .4 1 r
.018 w
.59334 .29396 m
.59334 .26755 L
s
P
p
.2 0 1 r
.02 w
.2 .46796 m
.10683 .33973 L
s
P
p
.2 0 1 r
.02 w
.2 .46796 m
.04925 .41898 L
s
P
p
.2 0 1 r
.02 w
.21321 .50861 m
.12004 .63684 L
s
P
p
.2 0 1 r
.02 w
.21321 .50861 m
.21321 .66712 L
s
P
p
0 .4 1 r
.018 w
.22137 .48349 m
.2 .46796 L
s
P
p
0 .4 1 r
.018 w
.22137 .48349 m
.21321 .50861 L
s
P
p
.2 0 1 r
.016 w
.42236 .41818 m
.42236 .62952 L
s
P
p
.2 0 1 r
.016 w
.42236 .41818 m
.48767 .21719 L
s
P
p
.2 0 1 r
.016 w
.42236 .41818 m
.29814 .58916 L
s
P
p
.2 0 1 r
.016 w
.42236 .41818 m
.59334 .29396 L
s
P
p
.2 0 1 r
.016 w
.42236 .41818 m
.22137 .48349 L
s
P
p
.2 0 1 r
.02 w
.61606 .63951 m
.52289 .76774 L
s
P
p
.2 0 1 r
.02 w
.61606 .63951 m
.61606 .79801 L
s
P
p
.2 0 1 r
.02 w
.65064 .61438 m
.80138 .66336 L
s
P
p
.2 0 1 r
.02 w
.65064 .61438 m
.80138 .5654 L
s
P
p
0 .4 1 r
.018 w
.62422 .61438 m
.61606 .63951 L
s
P
p
0 .4 1 r
.018 w
.62422 .61438 m
.65064 .61438 L
s
P
p
.2 0 1 r
.02 w
.45022 .22105 m
.57845 .12788 L
s
P
p
.2 0 1 r
.02 w
.45022 .22105 m
.4992 .0703 L
s
P
p
.2 0 1 r
.02 w
.40957 .23425 m
.28134 .14109 L
s
P
p
.2 0 1 r
.02 w
.40957 .23425 m
.25107 .23425 L
s
P
p
0 .4 1 r
.018 w
.43469 .24242 m
.45022 .22105 L
s
P
p
0 .4 1 r
.018 w
.43469 .24242 m
.40957 .23425 L
s
P
p
.2 0 1 r
.02 w
.47863 .67027 m
.32788 .71925 L
s
P
p
.2 0 1 r
.02 w
.47863 .67027 m
.38546 .7985 L
s
P
p
.2 0 1 r
.02 w
.52137 .67027 m
.61454 .7985 L
s
P
p
.2 0 1 r
.02 w
.52137 .67027 m
.67212 .71925 L
s
P
p
0 .4 1 r
.018 w
.5 .65475 m
.47863 .67027 L
s
P
p
0 .4 1 r
.018 w
.5 .65475 m
.52137 .67027 L
s
P
p
.2 0 1 r
.02 w
.59043 .23425 m
.74893 .23425 L
s
P
p
.2 0 1 r
.02 w
.59043 .23425 m
.71866 .14109 L
s
P
p
.2 0 1 r
.02 w
.54978 .22105 m
.5008 .0703 L
s
P
p
.2 0 1 r
.02 w
.54978 .22105 m
.42155 .12788 L
s
P
p
0 .4 1 r
.018 w
.56531 .24242 m
.59043 .23425 L
s
P
p
0 .4 1 r
.018 w
.56531 .24242 m
.54978 .22105 L
s
P
p
.2 0 1 r
.02 w
.34936 .61438 m
.19862 .5654 L
s
P
p
.2 0 1 r
.02 w
.34936 .61438 m
.19862 .66336 L
s
P
p
.2 0 1 r
.02 w
.38394 .63951 m
.38394 .79801 L
s
P
p
.2 0 1 r
.02 w
.38394 .63951 m
.47711 .76774 L
s
P
p
0 .4 1 r
.018 w
.37578 .61438 m
.34936 .61438 L
s
P
p
0 .4 1 r
.018 w
.37578 .61438 m
.38394 .63951 L
s
P
p
.2 0 1 r
.016 w
.5 .44341 m
.62422 .61438 L
s
P
p
.2 0 1 r
.016 w
.5 .44341 m
.43469 .24242 L
s
P
p
.2 0 1 r
.016 w
.5 .44341 m
.5 .65475 L
s
P
p
.2 0 1 r
.016 w
.5 .44341 m
.56531 .24242 L
s
P
p
.2 0 1 r
.016 w
.5 .44341 m
.37578 .61438 L
s
P
p
.2 0 1 r
.02 w
.78679 .50861 m
.78679 .66712 L
s
P
p
.2 0 1 r
.02 w
.78679 .50861 m
.87996 .63684 L
s
P
p
.2 0 1 r
.02 w
.8 .46796 m
.95075 .41898 L
s
P
p
.2 0 1 r
.02 w
.8 .46796 m
.89317 .33973 L
s
P
p
0 .4 1 r
.018 w
.77863 .48349 m
.78679 .50861 L
s
P
p
0 .4 1 r
.018 w
.77863 .48349 m
.8 .46796 L
s
P
p
.2 0 1 r
.02 w
.40666 .26755 m
.45564 .1168 L
s
P
p
.2 0 1 r
.02 w
.40666 .26755 m
.35768 .1168 L
s
P
p
.2 0 1 r
.02 w
.38154 .30213 m
.22304 .30213 L
s
P
p
.2 0 1 r
.02 w
.38154 .30213 m
.25331 .39529 L
s
P
p
0 .4 1 r
.018 w
.40666 .29396 m
.40666 .26755 L
s
P
p
0 .4 1 r
.018 w
.40666 .29396 m
.38154 .30213 L
s
P
p
.2 0 1 r
.02 w
.69369 .61428 m
.60053 .74251 L
s
P
p
.2 0 1 r
.02 w
.69369 .61428 m
.69369 .77278 L
s
P
p
.2 0 1 r
.02 w
.72827 .58916 m
.87902 .63814 L
s
P
p
.2 0 1 r
.02 w
.72827 .58916 m
.87902 .54018 L
s
P
p
0 .4 1 r
.018 w
.70186 .58916 m
.69369 .61428 L
s
P
p
0 .4 1 r
.018 w
.70186 .58916 m
.72827 .58916 L
s
P
p
.2 0 1 r
.02 w
.52786 .19582 m
.65609 .10265 L
s
P
p
.2 0 1 r
.02 w
.52786 .19582 m
.57684 .04507 L
s
P
p
.2 0 1 r
.02 w
.48721 .20903 m
.35898 .11586 L
s
P
p
.2 0 1 r
.02 w
.48721 .20903 m
.32871 .20903 L
s
P
p
0 .4 1 r
.018 w
.51233 .21719 m
.52786 .19582 L
s
P
p
0 .4 1 r
.018 w
.51233 .21719 m
.48721 .20903 L
s
P
p
.2 0 1 r
.02 w
.55627 .64505 m
.40552 .69403 L
s
P
p
.2 0 1 r
.02 w
.55627 .64505 m
.4631 .77328 L
s
P
p
.2 0 1 r
.02 w
.59901 .64505 m
.69217 .77328 L
s
P
p
.2 0 1 r
.02 w
.59901 .64505 m
.74975 .69403 L
s
P
p
0 .4 1 r
.018 w
.57764 .62952 m
.55627 .64505 L
s
P
p
0 .4 1 r
.018 w
.57764 .62952 m
.59901 .64505 L
s
P
p
.2 0 1 r
.016 w
.57764 .41818 m
.77863 .48349 L
s
P
p
.2 0 1 r
.016 w
.57764 .41818 m
.40666 .29396 L
s
P
p
.2 0 1 r
.016 w
.57764 .41818 m
.70186 .58916 L
s
P
p
.2 0 1 r
.016 w
.57764 .41818 m
.51233 .21719 L
s
P
p
.2 0 1 r
.016 w
.57764 .41818 m
.57764 .62952 L
s
P
p
1 .6 0 r
.016 w
.5 .31132 m
.42236 .41818 L
s
P
p
1 .6 0 r
.016 w
.5 .31132 m
.5 .44341 L
s
P
p
1 .6 0 r
.016 w
.5 .31132 m
.57764 .41818 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0735362 0.952381 [
[ 0 0 0 0 ]
[ 1 .80531 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .80531 L
0 .80531 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.39138 .68163 m
.33158 .72508 L
s
P
p
0 .4 1 r
.018 w
.39138 .68163 m
.45118 .72508 L
s
P
p
0 .4 1 r
.018 w
.48275 .10474 m
.55305 .0819 L
s
P
p
0 .4 1 r
.018 w
.48275 .10474 m
.4393 .04494 L
s
P
p
0 .4 1 r
.018 w
.21758 .62516 m
.14366 .62516 L
s
P
p
0 .4 1 r
.018 w
.21758 .62516 m
.24042 .69546 L
s
P
p
0 .4 1 r
.018 w
.63059 .21215 m
.70089 .235 L
s
P
p
0 .4 1 r
.018 w
.63059 .21215 m
.63059 .13823 L
s
P
p
0 .4 1 r
.018 w
.11017 .47732 m
.05037 .43387 L
s
P
p
0 .4 1 r
.018 w
.11017 .47732 m
.08733 .54762 L
s
P
p
.2 0 1 r
.016 w
.39138 .38595 m
.39138 .68163 L
s
P
p
.2 0 1 r
.016 w
.39138 .38595 m
.48275 .10474 L
s
P
p
.2 0 1 r
.016 w
.39138 .38595 m
.21758 .62516 L
s
P
p
.2 0 1 r
.016 w
.39138 .38595 m
.63059 .21215 L
s
P
p
.2 0 1 r
.016 w
.39138 .38595 m
.11017 .47732 L
s
P
p
0 .4 1 r
.018 w
.6738 .66045 m
.65095 .73075 L
s
P
p
0 .4 1 r
.018 w
.6738 .66045 m
.74772 .66045 L
s
P
p
0 .4 1 r
.018 w
.40863 .14003 m
.45208 .08023 L
s
P
p
0 .4 1 r
.018 w
.40863 .14003 m
.33833 .11719 L
s
P
p
0 .4 1 r
.018 w
.5 .71692 m
.4402 .76037 L
s
P
p
0 .4 1 r
.018 w
.5 .71692 m
.5598 .76037 L
s
P
p
0 .4 1 r
.018 w
.59137 .14003 m
.66167 .11719 L
s
P
p
0 .4 1 r
.018 w
.59137 .14003 m
.54792 .08023 L
s
P
p
0 .4 1 r
.018 w
.3262 .66045 m
.25228 .66045 L
s
P
p
0 .4 1 r
.018 w
.3262 .66045 m
.34905 .73075 L
s
P
p
.2 0 1 r
.016 w
.5 .42124 m
.6738 .66045 L
s
P
p
.2 0 1 r
.016 w
.5 .42124 m
.40863 .14003 L
s
P
p
.2 0 1 r
.016 w
.5 .42124 m
.5 .71692 L
s
P
p
.2 0 1 r
.016 w
.5 .42124 m
.59137 .14003 L
s
P
p
.2 0 1 r
.016 w
.5 .42124 m
.3262 .66045 L
s
P
p
0 .4 1 r
.018 w
.88983 .47732 m
.91267 .54762 L
s
P
p
0 .4 1 r
.018 w
.88983 .47732 m
.94963 .43387 L
s
P
p
0 .4 1 r
.018 w
.36941 .21215 m
.36941 .13823 L
s
P
p
0 .4 1 r
.018 w
.36941 .21215 m
.29911 .235 L
s
P
p
0 .4 1 r
.018 w
.78242 .62516 m
.75958 .69546 L
s
P
p
0 .4 1 r
.018 w
.78242 .62516 m
.85634 .62516 L
s
P
p
0 .4 1 r
.018 w
.51725 .10474 m
.5607 .04494 L
s
P
p
0 .4 1 r
.018 w
.51725 .10474 m
.44695 .0819 L
s
P
p
0 .4 1 r
.018 w
.60862 .68163 m
.54882 .72508 L
s
P
p
0 .4 1 r
.018 w
.60862 .68163 m
.66842 .72508 L
s
P
p
.2 0 1 r
.016 w
.60862 .38595 m
.88983 .47732 L
s
P
p
.2 0 1 r
.016 w
.60862 .38595 m
.36941 .21215 L
s
P
p
.2 0 1 r
.016 w
.60862 .38595 m
.78242 .62516 L
s
P
p
.2 0 1 r
.016 w
.60862 .38595 m
.51725 .10474 L
s
P
p
.2 0 1 r
.016 w
.60862 .38595 m
.60862 .68163 L
s
P
p
1 .6 0 r
.016 w
.5 .23644 m
.39138 .38595 L
s
P
p
1 .6 0 r
.016 w
.5 .23644 m
.5 .42124 L
s
P
p
1 .6 0 r
.016 w
.5 .23644 m
.60862 .38595 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.29387 .59845 m
.14698 .59845 L
s
P
p
.2 0 1 r
.02 w
.29387 .59845 m
.17503 .6848 L
s
P
p
.2 0 1 r
.02 w
.36922 .62294 m
.41462 .76264 L
s
P
p
.2 0 1 r
.02 w
.36922 .62294 m
.48806 .70928 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.29387 .59845 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.36922 .62294 L
s
P
p
.2 0 1 r
.02 w
.56505 .2386 m
.70476 .28399 L
s
P
p
.2 0 1 r
.02 w
.56505 .2386 m
.70476 .1932 L
s
P
p
.2 0 1 r
.02 w
.50096 .19203 m
.50096 .04513 L
s
P
p
.2 0 1 r
.02 w
.50096 .19203 m
.41462 .07319 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.56505 .2386 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.50096 .19203 L
s
P
p
.2 0 1 r
.02 w
.19594 .49704 m
.0771 .4107 L
s
P
p
.2 0 1 r
.02 w
.19594 .49704 m
.04905 .49704 L
s
P
p
.2 0 1 r
.02 w
.24251 .56114 m
.19712 .70084 L
s
P
p
.2 0 1 r
.02 w
.24251 .56114 m
.28791 .70084 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.19594 .49704 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.24251 .56114 L
s
P
p
.2 0 1 r
.02 w
.62685 .36531 m
.7132 .48415 L
s
P
p
.2 0 1 r
.02 w
.62685 .36531 m
.76656 .4107 L
s
P
p
.2 0 1 r
.02 w
.60237 .28996 m
.68871 .17112 L
s
P
p
.2 0 1 r
.02 w
.60237 .28996 m
.60237 .14306 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.62685 .36531 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.60237 .28996 L
s
P
p
.2 0 1 r
.02 w
.17633 .35744 m
.13093 .21773 L
s
P
p
.2 0 1 r
.02 w
.17633 .35744 m
.05749 .27109 L
s
P
p
.2 0 1 r
.02 w
.17633 .43666 m
.05749 .52301 L
s
P
p
.2 0 1 r
.02 w
.17633 .43666 m
.13093 .57637 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .35744 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .43666 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.34044 .58332 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.51609 .2386 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.24251 .51217 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.58724 .33653 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.20511 .39705 L
s
P
p
.2 0 1 r
.02 w
.49392 .66741 m
.37508 .75375 L
s
P
p
.2 0 1 r
.02 w
.49392 .66741 m
.44852 .80711 L
s
P
p
.2 0 1 r
.02 w
.56926 .64292 m
.6881 .72927 L
s
P
p
.2 0 1 r
.02 w
.56926 .64292 m
.71616 .64292 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.49392 .66741 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.56926 .64292 L
s
P
p
.2 0 1 r
.02 w
.50179 .21688 m
.64149 .17149 L
s
P
p
.2 0 1 r
.02 w
.50179 .21688 m
.58813 .09804 L
s
P
p
.2 0 1 r
.02 w
.42256 .21688 m
.33622 .09804 L
s
P
p
.2 0 1 r
.02 w
.42256 .21688 m
.28285 .17149 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.50179 .21688 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.42256 .21688 L
s
P
p
.2 0 1 r
.02 w
.35508 .64292 m
.20819 .64292 L
s
P
p
.2 0 1 r
.02 w
.35508 .64292 m
.23624 .72927 L
s
P
p
.2 0 1 r
.02 w
.43043 .66741 m
.47582 .80711 L
s
P
p
.2 0 1 r
.02 w
.43043 .66741 m
.54927 .75375 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.35508 .64292 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.43043 .66741 L
s
P
p
.2 0 1 r
.02 w
.62626 .28307 m
.76597 .32846 L
s
P
p
.2 0 1 r
.02 w
.62626 .28307 m
.76597 .23767 L
s
P
p
.2 0 1 r
.02 w
.56216 .2365 m
.56216 .0896 L
s
P
p
.2 0 1 r
.02 w
.56216 .2365 m
.47582 .11766 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.62626 .28307 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.56216 .2365 L
s
P
p
.2 0 1 r
.02 w
.25715 .54151 m
.13831 .45517 L
s
P
p
.2 0 1 r
.02 w
.25715 .54151 m
.11026 .54151 L
s
P
p
.2 0 1 r
.02 w
.30372 .60561 m
.25833 .74531 L
s
P
p
.2 0 1 r
.02 w
.30372 .60561 m
.34911 .74531 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.25715 .54151 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.30372 .60561 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5227 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.46217 .24566 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.40165 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5773 .28307 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.30372 .55664 L
s
P
p
.2 0 1 r
.02 w
.69628 .60561 m
.65089 .74531 L
s
P
p
.2 0 1 r
.02 w
.69628 .60561 m
.74167 .74531 L
s
P
p
.2 0 1 r
.02 w
.74285 .54151 m
.88974 .54151 L
s
P
p
.2 0 1 r
.02 w
.74285 .54151 m
.86169 .45517 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.69628 .60561 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.74285 .54151 L
s
P
p
.2 0 1 r
.02 w
.43784 .2365 m
.52418 .11766 L
s
P
p
.2 0 1 r
.02 w
.43784 .2365 m
.43784 .0896 L
s
P
p
.2 0 1 r
.02 w
.37374 .28307 m
.23403 .23767 L
s
P
p
.2 0 1 r
.02 w
.37374 .28307 m
.23403 .32846 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.43784 .2365 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.37374 .28307 L
s
P
p
.2 0 1 r
.02 w
.56957 .66741 m
.45073 .75375 L
s
P
p
.2 0 1 r
.02 w
.56957 .66741 m
.52418 .80711 L
s
P
p
.2 0 1 r
.02 w
.64492 .64292 m
.76376 .72927 L
s
P
p
.2 0 1 r
.02 w
.64492 .64292 m
.79181 .64292 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.56957 .66741 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.64492 .64292 L
s
P
p
.2 0 1 r
.02 w
.57744 .21688 m
.71715 .17149 L
s
P
p
.2 0 1 r
.02 w
.57744 .21688 m
.66378 .09804 L
s
P
p
.2 0 1 r
.02 w
.49821 .21688 m
.41187 .09804 L
s
P
p
.2 0 1 r
.02 w
.49821 .21688 m
.35851 .17149 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.57744 .21688 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.49821 .21688 L
s
P
p
.2 0 1 r
.02 w
.43074 .64292 m
.28384 .64292 L
s
P
p
.2 0 1 r
.02 w
.43074 .64292 m
.3119 .72927 L
s
P
p
.2 0 1 r
.02 w
.50608 .66741 m
.55148 .80711 L
s
P
p
.2 0 1 r
.02 w
.50608 .66741 m
.62492 .75375 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.43074 .64292 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.50608 .66741 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.69628 .55664 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4227 .28307 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.59835 .62779 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.53783 .24566 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4773 .62779 L
s
P
p
.2 0 1 r
.02 w
.82367 .43666 m
.86907 .57637 L
s
P
p
.2 0 1 r
.02 w
.82367 .43666 m
.94251 .52301 L
s
P
p
.2 0 1 r
.02 w
.82367 .35744 m
.94251 .27109 L
s
P
p
.2 0 1 r
.02 w
.82367 .35744 m
.86907 .21773 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .43666 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .35744 L
s
P
p
.2 0 1 r
.02 w
.39763 .28996 m
.39763 .14306 L
s
P
p
.2 0 1 r
.02 w
.39763 .28996 m
.31129 .17112 L
s
P
p
.2 0 1 r
.02 w
.37315 .36531 m
.23344 .4107 L
s
P
p
.2 0 1 r
.02 w
.37315 .36531 m
.2868 .48415 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.39763 .28996 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.37315 .36531 L
s
P
p
.2 0 1 r
.02 w
.75749 .56114 m
.71209 .70084 L
s
P
p
.2 0 1 r
.02 w
.75749 .56114 m
.80288 .70084 L
s
P
p
.2 0 1 r
.02 w
.80406 .49704 m
.95095 .49704 L
s
P
p
.2 0 1 r
.02 w
.80406 .49704 m
.9229 .4107 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.75749 .56114 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.80406 .49704 L
s
P
p
.2 0 1 r
.02 w
.49904 .19203 m
.58538 .07319 L
s
P
p
.2 0 1 r
.02 w
.49904 .19203 m
.49904 .04513 L
s
P
p
.2 0 1 r
.02 w
.43495 .2386 m
.29524 .1932 L
s
P
p
.2 0 1 r
.02 w
.43495 .2386 m
.29524 .28399 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.49904 .19203 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.43495 .2386 L
s
P
p
.2 0 1 r
.02 w
.63078 .62294 m
.51194 .70928 L
s
P
p
.2 0 1 r
.02 w
.63078 .62294 m
.58538 .76264 L
s
P
p
.2 0 1 r
.02 w
.70613 .59845 m
.82497 .6848 L
s
P
p
.2 0 1 r
.02 w
.70613 .59845 m
.85302 .59845 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.63078 .62294 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.70613 .59845 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.79489 .39705 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.41276 .33653 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.75749 .51217 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.48391 .2386 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.65956 .58332 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.40097 .39705 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.46217 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.53783 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0595917 0.952381 [
[ 0 0 0 0 ]
[ 1 .8332 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8332 L
0 .8332 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.37432 .63358 m
.23491 .67887 L
s
P
p
.2 0 1 r
.02 w
.37432 .63358 m
.28816 .75216 L
s
P
p
.2 0 1 r
.02 w
.45337 .63358 m
.53953 .75216 L
s
P
p
.2 0 1 r
.02 w
.45337 .63358 m
.59277 .67887 L
s
P
p
0 .4 1 r
.018 w
.41384 .60486 m
.37432 .63358 L
s
P
p
0 .4 1 r
.018 w
.41384 .60486 m
.45337 .63358 L
s
P
p
.2 0 1 r
.02 w
.5207 .20846 m
.66728 .20846 L
s
P
p
.2 0 1 r
.02 w
.5207 .20846 m
.63929 .1223 L
s
P
p
.2 0 1 r
.02 w
.44552 .18403 m
.40022 .04462 L
s
P
p
.2 0 1 r
.02 w
.44552 .18403 m
.32694 .09787 L
s
P
p
0 .4 1 r
.018 w
.47424 .22355 m
.5207 .20846 L
s
P
p
0 .4 1 r
.018 w
.47424 .22355 m
.44552 .18403 L
s
P
p
.2 0 1 r
.02 w
.25011 .56754 m
.11071 .52224 L
s
P
p
.2 0 1 r
.02 w
.25011 .56754 m
.11071 .61283 L
s
P
p
.2 0 1 r
.02 w
.31407 .614 m
.31407 .76058 L
s
P
p
.2 0 1 r
.02 w
.31407 .614 m
.40022 .73259 L
s
P
p
0 .4 1 r
.018 w
.29897 .56754 m
.25011 .56754 L
s
P
p
0 .4 1 r
.018 w
.29897 .56754 m
.31407 .614 L
s
P
p
.2 0 1 r
.02 w
.61842 .30965 m
.73701 .3958 L
s
P
p
.2 0 1 r
.02 w
.61842 .30965 m
.765 .30965 L
s
P
p
.2 0 1 r
.02 w
.57195 .24569 m
.61725 .10629 L
s
P
p
.2 0 1 r
.02 w
.57195 .24569 m
.52666 .10629 L
s
P
p
0 .4 1 r
.018 w
.57195 .29455 m
.61842 .30965 L
s
P
p
0 .4 1 r
.018 w
.57195 .29455 m
.57195 .24569 L
s
P
p
.2 0 1 r
.02 w
.18845 .4411 m
.10229 .32252 L
s
P
p
.2 0 1 r
.02 w
.18845 .4411 m
.04904 .3958 L
s
P
p
.2 0 1 r
.02 w
.21288 .51629 m
.12672 .63487 L
s
P
p
.2 0 1 r
.02 w
.21288 .51629 m
.21288 .66286 L
s
P
p
0 .4 1 r
.018 w
.22797 .46982 m
.18845 .4411 L
s
P
p
0 .4 1 r
.018 w
.22797 .46982 m
.21288 .51629 L
s
P
p
.2 0 1 r
.016 w
.41384 .40942 m
.41384 .60486 L
s
P
p
.2 0 1 r
.016 w
.41384 .40942 m
.47424 .22355 L
s
P
p
.2 0 1 r
.016 w
.41384 .40942 m
.29897 .56754 L
s
P
p
.2 0 1 r
.016 w
.41384 .40942 m
.57195 .29455 L
s
P
p
.2 0 1 r
.016 w
.41384 .40942 m
.22797 .46982 L
s
P
p
.2 0 1 r
.02 w
.59978 .642 m
.51362 .76058 L
s
P
p
.2 0 1 r
.02 w
.59978 .642 m
.59978 .78857 L
s
P
p
.2 0 1 r
.02 w
.66373 .59553 m
.80314 .64082 L
s
P
p
.2 0 1 r
.02 w
.66373 .59553 m
.80314 .55023 L
s
P
p
0 .4 1 r
.018 w
.61487 .59553 m
.59978 .642 L
s
P
p
0 .4 1 r
.018 w
.61487 .59553 m
.66373 .59553 L
s
P
p
.2 0 1 r
.02 w
.46833 .21202 m
.58691 .12587 L
s
P
p
.2 0 1 r
.02 w
.46833 .21202 m
.51362 .07262 L
s
P
p
.2 0 1 r
.02 w
.39314 .23645 m
.27456 .15029 L
s
P
p
.2 0 1 r
.02 w
.39314 .23645 m
.24656 .23645 L
s
P
p
0 .4 1 r
.018 w
.43961 .25155 m
.46833 .21202 L
s
P
p
0 .4 1 r
.018 w
.43961 .25155 m
.39314 .23645 L
s
P
p
.2 0 1 r
.02 w
.46047 .66157 m
.32107 .70687 L
s
P
p
.2 0 1 r
.02 w
.46047 .66157 m
.37432 .78016 L
s
P
p
.2 0 1 r
.02 w
.53953 .66157 m
.62568 .78016 L
s
P
p
.2 0 1 r
.02 w
.53953 .66157 m
.67893 .70687 L
s
P
p
0 .4 1 r
.018 w
.5 .63285 m
.46047 .66157 L
s
P
p
0 .4 1 r
.018 w
.5 .63285 m
.53953 .66157 L
s
P
p
.2 0 1 r
.02 w
.60686 .23645 m
.75344 .23645 L
s
P
p
.2 0 1 r
.02 w
.60686 .23645 m
.72544 .15029 L
s
P
p
.2 0 1 r
.02 w
.53167 .21202 m
.48638 .07262 L
s
P
p
.2 0 1 r
.02 w
.53167 .21202 m
.41309 .12587 L
s
P
p
0 .4 1 r
.018 w
.56039 .25155 m
.60686 .23645 L
s
P
p
0 .4 1 r
.018 w
.56039 .25155 m
.53167 .21202 L
s
P
p
.2 0 1 r
.02 w
.33627 .59553 m
.19686 .55023 L
s
P
p
.2 0 1 r
.02 w
.33627 .59553 m
.19686 .64082 L
s
P
p
.2 0 1 r
.02 w
.40022 .642 m
.40022 .78857 L
s
P
p
.2 0 1 r
.02 w
.40022 .642 m
.48638 .76058 L
s
P
p
0 .4 1 r
.018 w
.38513 .59553 m
.33627 .59553 L
s
P
p
0 .4 1 r
.018 w
.38513 .59553 m
.40022 .642 L
s
P
p
.2 0 1 r
.016 w
.5 .43742 m
.61487 .59553 L
s
P
p
.2 0 1 r
.016 w
.5 .43742 m
.43961 .25155 L
s
P
p
.2 0 1 r
.016 w
.5 .43742 m
.5 .63285 L
s
P
p
.2 0 1 r
.016 w
.5 .43742 m
.56039 .25155 L
s
P
p
.2 0 1 r
.016 w
.5 .43742 m
.38513 .59553 L
s
P
p
.2 0 1 r
.02 w
.78712 .51629 m
.78712 .66286 L
s
P
p
.2 0 1 r
.02 w
.78712 .51629 m
.87328 .63487 L
s
P
p
.2 0 1 r
.02 w
.81155 .4411 m
.95096 .3958 L
s
P
p
.2 0 1 r
.02 w
.81155 .4411 m
.89771 .32252 L
s
P
p
0 .4 1 r
.018 w
.77203 .46982 m
.78712 .51629 L
s
P
p
0 .4 1 r
.018 w
.77203 .46982 m
.81155 .4411 L
s
P
p
.2 0 1 r
.02 w
.42805 .24569 m
.47334 .10629 L
s
P
p
.2 0 1 r
.02 w
.42805 .24569 m
.38275 .10629 L
s
P
p
.2 0 1 r
.02 w
.38158 .30965 m
.235 .30965 L
s
P
p
.2 0 1 r
.02 w
.38158 .30965 m
.26299 .3958 L
s
P
p
0 .4 1 r
.018 w
.42805 .29455 m
.42805 .24569 L
s
P
p
0 .4 1 r
.018 w
.42805 .29455 m
.38158 .30965 L
s
P
p
.2 0 1 r
.02 w
.68593 .614 m
.59978 .73259 L
s
P
p
.2 0 1 r
.02 w
.68593 .614 m
.68593 .76058 L
s
P
p
.2 0 1 r
.02 w
.74989 .56754 m
.88929 .61283 L
s
P
p
.2 0 1 r
.02 w
.74989 .56754 m
.88929 .52224 L
s
P
p
0 .4 1 r
.018 w
.70103 .56754 m
.68593 .614 L
s
P
p
0 .4 1 r
.018 w
.70103 .56754 m
.74989 .56754 L
s
P
p
.2 0 1 r
.02 w
.55448 .18403 m
.67306 .09787 L
s
P
p
.2 0 1 r
.02 w
.55448 .18403 m
.59978 .04462 L
s
P
p
.2 0 1 r
.02 w
.4793 .20846 m
.36071 .1223 L
s
P
p
.2 0 1 r
.02 w
.4793 .20846 m
.33272 .20846 L
s
P
p
0 .4 1 r
.018 w
.52576 .22355 m
.55448 .18403 L
s
P
p
0 .4 1 r
.018 w
.52576 .22355 m
.4793 .20846 L
s
P
p
.2 0 1 r
.02 w
.54663 .63358 m
.40723 .67887 L
s
P
p
.2 0 1 r
.02 w
.54663 .63358 m
.46047 .75216 L
s
P
p
.2 0 1 r
.02 w
.62568 .63358 m
.71184 .75216 L
s
P
p
.2 0 1 r
.02 w
.62568 .63358 m
.76509 .67887 L
s
P
p
0 .4 1 r
.018 w
.58616 .60486 m
.54663 .63358 L
s
P
p
0 .4 1 r
.018 w
.58616 .60486 m
.62568 .63358 L
s
P
p
.2 0 1 r
.016 w
.58616 .40942 m
.77203 .46982 L
s
P
p
.2 0 1 r
.016 w
.58616 .40942 m
.42805 .29455 L
s
P
p
.2 0 1 r
.016 w
.58616 .40942 m
.70103 .56754 L
s
P
p
.2 0 1 r
.016 w
.58616 .40942 m
.52576 .22355 L
s
P
p
.2 0 1 r
.016 w
.58616 .40942 m
.58616 .60486 L
s
P
p
1 .6 0 r
.016 w
.5 .29084 m
.41384 .40942 L
s
P
p
1 .6 0 r
.016 w
.5 .29084 m
.5 .43742 L
s
P
p
1 .6 0 r
.016 w
.5 .29084 m
.58616 .40942 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0492176 0.952381 [
[ 0 0 0 0 ]
[ 1 .85395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85395 L
0 .85395 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.24108 .70023 L
s
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.29606 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.55565 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.61064 .70023 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.38504 .65346 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.46668 .65346 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.68758 .21443 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.65867 .12546 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.41179 .04525 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.33611 .10023 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.53621 .21443 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.45857 .18921 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .53848 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .63203 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.32282 .78461 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.41179 .7557 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.25677 .58525 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.32282 .63324 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.75958 .40791 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.78849 .31894 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.63591 .10893 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.54236 .10893 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.63712 .31894 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.58914 .25289 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.10412 .33222 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.04913 .40791 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.12934 .65479 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.21832 .6837 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.19309 .45468 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.21832 .53233 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.42586 .6238 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.48822 .23003 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.30723 .58525 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.58914 .30334 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.23391 .48434 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.51407 .77979 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.60304 .8087 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .65612 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .56257 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.60304 .65733 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.66909 .60934 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.58975 .12432 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.51407 .06934 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.26719 .14955 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.23828 .23853 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.46729 .2133 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.38965 .23853 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.31522 .72432 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.37021 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.62979 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.68478 .72432 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.45918 .67755 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.54082 .67755 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.76172 .23853 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.73281 .14955 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.48593 .06934 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.41025 .12432 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.61035 .23853 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.53271 .2133 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .56257 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .65612 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.39696 .8087 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.48593 .77979 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.33091 .60934 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.39696 .65733 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.61863 .60934 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.43763 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.5 .64789 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.56237 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.38137 .60934 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.78168 .6837 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.87066 .65479 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.95087 .40791 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.89588 .33222 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.78168 .53233 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.80691 .45468 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.45764 .10893 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.36409 .10893 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.21151 .31894 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.24042 .40791 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.41086 .25289 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.36288 .31894 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.58821 .7557 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.67718 .78461 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .63203 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .53848 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.67718 .63324 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.74323 .58525 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.66389 .10023 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.58821 .04525 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.34133 .12546 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.31242 .21443 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.54143 .18921 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.46379 .21443 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.38936 .70023 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.44435 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.70394 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.75892 .70023 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.53332 .65346 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.61496 .65346 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.76609 .48434 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.41086 .30334 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.69277 .58525 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.51178 .23003 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.57414 .6238 L
s
P
p
1 .6 0 r
.014 w
.5 .31992 m
.42586 .42197 L
s
P
p
1 .6 0 r
.014 w
.5 .31992 m
.5 .44606 L
s
P
p
1 .6 0 r
.014 w
.5 .31992 m
.57414 .42197 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0492176 0.952381 [
[ 0 0 0 0 ]
[ 1 .85395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85395 L
0 .85395 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.24108 .70023 L
s
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.29606 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.55565 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.61064 .70023 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.38504 .65346 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.46668 .65346 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.68758 .21443 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.65867 .12546 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.41179 .04525 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.33611 .10023 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.53621 .21443 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.45857 .18921 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .53848 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .63203 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.32282 .78461 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.41179 .7557 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.25677 .58525 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.32282 .63324 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.75958 .40791 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.78849 .31894 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.63591 .10893 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.54236 .10893 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.63712 .31894 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.58914 .25289 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.10412 .33222 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.04913 .40791 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.12934 .65479 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.21832 .6837 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.19309 .45468 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.21832 .53233 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.42586 .6238 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.48822 .23003 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.30723 .58525 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.58914 .30334 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.23391 .48434 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.51407 .77979 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.60304 .8087 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .65612 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .56257 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.60304 .65733 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.66909 .60934 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.58975 .12432 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.51407 .06934 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.26719 .14955 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.23828 .23853 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.46729 .2133 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.38965 .23853 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.31522 .72432 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.37021 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.62979 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.68478 .72432 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.45918 .67755 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.54082 .67755 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.76172 .23853 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.73281 .14955 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.48593 .06934 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.41025 .12432 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.61035 .23853 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.53271 .2133 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .56257 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .65612 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.39696 .8087 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.48593 .77979 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.33091 .60934 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.39696 .65733 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.61863 .60934 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.43763 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.5 .64789 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.56237 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.38137 .60934 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.78168 .6837 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.87066 .65479 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.95087 .40791 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.89588 .33222 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.78168 .53233 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.80691 .45468 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.45764 .10893 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.36409 .10893 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.21151 .31894 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.24042 .40791 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.41086 .25289 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.36288 .31894 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.58821 .7557 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.67718 .78461 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .63203 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .53848 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.67718 .63324 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.74323 .58525 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.66389 .10023 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.58821 .04525 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.34133 .12546 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.31242 .21443 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.54143 .18921 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.46379 .21443 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.38936 .70023 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.44435 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.70394 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.75892 .70023 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.53332 .65346 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.61496 .65346 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.76609 .48434 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.41086 .30334 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.69277 .58525 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.51178 .23003 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.57414 .6238 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.42586 .42197 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.5 .44606 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.57414 .42197 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0720399 0.952381 [
[ 0 0 0 0 ]
[ 1 .8083 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8083 L
0 .8083 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.67271 .64761 L
s
P
p
.2 0 1 r
.02 w
.6489 .4973 m
.75652 .60491 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.79734 .34714 L
s
P
p
.2 0 1 r
.02 w
.66174 .41623 m
.73084 .28063 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.6489 .4973 L
s
P
p
0 .4 1 r
.018 w
.62587 .4521 m
.66174 .41623 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.26053 .12782 L
s
P
p
.2 0 1 r
.02 w
.23672 .27813 m
.16763 .14253 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.04914 .37507 L
s
P
p
.2 0 1 r
.02 w
.19946 .35126 m
.09184 .45888 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.23672 .27813 L
s
P
p
0 .4 1 r
.018 w
.24466 .32823 m
.19946 .35126 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.49191 .74954 L
s
P
p
.2 0 1 r
.02 w
.561 .61394 m
.58481 .76426 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.76936 .57971 L
s
P
p
.2 0 1 r
.02 w
.61904 .5559 m
.75464 .48681 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.561 .61394 L
s
P
p
0 .4 1 r
.018 w
.56894 .56384 m
.61904 .5559 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.46398 .08674 L
s
P
p
.2 0 1 r
.02 w
.35636 .19436 m
.38017 .04404 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.14763 .16253 L
s
P
p
.2 0 1 r
.02 w
.28323 .23162 m
.13292 .25543 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.35636 .19436 L
s
P
p
0 .4 1 r
.018 w
.33333 .23956 m
.28323 .23162 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.62587 .4521 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.24466 .32823 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.56894 .56384 L
s
P
p
.2 0 1 r
.016 w
.42546 .42036 m
.33333 .23956 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.83361 .4831 L
s
P
p
.2 0 1 r
.02 w
.726 .37549 m
.87631 .39929 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.75783 .16675 L
s
P
p
.2 0 1 r
.02 w
.68874 .30235 m
.66493 .15204 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.726 .37549 L
s
P
p
0 .4 1 r
.018 w
.6808 .35246 m
.68874 .30235 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.19462 .30485 L
s
P
p
.2 0 1 r
.02 w
.26371 .44045 m
.12811 .37136 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.16894 .62913 L
s
P
p
.2 0 1 r
.02 w
.27655 .52152 m
.25274 .67183 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.26371 .44045 L
s
P
p
0 .4 1 r
.018 w
.29958 .47632 m
.27655 .52152 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.74726 .67183 L
s
P
p
.2 0 1 r
.02 w
.72345 .52152 m
.83106 .62913 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.87189 .37136 L
s
P
p
.2 0 1 r
.02 w
.73629 .44045 m
.80538 .30485 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.72345 .52152 L
s
P
p
0 .4 1 r
.018 w
.70042 .47632 m
.73629 .44045 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.33507 .15204 L
s
P
p
.2 0 1 r
.02 w
.31126 .30235 m
.24217 .16675 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.12369 .39929 L
s
P
p
.2 0 1 r
.02 w
.274 .37549 m
.16639 .4831 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.31126 .30235 L
s
P
p
0 .4 1 r
.018 w
.3192 .35246 m
.274 .37549 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.6808 .35246 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.29958 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.70042 .47632 L
s
P
p
.2 0 1 r
.016 w
.5 .44458 m
.3192 .35246 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.86708 .25543 L
s
P
p
.2 0 1 r
.02 w
.71677 .23162 m
.85237 .16253 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.61983 .04404 L
s
P
p
.2 0 1 r
.02 w
.64364 .19436 m
.53602 .08674 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.71677 .23162 L
s
P
p
0 .4 1 r
.018 w
.66667 .23956 m
.64364 .19436 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.24536 .48681 L
s
P
p
.2 0 1 r
.02 w
.38096 .5559 m
.23064 .57971 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.41519 .76426 L
s
P
p
.2 0 1 r
.02 w
.439 .61394 m
.50809 .74954 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.38096 .5559 L
s
P
p
0 .4 1 r
.018 w
.43106 .56384 m
.439 .61394 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.90816 .45888 L
s
P
p
.2 0 1 r
.02 w
.80054 .35126 m
.95086 .37507 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.83237 .14253 L
s
P
p
.2 0 1 r
.02 w
.76328 .27813 m
.73947 .12782 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.80054 .35126 L
s
P
p
0 .4 1 r
.018 w
.75534 .32823 m
.76328 .27813 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.26916 .28063 L
s
P
p
.2 0 1 r
.02 w
.33826 .41623 m
.20266 .34714 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.24348 .60491 L
s
P
p
.2 0 1 r
.02 w
.3511 .4973 m
.32729 .64761 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.33826 .41623 L
s
P
p
0 .4 1 r
.018 w
.37413 .4521 m
.3511 .4973 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.66667 .23956 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.43106 .56384 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.75534 .32823 L
s
P
p
.2 0 1 r
.016 w
.57454 .42036 m
.37413 .4521 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.42546 .42036 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.5 .44458 L
s
P
p
1 .6 0 r
.016 w
.5 .31775 m
.57454 .42036 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`0001@000==00000`000dd0000J0003C@0000<000==000070000dd0C@0M0003
C@0000D000==00006@001dd0C@1=04d070000dd000030003C@0001X000?600000`000lH0000C0000
500014`0C4`20003C00001X000A<04a<0P000d`0000I0005C01<C0000T`00`1<000H009<00@0C4`0
0T`00`1<C00J0007C01<04`0C00L0004C000C08000=<00006P000lH00002aP030<H001@0000B00]=
600;CAL000==04d00dd00`1=C@02C@0304d001L014d00`1=C@02CAP03DdG00]=600;aQ<0000?009<
0P09C00304a<01@000=<00002D`00`1<C00E00e<5P03C00304a<00=<00@0C4a<5002C0802D`2009<
4`02C00304a<00M<0P000d`0000B00;600<0a/H01lH20003aP0000l0000A0004C@1=00==00?6C@00
0TdG0004C@1=00E=00<0CDd05`07C@03aTe=00==5007C@03aTg600M=500=CAL00Td02P1=CDg6C@1=
04dG00;600<0a/H00lH010360<HB00004@05C003aP3600E<5P06C00304a<00A<5007C003aTc600=<
00@0C4a<4P04C00604a<aTc60T`00`1<C002C1H01D`01<I<C4`H00E<00?60<H01D`F00K600<0a/H0
1<HB00003`04C@;600I=04d0CLH5CA801dd00`1=0007CA@01Dd01@1=04g600==5`0024g6aTd0C@1=
0/H00dd0000B00Q=00G6CLI=aP06CA401Dd01/I=04d0C@;614dB00K600E=04d0C@06aQ00000D0007
aT`0C01<aP0L009<00<0C0000T`F00A<0P001lI<04`0C<H00P04C1H000O6C01<04c601`000O6C01<
04c601`000O6C01<04c601`000O6C01<04c601D0000D00==00@0CDe=7003C@0404e=CA@000A=0000
0dd01@1=CDd000==00@0CDe=0`000dd0000?009=00G6CDe=4@03C@04aTe=C@l000==00001P03C@04
04e=C@P000==00004@03C@0404e=CA`00dd0101=CDdE00002P0014`00005C006aP00C15<0P000lI<
C003C08000=<00001`0014`00006C08000=<4D`00P06C0<000=<000020000d`00002009<00K6001<
4D`20004aTa<C0<000=<0000200014`00004C0@000=<4D`01004C0<000=<00001`000d`00005C006
aP00C15<0P000lI<C003C08000=<00001`0014`00005C006aP00C15<0P000lI<C003C0<000=<0000
1P001<H00006aP8000=<4D`00P06aP<000?600002@0000X000==00000`02C@@000==4Dd01002C@@0
00==00001`000dd00003009=10000ddAC@04009=1@000dd00005009=00<0C@000dd00`1=00020003
CA5=00<000==00000Td0101=04d80003C@00008000==000010034@H000==00000P000dd000080003
C@00008000==00000P000ddAC@040003C@00008000==000020000dd00003009=10000ddAC@04009=
1@000dd000060003aP0000<00/H40003CA5=00@00/H50003aP0000T0000900=<0`000d`000030005
C14A4D`01@001D`004`0009<1P03C0<000=<00000`001D`A4A5<00D000A<00000d`80003C01<00<0
00E<0000C0034@05C00004`00`000d`0C00800=<0P000d`000040005C14A4D`01P000d`00003C0H0
0T`20004C000C0@000E<4A4AC0040004C000C0800T`600=<0`000d`000030005C14A4D`01@0014`0
0003C0H00lH30003aP0000<000E<4A4AC0050004aP0000?62P0000/00Td6009=00DA01404@02C@H0
0Td:009=1P02C@054@0A01400Td6009=2`02C@8000Y=0000CA404@0A0Td20003C@00009=2`02C@H0
0Td01A404@0A009=1P02C@X00dd00`1=00030006CA404@0A0Td30003C@1=009=2P02C@L000I=4@0A
0142C@H00Td:00;61`001TdA01404@9=1P02aP`0000=0003aP0000=<0P001D`04@1<00800d`00`36
aP0>0003C00000=<0P001D`04@1<00800d`00`1<C00:00A<0/H200=<00H0C00A04`200=<00<0a/H0
14`:0003aP0000=<0P001D`04@1<00800d`20003aP0000d000?600000d`01P1<0140C0800d`00`36
000>00;60P03C00604`04@1<0P03C0030<K600h00/H200=<00H0C00A04`200=<0P000lH0000<0000
3P02C@@00Td00`1=0002C@@000==00003`02C@@00Td00`1=0002C@@000==00003002C@800Td3009=
00<0C@000Td40004C@00C@h00Td4009=00<0C@000Td4009=4@02C@<00Td00`1=0002C@@000==0000
4002C@<00Td00`1=0002C@@000==00004002C@<00Td00`1=0002C@@00Td?00003P000lH000020003
C01<00A<00<0C0000`000lH0000>0003C000008000=<04`014`00`1<00030003C00000d00d`30003
C01<00A<00<0C0000P000dc6C00?0003aP00008000=<04`014`00`1<00030003aP0000/00T`00`36
00030003C01<00A<00<0C0000`001<H0C4`=0003aP00008000=<04`014`00`1<00030003aP0000h0
00?600000P000d`0C004C00304`000<000?600003@0000/014d30008C@00C@1=04d20004C@0000A=
2P04C@<000Q=001=04d0C@8000A=000014d;0007C@1=04d0C@020005C@1=04d00P001dd0C@1=04d0
2P05C@<000Q=001=04d0C@8000I=0000C@03C@/00dd20008C@00C@1=04d20003C@0000==3004C@<0
00Q=001=04d0C@8000A=000014d:00C60`0024d004d0C@1=0P0014d00004aP`0000=00E<0P02C003
04`0009<0P000dc6aP02C0h01D`2009<00<0C0000T`200E<3005C004aT`0009<00<0C0000T`20003
C<K600A<3003C004aT`0009<00<0C0000T`20003C<K600=<3@05C0800T`00`1<0002C08000=<aT`0
0T`>00E<0P02C00304`0009<0P000dc6aP02C0h01LH2009<00<0C0000T`20003C<K600;63P0000`0
1Dd2aP09CLI=04d0CLI=00;61Dd<00==00<0CDd014d00`1=000:C@X000==00001Dd02lI=aTd0C@1=
aTg600E=0P000dd0000600A=00<0CDd00/H02Dg6C@1=04g6C@02aP9=00<0C@000Td900A=00h0CDg6
C@1=04d0C@1=aPA=00<0CDd02`03C@0=04e=aTg6C@1=04g6C@02aPE=3003aP0=0<K6aTg6C@1=04g6
C@07aPd0000;0004C01<C08000W6C<K60<I<aP000/H014c60002C00304`000T000=<04`00T`00`1<
C002C00504a<C00014`2009<00<0C0002P02C00304a<00M<00C6C<K614`00`1<000=009<0P002LI<
a/H0aTc60002aP04C<H0009<30000d`0C002C00604a<C<H00T`00lI<aP03C0800T`00`1<00090003
C01<009<00<0aT`00/H01@36C<H000;600A<aP000T`00`1<00090003aP3600;600<0a/H00/H01@36
a/H000C60P02aP030<H000/0000>0003C@1=00I=00<0CDd01Dd00`1=000?0003C@1=00I=00<0CDd0
1Dd00`1=000<0005C@1=C@001dd00`1=C@05C@0404e=C@`00Td2009=00<0CDd00Td00`1=C@02C@03
04e=00800Td>00==00<0CDd00Td00lH0C@04C@0404e=CA0000==04d01Td00`1=C@05C@0304d000l0
00?60<H01/H00`36aP05aP030<H000h0000?0003C01<00a<00<0C0004@000d`0C00<C00304`00180
00=<04`02D`00`1<000C0003C01<00A<00<0C0001D`00`1<000@0003C00000Y<00<0C4`00P000d`0
000?0003C01<00a<00<0C0004@000lH0aP0<aP030<H000l0000A0003C@0000==00D0CDe=0002CAH0
00==00000dd01@1=CDd0009=5002C@0304e=00]=5@06C@0304e=00A=5P02C@0504e=C@000dd00`1=
C@0F009=00D0CDe=0003C@8000==00005002aP050<K6aP000lH20003aP000100000@009<0P04C003
04a<008000=<00004`02C08014`00`1<C0020003C00001<000]<04a<04`0C01<0002C00304`001<0
00=<04`00d`3009<00@0C01<500014`0C002C00304`0009<00@0C01<5@000d`00002C00304`0009<
0P02C1D000?600000/H00`36aP02aP800/HA00004`02C@D00TdJ009=1@02CAT000M=04e=04d0009=
00<0C@006@001dd0C@1=04d06P03C@D00ddI009=1@02CAX00/H500;650000?l00`000?l00`000?l0
0`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000:<000==0000G000010000=<0000
0P001D`0001<00<000=<00005`000d`000030003C00001X000=<00000`000d`0000J0003C00000<0
00=<00006P02C00304`0009<7@001D`0001<01h000=<00000P000d`0000C0000400014d00002C@<0
0Td20003C@0001L000M=04d0C@1=01`000A=04e=0P000dd0000J0004C@00C@8000==000060001dd0
CDd0C@000Td00`1=000H0004C@1=00==00<0C@006`000dd0C@020003C@0001<0000A0005C000C000
0d`0101<04`G00A<00D0C01<0004C1L02d`H00]<600024`004`0C01<0P000d`0000F00A<00<0C4`0
14`H00Q<00<0C4`04`0000h04ddA009=00<0CDd02ddD0003C@0000U=00<0CDd050000dd00009C@03
04e=01@000E=001=0005C@0504d004d05003C@0304e=00E=00@0CDe=5002C@0304e=009=00D0CDe=
0003CA40000;0007C000C01<0004C004aTc600;600E<04`0C0020003C00000h000=<00001d`00`1<
000F0004C01<00=<00?6C0000T`G0004C01<00=<00?6C0000T`F00=<00D0C4a<aP03C00404a<C1D0
1d`00lI<0003C1L00T`00`1<C003C00304a<01<0000;0006C@00C@1=0P03C@<00dd20003C@1=0080
00==00003`0024d0CDd0C@360TdH00E=00?60<H01DdF00E=00?60<H01DdF0003C@1=009=00@0aP36
0Td00`1=000C00M=00?60<H00dd0101=CDdE00E=0/H5CA80000<00A<00H0C01<aT`30006C<I<04`0
14`>00Q<0/H2C003aTa<00=<4P04C0;600H0aTc60<H5C18014`2aP060<I2aP361D`B00U<0/H6C1H0
0T`01P36C<H0aP9<5@07C00504`0C<H01D`@00003@02C@0304g6009=00<0C@000P0014d0CLH2C@03
04e=01H000?6C@000TdM0007aTd0C@1=aP0L0007aT80@P12aP0I009=00S6CDg6CLI=aP==6@001lI=
04d0CLH070001lI=04d0CLH05@0000h00T`30009aP1<0140C01<00800T`00lH0000D0004aT`04@9<
00?600006P03C00404a<C1`00d801012@T8E0003C00000M<00<AC4`01D`20003C00000d01D`01LI<
C4`000=<00?6C4`00d`@00E<00G6C4a<0003C003aTa<00=<3`0000d000==aP000`001/I=C@0A009=
00?600000P000lI=000:0004C@0000E=00K604e=4Dd20003aTe=00==0P000dd000070004C@0000E=
00K6001=4Dd20003aTe=00==0`000dd000060004C@0000E=00K600124D820003aTe=00==0`000dd0
00090004C@1=C@800Td01`1=4Dd0aTd00P02C@0304d0014000==00000P000ddAC@04009=3`000dd0
00030003C@00008000==4Dd010000dd000040003C@0000T0000=00A<0P03C0<A0d`2009<00?6C000
2P000d`000040005C00004`00a401D`0001<00D000=<00001`000d`00003009<10000d`AC004009<
1@000d`000060003C00000<00T`40003@Q5200@00T`50003C00000X000A<04`00d`01@0A4A4000=<
00@0C01<30000d`000030003C00000<000=<4D`01P000d`000020003C00000L000=<00000P000d`0
00030004C14AC0@000=<00000`000d`0000900002`03C@800Td01<I=04d34@03C@1=00E=00?6CDd0
2003C@@000M=0000CA5=008A00==00000P001Td0001=009=1P03C@<000==00000`001DdA4A5=00D0
00A=00000dd600==0`000dd000030005@Q4A4D801@0014d00003C@/00Td00`1=0003C@<A0dd00`1=
0002C@d000E=0000C@050005CA4A4Dd01P0014d004d;0004C@00C@D000E=4A5=4@050005C@0004d0
300000T01d`2000;C01<4D`AC15<04`00P07C0P00T`20006C00004`A0P000a404@02C0<000=<04`0
0T`:009<1P02C0054@0A01400T`6009<2P02C0L000I24@0A0142@PH00T`>000;aP1<C01<4@0A0140
14`00`1<000;00A<1`001T`A01404@9<1P04C0H00T`20003C00000<00T`00a404@0200034Da<00D0
00A<04a<2P0000`000==04d00/H00dd0C@02C@0304d000E=00G6CDd0C@0=00;600H0CDe=04d20003
4@1=00800dd00`36000>0003aP0000==0P001Dd04@1=00800dd00`36aP0>00;60P03@P0604804@12
0P03@P030<K600d00Td00`1=0005C@0304d0009=00<0CDd00Td00`1=C@0<0003CLK600800dd01P1=
0140C@800dd01036aTd;00==0P03C@8000==01400P000dd00003C@800Td<00002`000d`0000200=<
00<0C0000d`0101<0002C0<000=<00003@0014`00002C00404a<009<10000d`0000?009<1002C003
04`0009<10000d`0000@00920`02@P030480009210000d80000:00A<0/H3C0801d`200A<00?6C4`0
0T`<009<0`02C00304`0009<10000d`0000?009<1002C00404`0009<10000dc6000=00002P03C@80
0Td00lH0C@030007C@0004d0aP02C@800Td9009=0P001/H0001=009=00H0CDe=04d40004aP1=C@d0
00?600000P000dd0C@04C@0304d000<000?600003P000lH000020003@P1200A200<0@P000`000lH0
000<0005C@00CLH01Dd00`1=0007C@8000==000030000lH000020003C@1=00A=00<0C@000`000lH0
000>0003aP00008000==04d00dd0101=04d30003aP0000d0000=009<00<0aT`00T`2009<0`02C003
aP00009<3@05C00404`0C08000=<04`00P000d`00003C0`014`30008C000C01<04`20004C00000A<
2P04C0<000Q200120480@P8000A2000014`:0003C00000800T`00lH0C006C00404a<aP@000=<0000
2004C0<000Q<001<04`0C08000A<000014`:00A<0`001d`004`0C0000T`00`1<000200A<300000d0
0Td00lI=C@02C@03aTd0009=0/H3C@;60Td>009=0/H014g6CDd20004C@1=C@;600==a/H00Td>00E=
0P02C@0304d0009=0P000dg6aP02C@h01Dd2009200<0@P000T820003@/K6009=2`000dd0000200U=
00C6CLK614d40003C@0000T01Dd2009=00<0C@000Td20003CLK6009=3P05C@800Td01@1=001=0080
00==aTd00Td>00002`02C0800d`40003aTc600@000?6C0000P02C0T00d`04@1<C4c60<I<aP1<04c6
0<H000=<00<0C4`02`03C00=04a<aTc6C01<04c6C002aPE<3003C00=04a<aT;6@P1204;6@P02aPE<
3`001dc6C4c6C<H024`00lI<000>009<0`002dc6C01<04`0C01<00;600=<00000T`<00=<0P001dc6
C01<04`00P02C0;600=<04`00T`=00003P0014d0CDd400==10000dd0C@0>0004C@1=C@800Td2aP05
04e=aTd00/H3C@0504e=04d02P000dd0C@02C@030<I=00;600D0aTg60002aP04CLH0009=00<0C@00
2@000dd0C@02C@030<I=00;600D0aTg60002aP04CLH0009=00<0C@0030001Dd0CDg6008000E=04d0
aP020005aTe=04d03@0014d0C@02C@0=aP1=aP36CLH0aTd0aP02C@0404d0C@X000==000014d00`36
aP04C@04aTe=00A=0P000dd0000:00003@000d`00003C00304a<009<00?6C4`00d`20003C00000h0
24`00lH0C004C0800T`@0005C01<C00014`00`1<C002C00504a<04`040000d`0C006C00304a<00E<
00<0C0003P001T`004`0C0800T`00lI<C0020003C01<008000=<00003002C00504a<C0000d`01@1<
C4`000=<00<0C4`03P02C00304a<00I<00?6C4`014`00`1<C00>00004004C@8000==04d00P03CAH0
2Td00`1=C@0D0003C@1=00a=00<0C@004@000dd0C@0<C@0304d000h000A=001=0P001dd0CDd0C@00
0Td01@1=001=008000==00003@000dd0C@0<C@0304d0014000A=04d00Td01@1=04d000A=00<0C@00
3`00014000=<00000d`0101<C4`20003C00001@000=<00000d`01@1<C4`0009<5P000d`0C003C003
04a<00A<5P000d`00003C00504a<C0000T`D0003C01<008000=<04`00T`01`1<001<04`05003C007
04`0C01<0002C00304`001@01D`00`1<0005C180000A000:C@00C@1=04d0C@8000==00004`02C@80
0Td00`1=0002C@0404d0CA@00Td200A=00<0CDd00P000dd0000C009=0P02C@0304d0009=0P000dd0
000D000:C@00C@1=04d0C@8000==0000500014d0C@02C@0604e=04d00TdE0009C@1=C@1=04d0009=
00<0C@004@0001<000=<00001@000d`0000H009<1@02C1X00T`5009<6P02C0D00T`J0006C000C01<
0P000d`0000H009<1@02C1X000=<00001@000d`0000B0000XP000dd0C@1M0000o`030000o`030000
o`030000o`030000o`030000o`030000o`030000o`030000E`000d`00004C00304a<008000=<0000
W00003X000==00006P000dd00007C@8000==00005`000dd000030003C@0001X000==00000`000dd0
000J0003C@0000<000==0000=P0001D000G60000aP0M009<00<0C0000T`J0003C01<00I<00<0C000
6@0014`004`20003C00001X000A<001<0P000d`0000J0004C000C08000=<00006@000d`000050003
C0000180000E00;600<0a/H06`000dd0C@06C@0304d001@00Td0101=C@05C@0404e=009=5004C@05
04e=C@000ddH00]=600;CAT000E=04e=0002C@0304d001<0000B00;600L0aTa<0<H000;660000d`0
C007C1P03D`H00U<5`000d`00009C08000=<00004P02C00304a<00M<0P000d`0000A0004C000009<
1@02C0<000=<00003P0001<000?6C@000Td20003CLH001H03ddA009=0`000dd0aP06aP0304d00080
0TdA009=0P03C@0404e=C@800TdE0004C@1=00==00K6C@1=04dG009=00X0CDe=aTd0C@1=4@02C@04
04d0009=1`02C@8000A=04e=3@0001<000?6C4`00P0014`0C<HB0003C00000801d`00lI<aP04C0D0
00=<00002`05C0?600A<04a<0/H5C1@014`2aP03C<I<009<5`05C003aP3600E<5P05C003aP3600E<
4@0014`0C4`20003C00000L000?600000T`00`1<000<00004P001<I=CDd200A=00?600003`000dd0
0002C@8000A=04g60dd01LI=04d0009=0`000dd0000>0003CLK600==00@0CDe=0/H00dd0000B00M=
00G604e=aP05CA8014d01lI=CLI=aTd00/H4CA801dd01<I=aTd2aPA=40001Td0CDd0C@T000K604e=
04d>00004002aP<000=<01400T`30003aP0000`00T`00`1<000200E<00G6C4a<aP04C0@000A<04a<
2`03C0<00d`0101<C4`300=<5`000lI<0002C1d000O6C01<04c601`000O6C01<04c601<024`90003
C<K600E<300001@00dd00a5=C@0D009=0`03C@;600<0CDd00Td2aP9=1002C@`000==00001@02C@03
4De=00L000==00004`001<I=CA42C@03aP0001X00dd0101=CDdL00==00@0CDe=5`001<I=CDd900==
00?600003P0001@000=<01400Q400d`0000C0003C01<009<0`02C0<A0T`3009<0P000d`0000D0003
C15<01@000=<00000P04C005aP1<C1400T`00`36C003C0@000=<00001P0014`00005C006aP00C15<
0P000lI<C003C0<000=<00001P0014`00005C006aP00C15<0P000lI<C003C0<000=<00002@001d`0
aTc604`00`002a40001<0<I<aP1<00h0000D0006CA5=4DdA5P000lH00002000;CLH04DdACA40aTd0
10000lH0000E0003CA5=01@000==00000`02C@<000E=4A4AC@03009=1@000dd000060003C@0000<0
0Td40003CA5=00@00Td50003C@0000H000==00000`02C@@000==4Dd01002C@D000==00001`09C@<0
00@A00001Dd2aP9=300001<000Q<4@1<4D`AC1H01T`01a5<C15<01401T`H00<A4`03C0<000=<0000
0P001d`AC15<4D`0100014`00003C0H00d`30003C00000<000E<4A4AC0050004C00000=<1P03C0<0
00=<00000`001D`A4A5<00D000A<00000d`600a<00D04A4A0004C003aTa<00E<2P0001400Td01A40
000A008000<ACDd03`02C@0404g6C@<000]=04d04DdA04d0C@020003C@3600==20000dd000080005
CA4A4Dd02P000dd00007009=1P001DdA000A008000<ACDd01@02C@X00Td70006CA404@0A0Td6009=
2P02C@L000I=4@0A0142C@H00Td:00E=0P001<I=CDd34@==00?600001Dd<00002@000lH00005C080
00E<00004@020003C00000E<0P02aPP00d`3000=C01<04`A015<04`0C00300=<2P000d`000060003
C01<009<00<0C0001`000d`0000:0003aP0000=<00D0C0004@020003C00000=<00<0aP003@02aP80
0d`01P1<0140C0800d`00`36aP0>00;60P03C00604`04@1<0P03C0030<K600`001=<001<0<H0aP1<
4D`AC15<0<H000;600A<001<300000X00Td6009=0`000dd00002C@H00Td800E=00?604d00P02C@05
04d0C@000Td20004C@36aPA=2@000dd00003009=00<0CDd00dd00`1=C@050003C@0000`00Td3009=
0P000dd00002C@@000==00003`02C@<00Td00`1=0002C@@000==00004002C@<00Td00`1=0002C@@0
00==00002`0014d004d300I=00<0CDd014d30004C@00C@/0000:0003aP0000@000=<04`00P03C004
04`0C0H000?600001P001D`004`0009<0P02C00704`0C01<0002C0800T`01@1<001<00X000E<0000
C0030005C01<04`00`001D`0001<00`00T`00`3600020004C01<00=<00@0C01<0`001<H0C4`=0003
aP00008000=<04`014`00`1<00030003aP0000h000?600000P000d`0C004C00304`000<000?60000
30000d`00002C0;610000d`0000200;60T`20003C00000/0000:0003aP0000<000U=001=04d0C@00
0Td20003C@0000@000?600001`04C@;60Td20005C@1=04d00P02C@;614d800E=0/H014d00002C@03
04d0009=0`000dg6aP05C@X00Td30007C@1=C@1=0002C@0304d000800Td<00A=0`0024d004d0C@1=
0P0014d00004C@X014d30008C@00C@1=04d20004C@0000A=3`000lI=C@030003C@1=00<00Td00lI=
000?00002P000lH000030003C000009<0P0014`004`30003C00000<000?600001`0024`0001<0<I<
0P001D`0C01<008000A<aP1<0`000d`0000;00=<0`0014`004`20005C0000<H00T`?00E<0P0014`0
04`20004C000C0;60T`>00E<0P02C00304`0009<0P000dc6aP02C0h01D`2009<00<0C0000T`20003
C<K6009<4004C0;600E<0000C002aP=<00<0C0003P0000l000E=0000C@030004C@00C@@000==0000
3@04C@;600`0aTd0C@1=04g60<H5CA0000==a/H00Td01@1=CDd0009=0lH?009=00<0C@000Td00lI=
C@020003C@36009=0/H3C@0304e=00/00dd03@1=CLI=aTd0C@1=aTd00/H5C@`00dd03@1=CLI=aTd0
C@1=aTd00/H5C@h00dd01@1=003600<000C600001Dd>00003002aP04C000009<0`000d`00002C0@0
00=<a/H03P07C0;600H0aTc6C<H4C0h024`2aP=<00C6C4c61T`;0003C01<009<00<0C4`00lH2C004
aP36aP9<0P02C00304`000T000=<04`00T`00`36C002aP050<I<aP000/H014c60002C00304`000T0
00=<04`00T`00`36C002aP050<I<aP000/H014c60002C00304`000/000=<04`00P0014`00<H30007
aP0004`0C0020003C00000/0000>00?600==04d00`001Td004d0C@C63`02C@0>04e=04d0aTg6CLH0
C@02C@0304e=00d000==00000Td2009=00?6CLH00Td2aP0404e=C@8000==00003008C@03aP1=00Q=
40001Dd0CDd000A=00<0CDd00Td01@1=C@1=010000E=04e=0004C@0304e=009=00D0CDd0C@0A0004
C@00C@8000E=0000C@030003C@1=0100000?0006aP3604c60P0014`0aT`2aP8000?600003P001d`0
04`0C00014`01`1<C01<04`00P000d`0000>0003C01<00a<00<0C0004`0=C1@000=<04`034`00`1<
000A0003C01<00a<00<0C0004@000d`00003009<00<0C4`01@000d`0000>00004P000lH00002aP03
CLH0008000?600004`000dd0C@05C@0304e=00A=00<0C@004004C@0304e=009=00H0CDd0C@04CA<0
00==00001dd20003C@0001@01Td00`1=C@02C@0304d001D01Td00`1=C@02C@0304d001P000M=04d0
C@1=01D0000B0004aP00aP<000C600366P001d`0C01<04`05@02C00304a<009<00@0C4`01D`00`1<
0002C1400T`20003C01<009<00@0C0000T`E0003C000009<00<0C0000T`2009<5@000d`00002C003
04`0009<0P02C1P000A<001<0P000d`0000C0000>002C@0304e=01`000==04d014d00`1=000I009=
1@02CAX00Td5009=6P02C@D00TdK0003C@0000<000==00004`0005P00T`0101<C002C00304a<09l0
003o00<0003o00<0003o00<0003o00<0003o00<00000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.109416,
   0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110613, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.109416, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.74027, -0.110615, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.10942, 0.0329415, 0.0329415},
   {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277, -0.110613, 
  0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} -> {-7.1939,
   -0.109416, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 37.5625}} ->
   {-0.270008, -1.2634, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {69.375, 
  37.5625}} -> {-1.42777, -1.26687, 0.0330062, 0.0330062}, {{77.5, 109.375}, {
  69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415}, {{112.562, 
  144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26686, 0.0330062, 0.0330062},
   {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.88594, -1.2634, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277, -1.26687, 
  0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} -> {-7.1939,
   -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 2.5}} ->
   {-0.270008, -2.41738, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {34.375, 
  2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 109.375}, {
  34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{112.562, 
  144.375}, {34.375, 2.5}} -> {-3.74027, -2.42311, 0.0330062, 0.0330062}, {{
  147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277, -2.42311, 
  0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} -> {-7.1939,
   -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .93366 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{174, 162},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002^0000XPP10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000:h0002^0000[P000:h0002^0000[P000:h0
002^0000DP03C0<00daC0000B@03C@H00dd300==1P03CDX0001900=<1P03C0<00d`600=<BP0003@0
0dd<00==0`03C@H014d00`1=C@02C@H00dd300==3003CCD0000d00=<3003C0<00d`600A<00<0C4`0
0T`600=<0`03C0`00d`e0000=004C@/014d200==1`03C@0404e=C@L00dd200A=2`04CCD0000d00E<
2P05C00404a<C0L01d`700=<00<0C4`00d`:00E<=@0003D01Dd:00Q=100=C@@024d:00E==P0003H0
14`;00M<1003C00304a<00=<00@0C4a<1007C0/014`g0000=`04C@/01Td400e=1006C@/014dh0000
=`05C0P024`400e<1008C0P01D`h0000>005C@L024d500]=1@08C@L01Ddi0000>@04C0L024`600U<
1P08C0L014`j0000>P04C@P01dd500U=1@07C@P014dk0000>P05C0P01d`500M<1@07C0P01D`k0000
:004C@l01Dd800M=1007C@@01dd800E=3`04CBT0000X00E<3`04C0T01T`400M<1006C0T014`?00E<
:@0002P01dd>00A=2008C@801dd200Q=2004C@h01ddY0000:P06C0T02D`701]<1`09C0T01T`[0000
:P08C@L02Td600==00<0CDd01dd00`1=C@07C@0404e=C@H02Td700Q=:`0002X02d`400]<1@03C080
24`00`1<C006C0800d`500]<100;C2/0000]00]=100;C@800dd300M=00<0CDd01Dd300==0P0;C@@0
2dd^0000;`0<C0@03D`300m<0`0=C0@034``0000<@0=C@<034d200m=0P0<C@<03Ddb0000<P0?C003
04a<02M<00<0C4`03D`c0000=00CC@0304e=01]=00<0CDd04Dde0000=@06C00304a<00Y<00<0C4`0
6D`00`1<C00:C00304a<00A<=P0003H01dd200M=0lH<C@C62Td4aPM=0P07CCL0000h00I<1004C0?6
1d`00lI<C002C0G600A<a/K614`5aPA<1006C3T0000i00I=1P0014g6a/H6C@?600==aTd02LH2C@O6
00==00001006CCX0000k00I<1`000lI<C003C0S600<0a/H03<H700I<?00002001DdG00I=1`03aP9=
1lH300c61`06CAL01DdQ0000800PC0G61003aP03C<K600C61`0:aPD01<HPC240000P021=4LH;0003
aTe=00K600<0a/H01LHPCB40000R01i<4<H=009<3/HNC2<0000V00]=4P0;aP03C@0000`00Td<aQ40
2ddW0000:@0;C1801lH2C0h00T`01036C4`5aQ402d`Z0000;00;CA001LH00`1=C@0>009=0P02C@?6
400;CBd0000_00]<3@03aP03C000009<3P02C0800T`3aPd02d``0000<P0;C@T01<H2C@0304e=00h0
0Td0101=CDd4aPT02ddc0000=@07C0k60T`00`1<C00>009<00@0C4`03/H7C3H0000g00E=2/H2C@05
aP1=C@000Td>009=00<0CDd00P02C@_61Ddh0000=008C0[60T`00lH0C004C0h01D`2009<2lH8C3D0
000a00]=2P03C@8014d>00A=0P03C@/02ddb0000;P0;C0h00d`00`1<C002C0h014`0101<C4`?00]<
;`0002/02ddB00M=3P07CA<02dd/0000:00;C1H00T`0101<C4`>00=<00<0C4`05`0;C2T0000U00]=
6@06C@h01TdJ00]=9P0002802d`M00E<3P05C1h02d`S0000800:CB4014d6008A1P04CB802TdQ0000
8007C2D00d`6008A1P03C2H01d`Q00008004CBP014d400@A1004CBT014dQ0000C@03C0@0114400=<
C`0004d014d300@A0`04CDl0001=00A<0P064@8014a?0000C@05C@03014A00@A00<0CDd00de?0000
C@06C0HA1Ta?0000C@05C@PA1De?0000C@05C08A00@04A400Q45C4l0001=009=00<0CDd00Q4014dA
4Dd24@9=00<0CDd0C`0004d00T`00`1<4@024@04C14AC0<A00A<04a<C`0004d00Td01P1=4A40C@8A
00I=014AC@02CDl0001=009<0P024@0604`A4D`00Q42009<C`0004d00Td01P0A4A40C@8A00==0140
0Q400`1=C@1?0000C@02C003014A00=<0Q43C08A00<0C4`0C`0004d00Td00`0A4@03C@8A0dd24@03
04e=04l0001=009<0a43C08A0d`34@9<C`0004d00Td24@A=0Q44C@8A0Te?0000C@02C08A14`24@A<
0Q42C4l0001=0006CA4A4Dd00Td24@9=00<0CA400Q400dd0001=0000C@000d`A4@02C00304a<008A
0T`00`1<C0024@03C00004d0001=0004CA4AC@<000A=4A5=0`0014dA4De?0000C00014`A4A440004
C14AC0@00a400d`0001<0000B`02C@8A1@0014dA4Dd5008A0Te=00003@04C3T01T`5008A1@06C3X0
14`>00003@05CCH024d5008A1@08CCL01Dd>00003@07C3<014`00`1<C002C0@014`400A<00<0C4`0
0T`d00M<3P0000l01Tda00==0`05C@801Td200E=0`03CC801Td@00004006C2h014`300=<00@0C4`0
24`0101<C003C0<014`_00I<4@0001801Td[00A=1002C@800Td0101=C@02C@0404e=009=0P02C@@0
14d/00I=4`0001<01T`Y00=<1P02C0801D`0101<C005C0800T`600=<:P06C1@0000D00M=9@04C@H0
0dd300==0P02C@800dd300==1P04CBH01ddE00005P06C2<014`7009<0`03C0<00T`300=<0`02C0L0
14`T00I<5`0001L01TdP00A=2@02C@<014d2009=0P04C@<00Td900A=8@06CAP0000I00I<7@04C0T0
0d`200E<0P02C0801D`200=<2@04C1h01T`J00006P06CA/00dd;009=0P03C@0304e=00800Td2009=
00@0CDe=0P02C@/00ddL00I=6`0001/01d`G00A<3002C00404a<C0800d`0101<C003C0800d`00`1<
C00<00A<6007C1`0000M00I=5@04C@`00dd00`1=C@04009=00@0CDd00Td4009=00@0CDe=3004CAH0
1TdN00007P06C1<00d`>009<00@0C4a<1002C00404a<009<1003C00304a<00h00d`D00I<7`000200
1Td?00A=3`05C@D024d500E=3`04CA001TdQ00008@06C0d014`?00E<1`06C0L01D`?00A<3P06C280
000701i=1LH900==4@04C@P01Td800A=4@03C@/01<HNC@P0000701i<2<H400A<4P04C0P01T`800A<
4P04C0H01lHNC0P0000701i=2lH4CA<00dd:00A=2P03CA<014d200[67Td80000:007aP=<5003C0/0
14`;00=<5003C0W6:00001P01Dd>00?60ddE00==2`04C@/00ddE00==1LH=00E=6@0001P024`>009<
00?600004P03C0d00T`=00=<5@02C0;63@08C1T0000H00]=2`03aQ<014d=009=3@04CA@00lH;00]=
6@0001/02d`800?64`03C0d014`=00=<5003aPP02d`L00007P0;C@D00lHB00A=3@04C@d014dC00?6
1@0;CAl0000Q00]<0P03aQ401D`=00A<3@05C1800lH200]<8P0002@02dd2aQ001Dd=00I=3@05CA40
0lH:CBD0000W00]<3`02C00304a<00d01T`=009<00<0C4`0400014c6a/H7C2P0000Z00]=2`06C@d0
1Td=00I=3004C@?614d[0000;@07C0_60d`00`1<C00=00Q<3@02C00404a<C0c60d`3aP03C00002`0
000^0003aTe=00==2/H3C@800Td=009=00@0CDd00Td=009=0P03C@_60dd3aRl0000/00Q<2/H2C0;6
0d`=009<00@0C4`00T`=00=<00@0aTa<2lH3C0?60T`]0000:@0;C@X01<H2C@d00dd0101=C@03C@d0
0Td00`36aP02aPX02ddZ00009P0<C0d00lH2C0d00T`2009<0P02C0d00T`01036a/H=00a<9`0002<0
3dd=00C600==00002@02aP9=0P02C@800Td4aPT00dd3aPd03ddT0000800;C00304a<00E<2P07aPP0
1<H3C0800T`200=<1/H7009<1/H900M<00<0C4`02D`Q00007@0;C@@01dd700_61007aP9=0/H00`1=
C@020003aTe=00W60`000lI=C@09aPH01dd400]=7P0001X0;D`>aP9<3lH00dc6aP0<aQi<6`0001P0
;dd7aP<01LH00dg6aP03aP@03LH2C@K684dI0000600_C0C61P0;aPL02LH6C0?684`I00006004C@l0
0dd300Q=20000lI=C@04C@03aP0000@03lH600S62008C@<00dd?00A=6@0002X014`300M<2@06C0?6
00A<00002lH00dc6aP03aP<000=<a/H00lH4C0T01d`300A<:`0002X014d200I=2P06C@C60dd6aP03
CLK600?60Td5aP==1<H6C@X01Td200A=:`0002X00d`200I<2@09C003aTa<00=<1<H3C0G60d`4aP=<
0lH9C0T01T`200=<:`0002T03Dd7011=0lHPC@L03DdZ0000:@0=C0D0=d`500e<:P0002T024d200==
100LC@0304e=01Y=1003C@8024dZ0000:007C0@014`201e<00<0C4`06d`200A<1007C2T0000X00I=
1@0AC@8044d00`1=C@0>C@804Dd500I=:@0002H01d`7011<0`0>C0<03T`3011<1`07C2L0000U00I=
200;C@<00dd300I=100;C@@01Td300==0`0;C@P01TdV00009007C0H02T`600=<0P07C0@02d`400M<
0P03C0H02T`600M<9@00028024d700M=2@03C@0304e=00M=0`0;C@<02Dd0101=CDd900M=1`08CB<0
000Q00U<1`08C0P03D`200e<0P0=C0P024`700U<8P0002002Td600U=2008C@0304e=00==00<0CDd0
2dd00`1=C@03C@0304e=00I=2009C@H02TdQ00008004C0800d`700A<0P03C0P024`200]<00<0C4`0
2D`200Q<2003C08014`700=<0P04C240000P00==0P04C@L00dd300A=1@09C@<02Dd500U=0`09C@D0
14d300==1`04C@800ddQ00009@04C0d014`400U<1008C0L024`400U<1004C0d014`V00009@03C@l0
0dd300U=1P06C@T01Td600U=0`03C@l00ddV00009@03C0l00d`200Y<1@08C0L024`500Y<0P03C0l0
0d`V0000?004C@0304e=009=1P08C@L024d600A=00<0CDd00Tdm0000?003C00304a<009<1`09C0D0
2D`700A<00@0C4a<?@0003l01Dd900Q=0`08C@T01De00000?P06C0T024`300Q<2@06C3l0000n00I=
2@04C@0404e=C@<00dd00`1=C@02C@T01Tdo0000?@07C0P01T`900I<2007C3h0000l00Q=2006C@T0
1Td800Q=?@0003`014`0101<C4`800I<2@06C0P00d`00`1<C002C3d0000l00==0P03C@L024d700Q=
1`03C@800ddm0000@@03C0L024`700Q<1`03C480001100==1`03C@800dd700==0P03C@L00de20000
B`03C0800d`700=<0P03C4`0002^0000[P000:h0002^0000[P000:h0002^0000\
\>"],
  ImageRangeCache->{{{0, 173}, {161, 0}} -> {-0.0267113, 0.00982279, 
  0.00608915, 0.00608915}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.016 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.016 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.016 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.016 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.016 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.016 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.016 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.016 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.016 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.016 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.016 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.016 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.016 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.016 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.016 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.016 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.016 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.016 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.016 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.016 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.016 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.016 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.016 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.016 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.016 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.016 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.016 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.016 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.016 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.016 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 1 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 1 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 1 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 1 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 1 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 1 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 1 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 1 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 1 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 1 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 1 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 1 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 1 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 1 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 1 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 1 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 1 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 1 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 1 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 1 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 1 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 1 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 1 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 1 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 1 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 1 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 1 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 1 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 1 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 1 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0195479 0.952381 [
[ 0 0 0 0 ]
[ 1 .91329 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .91329 L
0 .91329 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49284 .71912 m
.39116 .85906 L
s
P
p
.2 0 1 r
.02 w
.58157 .69029 m
.74608 .74374 L
s
P
p
0 .4 1 r
.018 w
.52673 .67247 m
.49284 .71912 L
s
P
p
0 .4 1 r
.018 w
.52673 .67247 m
.58157 .69029 L
s
P
p
.2 0 1 r
.02 w
.5021 .18858 m
.64205 .08691 L
s
P
p
.2 0 1 r
.02 w
.40881 .18858 m
.26886 .08691 L
s
P
p
0 .4 1 r
.018 w
.45545 .22247 m
.5021 .18858 L
s
P
p
0 .4 1 r
.018 w
.45545 .22247 m
.40881 .18858 L
s
P
p
.2 0 1 r
.02 w
.32934 .69029 m
.16483 .74374 L
s
P
p
.2 0 1 r
.02 w
.41807 .71912 m
.51975 .85906 L
s
P
p
0 .4 1 r
.018 w
.38418 .67247 m
.32934 .69029 L
s
P
p
0 .4 1 r
.018 w
.38418 .67247 m
.41807 .71912 L
s
P
p
.2 0 1 r
.02 w
.64868 .26652 m
.82166 .26652 L
s
P
p
.2 0 1 r
.02 w
.5732 .21168 m
.51975 .04717 L
s
P
p
0 .4 1 r
.018 w
.59102 .26652 m
.64868 .26652 L
s
P
p
0 .4 1 r
.018 w
.59102 .26652 m
.5732 .21168 L
s
P
p
.2 0 1 r
.02 w
.21402 .57086 m
.04951 .51741 L
s
P
p
.2 0 1 r
.02 w
.26886 .64634 m
.26886 .81932 L
s
P
p
0 .4 1 r
.018 w
.26886 .58868 m
.21402 .57086 L
s
P
p
0 .4 1 r
.018 w
.26886 .58868 m
.26886 .64634 L
s
P
p
.2 0 1 r
.016 w
.45545 .45311 m
.52673 .67247 L
s
P
p
.2 0 1 r
.016 w
.45545 .45311 m
.45545 .22247 L
s
P
p
.2 0 1 r
.016 w
.45545 .45311 m
.38418 .67247 L
s
P
p
.2 0 1 r
.016 w
.45545 .45311 m
.59102 .26652 L
s
P
p
.2 0 1 r
.016 w
.45545 .45311 m
.26886 .58868 L
s
P
p
.2 0 1 r
.02 w
.61775 .7016 m
.5643 .86612 L
s
P
p
.2 0 1 r
.02 w
.69323 .64676 m
.86621 .64676 L
s
P
p
0 .4 1 r
.018 w
.63557 .64676 m
.61775 .7016 L
s
P
p
0 .4 1 r
.018 w
.63557 .64676 m
.69323 .64676 L
s
P
p
.2 0 1 r
.02 w
.46262 .19417 m
.5643 .05422 L
s
P
p
.2 0 1 r
.02 w
.37389 .223 m
.20937 .16954 L
s
P
p
0 .4 1 r
.018 w
.42873 .24082 m
.46262 .19417 L
s
P
p
0 .4 1 r
.018 w
.42873 .24082 m
.37389 .223 L
s
P
p
.2 0 1 r
.02 w
.45335 .7247 m
.31341 .82638 L
s
P
p
.2 0 1 r
.02 w
.54665 .7247 m
.68659 .82638 L
s
P
p
0 .4 1 r
.018 w
.5 .69081 m
.45335 .7247 L
s
P
p
0 .4 1 r
.018 w
.5 .69081 m
.54665 .7247 L
s
P
p
.2 0 1 r
.02 w
.62611 .223 m
.79063 .16954 L
s
P
p
.2 0 1 r
.02 w
.53738 .19417 m
.4357 .05422 L
s
P
p
0 .4 1 r
.018 w
.57127 .24082 m
.62611 .223 L
s
P
p
0 .4 1 r
.018 w
.57127 .24082 m
.53738 .19417 L
s
P
p
.2 0 1 r
.02 w
.30677 .64676 m
.13379 .64676 L
s
P
p
.2 0 1 r
.02 w
.38225 .7016 m
.4357 .86612 L
s
P
p
0 .4 1 r
.018 w
.36443 .64676 m
.30677 .64676 L
s
P
p
0 .4 1 r
.018 w
.36443 .64676 m
.38225 .7016 L
s
P
p
.2 0 1 r
.016 w
.5 .46017 m
.63557 .64676 L
s
P
p
.2 0 1 r
.016 w
.5 .46017 m
.42873 .24082 L
s
P
p
.2 0 1 r
.016 w
.5 .46017 m
.5 .69081 L
s
P
p
.2 0 1 r
.016 w
.5 .46017 m
.57127 .24082 L
s
P
p
.2 0 1 r
.016 w
.5 .46017 m
.36443 .64676 L
s
P
p
.2 0 1 r
.02 w
.73114 .64634 m
.73114 .81932 L
s
P
p
.2 0 1 r
.02 w
.78598 .57086 m
.95049 .51741 L
s
P
p
0 .4 1 r
.018 w
.73114 .58868 m
.73114 .64634 L
s
P
p
0 .4 1 r
.018 w
.73114 .58868 m
.78598 .57086 L
s
P
p
.2 0 1 r
.02 w
.4268 .21168 m
.48025 .04717 L
s
P
p
.2 0 1 r
.02 w
.35132 .26652 m
.17834 .26652 L
s
P
p
0 .4 1 r
.018 w
.40898 .26652 m
.4268 .21168 L
s
P
p
0 .4 1 r
.018 w
.40898 .26652 m
.35132 .26652 L
s
P
p
.2 0 1 r
.02 w
.58193 .71912 m
.48025 .85906 L
s
P
p
.2 0 1 r
.02 w
.67066 .69029 m
.83517 .74374 L
s
P
p
0 .4 1 r
.018 w
.61582 .67247 m
.58193 .71912 L
s
P
p
0 .4 1 r
.018 w
.61582 .67247 m
.67066 .69029 L
s
P
p
.2 0 1 r
.02 w
.59119 .18858 m
.73114 .08691 L
s
P
p
.2 0 1 r
.02 w
.4979 .18858 m
.35795 .08691 L
s
P
p
0 .4 1 r
.018 w
.54455 .22247 m
.59119 .18858 L
s
P
p
0 .4 1 r
.018 w
.54455 .22247 m
.4979 .18858 L
s
P
p
.2 0 1 r
.02 w
.41843 .69029 m
.25392 .74374 L
s
P
p
.2 0 1 r
.02 w
.50716 .71912 m
.60884 .85906 L
s
P
p
0 .4 1 r
.018 w
.47327 .67247 m
.41843 .69029 L
s
P
p
0 .4 1 r
.018 w
.47327 .67247 m
.50716 .71912 L
s
P
p
.2 0 1 r
.016 w
.54455 .45311 m
.73114 .58868 L
s
P
p
.2 0 1 r
.016 w
.54455 .45311 m
.40898 .26652 L
s
P
p
.2 0 1 r
.016 w
.54455 .45311 m
.61582 .67247 L
s
P
p
.2 0 1 r
.016 w
.54455 .45311 m
.54455 .22247 L
s
P
p
.2 0 1 r
.016 w
.54455 .45311 m
.47327 .67247 L
s
P
p
1 .6 0 r
.016 w
.5 .31602 m
.45545 .45311 L
s
P
p
1 .6 0 r
.016 w
.5 .31602 m
.5 .46017 L
s
P
p
1 .6 0 r
.016 w
.5 .31602 m
.54455 .45311 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0181222 0.952381 [
[ 0 0 0 0 ]
[ 1 .91614 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .91614 L
0 .91614 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49293 .71693 m
.3723 .83756 L
s
P
p
.2 0 1 r
.02 w
.49293 .71693 m
.41548 .86893 L
s
P
p
.2 0 1 r
.02 w
.58044 .68849 m
.73245 .76594 L
s
P
p
.2 0 1 r
.02 w
.58044 .68849 m
.74894 .71518 L
s
P
p
0 .4 1 r
.018 w
.52636 .67092 m
.49293 .71693 L
s
P
p
0 .4 1 r
.018 w
.52636 .67092 m
.58044 .68849 L
s
P
p
.2 0 1 r
.02 w
.50207 .1937 m
.65408 .11625 L
s
P
p
.2 0 1 r
.02 w
.50207 .1937 m
.6227 .07307 L
s
P
p
.2 0 1 r
.02 w
.41006 .1937 m
.28943 .07307 L
s
P
p
.2 0 1 r
.02 w
.41006 .1937 m
.25806 .11625 L
s
P
p
0 .4 1 r
.018 w
.45607 .22713 m
.50207 .1937 L
s
P
p
0 .4 1 r
.018 w
.45607 .22713 m
.41006 .1937 L
s
P
p
.2 0 1 r
.02 w
.3317 .68849 m
.1632 .71518 L
s
P
p
.2 0 1 r
.02 w
.3317 .68849 m
.17969 .76594 L
s
P
p
.2 0 1 r
.02 w
.4192 .71693 m
.49665 .86893 L
s
P
p
.2 0 1 r
.02 w
.4192 .71693 m
.53983 .83756 L
s
P
p
0 .4 1 r
.018 w
.38578 .67092 m
.3317 .68849 L
s
P
p
0 .4 1 r
.018 w
.38578 .67092 m
.4192 .71693 L
s
P
p
.2 0 1 r
.02 w
.64663 .27057 m
.81513 .29725 L
s
P
p
.2 0 1 r
.02 w
.64663 .27057 m
.81513 .24388 L
s
P
p
.2 0 1 r
.02 w
.5722 .21648 m
.54551 .04799 L
s
P
p
.2 0 1 r
.02 w
.5722 .21648 m
.49475 .06448 L
s
P
p
0 .4 1 r
.018 w
.58977 .27057 m
.64663 .27057 L
s
P
p
0 .4 1 r
.018 w
.58977 .27057 m
.5722 .21648 L
s
P
p
.2 0 1 r
.02 w
.21796 .57072 m
.06596 .49327 L
s
P
p
.2 0 1 r
.02 w
.21796 .57072 m
.04947 .54403 L
s
P
p
.2 0 1 r
.02 w
.27205 .64515 m
.24536 .81365 L
s
P
p
.2 0 1 r
.02 w
.27205 .64515 m
.29873 .81365 L
s
P
p
0 .4 1 r
.018 w
.27205 .58829 m
.21796 .57072 L
s
P
p
0 .4 1 r
.018 w
.27205 .58829 m
.27205 .64515 L
s
P
p
.2 0 1 r
.016 w
.45607 .45459 m
.52636 .67092 L
s
P
p
.2 0 1 r
.016 w
.45607 .45459 m
.45607 .22713 L
s
P
p
.2 0 1 r
.016 w
.45607 .45459 m
.38578 .67092 L
s
P
p
.2 0 1 r
.016 w
.45607 .45459 m
.58977 .27057 L
s
P
p
.2 0 1 r
.016 w
.45607 .45459 m
.27205 .58829 L
s
P
p
.2 0 1 r
.02 w
.61613 .69965 m
.53868 .85166 L
s
P
p
.2 0 1 r
.02 w
.61613 .69965 m
.58944 .86815 L
s
P
p
.2 0 1 r
.02 w
.69057 .64557 m
.85906 .67226 L
s
P
p
.2 0 1 r
.02 w
.69057 .64557 m
.85906 .61888 L
s
P
p
0 .4 1 r
.018 w
.6337 .64557 m
.61613 .69965 L
s
P
p
0 .4 1 r
.018 w
.6337 .64557 m
.69057 .64557 L
s
P
p
.2 0 1 r
.02 w
.46313 .19921 m
.58377 .07858 L
s
P
p
.2 0 1 r
.02 w
.46313 .19921 m
.54058 .04721 L
s
P
p
.2 0 1 r
.02 w
.37563 .22764 m
.22362 .15019 L
s
P
p
.2 0 1 r
.02 w
.37563 .22764 m
.20713 .20096 L
s
P
p
0 .4 1 r
.018 w
.42971 .24522 m
.46313 .19921 L
s
P
p
0 .4 1 r
.018 w
.42971 .24522 m
.37563 .22764 L
s
P
p
.2 0 1 r
.02 w
.45399 .72244 m
.30199 .79989 L
s
P
p
.2 0 1 r
.02 w
.45399 .72244 m
.33336 .84307 L
s
P
p
.2 0 1 r
.02 w
.54601 .72244 m
.66664 .84307 L
s
P
p
.2 0 1 r
.02 w
.54601 .72244 m
.69801 .79989 L
s
P
p
0 .4 1 r
.018 w
.5 .68901 m
.45399 .72244 L
s
P
p
0 .4 1 r
.018 w
.5 .68901 m
.54601 .72244 L
s
P
p
.2 0 1 r
.02 w
.62437 .22764 m
.79287 .20096 L
s
P
p
.2 0 1 r
.02 w
.62437 .22764 m
.77638 .15019 L
s
P
p
.2 0 1 r
.02 w
.53687 .19921 m
.45942 .04721 L
s
P
p
.2 0 1 r
.02 w
.53687 .19921 m
.41623 .07858 L
s
P
p
0 .4 1 r
.018 w
.57029 .24522 m
.62437 .22764 L
s
P
p
0 .4 1 r
.018 w
.57029 .24522 m
.53687 .19921 L
s
P
p
.2 0 1 r
.02 w
.30943 .64557 m
.14094 .61888 L
s
P
p
.2 0 1 r
.02 w
.30943 .64557 m
.14094 .67226 L
s
P
p
.2 0 1 r
.02 w
.38387 .69965 m
.41056 .86815 L
s
P
p
.2 0 1 r
.02 w
.38387 .69965 m
.46132 .85166 L
s
P
p
0 .4 1 r
.018 w
.3663 .64557 m
.30943 .64557 L
s
P
p
0 .4 1 r
.018 w
.3663 .64557 m
.38387 .69965 L
s
P
p
.2 0 1 r
.016 w
.5 .46155 m
.6337 .64557 L
s
P
p
.2 0 1 r
.016 w
.5 .46155 m
.42971 .24522 L
s
P
p
.2 0 1 r
.016 w
.5 .46155 m
.5 .68901 L
s
P
p
.2 0 1 r
.016 w
.5 .46155 m
.57029 .24522 L
s
P
p
.2 0 1 r
.016 w
.5 .46155 m
.3663 .64557 L
s
P
p
.2 0 1 r
.02 w
.72795 .64515 m
.70127 .81365 L
s
P
p
.2 0 1 r
.02 w
.72795 .64515 m
.75464 .81365 L
s
P
p
.2 0 1 r
.02 w
.78204 .57072 m
.95053 .54403 L
s
P
p
.2 0 1 r
.02 w
.78204 .57072 m
.93404 .49327 L
s
P
p
0 .4 1 r
.018 w
.72795 .58829 m
.72795 .64515 L
s
P
p
0 .4 1 r
.018 w
.72795 .58829 m
.78204 .57072 L
s
P
p
.2 0 1 r
.02 w
.4278 .21648 m
.50525 .06448 L
s
P
p
.2 0 1 r
.02 w
.4278 .21648 m
.45449 .04799 L
s
P
p
.2 0 1 r
.02 w
.35337 .27057 m
.18487 .24388 L
s
P
p
.2 0 1 r
.02 w
.35337 .27057 m
.18487 .29725 L
s
P
p
0 .4 1 r
.018 w
.41023 .27057 m
.4278 .21648 L
s
P
p
0 .4 1 r
.018 w
.41023 .27057 m
.35337 .27057 L
s
P
p
.2 0 1 r
.02 w
.5808 .71693 m
.46017 .83756 L
s
P
p
.2 0 1 r
.02 w
.5808 .71693 m
.50335 .86893 L
s
P
p
.2 0 1 r
.02 w
.6683 .68849 m
.82031 .76594 L
s
P
p
.2 0 1 r
.02 w
.6683 .68849 m
.8368 .71518 L
s
P
p
0 .4 1 r
.018 w
.61422 .67092 m
.5808 .71693 L
s
P
p
0 .4 1 r
.018 w
.61422 .67092 m
.6683 .68849 L
s
P
p
.2 0 1 r
.02 w
.58994 .1937 m
.74194 .11625 L
s
P
p
.2 0 1 r
.02 w
.58994 .1937 m
.71057 .07307 L
s
P
p
.2 0 1 r
.02 w
.49793 .1937 m
.3773 .07307 L
s
P
p
.2 0 1 r
.02 w
.49793 .1937 m
.34592 .11625 L
s
P
p
0 .4 1 r
.018 w
.54393 .22713 m
.58994 .1937 L
s
P
p
0 .4 1 r
.018 w
.54393 .22713 m
.49793 .1937 L
s
P
p
.2 0 1 r
.02 w
.41956 .68849 m
.25106 .71518 L
s
P
p
.2 0 1 r
.02 w
.41956 .68849 m
.26755 .76594 L
s
P
p
.2 0 1 r
.02 w
.50707 .71693 m
.58452 .86893 L
s
P
p
.2 0 1 r
.02 w
.50707 .71693 m
.6277 .83756 L
s
P
p
0 .4 1 r
.018 w
.47364 .67092 m
.41956 .68849 L
s
P
p
0 .4 1 r
.018 w
.47364 .67092 m
.50707 .71693 L
s
P
p
.2 0 1 r
.016 w
.54393 .45459 m
.72795 .58829 L
s
P
p
.2 0 1 r
.016 w
.54393 .45459 m
.41023 .27057 L
s
P
p
.2 0 1 r
.016 w
.54393 .45459 m
.61422 .67092 L
s
P
p
.2 0 1 r
.016 w
.54393 .45459 m
.54393 .22713 L
s
P
p
.2 0 1 r
.016 w
.54393 .45459 m
.47364 .67092 L
s
P
p
1 .6 0 r
.016 w
.5 .31938 m
.45607 .45459 L
s
P
p
1 .6 0 r
.016 w
.5 .31938 m
.5 .46155 L
s
P
p
1 .6 0 r
.016 w
.5 .31938 m
.54393 .45459 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0100208 0.952381 [
[ 0 0 0 0 ]
[ 1 .93234 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93234 L
0 .93234 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.4925 .74098 m
.3704 .8297 L
s
P
p
.2 0 1 r
.02 w
.4925 .74098 m
.44586 .88452 L
s
P
p
.2 0 1 r
.02 w
.5854 .7108 m
.7075 .79951 L
s
P
p
.2 0 1 r
.02 w
.5854 .7108 m
.73633 .7108 L
s
P
p
0 .4 1 r
.018 w
.52798 .69214 m
.4925 .74098 L
s
P
p
0 .4 1 r
.018 w
.52798 .69214 m
.5854 .7108 L
s
P
p
.2 0 1 r
.02 w
.5022 .18551 m
.64574 .13887 L
s
P
p
.2 0 1 r
.02 w
.5022 .18551 m
.59092 .0634 L
s
P
p
.2 0 1 r
.02 w
.40452 .18551 m
.31581 .0634 L
s
P
p
.2 0 1 r
.02 w
.40452 .18551 m
.26098 .13887 L
s
P
p
0 .4 1 r
.018 w
.45336 .22099 m
.5022 .18551 L
s
P
p
0 .4 1 r
.018 w
.45336 .22099 m
.40452 .18551 L
s
P
p
.2 0 1 r
.02 w
.32132 .7108 m
.17039 .7108 L
s
P
p
.2 0 1 r
.02 w
.32132 .7108 m
.19922 .79951 L
s
P
p
.2 0 1 r
.02 w
.41422 .74098 m
.46086 .88452 L
s
P
p
.2 0 1 r
.02 w
.41422 .74098 m
.53633 .8297 L
s
P
p
0 .4 1 r
.018 w
.37874 .69214 m
.32132 .7108 L
s
P
p
0 .4 1 r
.018 w
.37874 .69214 m
.41422 .74098 L
s
P
p
.2 0 1 r
.02 w
.65567 .26711 m
.79921 .31375 L
s
P
p
.2 0 1 r
.02 w
.65567 .26711 m
.79921 .22047 L
s
P
p
.2 0 1 r
.02 w
.57665 .20969 m
.57665 .05877 L
s
P
p
.2 0 1 r
.02 w
.57665 .20969 m
.48793 .08759 L
s
P
p
0 .4 1 r
.018 w
.5953 .26711 m
.65567 .26711 L
s
P
p
0 .4 1 r
.018 w
.5953 .26711 m
.57665 .20969 L
s
P
p
.2 0 1 r
.02 w
.20058 .58576 m
.07848 .49705 L
s
P
p
.2 0 1 r
.02 w
.20058 .58576 m
.04965 .58576 L
s
P
p
.2 0 1 r
.02 w
.258 .66479 m
.21136 .80833 L
s
P
p
.2 0 1 r
.02 w
.258 .66479 m
.30464 .80833 L
s
P
p
0 .4 1 r
.018 w
.258 .60442 m
.20058 .58576 L
s
P
p
0 .4 1 r
.018 w
.258 .60442 m
.258 .66479 L
s
P
p
.2 0 1 r
.016 w
.45336 .46248 m
.52798 .69214 L
s
P
p
.2 0 1 r
.016 w
.45336 .46248 m
.45336 .22099 L
s
P
p
.2 0 1 r
.016 w
.45336 .46248 m
.37874 .69214 L
s
P
p
.2 0 1 r
.016 w
.45336 .46248 m
.5953 .26711 L
s
P
p
.2 0 1 r
.016 w
.45336 .46248 m
.258 .60442 L
s
P
p
.2 0 1 r
.02 w
.62329 .72264 m
.53457 .84475 L
s
P
p
.2 0 1 r
.02 w
.62329 .72264 m
.62329 .87357 L
s
P
p
.2 0 1 r
.02 w
.70231 .66523 m
.84585 .71187 L
s
P
p
.2 0 1 r
.02 w
.70231 .66523 m
.84585 .61859 L
s
P
p
0 .4 1 r
.018 w
.64194 .66523 m
.62329 .72264 L
s
P
p
0 .4 1 r
.018 w
.64194 .66523 m
.70231 .66523 L
s
P
p
.2 0 1 r
.02 w
.46086 .19136 m
.58297 .10264 L
s
P
p
.2 0 1 r
.02 w
.46086 .19136 m
.5075 .04782 L
s
P
p
.2 0 1 r
.02 w
.36796 .22154 m
.24586 .13283 L
s
P
p
.2 0 1 r
.02 w
.36796 .22154 m
.21703 .22154 L
s
P
p
0 .4 1 r
.018 w
.42538 .2402 m
.46086 .19136 L
s
P
p
0 .4 1 r
.018 w
.42538 .2402 m
.36796 .22154 L
s
P
p
.2 0 1 r
.02 w
.45116 .74683 m
.30762 .79347 L
s
P
p
.2 0 1 r
.02 w
.45116 .74683 m
.36245 .86894 L
s
P
p
.2 0 1 r
.02 w
.54884 .74683 m
.63755 .86894 L
s
P
p
.2 0 1 r
.02 w
.54884 .74683 m
.69238 .79347 L
s
P
p
0 .4 1 r
.018 w
.5 .71135 m
.45116 .74683 L
s
P
p
0 .4 1 r
.018 w
.5 .71135 m
.54884 .74683 L
s
P
p
.2 0 1 r
.02 w
.63204 .22154 m
.78297 .22154 L
s
P
p
.2 0 1 r
.02 w
.63204 .22154 m
.75414 .13283 L
s
P
p
.2 0 1 r
.02 w
.53914 .19136 m
.4925 .04782 L
s
P
p
.2 0 1 r
.02 w
.53914 .19136 m
.41703 .10264 L
s
P
p
0 .4 1 r
.018 w
.57462 .2402 m
.63204 .22154 L
s
P
p
0 .4 1 r
.018 w
.57462 .2402 m
.53914 .19136 L
s
P
p
.2 0 1 r
.02 w
.29769 .66523 m
.15415 .61859 L
s
P
p
.2 0 1 r
.02 w
.29769 .66523 m
.15415 .71187 L
s
P
p
.2 0 1 r
.02 w
.37671 .72264 m
.37671 .87357 L
s
P
p
.2 0 1 r
.02 w
.37671 .72264 m
.46543 .84475 L
s
P
p
0 .4 1 r
.018 w
.35806 .66523 m
.29769 .66523 L
s
P
p
0 .4 1 r
.018 w
.35806 .66523 m
.37671 .72264 L
s
P
p
.2 0 1 r
.016 w
.5 .46986 m
.64194 .66523 L
s
P
p
.2 0 1 r
.016 w
.5 .46986 m
.42538 .2402 L
s
P
p
.2 0 1 r
.016 w
.5 .46986 m
.5 .71135 L
s
P
p
.2 0 1 r
.016 w
.5 .46986 m
.57462 .2402 L
s
P
p
.2 0 1 r
.016 w
.5 .46986 m
.35806 .66523 L
s
P
p
.2 0 1 r
.02 w
.742 .66479 m
.69536 .80833 L
s
P
p
.2 0 1 r
.02 w
.742 .66479 m
.78864 .80833 L
s
P
p
.2 0 1 r
.02 w
.79942 .58576 m
.95035 .58576 L
s
P
p
.2 0 1 r
.02 w
.79942 .58576 m
.92152 .49705 L
s
P
p
0 .4 1 r
.018 w
.742 .60442 m
.742 .66479 L
s
P
p
0 .4 1 r
.018 w
.742 .60442 m
.79942 .58576 L
s
P
p
.2 0 1 r
.02 w
.42335 .20969 m
.51207 .08759 L
s
P
p
.2 0 1 r
.02 w
.42335 .20969 m
.42335 .05877 L
s
P
p
.2 0 1 r
.02 w
.34433 .26711 m
.20079 .22047 L
s
P
p
.2 0 1 r
.02 w
.34433 .26711 m
.20079 .31375 L
s
P
p
0 .4 1 r
.018 w
.4047 .26711 m
.42335 .20969 L
s
P
p
0 .4 1 r
.018 w
.4047 .26711 m
.34433 .26711 L
s
P
p
.2 0 1 r
.02 w
.58578 .74098 m
.46367 .8297 L
s
P
p
.2 0 1 r
.02 w
.58578 .74098 m
.53914 .88452 L
s
P
p
.2 0 1 r
.02 w
.67868 .7108 m
.80078 .79951 L
s
P
p
.2 0 1 r
.02 w
.67868 .7108 m
.82961 .7108 L
s
P
p
0 .4 1 r
.018 w
.62126 .69214 m
.58578 .74098 L
s
P
p
0 .4 1 r
.018 w
.62126 .69214 m
.67868 .7108 L
s
P
p
.2 0 1 r
.02 w
.59548 .18551 m
.73902 .13887 L
s
P
p
.2 0 1 r
.02 w
.59548 .18551 m
.68419 .0634 L
s
P
p
.2 0 1 r
.02 w
.4978 .18551 m
.40908 .0634 L
s
P
p
.2 0 1 r
.02 w
.4978 .18551 m
.35426 .13887 L
s
P
p
0 .4 1 r
.018 w
.54664 .22099 m
.59548 .18551 L
s
P
p
0 .4 1 r
.018 w
.54664 .22099 m
.4978 .18551 L
s
P
p
.2 0 1 r
.02 w
.4146 .7108 m
.26367 .7108 L
s
P
p
.2 0 1 r
.02 w
.4146 .7108 m
.2925 .79951 L
s
P
p
.2 0 1 r
.02 w
.5075 .74098 m
.55414 .88452 L
s
P
p
.2 0 1 r
.02 w
.5075 .74098 m
.6296 .8297 L
s
P
p
0 .4 1 r
.018 w
.47202 .69214 m
.4146 .7108 L
s
P
p
0 .4 1 r
.018 w
.47202 .69214 m
.5075 .74098 L
s
P
p
.2 0 1 r
.016 w
.54664 .46248 m
.742 .60442 L
s
P
p
.2 0 1 r
.016 w
.54664 .46248 m
.4047 .26711 L
s
P
p
.2 0 1 r
.016 w
.54664 .46248 m
.62126 .69214 L
s
P
p
.2 0 1 r
.016 w
.54664 .46248 m
.54664 .22099 L
s
P
p
.2 0 1 r
.016 w
.54664 .46248 m
.47202 .69214 L
s
P
p
1 .6 0 r
.016 w
.5 .31894 m
.45336 .46248 L
s
P
p
1 .6 0 r
.016 w
.5 .31894 m
.5 .46986 L
s
P
p
1 .6 0 r
.016 w
.5 .31894 m
.54664 .46248 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.018 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.018 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.018 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.018 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.018 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.018 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.018 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.018 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.018 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.018 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.018 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.018 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.018 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.018 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.018 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.018 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.018 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.018 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.018 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.018 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.018 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.018 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.018 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.018 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.018 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.018 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.018 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.018 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.018 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.018 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.018 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.018 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.018 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.018 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.018 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.018 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.018 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.018 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.018 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.018 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.018 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.018 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.018 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.018 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.018 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.018 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.018 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.018 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.018 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.018 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.018 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.018 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.018 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.018 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.018 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.018 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.018 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.018 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.018 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.018 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
0 .4 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
0 .4 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
0 .4 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
0 .4 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
0 .4 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
0 .4 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
0 .4 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
0 .4 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
0 .4 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
0 .4 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
0 .4 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
0 .4 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
0 .4 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
0 .4 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
0 .4 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
0 .4 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
0 .4 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
0 .4 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
0 .4 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
0 .4 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
0 .4 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
0 .4 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
0 .4 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
0 .4 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
0 .4 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
0 .4 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
0 .4 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
0 .4 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
0 .4 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
0 .4 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
0 .4 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
0 .4 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
0 .4 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
0 .4 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
0 .4 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
0 .4 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
0 .4 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
0 .4 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
0 .4 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
0 .4 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
0 .4 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
0 .4 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
0 .4 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
0 .4 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
0 .4 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
0 .4 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
0 .4 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
0 .4 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
0 .4 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
0 .4 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
0 .4 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
0 .4 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
0 .4 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
0 .4 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
0 .4 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
0 .4 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
0 .4 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
0 .4 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
0 .4 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0894858 1.17897 0.0294743 1.17897 [
[ 0 0 0 0 ]
[ 1 1.23792 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.23792 L
0 1.23792 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.27901 .92609 m
.05501 .92609 L
s
P
p
.2 0 1 r
.02 w
.27901 .92609 m
.09779 1.05775 L
s
P
p
.2 0 1 r
.02 w
.39391 .96342 m
.46313 1.17646 L
s
P
p
.2 0 1 r
.02 w
.39391 .96342 m
.57513 1.09509 L
s
P
p
0 .4 1 r
.018 w
.35002 .90301 m
.27901 .92609 L
s
P
p
0 .4 1 r
.018 w
.35002 .90301 m
.39391 .96342 L
s
P
p
.2 0 1 r
.02 w
.60562 .31183 m
.82963 .31183 L
s
P
p
.2 0 1 r
.02 w
.60562 .31183 m
.78685 .18017 L
s
P
p
.2 0 1 r
.02 w
.49072 .2745 m
.4215 .06146 L
s
P
p
.2 0 1 r
.02 w
.49072 .2745 m
.3095 .14284 L
s
P
p
0 .4 1 r
.018 w
.53461 .33491 m
.60562 .31183 L
s
P
p
0 .4 1 r
.018 w
.53461 .33491 m
.49072 .2745 L
s
P
p
.2 0 1 r
.016 w
.44232 .61896 m
.35002 .90301 L
s
P
p
.2 0 1 r
.016 w
.44232 .61896 m
.53461 .33491 L
s
P
p
.2 0 1 r
.02 w
.43959 .97066 m
.22655 1.03988 L
s
P
p
.2 0 1 r
.02 w
.43959 .97066 m
.30793 1.15188 L
s
P
p
.2 0 1 r
.02 w
.56041 .97066 m
.69207 1.15188 L
s
P
p
.2 0 1 r
.02 w
.56041 .97066 m
.77345 1.03988 L
s
P
p
0 .4 1 r
.018 w
.5 .92677 m
.43959 .97066 L
s
P
p
0 .4 1 r
.018 w
.5 .92677 m
.56041 .97066 L
s
P
p
.2 0 1 r
.02 w
.56041 .28554 m
.77345 .21632 L
s
P
p
.2 0 1 r
.02 w
.56041 .28554 m
.69207 .10432 L
s
P
p
.2 0 1 r
.02 w
.43959 .28554 m
.30793 .10432 L
s
P
p
.2 0 1 r
.02 w
.43959 .28554 m
.22655 .21632 L
s
P
p
0 .4 1 r
.018 w
.5 .32943 m
.56041 .28554 L
s
P
p
0 .4 1 r
.018 w
.5 .32943 m
.43959 .28554 L
s
P
p
.2 0 1 r
.016 w
.5 .6281 m
.5 .92677 L
s
P
p
.2 0 1 r
.016 w
.5 .6281 m
.5 .32943 L
s
P
p
.2 0 1 r
.02 w
.60609 .96342 m
.42487 1.09509 L
s
P
p
.2 0 1 r
.02 w
.60609 .96342 m
.53687 1.17646 L
s
P
p
.2 0 1 r
.02 w
.72099 .92609 m
.90221 1.05775 L
s
P
p
.2 0 1 r
.02 w
.72099 .92609 m
.94499 .92609 L
s
P
p
0 .4 1 r
.018 w
.64998 .90301 m
.60609 .96342 L
s
P
p
0 .4 1 r
.018 w
.64998 .90301 m
.72099 .92609 L
s
P
p
.2 0 1 r
.02 w
.50928 .2745 m
.6905 .14284 L
s
P
p
.2 0 1 r
.02 w
.50928 .2745 m
.5785 .06146 L
s
P
p
.2 0 1 r
.02 w
.39438 .31183 m
.21315 .18017 L
s
P
p
.2 0 1 r
.02 w
.39438 .31183 m
.17037 .31183 L
s
P
p
0 .4 1 r
.018 w
.46539 .33491 m
.50928 .2745 L
s
P
p
0 .4 1 r
.018 w
.46539 .33491 m
.39438 .31183 L
s
P
p
.2 0 1 r
.016 w
.55768 .61896 m
.64998 .90301 L
s
P
p
.2 0 1 r
.016 w
.55768 .61896 m
.46539 .33491 L
s
P
p
1 .6 0 r
.016 w
.5 .44143 m
.44232 .61896 L
s
P
p
1 .6 0 r
.016 w
.5 .44143 m
.5 .6281 L
s
P
p
1 .6 0 r
.016 w
.5 .44143 m
.55768 .61896 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0156119 0.952381 [
[ 0 0 0 0 ]
[ 1 .92116 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .92116 L
0 .92116 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.48338 .70359 m
.3387 .80871 L
s
P
p
.2 0 1 r
.02 w
.48338 .70359 m
.42812 .87368 L
s
P
p
.2 0 1 r
.02 w
.57512 .67379 m
.7198 .77891 L
s
P
p
.2 0 1 r
.02 w
.57512 .67379 m
.75396 .67379 L
s
P
p
0 .4 1 r
.018 w
.51842 .65537 m
.48338 .70359 L
s
P
p
0 .4 1 r
.018 w
.51842 .65537 m
.57512 .67379 L
s
P
p
.2 0 1 r
.02 w
.50217 .21324 m
.67226 .15798 L
s
P
p
.2 0 1 r
.02 w
.50217 .21324 m
.60729 .06856 L
s
P
p
.2 0 1 r
.02 w
.40572 .21324 m
.3006 .06856 L
s
P
p
.2 0 1 r
.02 w
.40572 .21324 m
.23563 .15798 L
s
P
p
0 .4 1 r
.018 w
.45395 .24828 m
.50217 .21324 L
s
P
p
0 .4 1 r
.018 w
.45395 .24828 m
.40572 .21324 L
s
P
p
.2 0 1 r
.02 w
.33278 .67379 m
.15394 .67379 L
s
P
p
.2 0 1 r
.02 w
.33278 .67379 m
.18809 .77891 L
s
P
p
.2 0 1 r
.02 w
.42451 .70359 m
.47978 .87368 L
s
P
p
.2 0 1 r
.02 w
.42451 .70359 m
.5692 .80871 L
s
P
p
0 .4 1 r
.018 w
.38947 .65537 m
.33278 .67379 L
s
P
p
0 .4 1 r
.018 w
.38947 .65537 m
.42451 .70359 L
s
P
p
.2 0 1 r
.02 w
.6362 .28813 m
.80629 .3434 L
s
P
p
.2 0 1 r
.02 w
.6362 .28813 m
.80629 .23287 L
s
P
p
.2 0 1 r
.02 w
.55816 .23144 m
.55816 .0526 L
s
P
p
.2 0 1 r
.02 w
.55816 .23144 m
.45304 .08675 L
s
P
p
0 .4 1 r
.018 w
.57659 .28813 m
.6362 .28813 L
s
P
p
0 .4 1 r
.018 w
.57659 .28813 m
.55816 .23144 L
s
P
p
.2 0 1 r
.02 w
.22845 .56115 m
.08377 .45603 L
s
P
p
.2 0 1 r
.02 w
.22845 .56115 m
.04961 .56115 L
s
P
p
.2 0 1 r
.02 w
.28515 .63918 m
.22988 .80927 L
s
P
p
.2 0 1 r
.02 w
.28515 .63918 m
.34041 .80927 L
s
P
p
0 .4 1 r
.018 w
.28515 .57957 m
.22845 .56115 L
s
P
p
0 .4 1 r
.018 w
.28515 .57957 m
.28515 .63918 L
s
P
p
.2 0 1 r
.016 w
.45395 .45693 m
.51842 .65537 L
s
P
p
.2 0 1 r
.016 w
.45395 .45693 m
.45395 .24828 L
s
P
p
.2 0 1 r
.016 w
.45395 .45693 m
.38947 .65537 L
s
P
p
.2 0 1 r
.016 w
.45395 .45693 m
.57659 .28813 L
s
P
p
.2 0 1 r
.016 w
.45395 .45693 m
.28515 .57957 L
s
P
p
.2 0 1 r
.02 w
.60422 .68972 m
.4991 .8344 L
s
P
p
.2 0 1 r
.02 w
.60422 .68972 m
.60422 .86856 L
s
P
p
.2 0 1 r
.02 w
.68225 .63302 m
.85234 .68829 L
s
P
p
.2 0 1 r
.02 w
.68225 .63302 m
.85234 .57776 L
s
P
p
0 .4 1 r
.018 w
.62264 .63302 m
.60422 .68972 L
s
P
p
0 .4 1 r
.018 w
.62264 .63302 m
.68225 .63302 L
s
P
p
.2 0 1 r
.02 w
.47056 .21756 m
.61525 .11244 L
s
P
p
.2 0 1 r
.02 w
.47056 .21756 m
.52583 .04748 L
s
P
p
.2 0 1 r
.02 w
.37883 .24737 m
.23414 .14225 L
s
P
p
.2 0 1 r
.02 w
.37883 .24737 m
.19999 .24737 L
s
P
p
0 .4 1 r
.018 w
.43552 .26579 m
.47056 .21756 L
s
P
p
0 .4 1 r
.018 w
.43552 .26579 m
.37883 .24737 L
s
P
p
.2 0 1 r
.02 w
.45177 .70791 m
.28168 .76318 L
s
P
p
.2 0 1 r
.02 w
.45177 .70791 m
.34665 .8526 L
s
P
p
.2 0 1 r
.02 w
.54823 .70791 m
.65335 .8526 L
s
P
p
.2 0 1 r
.02 w
.54823 .70791 m
.71832 .76318 L
s
P
p
0 .4 1 r
.018 w
.5 .67287 m
.45177 .70791 L
s
P
p
0 .4 1 r
.018 w
.5 .67287 m
.54823 .70791 L
s
P
p
.2 0 1 r
.02 w
.62117 .24737 m
.80001 .24737 L
s
P
p
.2 0 1 r
.02 w
.62117 .24737 m
.76586 .14225 L
s
P
p
.2 0 1 r
.02 w
.52944 .21756 m
.47417 .04748 L
s
P
p
.2 0 1 r
.02 w
.52944 .21756 m
.38475 .11244 L
s
P
p
0 .4 1 r
.018 w
.56448 .26579 m
.62117 .24737 L
s
P
p
0 .4 1 r
.018 w
.56448 .26579 m
.52944 .21756 L
s
P
p
.2 0 1 r
.02 w
.31775 .63302 m
.14766 .57776 L
s
P
p
.2 0 1 r
.02 w
.31775 .63302 m
.14766 .68829 L
s
P
p
.2 0 1 r
.02 w
.39578 .68972 m
.39578 .86856 L
s
P
p
.2 0 1 r
.02 w
.39578 .68972 m
.5009 .8344 L
s
P
p
0 .4 1 r
.018 w
.37736 .63302 m
.31775 .63302 L
s
P
p
0 .4 1 r
.018 w
.37736 .63302 m
.39578 .68972 L
s
P
p
.2 0 1 r
.016 w
.5 .46423 m
.62264 .63302 L
s
P
p
.2 0 1 r
.016 w
.5 .46423 m
.43552 .26579 L
s
P
p
.2 0 1 r
.016 w
.5 .46423 m
.5 .67287 L
s
P
p
.2 0 1 r
.016 w
.5 .46423 m
.56448 .26579 L
s
P
p
.2 0 1 r
.016 w
.5 .46423 m
.37736 .63302 L
s
P
p
.2 0 1 r
.02 w
.71485 .63918 m
.65959 .80927 L
s
P
p
.2 0 1 r
.02 w
.71485 .63918 m
.77012 .80927 L
s
P
p
.2 0 1 r
.02 w
.77155 .56115 m
.95039 .56115 L
s
P
p
.2 0 1 r
.02 w
.77155 .56115 m
.91623 .45603 L
s
P
p
0 .4 1 r
.018 w
.71485 .57957 m
.71485 .63918 L
s
P
p
0 .4 1 r
.018 w
.71485 .57957 m
.77155 .56115 L
s
P
p
.2 0 1 r
.02 w
.44184 .23144 m
.54696 .08675 L
s
P
p
.2 0 1 r
.02 w
.44184 .23144 m
.44184 .0526 L
s
P
p
.2 0 1 r
.02 w
.3638 .28813 m
.19371 .23287 L
s
P
p
.2 0 1 r
.02 w
.3638 .28813 m
.19371 .3434 L
s
P
p
0 .4 1 r
.018 w
.42341 .28813 m
.44184 .23144 L
s
P
p
0 .4 1 r
.018 w
.42341 .28813 m
.3638 .28813 L
s
P
p
.2 0 1 r
.02 w
.57549 .70359 m
.4308 .80871 L
s
P
p
.2 0 1 r
.02 w
.57549 .70359 m
.52022 .87368 L
s
P
p
.2 0 1 r
.02 w
.66722 .67379 m
.81191 .77891 L
s
P
p
.2 0 1 r
.02 w
.66722 .67379 m
.84606 .67379 L
s
P
p
0 .4 1 r
.018 w
.61053 .65537 m
.57549 .70359 L
s
P
p
0 .4 1 r
.018 w
.61053 .65537 m
.66722 .67379 L
s
P
p
.2 0 1 r
.02 w
.59428 .21324 m
.76437 .15798 L
s
P
p
.2 0 1 r
.02 w
.59428 .21324 m
.6994 .06856 L
s
P
p
.2 0 1 r
.02 w
.49783 .21324 m
.39271 .06856 L
s
P
p
.2 0 1 r
.02 w
.49783 .21324 m
.32774 .15798 L
s
P
p
0 .4 1 r
.018 w
.54605 .24828 m
.59428 .21324 L
s
P
p
0 .4 1 r
.018 w
.54605 .24828 m
.49783 .21324 L
s
P
p
.2 0 1 r
.02 w
.42488 .67379 m
.24604 .67379 L
s
P
p
.2 0 1 r
.02 w
.42488 .67379 m
.2802 .77891 L
s
P
p
.2 0 1 r
.02 w
.51662 .70359 m
.57188 .87368 L
s
P
p
.2 0 1 r
.02 w
.51662 .70359 m
.6613 .80871 L
s
P
p
0 .4 1 r
.018 w
.48158 .65537 m
.42488 .67379 L
s
P
p
0 .4 1 r
.018 w
.48158 .65537 m
.51662 .70359 L
s
P
p
.2 0 1 r
.016 w
.54605 .45693 m
.71485 .57957 L
s
P
p
.2 0 1 r
.016 w
.54605 .45693 m
.42341 .28813 L
s
P
p
.2 0 1 r
.016 w
.54605 .45693 m
.61053 .65537 L
s
P
p
.2 0 1 r
.016 w
.54605 .45693 m
.54605 .24828 L
s
P
p
.2 0 1 r
.016 w
.54605 .45693 m
.48158 .65537 L
s
P
p
1 .6 0 r
.016 w
.5 .31519 m
.45395 .45693 L
s
P
p
1 .6 0 r
.016 w
.5 .31519 m
.5 .46423 L
s
P
p
1 .6 0 r
.016 w
.5 .31519 m
.54605 .45693 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.018 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.018 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.018 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.018 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.018 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.018 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.018 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.018 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.018 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.018 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.018 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.018 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.018 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.018 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.018 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
0 .4 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
0 .4 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
0 .4 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
0 .4 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
0 .4 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
0 .4 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
0 .4 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
0 .4 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
0 .4 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
0 .4 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
0 .4 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
0 .4 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
0 .4 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
0 .4 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
0 .4 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00943193 0.981136 0.0245284 0.981136 [
[ 0 0 0 0 ]
[ 1 1.03019 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.03019 L
0 1.03019 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.54531 .79038 m
.54531 .96631 L
s
P
p
.2 0 1 r
.02 w
.54531 .79038 m
.64872 .93271 L
s
P
p
0 .4 1 r
.018 w
.52718 .73461 m
.54531 .79038 L
s
P
p
.2 0 1 r
.02 w
.45469 .21829 m
.50906 .05096 L
s
P
p
.2 0 1 r
.02 w
.45469 .21829 m
.40033 .05096 L
s
P
p
0 .4 1 r
.018 w
.45469 .27693 m
.45469 .21829 L
s
P
p
.2 0 1 r
.02 w
.36408 .79038 m
.26067 .93271 L
s
P
p
.2 0 1 r
.02 w
.36408 .79038 m
.36408 .96631 L
s
P
p
0 .4 1 r
.018 w
.38221 .73461 m
.36408 .79038 L
s
P
p
.2 0 1 r
.02 w
.62705 .27429 m
.76938 .17088 L
s
P
p
.2 0 1 r
.02 w
.62705 .27429 m
.68141 .10696 L
s
P
p
0 .4 1 r
.018 w
.59258 .32173 m
.62705 .27429 L
s
P
p
.2 0 1 r
.02 w
.21747 .68386 m
.05015 .73823 L
s
P
p
.2 0 1 r
.02 w
.21747 .68386 m
.11406 .82619 L
s
P
p
0 .4 1 r
.018 w
.26492 .64939 m
.21747 .68386 L
s
P
p
.2 0 1 r
.016 w
.45469 .51151 m
.52718 .73461 L
s
P
p
.2 0 1 r
.016 w
.45469 .51151 m
.45469 .27693 L
s
P
p
.2 0 1 r
.016 w
.45469 .51151 m
.38221 .73461 L
s
P
p
.2 0 1 r
.016 w
.45469 .51151 m
.59258 .32173 L
s
P
p
.2 0 1 r
.016 w
.45469 .51151 m
.26492 .64939 L
s
P
p
.2 0 1 r
.02 w
.67235 .75591 m
.72672 .92323 L
s
P
p
.2 0 1 r
.02 w
.67235 .75591 m
.81469 .85932 L
s
P
p
0 .4 1 r
.018 w
.63788 .70846 m
.67235 .75591 L
s
P
p
.2 0 1 r
.02 w
.40939 .23981 m
.40939 .06388 L
s
P
p
.2 0 1 r
.02 w
.40939 .23981 m
.30598 .09748 L
s
P
p
0 .4 1 r
.018 w
.42751 .29559 m
.40939 .23981 L
s
P
p
.2 0 1 r
.02 w
.5 .81191 m
.44563 .97923 L
s
P
p
.2 0 1 r
.02 w
.5 .81191 m
.55437 .97923 L
s
P
p
0 .4 1 r
.018 w
.5 .75326 m
.5 .81191 L
s
P
p
.2 0 1 r
.02 w
.59061 .23981 m
.69402 .09748 L
s
P
p
.2 0 1 r
.02 w
.59061 .23981 m
.59061 .06388 L
s
P
p
0 .4 1 r
.018 w
.57249 .29559 m
.59061 .23981 L
s
P
p
.2 0 1 r
.02 w
.32765 .75591 m
.18531 .85932 L
s
P
p
.2 0 1 r
.02 w
.32765 .75591 m
.27328 .92323 L
s
P
p
0 .4 1 r
.018 w
.36212 .70846 m
.32765 .75591 L
s
P
p
.2 0 1 r
.016 w
.5 .51868 m
.63788 .70846 L
s
P
p
.2 0 1 r
.016 w
.5 .51868 m
.42751 .29559 L
s
P
p
.2 0 1 r
.016 w
.5 .51868 m
.5 .75326 L
s
P
p
.2 0 1 r
.016 w
.5 .51868 m
.57249 .29559 L
s
P
p
.2 0 1 r
.016 w
.5 .51868 m
.36212 .70846 L
s
P
p
.2 0 1 r
.02 w
.78253 .68386 m
.88594 .82619 L
s
P
p
.2 0 1 r
.02 w
.78253 .68386 m
.94985 .73823 L
s
P
p
0 .4 1 r
.018 w
.73508 .64939 m
.78253 .68386 L
s
P
p
.2 0 1 r
.02 w
.37295 .27429 m
.31859 .10696 L
s
P
p
.2 0 1 r
.02 w
.37295 .27429 m
.23062 .17088 L
s
P
p
0 .4 1 r
.018 w
.40742 .32173 m
.37295 .27429 L
s
P
p
.2 0 1 r
.02 w
.63592 .79038 m
.63592 .96631 L
s
P
p
.2 0 1 r
.02 w
.63592 .79038 m
.73933 .93271 L
s
P
p
0 .4 1 r
.018 w
.61779 .73461 m
.63592 .79038 L
s
P
p
.2 0 1 r
.02 w
.54531 .21829 m
.59967 .05096 L
s
P
p
.2 0 1 r
.02 w
.54531 .21829 m
.49094 .05096 L
s
P
p
0 .4 1 r
.018 w
.54531 .27693 m
.54531 .21829 L
s
P
p
.2 0 1 r
.02 w
.45469 .79038 m
.35128 .93271 L
s
P
p
.2 0 1 r
.02 w
.45469 .79038 m
.45469 .96631 L
s
P
p
0 .4 1 r
.018 w
.47282 .73461 m
.45469 .79038 L
s
P
p
.2 0 1 r
.016 w
.54531 .51151 m
.73508 .64939 L
s
P
p
.2 0 1 r
.016 w
.54531 .51151 m
.40742 .32173 L
s
P
p
.2 0 1 r
.016 w
.54531 .51151 m
.61779 .73461 L
s
P
p
.2 0 1 r
.016 w
.54531 .51151 m
.54531 .27693 L
s
P
p
.2 0 1 r
.016 w
.54531 .51151 m
.47282 .73461 L
s
P
p
1 .6 0 r
.016 w
.5 .37207 m
.45469 .51151 L
s
P
p
1 .6 0 r
.016 w
.5 .37207 m
.5 .51868 L
s
P
p
1 .6 0 r
.016 w
.5 .37207 m
.54531 .51151 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0021372 0.952381 [
[ 0 0 0 0 ]
[ 1 .95666 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95666 L
0 .95666 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.50054 .74064 m
.38046 .86072 L
s
P
p
.2 0 1 r
.02 w
.50054 .74064 m
.47397 .90837 L
s
P
p
.2 0 1 r
.02 w
.57667 .7159 m
.69675 .83598 L
s
P
p
.2 0 1 r
.02 w
.57667 .7159 m
.7444 .74247 L
s
P
p
0 .4 1 r
.018 w
.52624 .69021 m
.50054 .74064 L
s
P
p
0 .4 1 r
.018 w
.52624 .69021 m
.57667 .7159 L
s
P
p
.2 0 1 r
.02 w
.4963 .20841 m
.6476 .13132 L
s
P
p
.2 0 1 r
.02 w
.4963 .20841 m
.57339 .05711 L
s
P
p
.2 0 1 r
.02 w
.41624 .20841 m
.33915 .05711 L
s
P
p
.2 0 1 r
.02 w
.41624 .20841 m
.26493 .13132 L
s
P
p
0 .4 1 r
.018 w
.45627 .24844 m
.4963 .20841 L
s
P
p
0 .4 1 r
.018 w
.45627 .24844 m
.41624 .20841 L
s
P
p
.2 0 1 r
.02 w
.33586 .7159 m
.16814 .74247 L
s
P
p
.2 0 1 r
.02 w
.33586 .7159 m
.21579 .83598 L
s
P
p
.2 0 1 r
.02 w
.412 .74064 m
.43856 .90837 L
s
P
p
.2 0 1 r
.02 w
.412 .74064 m
.53208 .86072 L
s
P
p
0 .4 1 r
.018 w
.3863 .69021 m
.33586 .7159 L
s
P
p
0 .4 1 r
.018 w
.3863 .69021 m
.412 .74064 L
s
P
p
.2 0 1 r
.02 w
.64527 .28283 m
.81299 .30939 L
s
P
p
.2 0 1 r
.02 w
.64527 .28283 m
.79658 .20573 L
s
P
p
.2 0 1 r
.02 w
.5805 .23577 m
.60707 .06805 L
s
P
p
.2 0 1 r
.02 w
.5805 .23577 m
.50341 .08447 L
s
P
p
0 .4 1 r
.018 w
.58936 .29168 m
.64527 .28283 L
s
P
p
0 .4 1 r
.018 w
.58936 .29168 m
.5805 .23577 L
s
P
p
.2 0 1 r
.02 w
.21718 .5991 m
.06587 .522 L
s
P
p
.2 0 1 r
.02 w
.21718 .5991 m
.04945 .62566 L
s
P
p
.2 0 1 r
.02 w
.26423 .66386 m
.18714 .81517 L
s
P
p
.2 0 1 r
.02 w
.26423 .66386 m
.2908 .83159 L
s
P
p
0 .4 1 r
.018 w
.27309 .60795 m
.21718 .5991 L
s
P
p
0 .4 1 r
.018 w
.27309 .60795 m
.26423 .66386 L
s
P
p
.2 0 1 r
.016 w
.45627 .47486 m
.52624 .69021 L
s
P
p
.2 0 1 r
.016 w
.45627 .47486 m
.45627 .24844 L
s
P
p
.2 0 1 r
.016 w
.45627 .47486 m
.3863 .69021 L
s
P
p
.2 0 1 r
.016 w
.45627 .47486 m
.58936 .29168 L
s
P
p
.2 0 1 r
.016 w
.45627 .47486 m
.27309 .60795 L
s
P
p
.2 0 1 r
.02 w
.62423 .72088 m
.54714 .87219 L
s
P
p
.2 0 1 r
.02 w
.62423 .72088 m
.6508 .88861 L
s
P
p
.2 0 1 r
.02 w
.689 .67383 m
.84031 .75092 L
s
P
p
.2 0 1 r
.02 w
.689 .67383 m
.85672 .64726 L
s
P
p
0 .4 1 r
.018 w
.63309 .66497 m
.62423 .72088 L
s
P
p
0 .4 1 r
.018 w
.63309 .66497 m
.689 .67383 L
s
P
p
.2 0 1 r
.02 w
.45573 .21601 m
.57581 .09593 L
s
P
p
.2 0 1 r
.02 w
.45573 .21601 m
.4823 .04829 L
s
P
p
.2 0 1 r
.02 w
.37959 .24075 m
.25952 .12067 L
s
P
p
.2 0 1 r
.02 w
.37959 .24075 m
.21187 .21419 L
s
P
p
0 .4 1 r
.018 w
.43003 .26645 m
.45573 .21601 L
s
P
p
0 .4 1 r
.018 w
.43003 .26645 m
.37959 .24075 L
s
P
p
.2 0 1 r
.02 w
.45997 .74824 m
.30866 .82534 L
s
P
p
.2 0 1 r
.02 w
.45997 .74824 m
.38288 .89955 L
s
P
p
.2 0 1 r
.02 w
.54003 .74824 m
.61712 .89955 L
s
P
p
.2 0 1 r
.02 w
.54003 .74824 m
.69134 .82534 L
s
P
p
0 .4 1 r
.018 w
.5 .70821 m
.45997 .74824 L
s
P
p
0 .4 1 r
.018 w
.5 .70821 m
.54003 .74824 L
s
P
p
.2 0 1 r
.02 w
.62041 .24075 m
.78813 .21419 L
s
P
p
.2 0 1 r
.02 w
.62041 .24075 m
.74048 .12067 L
s
P
p
.2 0 1 r
.02 w
.54427 .21601 m
.5177 .04829 L
s
P
p
.2 0 1 r
.02 w
.54427 .21601 m
.42419 .09593 L
s
P
p
0 .4 1 r
.018 w
.56997 .26645 m
.62041 .24075 L
s
P
p
0 .4 1 r
.018 w
.56997 .26645 m
.54427 .21601 L
s
P
p
.2 0 1 r
.02 w
.311 .67383 m
.14328 .64726 L
s
P
p
.2 0 1 r
.02 w
.311 .67383 m
.15969 .75092 L
s
P
p
.2 0 1 r
.02 w
.37577 .72088 m
.3492 .88861 L
s
P
p
.2 0 1 r
.02 w
.37577 .72088 m
.45286 .87219 L
s
P
p
0 .4 1 r
.018 w
.36691 .66497 m
.311 .67383 L
s
P
p
0 .4 1 r
.018 w
.36691 .66497 m
.37577 .72088 L
s
P
p
.2 0 1 r
.016 w
.5 .48179 m
.63309 .66497 L
s
P
p
.2 0 1 r
.016 w
.5 .48179 m
.43003 .26645 L
s
P
p
.2 0 1 r
.016 w
.5 .48179 m
.5 .70821 L
s
P
p
.2 0 1 r
.016 w
.5 .48179 m
.56997 .26645 L
s
P
p
.2 0 1 r
.016 w
.5 .48179 m
.36691 .66497 L
s
P
p
.2 0 1 r
.02 w
.73577 .66386 m
.7092 .83159 L
s
P
p
.2 0 1 r
.02 w
.73577 .66386 m
.81286 .81517 L
s
P
p
.2 0 1 r
.02 w
.78282 .5991 m
.95055 .62566 L
s
P
p
.2 0 1 r
.02 w
.78282 .5991 m
.93413 .522 L
s
P
p
0 .4 1 r
.018 w
.72691 .60795 m
.73577 .66386 L
s
P
p
0 .4 1 r
.018 w
.72691 .60795 m
.78282 .5991 L
s
P
p
.2 0 1 r
.02 w
.4195 .23577 m
.49659 .08447 L
s
P
p
.2 0 1 r
.02 w
.4195 .23577 m
.39293 .06805 L
s
P
p
.2 0 1 r
.02 w
.35473 .28283 m
.20342 .20573 L
s
P
p
.2 0 1 r
.02 w
.35473 .28283 m
.18701 .30939 L
s
P
p
0 .4 1 r
.018 w
.41064 .29168 m
.4195 .23577 L
s
P
p
0 .4 1 r
.018 w
.41064 .29168 m
.35473 .28283 L
s
P
p
.2 0 1 r
.02 w
.588 .74064 m
.46792 .86072 L
s
P
p
.2 0 1 r
.02 w
.588 .74064 m
.56144 .90837 L
s
P
p
.2 0 1 r
.02 w
.66414 .7159 m
.78421 .83598 L
s
P
p
.2 0 1 r
.02 w
.66414 .7159 m
.83186 .74247 L
s
P
p
0 .4 1 r
.018 w
.6137 .69021 m
.588 .74064 L
s
P
p
0 .4 1 r
.018 w
.6137 .69021 m
.66414 .7159 L
s
P
p
.2 0 1 r
.02 w
.58376 .20841 m
.73507 .13132 L
s
P
p
.2 0 1 r
.02 w
.58376 .20841 m
.66085 .05711 L
s
P
p
.2 0 1 r
.02 w
.5037 .20841 m
.42661 .05711 L
s
P
p
.2 0 1 r
.02 w
.5037 .20841 m
.3524 .13132 L
s
P
p
0 .4 1 r
.018 w
.54373 .24844 m
.58376 .20841 L
s
P
p
0 .4 1 r
.018 w
.54373 .24844 m
.5037 .20841 L
s
P
p
.2 0 1 r
.02 w
.42333 .7159 m
.2556 .74247 L
s
P
p
.2 0 1 r
.02 w
.42333 .7159 m
.30325 .83598 L
s
P
p
.2 0 1 r
.02 w
.49946 .74064 m
.52603 .90837 L
s
P
p
.2 0 1 r
.02 w
.49946 .74064 m
.61954 .86072 L
s
P
p
0 .4 1 r
.018 w
.47376 .69021 m
.42333 .7159 L
s
P
p
0 .4 1 r
.018 w
.47376 .69021 m
.49946 .74064 L
s
P
p
.2 0 1 r
.016 w
.54373 .47486 m
.72691 .60795 L
s
P
p
.2 0 1 r
.016 w
.54373 .47486 m
.41064 .29168 L
s
P
p
.2 0 1 r
.016 w
.54373 .47486 m
.6137 .69021 L
s
P
p
.2 0 1 r
.016 w
.54373 .47486 m
.54373 .24844 L
s
P
p
.2 0 1 r
.016 w
.54373 .47486 m
.47376 .69021 L
s
P
p
1 .6 0 r
.016 w
.5 .34028 m
.45627 .47486 L
s
P
p
1 .6 0 r
.016 w
.5 .34028 m
.5 .48179 L
s
P
p
1 .6 0 r
.016 w
.5 .34028 m
.54373 .47486 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0114991 0.952381 [
[ 0 0 0 0 ]
[ 1 .92938 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .92938 L
0 .92938 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.47766 .72953 m
.34797 .82375 L
s
P
p
.2 0 1 r
.02 w
.47766 .72953 m
.42812 .88199 L
s
P
p
.2 0 1 r
.02 w
.60099 .68946 m
.73068 .78368 L
s
P
p
.2 0 1 r
.02 w
.60099 .68946 m
.76129 .68946 L
s
P
p
0 .4 1 r
.018 w
.52477 .66469 m
.47766 .72953 L
s
P
p
0 .4 1 r
.018 w
.52477 .66469 m
.60099 .68946 L
s
P
p
.2 0 1 r
.02 w
.52356 .20058 m
.67602 .15105 L
s
P
p
.2 0 1 r
.02 w
.52356 .20058 m
.61778 .0709 L
s
P
p
.2 0 1 r
.02 w
.39388 .20058 m
.29966 .0709 L
s
P
p
.2 0 1 r
.02 w
.39388 .20058 m
.24143 .15105 L
s
P
p
0 .4 1 r
.018 w
.45872 .24769 m
.52356 .20058 L
s
P
p
0 .4 1 r
.018 w
.45872 .24769 m
.39388 .20058 L
s
P
p
.2 0 1 r
.02 w
.31645 .68946 m
.15615 .68946 L
s
P
p
.2 0 1 r
.02 w
.31645 .68946 m
.18676 .78368 L
s
P
p
.2 0 1 r
.02 w
.43979 .72953 m
.48932 .88199 L
s
P
p
.2 0 1 r
.02 w
.43979 .72953 m
.56947 .82375 L
s
P
p
0 .4 1 r
.018 w
.39267 .66469 m
.31645 .68946 L
s
P
p
0 .4 1 r
.018 w
.39267 .66469 m
.43979 .72953 L
s
P
p
.2 0 1 r
.02 w
.6645 .28851 m
.81695 .33805 L
s
P
p
.2 0 1 r
.02 w
.6645 .28851 m
.81695 .23898 L
s
P
p
.2 0 1 r
.02 w
.55958 .21228 m
.55958 .05199 L
s
P
p
.2 0 1 r
.02 w
.55958 .21228 m
.46536 .0826 L
s
P
p
0 .4 1 r
.018 w
.58435 .28851 m
.6645 .28851 L
s
P
p
0 .4 1 r
.018 w
.58435 .28851 m
.55958 .21228 L
s
P
p
.2 0 1 r
.02 w
.20958 .56228 m
.0799 .46806 L
s
P
p
.2 0 1 r
.02 w
.20958 .56228 m
.04929 .56228 L
s
P
p
.2 0 1 r
.02 w
.28581 .6672 m
.23627 .81965 L
s
P
p
.2 0 1 r
.02 w
.28581 .6672 m
.33534 .81965 L
s
P
p
0 .4 1 r
.018 w
.28581 .58705 m
.20958 .56228 L
s
P
p
0 .4 1 r
.018 w
.28581 .58705 m
.28581 .6672 L
s
P
p
.2 0 1 r
.016 w
.45872 .46142 m
.52477 .66469 L
s
P
p
.2 0 1 r
.016 w
.45872 .46142 m
.45872 .24769 L
s
P
p
.2 0 1 r
.016 w
.45872 .46142 m
.39267 .66469 L
s
P
p
.2 0 1 r
.016 w
.45872 .46142 m
.58435 .28851 L
s
P
p
.2 0 1 r
.016 w
.45872 .46142 m
.28581 .58705 L
s
P
p
.2 0 1 r
.02 w
.60086 .7171 m
.50664 .84678 L
s
P
p
.2 0 1 r
.02 w
.60086 .7171 m
.60086 .8774 L
s
P
p
.2 0 1 r
.02 w
.70578 .64087 m
.85823 .69041 L
s
P
p
.2 0 1 r
.02 w
.70578 .64087 m
.85823 .59134 L
s
P
p
0 .4 1 r
.018 w
.62563 .64087 m
.60086 .7171 L
s
P
p
0 .4 1 r
.018 w
.62563 .64087 m
.70578 .64087 L
s
P
p
.2 0 1 r
.02 w
.48106 .19985 m
.61075 .10563 L
s
P
p
.2 0 1 r
.02 w
.48106 .19985 m
.5306 .0474 L
s
P
p
.2 0 1 r
.02 w
.35773 .23992 m
.22804 .1457 L
s
P
p
.2 0 1 r
.02 w
.35773 .23992 m
.19743 .23992 L
s
P
p
0 .4 1 r
.018 w
.43395 .26469 m
.48106 .19985 L
s
P
p
0 .4 1 r
.018 w
.43395 .26469 m
.35773 .23992 L
s
P
p
.2 0 1 r
.02 w
.43516 .7288 m
.28271 .77834 L
s
P
p
.2 0 1 r
.02 w
.43516 .7288 m
.34094 .85848 L
s
P
p
.2 0 1 r
.02 w
.56484 .7288 m
.65906 .85848 L
s
P
p
.2 0 1 r
.02 w
.56484 .7288 m
.71729 .77834 L
s
P
p
0 .4 1 r
.018 w
.5 .68169 m
.43516 .7288 L
s
P
p
0 .4 1 r
.018 w
.5 .68169 m
.56484 .7288 L
s
P
p
.2 0 1 r
.02 w
.64227 .23992 m
.80257 .23992 L
s
P
p
.2 0 1 r
.02 w
.64227 .23992 m
.77196 .1457 L
s
P
p
.2 0 1 r
.02 w
.51894 .19985 m
.4694 .0474 L
s
P
p
.2 0 1 r
.02 w
.51894 .19985 m
.38925 .10563 L
s
P
p
0 .4 1 r
.018 w
.56605 .26469 m
.64227 .23992 L
s
P
p
0 .4 1 r
.018 w
.56605 .26469 m
.51894 .19985 L
s
P
p
.2 0 1 r
.02 w
.29422 .64087 m
.14177 .59134 L
s
P
p
.2 0 1 r
.02 w
.29422 .64087 m
.14177 .69041 L
s
P
p
.2 0 1 r
.02 w
.39914 .7171 m
.39914 .8774 L
s
P
p
.2 0 1 r
.02 w
.39914 .7171 m
.49336 .84678 L
s
P
p
0 .4 1 r
.018 w
.37437 .64087 m
.29422 .64087 L
s
P
p
0 .4 1 r
.018 w
.37437 .64087 m
.39914 .7171 L
s
P
p
.2 0 1 r
.016 w
.5 .46796 m
.62563 .64087 L
s
P
p
.2 0 1 r
.016 w
.5 .46796 m
.43395 .26469 L
s
P
p
.2 0 1 r
.016 w
.5 .46796 m
.5 .68169 L
s
P
p
.2 0 1 r
.016 w
.5 .46796 m
.56605 .26469 L
s
P
p
.2 0 1 r
.016 w
.5 .46796 m
.37437 .64087 L
s
P
p
.2 0 1 r
.02 w
.71419 .6672 m
.66466 .81965 L
s
P
p
.2 0 1 r
.02 w
.71419 .6672 m
.76373 .81965 L
s
P
p
.2 0 1 r
.02 w
.79042 .56228 m
.95071 .56228 L
s
P
p
.2 0 1 r
.02 w
.79042 .56228 m
.9201 .46806 L
s
P
p
0 .4 1 r
.018 w
.71419 .58705 m
.71419 .6672 L
s
P
p
0 .4 1 r
.018 w
.71419 .58705 m
.79042 .56228 L
s
P
p
.2 0 1 r
.02 w
.44042 .21228 m
.53464 .0826 L
s
P
p
.2 0 1 r
.02 w
.44042 .21228 m
.44042 .05199 L
s
P
p
.2 0 1 r
.02 w
.3355 .28851 m
.18305 .23898 L
s
P
p
.2 0 1 r
.02 w
.3355 .28851 m
.18305 .33805 L
s
P
p
0 .4 1 r
.018 w
.41565 .28851 m
.44042 .21228 L
s
P
p
0 .4 1 r
.018 w
.41565 .28851 m
.3355 .28851 L
s
P
p
.2 0 1 r
.02 w
.56021 .72953 m
.43053 .82375 L
s
P
p
.2 0 1 r
.02 w
.56021 .72953 m
.51068 .88199 L
s
P
p
.2 0 1 r
.02 w
.68355 .68946 m
.81324 .78368 L
s
P
p
.2 0 1 r
.02 w
.68355 .68946 m
.84385 .68946 L
s
P
p
0 .4 1 r
.018 w
.60733 .66469 m
.56021 .72953 L
s
P
p
0 .4 1 r
.018 w
.60733 .66469 m
.68355 .68946 L
s
P
p
.2 0 1 r
.02 w
.60612 .20058 m
.75857 .15105 L
s
P
p
.2 0 1 r
.02 w
.60612 .20058 m
.70034 .0709 L
s
P
p
.2 0 1 r
.02 w
.47644 .20058 m
.38222 .0709 L
s
P
p
.2 0 1 r
.02 w
.47644 .20058 m
.32398 .15105 L
s
P
p
0 .4 1 r
.018 w
.54128 .24769 m
.60612 .20058 L
s
P
p
0 .4 1 r
.018 w
.54128 .24769 m
.47644 .20058 L
s
P
p
.2 0 1 r
.02 w
.39901 .68946 m
.23871 .68946 L
s
P
p
.2 0 1 r
.02 w
.39901 .68946 m
.26932 .78368 L
s
P
p
.2 0 1 r
.02 w
.52234 .72953 m
.57188 .88199 L
s
P
p
.2 0 1 r
.02 w
.52234 .72953 m
.65203 .82375 L
s
P
p
0 .4 1 r
.018 w
.47523 .66469 m
.39901 .68946 L
s
P
p
0 .4 1 r
.018 w
.47523 .66469 m
.52234 .72953 L
s
P
p
.2 0 1 r
.016 w
.54128 .46142 m
.71419 .58705 L
s
P
p
.2 0 1 r
.016 w
.54128 .46142 m
.41565 .28851 L
s
P
p
.2 0 1 r
.016 w
.54128 .46142 m
.60733 .66469 L
s
P
p
.2 0 1 r
.016 w
.54128 .46142 m
.54128 .24769 L
s
P
p
.2 0 1 r
.016 w
.54128 .46142 m
.47523 .66469 L
s
P
p
1 .6 0 r
.016 w
.5 .33438 m
.45872 .46142 L
s
P
p
1 .6 0 r
.016 w
.5 .33438 m
.5 .46796 L
s
P
p
1 .6 0 r
.016 w
.5 .33438 m
.54128 .46142 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00602182 0.952381 [
[ 0 0 0 0 ]
[ 1 .94034 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .94034 L
0 .94034 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.54194 .80884 m
.48876 .88204 L
s
P
p
0 .4 1 r
.018 w
.54194 .80884 m
.62799 .8368 L
s
P
p
0 .4 1 r
.018 w
.4301 .10271 m
.5033 .04953 L
s
P
p
0 .4 1 r
.018 w
.4301 .10271 m
.3569 .04953 L
s
P
p
0 .4 1 r
.018 w
.31826 .80884 m
.23221 .8368 L
s
P
p
0 .4 1 r
.018 w
.31826 .80884 m
.37144 .88204 L
s
P
p
0 .4 1 r
.018 w
.64283 .17183 m
.73331 .17183 L
s
P
p
0 .4 1 r
.018 w
.64283 .17183 m
.61487 .08578 L
s
P
p
0 .4 1 r
.018 w
.1373 .67737 m
.05125 .64941 L
s
P
p
0 .4 1 r
.018 w
.1373 .67737 m
.1373 .76785 L
s
P
p
.2 0 1 r
.016 w
.4301 .46463 m
.54194 .80884 L
s
P
p
.2 0 1 r
.016 w
.4301 .46463 m
.4301 .10271 L
s
P
p
.2 0 1 r
.016 w
.4301 .46463 m
.31826 .80884 L
s
P
p
.2 0 1 r
.016 w
.4301 .46463 m
.64283 .17183 L
s
P
p
.2 0 1 r
.016 w
.4301 .46463 m
.1373 .67737 L
s
P
p
0 .4 1 r
.018 w
.71273 .7685 m
.68477 .85456 L
s
P
p
0 .4 1 r
.018 w
.71273 .7685 m
.80321 .7685 L
s
P
p
0 .4 1 r
.018 w
.38816 .1315 m
.44134 .0583 L
s
P
p
0 .4 1 r
.018 w
.38816 .1315 m
.30211 .10354 L
s
P
p
0 .4 1 r
.018 w
.5 .83763 m
.4268 .89081 L
s
P
p
0 .4 1 r
.018 w
.5 .83763 m
.5732 .89081 L
s
P
p
0 .4 1 r
.018 w
.61184 .1315 m
.69789 .10354 L
s
P
p
0 .4 1 r
.018 w
.61184 .1315 m
.55866 .0583 L
s
P
p
0 .4 1 r
.018 w
.28727 .7685 m
.19679 .7685 L
s
P
p
0 .4 1 r
.018 w
.28727 .7685 m
.31523 .85456 L
s
P
p
.2 0 1 r
.016 w
.5 .4757 m
.71273 .7685 L
s
P
p
.2 0 1 r
.016 w
.5 .4757 m
.38816 .1315 L
s
P
p
.2 0 1 r
.016 w
.5 .4757 m
.5 .83763 L
s
P
p
.2 0 1 r
.016 w
.5 .4757 m
.61184 .1315 L
s
P
p
.2 0 1 r
.016 w
.5 .4757 m
.28727 .7685 L
s
P
p
0 .4 1 r
.018 w
.8627 .67737 m
.8627 .76785 L
s
P
p
0 .4 1 r
.018 w
.8627 .67737 m
.94875 .64941 L
s
P
p
0 .4 1 r
.018 w
.35717 .17183 m
.38513 .08578 L
s
P
p
0 .4 1 r
.018 w
.35717 .17183 m
.26669 .17183 L
s
P
p
0 .4 1 r
.018 w
.68174 .80884 m
.62856 .88204 L
s
P
p
0 .4 1 r
.018 w
.68174 .80884 m
.76779 .8368 L
s
P
p
0 .4 1 r
.018 w
.5699 .10271 m
.6431 .04953 L
s
P
p
0 .4 1 r
.018 w
.5699 .10271 m
.4967 .04953 L
s
P
p
0 .4 1 r
.018 w
.45806 .80884 m
.37201 .8368 L
s
P
p
0 .4 1 r
.018 w
.45806 .80884 m
.51124 .88204 L
s
P
p
.2 0 1 r
.016 w
.5699 .46463 m
.8627 .67737 L
s
P
p
.2 0 1 r
.016 w
.5699 .46463 m
.35717 .17183 L
s
P
p
.2 0 1 r
.016 w
.5699 .46463 m
.68174 .80884 L
s
P
p
.2 0 1 r
.016 w
.5699 .46463 m
.5699 .10271 L
s
P
p
.2 0 1 r
.016 w
.5699 .46463 m
.45806 .80884 L
s
P
p
1 .6 0 r
.016 w
.5 .2495 m
.4301 .46463 L
s
P
p
1 .6 0 r
.016 w
.5 .2495 m
.5 .4757 L
s
P
p
1 .6 0 r
.016 w
.5 .2495 m
.5699 .46463 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00816013 0.98368 0.024592 0.98368 [
[ 0 0 0 0 ]
[ 1 1.03286 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.03286 L
0 1.03286 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.56088 .79577 m
.42787 .92878 L
s
P
p
.2 0 1 r
.02 w
.56088 .79577 m
.53145 .98156 L
s
P
p
.2 0 1 r
.02 w
.65127 .74971 m
.81888 .83511 L
s
P
p
.2 0 1 r
.02 w
.65127 .74971 m
.83706 .72029 L
s
P
p
0 .4 1 r
.018 w
.58934 .7399 m
.56088 .79577 L
s
P
p
0 .4 1 r
.018 w
.58934 .7399 m
.65127 .74971 L
s
P
p
.2 0 1 r
.02 w
.48058 .22437 m
.64818 .13898 L
s
P
p
.2 0 1 r
.02 w
.48058 .22437 m
.56598 .05677 L
s
P
p
.2 0 1 r
.02 w
.38038 .24025 m
.24736 .10723 L
s
P
p
.2 0 1 r
.02 w
.38038 .24025 m
.19458 .21082 L
s
P
p
0 .4 1 r
.018 w
.43624 .26871 m
.48058 .22437 L
s
P
p
0 .4 1 r
.018 w
.43624 .26871 m
.38038 .24025 L
s
P
p
.2 0 1 r
.02 w
.38038 .79262 m
.19458 .82204 L
s
P
p
.2 0 1 r
.02 w
.38038 .79262 m
.24736 .92563 L
s
P
p
.2 0 1 r
.02 w
.48058 .80849 m
.56598 .97609 L
s
P
p
.2 0 1 r
.02 w
.48058 .80849 m
.64818 .89389 L
s
P
p
0 .4 1 r
.018 w
.43624 .76415 m
.38038 .79262 L
s
P
p
0 .4 1 r
.018 w
.43624 .76415 m
.48058 .80849 L
s
P
p
.2 0 1 r
.02 w
.65127 .28315 m
.83706 .31258 L
s
P
p
.2 0 1 r
.02 w
.65127 .28315 m
.81888 .19775 L
s
P
p
.2 0 1 r
.02 w
.56088 .23709 m
.53145 .0513 L
s
P
p
.2 0 1 r
.02 w
.56088 .23709 m
.42787 .10408 L
s
P
p
0 .4 1 r
.018 w
.58934 .29296 m
.65127 .28315 L
s
P
p
0 .4 1 r
.018 w
.58934 .29296 m
.56088 .23709 L
s
P
p
.2 0 1 r
.02 w
.2362 .68397 m
.0686 .59857 L
s
P
p
.2 0 1 r
.02 w
.2362 .68397 m
.05041 .7134 L
s
P
p
.2 0 1 r
.02 w
.30794 .75571 m
.27851 .9415 L
s
P
p
.2 0 1 r
.02 w
.30794 .75571 m
.39334 .92331 L
s
P
p
0 .4 1 r
.018 w
.29813 .69378 m
.2362 .68397 L
s
P
p
0 .4 1 r
.018 w
.29813 .69378 m
.30794 .75571 L
s
P
p
.2 0 1 r
.016 w
.47548 .51643 m
.58934 .7399 L
s
P
p
.2 0 1 r
.016 w
.47548 .51643 m
.43624 .26871 L
s
P
p
.2 0 1 r
.016 w
.47548 .51643 m
.43624 .76415 L
s
P
p
.2 0 1 r
.016 w
.47548 .51643 m
.58934 .29296 L
s
P
p
.2 0 1 r
.016 w
.47548 .51643 m
.29813 .69378 L
s
P
p
.2 0 1 r
.02 w
.69206 .75571 m
.60666 .92331 L
s
P
p
.2 0 1 r
.02 w
.69206 .75571 m
.72149 .9415 L
s
P
p
.2 0 1 r
.02 w
.7638 .68397 m
.94959 .7134 L
s
P
p
.2 0 1 r
.02 w
.7638 .68397 m
.9314 .59857 L
s
P
p
0 .4 1 r
.018 w
.70187 .69378 m
.69206 .75571 L
s
P
p
0 .4 1 r
.018 w
.70187 .69378 m
.7638 .68397 L
s
P
p
.2 0 1 r
.02 w
.43912 .23709 m
.57213 .10408 L
s
P
p
.2 0 1 r
.02 w
.43912 .23709 m
.46855 .0513 L
s
P
p
.2 0 1 r
.02 w
.34873 .28315 m
.18112 .19775 L
s
P
p
.2 0 1 r
.02 w
.34873 .28315 m
.16294 .31258 L
s
P
p
0 .4 1 r
.018 w
.41066 .29296 m
.43912 .23709 L
s
P
p
0 .4 1 r
.018 w
.41066 .29296 m
.34873 .28315 L
s
P
p
.2 0 1 r
.02 w
.51942 .80849 m
.35182 .89389 L
s
P
p
.2 0 1 r
.02 w
.51942 .80849 m
.43402 .97609 L
s
P
p
.2 0 1 r
.02 w
.61962 .79262 m
.75264 .92563 L
s
P
p
.2 0 1 r
.02 w
.61962 .79262 m
.80542 .82204 L
s
P
p
0 .4 1 r
.018 w
.56376 .76415 m
.51942 .80849 L
s
P
p
0 .4 1 r
.018 w
.56376 .76415 m
.61962 .79262 L
s
P
p
.2 0 1 r
.02 w
.61962 .24025 m
.80542 .21082 L
s
P
p
.2 0 1 r
.02 w
.61962 .24025 m
.75264 .10723 L
s
P
p
.2 0 1 r
.02 w
.51942 .22437 m
.43402 .05677 L
s
P
p
.2 0 1 r
.02 w
.51942 .22437 m
.35182 .13898 L
s
P
p
0 .4 1 r
.018 w
.56376 .26871 m
.61962 .24025 L
s
P
p
0 .4 1 r
.018 w
.56376 .26871 m
.51942 .22437 L
s
P
p
.2 0 1 r
.02 w
.34873 .74971 m
.16294 .72029 L
s
P
p
.2 0 1 r
.02 w
.34873 .74971 m
.18112 .83511 L
s
P
p
.2 0 1 r
.02 w
.43912 .79577 m
.46855 .98156 L
s
P
p
.2 0 1 r
.02 w
.43912 .79577 m
.57213 .92878 L
s
P
p
0 .4 1 r
.018 w
.41066 .7399 m
.34873 .74971 L
s
P
p
0 .4 1 r
.018 w
.41066 .7399 m
.43912 .79577 L
s
P
p
.2 0 1 r
.016 w
.52452 .51643 m
.70187 .69378 L
s
P
p
.2 0 1 r
.016 w
.52452 .51643 m
.41066 .29296 L
s
P
p
.2 0 1 r
.016 w
.52452 .51643 m
.56376 .76415 L
s
P
p
.2 0 1 r
.016 w
.52452 .51643 m
.56376 .26871 L
s
P
p
.2 0 1 r
.016 w
.52452 .51643 m
.41066 .7399 L
s
P
p
1 .6 0 r
.016 w
.5 .36161 m
.47548 .51643 L
s
P
p
1 .6 0 r
.016 w
.5 .36161 m
.52452 .51643 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.077986 1.15597 0.0288993 1.15597 [
[ 0 0 0 0 ]
[ 1 1.21377 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.21377 L
0 1.21377 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.50697 .21933 m
.64304 .12046 L
s
P
p
.2 0 1 r
.02 w
.50697 .21933 m
.55894 .05936 L
s
P
p
.2 0 1 r
.02 w
.42069 .24736 m
.28461 .14849 L
s
P
p
.2 0 1 r
.02 w
.42069 .24736 m
.25249 .24736 L
s
P
p
0 .4 1 r
.018 w
.47401 .26469 m
.50697 .21933 L
s
P
p
0 .4 1 r
.018 w
.47401 .26469 m
.42069 .24736 L
s
P
p
.2 0 1 r
.02 w
.49795 .7352 m
.33799 .78718 L
s
P
p
.2 0 1 r
.02 w
.49795 .7352 m
.39909 .87128 L
s
P
p
.2 0 1 r
.02 w
.58867 .7352 m
.68754 .87128 L
s
P
p
.2 0 1 r
.02 w
.58867 .7352 m
.74864 .78718 L
s
P
p
0 .4 1 r
.018 w
.54331 .70225 m
.49795 .7352 L
s
P
p
0 .4 1 r
.018 w
.54331 .70225 m
.58867 .7352 L
s
P
p
.2 0 1 r
.02 w
.66594 .24736 m
.83414 .24736 L
s
P
p
.2 0 1 r
.02 w
.66594 .24736 m
.80202 .14849 L
s
P
p
.2 0 1 r
.02 w
.57966 .21933 m
.52768 .05936 L
s
P
p
.2 0 1 r
.02 w
.57966 .21933 m
.44358 .12046 L
s
P
p
0 .4 1 r
.018 w
.61262 .26469 m
.66594 .24736 L
s
P
p
0 .4 1 r
.018 w
.61262 .26469 m
.57966 .21933 L
s
P
p
.2 0 1 r
.02 w
.35543 .65941 m
.19546 .60744 L
s
P
p
.2 0 1 r
.02 w
.35543 .65941 m
.19546 .71139 L
s
P
p
.2 0 1 r
.02 w
.42882 .71274 m
.42882 .88094 L
s
P
p
.2 0 1 r
.02 w
.42882 .71274 m
.52768 .84881 L
s
P
p
0 .4 1 r
.018 w
.41149 .65941 m
.35543 .65941 L
s
P
p
0 .4 1 r
.018 w
.41149 .65941 m
.42882 .71274 L
s
P
p
.2 0 1 r
.02 w
.77807 .36348 m
.91415 .46235 L
s
P
p
.2 0 1 r
.02 w
.77807 .36348 m
.94627 .36348 L
s
P
p
.2 0 1 r
.02 w
.72475 .29009 m
.77673 .13012 L
s
P
p
.2 0 1 r
.02 w
.72475 .29009 m
.67277 .13012 L
s
P
p
0 .4 1 r
.018 w
.72475 .34616 m
.77807 .36348 L
s
P
p
0 .4 1 r
.018 w
.72475 .34616 m
.72475 .29009 L
s
P
p
.2 0 1 r
.016 w
.54331 .47798 m
.47401 .26469 L
s
P
p
.2 0 1 r
.016 w
.54331 .47798 m
.54331 .70225 L
s
P
p
.2 0 1 r
.016 w
.54331 .47798 m
.61262 .26469 L
s
P
p
.2 0 1 r
.016 w
.54331 .47798 m
.41149 .65941 L
s
P
p
.2 0 1 r
.016 w
.54331 .47798 m
.72475 .34616 L
s
P
p
.2 0 1 r
.02 w
.6145 .98621 m
.51563 1.12229 L
s
P
p
.2 0 1 r
.02 w
.6145 .98621 m
.6145 1.15441 L
s
P
p
.2 0 1 r
.02 w
.68789 .93289 m
.84786 .98487 L
s
P
p
.2 0 1 r
.02 w
.68789 .93289 m
.84786 .88091 L
s
P
p
0 .4 1 r
.018 w
.63182 .93289 m
.6145 .98621 L
s
P
p
0 .4 1 r
.018 w
.63182 .93289 m
.68789 .93289 L
s
P
p
.2 0 1 r
.02 w
.46365 .4928 m
.59973 .39394 L
s
P
p
.2 0 1 r
.02 w
.46365 .4928 m
.51563 .33283 L
s
P
p
.2 0 1 r
.02 w
.37737 .52083 m
.2413 .42197 L
s
P
p
.2 0 1 r
.02 w
.37737 .52083 m
.20917 .52083 L
s
P
p
0 .4 1 r
.018 w
.4307 .53816 m
.46365 .4928 L
s
P
p
0 .4 1 r
.018 w
.4307 .53816 m
.37737 .52083 L
s
P
p
.2 0 1 r
.02 w
.45464 1.00868 m
.29467 1.06065 L
s
P
p
.2 0 1 r
.02 w
.45464 1.00868 m
.35577 1.14475 L
s
P
p
.2 0 1 r
.02 w
.54536 1.00868 m
.64423 1.14475 L
s
P
p
.2 0 1 r
.02 w
.54536 1.00868 m
.70533 1.06065 L
s
P
p
0 .4 1 r
.018 w
.5 .97572 m
.45464 1.00868 L
s
P
p
0 .4 1 r
.018 w
.5 .97572 m
.54536 1.00868 L
s
P
p
.2 0 1 r
.02 w
.62263 .52083 m
.79083 .52083 L
s
P
p
.2 0 1 r
.02 w
.62263 .52083 m
.7587 .42197 L
s
P
p
.2 0 1 r
.02 w
.53635 .4928 m
.48437 .33283 L
s
P
p
.2 0 1 r
.02 w
.53635 .4928 m
.40027 .39394 L
s
P
p
0 .4 1 r
.018 w
.5693 .53816 m
.62263 .52083 L
s
P
p
0 .4 1 r
.018 w
.5693 .53816 m
.53635 .4928 L
s
P
p
.2 0 1 r
.02 w
.31211 .93289 m
.15214 .88091 L
s
P
p
.2 0 1 r
.02 w
.31211 .93289 m
.15214 .98487 L
s
P
p
.2 0 1 r
.02 w
.3855 .98621 m
.3855 1.15441 L
s
P
p
.2 0 1 r
.02 w
.3855 .98621 m
.48437 1.12229 L
s
P
p
0 .4 1 r
.018 w
.36818 .93289 m
.31211 .93289 L
s
P
p
0 .4 1 r
.018 w
.36818 .93289 m
.3855 .98621 L
s
P
p
.2 0 1 r
.016 w
.5 .75145 m
.63182 .93289 L
s
P
p
.2 0 1 r
.016 w
.5 .75145 m
.4307 .53816 L
s
P
p
.2 0 1 r
.016 w
.5 .75145 m
.5 .97572 L
s
P
p
.2 0 1 r
.016 w
.5 .75145 m
.5693 .53816 L
s
P
p
.2 0 1 r
.016 w
.5 .75145 m
.36818 .93289 L
s
P
p
.2 0 1 r
.02 w
.27525 .29009 m
.32723 .13012 L
s
P
p
.2 0 1 r
.02 w
.27525 .29009 m
.22327 .13012 L
s
P
p
.2 0 1 r
.02 w
.22193 .36348 m
.05373 .36348 L
s
P
p
.2 0 1 r
.02 w
.22193 .36348 m
.08585 .46235 L
s
P
p
0 .4 1 r
.018 w
.27525 .34616 m
.27525 .29009 L
s
P
p
0 .4 1 r
.018 w
.27525 .34616 m
.22193 .36348 L
s
P
p
.2 0 1 r
.02 w
.57118 .71274 m
.47232 .84881 L
s
P
p
.2 0 1 r
.02 w
.57118 .71274 m
.57118 .88094 L
s
P
p
.2 0 1 r
.02 w
.64457 .65941 m
.80454 .71139 L
s
P
p
.2 0 1 r
.02 w
.64457 .65941 m
.80454 .60744 L
s
P
p
0 .4 1 r
.018 w
.58851 .65941 m
.57118 .71274 L
s
P
p
0 .4 1 r
.018 w
.58851 .65941 m
.64457 .65941 L
s
P
p
.2 0 1 r
.02 w
.42034 .21933 m
.55642 .12046 L
s
P
p
.2 0 1 r
.02 w
.42034 .21933 m
.47232 .05936 L
s
P
p
.2 0 1 r
.02 w
.33406 .24736 m
.19798 .14849 L
s
P
p
.2 0 1 r
.02 w
.33406 .24736 m
.16586 .24736 L
s
P
p
0 .4 1 r
.018 w
.38738 .26469 m
.42034 .21933 L
s
P
p
0 .4 1 r
.018 w
.38738 .26469 m
.33406 .24736 L
s
P
p
.2 0 1 r
.02 w
.41133 .7352 m
.25136 .78718 L
s
P
p
.2 0 1 r
.02 w
.41133 .7352 m
.31246 .87128 L
s
P
p
.2 0 1 r
.02 w
.50205 .7352 m
.60091 .87128 L
s
P
p
.2 0 1 r
.02 w
.50205 .7352 m
.66201 .78718 L
s
P
p
0 .4 1 r
.018 w
.45669 .70225 m
.41133 .7352 L
s
P
p
0 .4 1 r
.018 w
.45669 .70225 m
.50205 .7352 L
s
P
p
.2 0 1 r
.02 w
.57931 .24736 m
.74751 .24736 L
s
P
p
.2 0 1 r
.02 w
.57931 .24736 m
.71539 .14849 L
s
P
p
.2 0 1 r
.02 w
.49303 .21933 m
.44106 .05936 L
s
P
p
.2 0 1 r
.02 w
.49303 .21933 m
.35696 .12046 L
s
P
p
0 .4 1 r
.018 w
.52599 .26469 m
.57931 .24736 L
s
P
p
0 .4 1 r
.018 w
.52599 .26469 m
.49303 .21933 L
s
P
p
.2 0 1 r
.016 w
.45669 .47798 m
.27525 .34616 L
s
P
p
.2 0 1 r
.016 w
.45669 .47798 m
.58851 .65941 L
s
P
p
.2 0 1 r
.016 w
.45669 .47798 m
.38738 .26469 L
s
P
p
.2 0 1 r
.016 w
.45669 .47798 m
.45669 .70225 L
s
P
p
.2 0 1 r
.016 w
.45669 .47798 m
.52599 .26469 L
s
P
p
1 .6 0 r
.016 w
.5 .61128 m
.54331 .47798 L
s
P
p
1 .6 0 r
.016 w
.5 .61128 m
.5 .75145 L
s
P
p
1 .6 0 r
.016 w
.5 .61128 m
.45669 .47798 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.000156707 0.952381 [
[ 0 0 0 0 ]
[ 1 .95269 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95269 L
0 .95269 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.50175 .73978 m
.36166 .84156 L
s
P
p
.2 0 1 r
.02 w
.50175 .73978 m
.44824 .90446 L
s
P
p
.2 0 1 r
.02 w
.59056 .71093 m
.73064 .8127 L
s
P
p
.2 0 1 r
.02 w
.59056 .71093 m
.76371 .71093 L
s
P
p
0 .4 1 r
.018 w
.53567 .69309 m
.50175 .73978 L
s
P
p
0 .4 1 r
.018 w
.53567 .69309 m
.59056 .71093 L
s
P
p
.2 0 1 r
.02 w
.51102 .20873 m
.6757 .15522 L
s
P
p
.2 0 1 r
.02 w
.51102 .20873 m
.6128 .06865 L
s
P
p
.2 0 1 r
.02 w
.41764 .20873 m
.31586 .06865 L
s
P
p
.2 0 1 r
.02 w
.41764 .20873 m
.25296 .15522 L
s
P
p
0 .4 1 r
.018 w
.46433 .24266 m
.51102 .20873 L
s
P
p
0 .4 1 r
.018 w
.46433 .24266 m
.41764 .20873 L
s
P
p
.2 0 1 r
.02 w
.3381 .71093 m
.16495 .71093 L
s
P
p
.2 0 1 r
.02 w
.3381 .71093 m
.19801 .8127 L
s
P
p
.2 0 1 r
.02 w
.42691 .73978 m
.48042 .90446 L
s
P
p
.2 0 1 r
.02 w
.42691 .73978 m
.56699 .84156 L
s
P
p
0 .4 1 r
.018 w
.39299 .69309 m
.3381 .71093 L
s
P
p
0 .4 1 r
.018 w
.39299 .69309 m
.42691 .73978 L
s
P
p
.2 0 1 r
.02 w
.65775 .28675 m
.82242 .34025 L
s
P
p
.2 0 1 r
.02 w
.65775 .28675 m
.82242 .23324 L
s
P
p
.2 0 1 r
.02 w
.58219 .23186 m
.58219 .0587 L
s
P
p
.2 0 1 r
.02 w
.58219 .23186 m
.48042 .09177 L
s
P
p
0 .4 1 r
.018 w
.60003 .28675 m
.65775 .28675 L
s
P
p
0 .4 1 r
.018 w
.60003 .28675 m
.58219 .23186 L
s
P
p
.2 0 1 r
.02 w
.22266 .59139 m
.08258 .48961 L
s
P
p
.2 0 1 r
.02 w
.22266 .59139 m
.04951 .59139 L
s
P
p
.2 0 1 r
.02 w
.27755 .66694 m
.22405 .83162 L
s
P
p
.2 0 1 r
.02 w
.27755 .66694 m
.33106 .83162 L
s
P
p
0 .4 1 r
.018 w
.27755 .60922 m
.22266 .59139 L
s
P
p
0 .4 1 r
.018 w
.27755 .60922 m
.27755 .66694 L
s
P
p
.2 0 1 r
.016 w
.46433 .47352 m
.53567 .69309 L
s
P
p
.2 0 1 r
.016 w
.46433 .47352 m
.46433 .24266 L
s
P
p
.2 0 1 r
.016 w
.46433 .47352 m
.39299 .69309 L
s
P
p
.2 0 1 r
.016 w
.46433 .47352 m
.60003 .28675 L
s
P
p
.2 0 1 r
.016 w
.46433 .47352 m
.27755 .60922 L
s
P
p
.2 0 1 r
.02 w
.61786 .72084 m
.51609 .86092 L
s
P
p
.2 0 1 r
.02 w
.61786 .72084 m
.61786 .89399 L
s
P
p
.2 0 1 r
.02 w
.69342 .66595 m
.85809 .71945 L
s
P
p
.2 0 1 r
.02 w
.69342 .66595 m
.85809 .61244 L
s
P
p
0 .4 1 r
.018 w
.6357 .66595 m
.61786 .72084 L
s
P
p
0 .4 1 r
.018 w
.6357 .66595 m
.69342 .66595 L
s
P
p
.2 0 1 r
.02 w
.46258 .21291 m
.60266 .11114 L
s
P
p
.2 0 1 r
.02 w
.46258 .21291 m
.51609 .04823 L
s
P
p
.2 0 1 r
.02 w
.37377 .24177 m
.23368 .13999 L
s
P
p
.2 0 1 r
.02 w
.37377 .24177 m
.20062 .24177 L
s
P
p
0 .4 1 r
.018 w
.42866 .2596 m
.46258 .21291 L
s
P
p
0 .4 1 r
.018 w
.42866 .2596 m
.37377 .24177 L
s
P
p
.2 0 1 r
.02 w
.45331 .74396 m
.28863 .79747 L
s
P
p
.2 0 1 r
.02 w
.45331 .74396 m
.35153 .88405 L
s
P
p
.2 0 1 r
.02 w
.54669 .74396 m
.64847 .88405 L
s
P
p
.2 0 1 r
.02 w
.54669 .74396 m
.71137 .79747 L
s
P
p
0 .4 1 r
.018 w
.5 .71004 m
.45331 .74396 L
s
P
p
0 .4 1 r
.018 w
.5 .71004 m
.54669 .74396 L
s
P
p
.2 0 1 r
.02 w
.62623 .24177 m
.79938 .24177 L
s
P
p
.2 0 1 r
.02 w
.62623 .24177 m
.76632 .13999 L
s
P
p
.2 0 1 r
.02 w
.53742 .21291 m
.48391 .04823 L
s
P
p
.2 0 1 r
.02 w
.53742 .21291 m
.39734 .11114 L
s
P
p
0 .4 1 r
.018 w
.57134 .2596 m
.62623 .24177 L
s
P
p
0 .4 1 r
.018 w
.57134 .2596 m
.53742 .21291 L
s
P
p
.2 0 1 r
.02 w
.30658 .66595 m
.14191 .61244 L
s
P
p
.2 0 1 r
.02 w
.30658 .66595 m
.14191 .71945 L
s
P
p
.2 0 1 r
.02 w
.38214 .72084 m
.38214 .89399 L
s
P
p
.2 0 1 r
.02 w
.38214 .72084 m
.48391 .86092 L
s
P
p
0 .4 1 r
.018 w
.3643 .66595 m
.30658 .66595 L
s
P
p
0 .4 1 r
.018 w
.3643 .66595 m
.38214 .72084 L
s
P
p
.2 0 1 r
.016 w
.5 .47917 m
.6357 .66595 L
s
P
p
.2 0 1 r
.016 w
.5 .47917 m
.42866 .2596 L
s
P
p
.2 0 1 r
.016 w
.5 .47917 m
.5 .71004 L
s
P
p
.2 0 1 r
.016 w
.5 .47917 m
.57134 .2596 L
s
P
p
.2 0 1 r
.016 w
.5 .47917 m
.3643 .66595 L
s
P
p
.2 0 1 r
.02 w
.72245 .66694 m
.66894 .83162 L
s
P
p
.2 0 1 r
.02 w
.72245 .66694 m
.77595 .83162 L
s
P
p
.2 0 1 r
.02 w
.77734 .59139 m
.95049 .59139 L
s
P
p
.2 0 1 r
.02 w
.77734 .59139 m
.91742 .48961 L
s
P
p
0 .4 1 r
.018 w
.72245 .60922 m
.72245 .66694 L
s
P
p
0 .4 1 r
.018 w
.72245 .60922 m
.77734 .59139 L
s
P
p
.2 0 1 r
.02 w
.41781 .23186 m
.51958 .09177 L
s
P
p
.2 0 1 r
.02 w
.41781 .23186 m
.41781 .0587 L
s
P
p
.2 0 1 r
.02 w
.34225 .28675 m
.17758 .23324 L
s
P
p
.2 0 1 r
.02 w
.34225 .28675 m
.17758 .34025 L
s
P
p
0 .4 1 r
.018 w
.39997 .28675 m
.41781 .23186 L
s
P
p
0 .4 1 r
.018 w
.39997 .28675 m
.34225 .28675 L
s
P
p
.2 0 1 r
.02 w
.57309 .73978 m
.43301 .84156 L
s
P
p
.2 0 1 r
.02 w
.57309 .73978 m
.51958 .90446 L
s
P
p
.2 0 1 r
.02 w
.6619 .71093 m
.80199 .8127 L
s
P
p
.2 0 1 r
.02 w
.6619 .71093 m
.83505 .71093 L
s
P
p
0 .4 1 r
.018 w
.60701 .69309 m
.57309 .73978 L
s
P
p
0 .4 1 r
.018 w
.60701 .69309 m
.6619 .71093 L
s
P
p
.2 0 1 r
.02 w
.58236 .20873 m
.74704 .15522 L
s
P
p
.2 0 1 r
.02 w
.58236 .20873 m
.68414 .06865 L
s
P
p
.2 0 1 r
.02 w
.48898 .20873 m
.3872 .06865 L
s
P
p
.2 0 1 r
.02 w
.48898 .20873 m
.3243 .15522 L
s
P
p
0 .4 1 r
.018 w
.53567 .24266 m
.58236 .20873 L
s
P
p
0 .4 1 r
.018 w
.53567 .24266 m
.48898 .20873 L
s
P
p
.2 0 1 r
.02 w
.40944 .71093 m
.23629 .71093 L
s
P
p
.2 0 1 r
.02 w
.40944 .71093 m
.26936 .8127 L
s
P
p
.2 0 1 r
.02 w
.49825 .73978 m
.55176 .90446 L
s
P
p
.2 0 1 r
.02 w
.49825 .73978 m
.63834 .84156 L
s
P
p
0 .4 1 r
.018 w
.46433 .69309 m
.40944 .71093 L
s
P
p
0 .4 1 r
.018 w
.46433 .69309 m
.49825 .73978 L
s
P
p
.2 0 1 r
.016 w
.53567 .47352 m
.72245 .60922 L
s
P
p
.2 0 1 r
.016 w
.53567 .47352 m
.39997 .28675 L
s
P
p
.2 0 1 r
.016 w
.53567 .47352 m
.60701 .69309 L
s
P
p
.2 0 1 r
.016 w
.53567 .47352 m
.53567 .24266 L
s
P
p
.2 0 1 r
.016 w
.53567 .47352 m
.46433 .69309 L
s
P
p
1 .6 0 r
.016 w
.5 .36374 m
.46433 .47352 L
s
P
p
1 .6 0 r
.016 w
.5 .36374 m
.5 .47917 L
s
P
p
1 .6 0 r
.016 w
.5 .36374 m
.53567 .47352 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.014 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.014 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.014 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
.8 1 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
.8 1 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
.8 1 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0591002 0.952381 [
[ 0 0 0 0 ]
[ 1 .83418 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .83418 L
0 .83418 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.27675 .53543 m
.05045 .53543 L
s
P
p
.2 0 1 r
.02 w
.27675 .53543 m
.09367 .66845 L
s
P
p
.2 0 1 r
.02 w
.39282 .57315 m
.46275 .78837 L
s
P
p
.2 0 1 r
.02 w
.39282 .57315 m
.5759 .70616 L
s
P
p
0 .4 1 r
.018 w
.34849 .51212 m
.27675 .53543 L
s
P
p
0 .4 1 r
.018 w
.34849 .51212 m
.39282 .57315 L
s
P
p
.2 0 1 r
.016 w
.44173 .22516 m
.34849 .51212 L
s
P
p
.2 0 1 r
.02 w
.43897 .58046 m
.22375 .65039 L
s
P
p
.2 0 1 r
.02 w
.43897 .58046 m
.30596 .76354 L
s
P
p
.2 0 1 r
.02 w
.56103 .58046 m
.69404 .76354 L
s
P
p
.2 0 1 r
.02 w
.56103 .58046 m
.77625 .65039 L
s
P
p
0 .4 1 r
.018 w
.5 .53612 m
.43897 .58046 L
s
P
p
0 .4 1 r
.018 w
.5 .53612 m
.56103 .58046 L
s
P
p
.2 0 1 r
.016 w
.5 .23439 m
.5 .53612 L
s
P
p
.2 0 1 r
.02 w
.60718 .57315 m
.4241 .70616 L
s
P
p
.2 0 1 r
.02 w
.60718 .57315 m
.53725 .78837 L
s
P
p
.2 0 1 r
.02 w
.72325 .53543 m
.90633 .66845 L
s
P
p
.2 0 1 r
.02 w
.72325 .53543 m
.94955 .53543 L
s
P
p
0 .4 1 r
.018 w
.65151 .51212 m
.60718 .57315 L
s
P
p
0 .4 1 r
.018 w
.65151 .51212 m
.72325 .53543 L
s
P
p
.2 0 1 r
.016 w
.55827 .22516 m
.65151 .51212 L
s
P
p
1 .6 0 r
.016 w
.5 .04581 m
.44173 .22516 L
s
P
p
1 .6 0 r
.016 w
.5 .04581 m
.5 .23439 L
s
P
p
1 .6 0 r
.016 w
.5 .04581 m
.55827 .22516 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`00014000=<000014`00`1<C0020003C00001@000=<000014`00`1<C0020003C00001P0
0T`00`1<C00O00=<6`000d`00002C00304`0009<0P000d`0000D0003C000009<00<0C4`00T`20003
C00001@000?600000/H00`36aP02aP8000?600004000014000==00001dd20003C@0001@000==0000
1dd20003C@0001<014d0101=C@04C@0304e=01@000==00000Td01@1=CDd0009=0P000dd0000C0003
C@00009=00<0C@000Td20003C@0001@000==00001dd20003C@0001@000?600001lH20003aP000100
000B0003C01<00I<00<0C0005`000d`0C006C00304`001L000=<04`00T`00`1<C0020003C00001<0
4D`B009<00@0C0001D`20004C01<C1D000=<04`01T`00`1<000G0003aP3600K600<0aP004P0000l0
0Td0101=C@05C@0404e=009=4P02C@0404e=00E=00@0CDd00TdF0003C@1=00A=00<0C@005002C@04
04e=00M=00@0CDd00TdA015=4P02C@0404e=00E=00@0CDd00TdB00;600@0a/H01LH01036aP02aQ00
000A00e<5P0=C1<00T`40007aT`0aP1<aP04009<4P02C00304`000E<00<0C0000T`F009<00?6C4`0
1<H2C1L03D`F00g64P0000d00Td30003C@3600K600<0C@000P02C@h00Td30003C@2d00Jd00<0C@00
0P02CA400dd200G60P03CA801Dd00`36aP05aP0304d000==3`06C@C600<0CLH00/H6C@h00Td30003
C@3600K600<0C@000P02C@h00/H30003aP3600K600<0aP000P02aPh0000>00E<0lH2009<0/H5C100
1D`3]004C01<C0:d1D`E00?600A<04a<0/HD00A<00<0C<H00/H014`0C4`2aP9<00@0C4a<4003C0<0
00?6C0000T`300=<4@05C0?600A<04a<0/H5C1002<H014`0C4`7aPl0000A0003CLK6009=0P03C@;6
00==000050000dfd]003C@0404e=C@:d00==00004005C@;60dd0101=CDd2aPE=4@02C@;60dd0101=
CDd2aP==4`02C@;60dd0101=CDd2aP==50000dg6aP03C@0404e=C@;600==00005003aP==00@0CDe=
0lHB00003P03C0<00T`200=<0`03C1000d`300=<00@0C4a<0`03C1H00d`0101<C4`E00=<1003C004
04a<C0D00T`>00=<1003C0044Da<C0D00T`?00=<0`03C00404a<C0<00d`@00?60`03C00404a<C0<0
0lH?00003@000dd00005009=00<ACDd01`000dd0000<0003C@0000D00Td00a5=C@070003C@0001@0
0Td00a5=C@0N009=00<ACDd07P02C@034De=01H000==00001@02C@034De=00L000==000030000lH0
0005009=00<ACDd01`000lH0000<00005@02C0034D`001l000=<4D`080000d`AC00P0003C15<0200
00=<4D`080000d`AC00P0003C15<01L0000E0004CA4ACB0000==4Dd080000ddAC@0P0003CA5=0200
0a4P0003CA5=020000==4Dd05`0001D000A<4A4A80034B000a4P00<A80034B000a4P00<A5`0000X0
00==00001`000ddA00024@03C@0000P000==00001P000dd000080005CA4A4Dd02P000dd0000A0005
CA4A4Dd07P001DdA4A5=01h000E=4A4AC@0C0003C@0000P000E=4A4AC@0:0003C@0000H000?60000
20001DdA4A5=00X000?600002@0000/000=<00001@0014`0C002C00304`000L000=<000020000d`0
00060003C01<009<00<0C0001`000d`0000A0003C01<009<00<0C0004002C0T000=<04`00T`00`1<
0008009<1`000d`00006009<00D0C4a<0002C0P000=<00001`000d`000060003C01<009<00<0C000
1`000d`000080003aP0000H000=<04`00T`00`1<00070003aP0000X0000<0003C@0000<000==0000
1Dd00`1=C@050003C@0000X000==00000`02C@0304e=00==00<0CDd01@000dd00007009=1`02C@03
04e=00==00<0CDd01`02C@P00Td5009=00<0CDd00dd00`1=C@05009=2P000dd000040003C@0000E=
0P000dd000040003C@0000T000==00000`02C@0304e=00==00<0CDd01@000dd0000:0003aP0000<0
0Td00`1=C@03C@0304e=00D000?600002`0000d000E<0000C00200A<00<0C0000P001D`0001<00h0
00E<0000C0030005C01<04`00`001D`0001<00`00d`30009C00004`0C01<00<000A<00000d`800E<
0`002D`0001<04`0C0030006C00004`00d`90004C000009<0`001D`0C01<00<00T`30003C00000/0
00E<0000C0030005C01<04`00`001D`0001<00h000G60000C0030005C01<04`00`001D`0003600h0
000900E=0/H014d00002C@0304d0009=0`000dg6aP05C@H01Dd2]004C@00009=00<0C@000Td30003
CKBd00E=2`02aP04C@00009=00<0C@000Td30003CLK600l000A=a/I=0`02C@0304d0009=0`000dg6
aP02C@T014d2aP03C@00008000A=001=0P000dd000020003CLK600A=1P05C@;600A=00000Td00`1=
0002C@<000==a/H01Dd600O600A=00000Td00`1=0002C@<000==a/H01LH:00003P03C0<000A<001<
0P001D`00036009<4003C0<000A<001<0P001D`0002d009<4P001LH0001<008000A<001<0`000lH0
000>00A<00G60000C0020004C000C0<000?604`00T`<00A<0`02C08000=<00000T`30004aTa<C0h0
0d`30004C000C08000E<0000aP02C1000lH30004C000C08000A<00000lH?0000400014g6aTd2009=
0P02C@?650000dfd]002C@0504e=C@000Td3]0l01Td2aP9=00D0CDe=0002C@?61Dd>009=0/H2C@05
04e=C@000Td3aP9=4@001lI=aTd0C@000dd01`1=04g6CLH04`000dg6aP02C@0504e=C@000Td3aQ@0
0lH2C@0504e=C@000Td3aQ40000<00Q<0/H3C0;600=<aT`01D`<00Q<0[@3C0:d00=<]4`01D`@0004
C<K6C0;60d`2aP04C<I<C10024`2aP=<0/H00dc6C002C00304a<00d00d`20004aT`0aP=<00C604c6
0P03C0d024`2aP=<0/H00dc6C005C0`02/H2C0?600=<a/H01LH=000030000dd00002C@0;04g6CLI=
aTg60<H014d20003C@0000X000==00000Td02`1=]4fdCKA=]4fd00A=0P000dd0000;00I=0/H00`36
aP0200;61Td=00M=0/H01Dg6a/I=00;600==04d014d<00Q=00K60<I=aP02aP03CLI=00A=30000dd0
0002C@0504g6aTd00/H2C@;600A=04e=0P000dd0000:0003aP0000G600<0a/H01/H00`36aP020003
aP0000/0000>009<00<0C4`02d`00`1<C00@009<00<0C4`02d`00`1<C00>0003C000009<0P02C004
aP1<aP=<0P02C08000=<00003002C00304`000U<00<0C0000T`@00=<00L0C4a<aTc6009<00C6C4`0
0d`@009<00<0C4`02d`00`1<C00@00;600<0a/H02lH00`36aP0?00003@000dd0C@02C@0304e=009=
00<0CDd00Td01P1=CDd0C@h000==04d00Td00`1=C@02C@0604e=04d00dd00`1=000@0003C@0000A=
00<0CDd00Td20003C@0000l000==04d01dd00`1=C@06C@0304d000h000==04d03Td00`1=000>0003
C@1=009=00<0C@000Td00`1=C@02C@0604e=C@1=3P000lH0aP02aP030<H000;600<0a/H00/H01P36
a/H0aPh0000>0003C00000=<00@0C4`01D`30003C00000h000=<00000d`0101<C005C0<000=<0000
400014`0C003C00804a<C01<04`C0004C01<00U<00@0C01<4002C00404a<00U<00@0C4`00T`?0003
C00000I<00<0C4`014`20003C00000h000C600001LH01036aP03aP8000?600003@0001<000==04d0
0dd20003C@0001P000==04d00dd20003C@0001D00Td20005C@00C@000Td2009=5P05C@0304e=00==
6@04C@0304e=009=6P000dd0C@04C@0304d001T000?600001<H00`36000C00004P02C00404a<009<
00<0C4`06002C00404a<009<00<0C4`06@001D`0C4`000=<70000d`0C002C00304`001X000E<04a<
0002C00304`001P00T`0101<C002C00304a<01P00/H01036aP02aP030<K601<0003o00<0003o00<0
003o00<0003o00<0003o00<0003o00<0003o00<0000E0005C00004`0QP0014`004`20003C00001`0
00=<04`0>P00018000A=001=0`0014d004dK009=00<0CDd06P000dd00004C@0304e=008000==0000
50000dd00004C@0304e=008000==0000500014d004d20004C@00C@8000==00005@000dd0C@06C@03
04d001H000A=04d00Td01`1=C@1=04d04P0001800T`20003C01<00800T`G0004C01<009<00@0C4a<
0P000d`0000D0003C00000M<0P000d`0000D0003C00000M<0P000d`0000D0003C000009<00<0C000
0T`20003C00001D000=<04`01T`00`1<000F0004C01<009<00L0C4`0C01<0180000@009=00<0CDd0
0Td0101=CDd2009=5@000dd0C@02C@0304e=00==00<0C@005P000dd0C@06C@0304d001L000==04d0
1Td00`1=000D0005C@00C@000dd01P1=CDd0C@8000==00004008C@0304e=00==00<0CDd05@000dd0
C@08CA<0000@00E<00<0C0000T`00`1<C002C1801T`00`1<C003C00404a<009<4P02C00404a<00E<
00@0C4`00T`B009<00@0C4`01D`0101<C002C1<000=<04`014`00`1<C003C00304`001@01T`00`1<
C004C1<01T`00`1<C003C00304a<00A<3`0001<00Td01<H0a/H3CAL03TdF00e=5P0=CAH014d01@36
0<H000A=4`02C@8000==04d00Td01/I=CLH0C@800TdB00m=4@0000h01T`7aPE<5@000d`0aP02C0C6
00<0C0004P02C0<000=<0<H01/H00`1<0002009<3P02C0<000=<0<H01/H00`1<0002009<4`02C007
aP360<H0aP02C1@01D`9aPE<50000d`0aP06aP8000=<0000400001H00ddG00I=1<H00`1=aP02aPI=
3`05C@?600A=04e=0/H5CA001Dd4aP030<K600;61DdE0005aP1=C@000Td00`36000G0004C@00aP9=
00@0CDg60P000dd0000@00I=1<H0101=aP02aPE=3P0001H00d`J00=<0P000lH00002C0<00d`D0003
C<K600=<00@0C4a<0/H00d`0000D0003C<K600?600<0a/H00lH00d`0000G00=<00@0C4a<6002C0;6
0d`0101<C4`2aP=<50000dc6aP03C00304a<00?60T`A00005P000ddA000J00==00G6CDd04@02C@;6
0ddB00==0`03C@0404e=C@<00dd@00==0`03aP040<K6aP<00ddF00==00@0CDe=5@03C@@00dd0101=
CDd5009=3`03C@<00dd0101=CDd300==3`0001L000<A00005P03C0@00d`00a5<C00500=<3P000d`0
0005009<00<AC4`01`000d`0000<0003C00000D00/H00a76aP070003C00001@00T`00a5<C00N009<
00<AC4`05P000d`00005009<00<AC4`01`000d`0000<00005P024B0000A=4A5=80000ddAC@0P0003
aQ76020000==4Dd080000ddAC@0P0003CA5=01L0000F00<A7`0014`A4A4P0003C15<020000?64LH0
80000d`AC00P0003C15<020000=<4D`05`0001H00a4O0004CA4A4B000a4P00<A80034B000a4P00<A
5`0001D000@A014A5002C0P000=<4@000Q400d`00007009<20000d`000080005C14A4D`02P000d`0
00060003C00000P000G64A4AaP0:0003C000014000E<4A4AC00N0005C14A4D`04`02C0T000E<4A4A
C009009<2`0001D000A=04e=5P000dd000040004C@1=009=00<0C@001P000dd000090003C@0000H0
00==04d00Td00`1=00070003C@0000P000==00001P000lH0aP02aP030<H000L000==00004@000dd0
C@02C@0304d001000Td90003C@1=009=00<0C@002002C@T000==00001@000dd0C@02C@0304d000H0
00==00002`0001D000E<04`0C00F0003C000008000A<04`014`00`1<C0040003C00000/000=<0000
0`02C00304a<00=<00<0C4`01@000d`0000:0003C00000<00/H00`36aP03aP030<K600D000=<0000
4002C00304a<00=<00<0C4`04@02C0D00T`00`1<C003C00304a<00D00T`<0003C00000800T`00`1<
C003C00304a<00@000=<0000300001@000I=001=04dB00E=0/H0101=0004C@0304d0008000A=0<K6
1Dd:0005C@0004d00`001Dd0C@1=00<000E=0000C@0>0005C@000<H00`001LH0aP3600<000G60000
C@0B0009C@0004d0C@1=00<000==000040001Dd0001=00<000E=04d0C@030005C@0004d02P05C@;6
00<0C@000P001Dd0C@1=00<000A=0<K61Dd:0000500014`004`20003C00001800T`20004C00000A<
00<0C0000`000d`00002C0T01D`2aP04C000009<00<0C0000T`30003C<K600E<1P05C0?60`02aP03
0<H000;60`03aPE<30000lI<0002009<00<0C0000T`30003C<H000h00T`2aP04C000009<00<0C000
0T`30003C<K600=<2`02C08000=<00000P001D`0C01<00@000=<00000T`=0000500014d004d20003
C@0001@00dd2009=00<0CDd00P001Dd00036009=4003C@<000A=001=0P001Dd00036009=4003C@<0
00C600360P001LH00036009=3`000dg600040004C@00C@8000==00000`000lI=000900M=00G60000
C@020004C@00C@<000?604d00Td00`1=C@0;00==0`000dd0C@02C@0304d0008000?6CDd03`0001<0
00E<0000C0020003C00001D00T`2aP03C000009<00?604`01<H2C18000=<a/H00T`01@1<C4`0009<
0lHD0003C<K600;600D0a/K60005aPh00d`00`1<0003009<00D0C4a<0002C0@000=<04`00T`>0003
C<K6009<00D0C4a<0002C0;600=<aP004@02C0;60T`01/I<C4c6C0C60T`?00004P000lI=00020006
C@0004g64P09C@;600I=0<K6CLH6C@`024d2aP==00C6CDg61Td<00Q=2LH6C@T000E=0000C@030003
CLI=00800dd20003CLI=00<000E=0000C@0;00==0P000lH00003C@8000A=00000Td>00Q=00?60<H0
0/H01@36aTg600E=3@0000/01T`00lH0aP020003aT`0008000?60<H01D`?00I<00G6C<I<aP06C0l0
00=<00000T`2009<00?6C<H00T`2aP0404a<C08000=<00002P000d`00002C08000=<aT`00/H2C0;6
0P02C08000=<00002P0024`0001<04c60P03aP8000C6C01<0`000d`0000:00U<00C60<H01<H6C0l0
14`01P36aT`0aP9<00<0C4`00T`@00003`000dd000020007CLH00<I=aP040003C@0000l00Td00`1=
C@0;C@0304e=014000==04d034d00`1=000A0003C@1=00a=00<0C@003P0024d004d0C@360P03aP80
00G604d0C@020003C@0000X000E=04d0C@0200==00?6CDd00dd20005C@1=04d03P02C@0304e=00]=
00<0CDd03`0000h000=<000024`00`1<C002C08000=<00003@000d`0C002C00304a<009<00<0C4`0
0T`01P1<C4`0C0l014`00`1<C002C00604a<04`014`@00A<00<0C4`00T`01P1<C01<00A<3@0014`0
04`20004C01<00E<00@0C01<0P0014`004`=00=<00<0C4`02D`0101<C4`?0003C01<009<00<0C4`0
0T`00`1<C002C00604a<C01<3P0000d000A=001=0`03C@0304e=00@000A=001=3`0014d00005C@06
04e=C@1=0`000dd0000=009=00<0CDd00Td0101=C@05C@0304d0009=3P02C@0304e=00E=00<0CDd0
1Dd00`1=C@0>0004C@0000A=00D0C@1=0004C@<000==00003002C@0504e=C@000Td00`1=0002C@05
04e=C@000Td@0003C@0000E=00<0CDd00dd20003C@0000h0000C0003C01<00<00T`K00I<00<0C4`0
6P000d`0C004C00304`001T000=<04`014`00`1<000F009<00L0C000C01<008000A<04a<5P05C003
04a<00=<6@09C1@0000C0003C@1=00<000==04d06@000dd0C@02C@0604e=C@1=6002C@0404e=009=
00<0CDd06002C@0404e=009=00<0CDd05P0014d0CDd20003C@1=00800Td00`1=000E009=00@0CDd0
0Td00`1=C@0H0007C@1=C@1=0002C@0304d00180000B0007C00004`0C0030003C000080000E<04a<
0002C00304`001/00T`00`1<C00i0000o`030000o`030000o`030000o`030000o`030000o`030000
>002C@0304e=01h00Td00`1=000O009=P@0001802/HF0003C00000<00T`00`1<C0050003C00001@0
14`00`1<0002C1P000E<04a<0002C0800T`00`1<000E0003C00000=<00@0C4a<0P000d`0000D0003
C000009<00<0C4`00T`20003C00003<0000A00C600I=0000C@03aQ@000==00000Td20004C@1=009=
0`000dd0000@00A=0P05C@0304e=00==50001Dd0CDd000==00D0CDd0C@0F0003C@0000==00@0CDe=
0P000dd0000D0003C@0000M=0P000dd0000J00034@0001H0000C0003aP1<00<00T`00lH0000E0004
C000009<00@0C4a<10000d`0000B00A<00<0C4`00d`00`1<0002C1800T`20007C01<C01<0002C005
04`004`05@000d`0C006C00304`001L000=<04`01T`00`1<000L00034@0001H0000B0004aTd0C@<0
0Td00lH0000B009=0P0014d00005C@<000==00000TdA000?C@1=04g60<H0aTd0C@1=01<04DdB009=
00@0CDd01Dd0101=C@02CA800Td0101=C@05C@0404e=009=6@034AL0000?00?600A<04a<0`03C0?6
4@04C00404`000;600<0a/H00P000d`0C002C1001D`01lI<aT`0C<H01d`C00e<5P0=C1H03D`K00<A
5`00018000A=04e=0`000dd0C@0H009=0lH30003CLK6009=5P002/H004d0C@1=04d20003aP000100
0Td30003C@3600K600<0C@000P02C@h00Td30003C@3600K600<0C@000P02C@h00Td30003C@3600K6
00<0C@000P02CAL00a4G00004`03C0030140009<6002C0;60T`3009<0/H3C1@00T`20005C01<04`0
0P02C1801T`2aP9<00<0C4`00/H5C1001D`3aP04C01<C0;61D`@00E<0lH014`0C4`2aPE<5`001A40
4@0A01H0000D009=00@04@1=5P03C@@00Td3009=1@02C@`01Dd00lH00003C@0304d000==0P000lI=
C@03CA0000==a/H00dd0101=CDd2aP03C@0001@000==a/H00dd0101=CDd2aP03C@0001@000==a/H0
0dd0101=CDd2aP03C@0001P000DA01404@0F00005@000d`04@02C1h000E<0140C00F009<00<0C4`0
0P07C0800T`00`1<C00?00=<0`03C00404a<C0<00d`@00=<0`03C00404a<C0<00d`@00=<0`03C004
04a<C0<00d`G0005C01<04`05P0001D000E=4A4AC@0N0005C@0A04d05@000dd000030003C@0000E=
0P000dd000030003C@0000/000==00001@02C@034De=00L000==000030000dd00005009=00<ACDd0
1`000dd0000<0003C@0000D00Td00mi=C@070003C@0001<000A=001=0P000dd0000C00005@001D`A
4A5<01l000=<4D`07@001T`001404@8000=<00006`000d`AC00P0003C15<020000=<gd`07P0014`0
04`20003C00001<0000E0005CA4A4Dd07`000a5=4@0I00E=00O6CA404Dg600E=6@000ddAC@0P0003
CA5=020000==gTd07P0014d004d20003C@0001<0000E00054D`AC1407`000a5<4@0O009<00<AC4`0
7`034B000a4P00?O7@001D`0001<00<000=<00004P0001@000M=4@0A015=01h000<A01406@03C@@0
00==4Dd01003C@d000==000020001DdA4A5=00X000==00001P000dd000080005CA4A4Dd02P000dd0
00060003C@0000P000E=g]kNC@0:0003C@0000l000E=0000C@030003C@000180000C0009C01<04`0
C01<01d000=<04`070000dc6aP02C0034Da<00;600=<00003`000d`000060003C01<009<00<0C000
1`000d`000080003C00000H000=<04`00T`00`1<00070003C00000P000=<00001P000d`0C002C003
04`000L000=<000040001D`0001<00<000=<00004P0001400Td00`1=C@05C@0304d001X01DdI009=
0`001LI=4Dg600<00Td@0003C@0000<00Td200==0P02C@D000==00002P000dd00003009=00<0CDd0
0dd00`1=C@050003C@0000X000==00000`02C@0304e=00==00<0CDd01@000dd0000@0003C@000080
00==00000P000dd0000A0000400014`00007C0800T`>009<20000d`0C002C00304`000L00T`=0003
C000008000M<aT`AC<I<00@000=<00003P001D`0001<00<000E<04`0C0030005C00004`03P001D`0
001<00<000E<04`0C0030005C00004`03P001D`0001<00<000E<04`0C0030005C00004`04P000lI<
00030003C000008000=<aP004@0000l000==00000P07C@@000==00003@03C@@000I=001=04d20003
C@0000800ddA00I=00<ACDd00dd?00E=0/H00dd000020005C@1=04d010000dg6aP05C@H01Dd2aP04
C@00009=00<0C@000Td30003CLK600E=1P05C@;600A=00000Td00`1=0002C@<000==a/H01Dd600M=
00C600360P000lI=aP020004aP00aPM=2P0000d00T`4009<00D0C4a<0002C0@000=<00003003C0;6
00D0C000C0030005C000C0000/H3C10000=<00002D`00`1<000B00=<0`02C00304`0009<0`000lI<
C00@00=<0`0014`004`20005C0000<H00T`@00=<0`0014`004`20005C0000<H00T`@0003C0000080
0T`01lH0001<aT`010000d`0000=00002@02aP0304d000D000E=0000C@030003C@0000<000==0000
0/H600==00<0CDd00dd30005C@0004d00`000dd0C@02C@0404e=CA0000==04d014d00`1=000F0003
CLK6009=00D0CDe=0002C@?650000dg6aP02C@0504e=C@000Td3aQ@000==a/H00Td01@1=CDd0009=
0lH@009=0P03C@0504e=C@000dd0101=CDd2009=3@0000/000=<00001002C0<000A<00000T`50003
C<H000l000=<a/H00T`3009<0lH00d`0000@009<0P001d`0C4`0C0000T`0101<0002C0l014`20003
aTc600=<00?6C<H00P04C0d024`2aP=<0/H00dc6C005C0`024`2aP=<0/H00dc6C005C0/000=<0000
0T`40004C000C08000=<00000P02C08000=<00002P0000/000?6000010000dd000020003C@000080
00==00000`000lH0000=00==0P000lI=00020004CLH000==4`02C@8000I=001=04d3009=4008C@C6
00<0a/H00/H6C@`000==00000Td20003CLI=00;60Td2aP800Td20003C@0000X000==00000Td20003
CLI=00;60Td2aP800Td20003C@0000P000==00001P001Dd0CDd0009=00<0C@001`000dd000090000
2`000lH00003009<10000d`00002009<10000lH0000;00I<00G60<K6C002aP030<I<00A<4P02C003
aT`0008000A<001<0/H2C1<01T`00lI<C008C18000=<04`034`00`1<000A0003C01<00a<00<0C000
5@000d`0C0030003C01<01@0000;0003aP3600;600==04d00`03C@<000==04d01<H=0004C@00009=
0P02C@0304e=00800Td30003C@0000d00Td40004aP00C@8000?600000P02CA0034d00`1=C@04CA00
14d00`1=C@02C@0304e=009=00<0CDd00Td@00A=00<0C@000Td00`1=C@02C@0304e=009=500014d0
04d30004C@00CA<0000@0003aT`0008000C6C4a<0/H20003C<H001<00T`01`1<C4`0C0000d`00`1<
C00H009<00?60<H00T`E009<00<0C0001D`00`1<C003C00304`0009<3P02C00304a<00E<00<0C4`0
1D`00`1<C00>009<00<0C4`01D`00`1<C005C00304a<018000=<00000P000d`0C0040003C0000100
000>00;600<0a/H00/H01036CLH200?600<0aP004P0014d0CDd20003C@1=008000A=001=5P04C@<0
14dI0003C@1=00A=00<0C@006@001Dd0CDd0009=00<0C@006@000dd0C@04C@0304d001`000==04d0
5`0001<000W60<H0aP360<H05P02C0<00d`0101<C4`3009<5`001d`0C01<04`06P02C00404a<009<
00<0C4`06002C00404a<009<00<0C4`06002C00404a<009<00<0C4`0=P0003P00Td00`1=C@0L009=
0P000dd00002CA`00Td00`1=C@1o0000o`030000o`030000o`030000o`030000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.109419,
   0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110616, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.109415, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.74027, -0.110613, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.109418, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277,
   -0.110616, 0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.1939, -0.109419, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.271513, -1.26685, 0.0330059, 0.0330059}, {{42.5, 74.3125},
   {69.375, 37.5625}} -> {-1.42777, -1.26686, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26687, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.8965, -1.26686, 
  0.0330061, 0.0330061}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277,
   -1.26686, 0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.1939, -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.270008, -2.41738, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42398, -2.41737, 0.0329414, 0.0329414}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57798, -2.41739, 0.0329415, 0.0329415}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.74027, -2.42312, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277,
   -2.42311, 0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1939, -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.21377 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.077986 1.15597 0.0288993 1.15597 [
[ 0 0 0 0 ]
[ 1 1.21377 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 1.21377 L
0 1.21377 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.50697 .21933 m
.64304 .12046 L
s
P
p
.2 0 1 r
.02 w
.50697 .21933 m
.55894 .05936 L
s
P
p
.2 0 1 r
.02 w
.42069 .24736 m
.28461 .14849 L
s
P
p
.2 0 1 r
.02 w
.42069 .24736 m
.25249 .24736 L
s
P
p
0 .4 1 r
.018 w
.47401 .26469 m
.50697 .21933 L
s
P
p
0 .4 1 r
.018 w
.47401 .26469 m
.42069 .24736 L
s
P
p
.2 0 1 r
.02 w
.49795 .7352 m
.33799 .78718 L
s
P
p
.2 0 1 r
.02 w
.49795 .7352 m
.39909 .87128 L
s
P
p
.2 0 1 r
.02 w
.58867 .7352 m
.68754 .87128 L
s
P
p
.2 0 1 r
.02 w
.58867 .7352 m
.74864 .78718 L
s
P
p
0 .4 1 r
.018 w
.54331 .70225 m
.49795 .7352 L
s
P
p
0 .4 1 r
.018 w
.54331 .70225 m
.58867 .7352 L
s
P
p
.2 0 1 r
.02 w
.66594 .24736 m
.83414 .24736 L
s
P
p
.2 0 1 r
.02 w
.66594 .24736 m
.80202 .14849 L
s
P
p
.2 0 1 r
.02 w
.57966 .21933 m
.52768 .05936 L
s
P
p
.2 0 1 r
.02 w
.57966 .21933 m
.44358 .12046 L
s
P
p
0 .4 1 r
.018 w
.61262 .26469 m
.66594 .24736 L
s
P
p
0 .4 1 r
.018 w
.61262 .26469 m
.57966 .21933 L
s
P
p
.2 0 1 r
.02 w
.35543 .65941 m
.19546 .60744 L
s
P
p
.2 0 1 r
.02 w
.35543 .65941 m
.19546 .71139 L
s
P
p
.2 0 1 r
.02 w
.42882 .71274 m
.42882 .88094 L
s
P
p
.2 0 1 r
.02 w
.42882 .71274 m
.52768 .84881 L
s
P
p
0 .4 1 r
.018 w
.41149 .65941 m
.35543 .65941 L
s
P
p
0 .4 1 r
.018 w
.41149 .65941 m
.42882 .71274 L
s
P
p
.2 0 1 r
.02 w
.77807 .36348 m
.91415 .46235 L
s
P
p
.2 0 1 r
.02 w
.77807 .36348 m
.94627 .36348 L
s
P
p
.2 0 1 r
.02 w
.72475 .29009 m
.77673 .13012 L
s
P
p
.2 0 1 r
.02 w
.72475 .29009 m
.67277 .13012 L
s
P
p
0 .4 1 r
.018 w
.72475 .34616 m
.77807 .36348 L
s
P
p
0 .4 1 r
.018 w
.72475 .34616 m
.72475 .29009 L
s
P
p
.2 0 1 r
.016 w
.54331 .47798 m
.47401 .26469 L
s
P
p
.2 0 1 r
.016 w
.54331 .47798 m
.54331 .70225 L
s
P
p
.2 0 1 r
.016 w
.54331 .47798 m
.61262 .26469 L
s
P
p
.2 0 1 r
.016 w
.54331 .47798 m
.41149 .65941 L
s
P
p
.2 0 1 r
.016 w
.54331 .47798 m
.72475 .34616 L
s
P
p
.2 0 1 r
.02 w
.6145 .98621 m
.51563 1.12229 L
s
P
p
.2 0 1 r
.02 w
.6145 .98621 m
.6145 1.15441 L
s
P
p
.2 0 1 r
.02 w
.68789 .93289 m
.84786 .98487 L
s
P
p
.2 0 1 r
.02 w
.68789 .93289 m
.84786 .88091 L
s
P
p
0 .4 1 r
.018 w
.63182 .93289 m
.6145 .98621 L
s
P
p
0 .4 1 r
.018 w
.63182 .93289 m
.68789 .93289 L
s
P
p
.2 0 1 r
.02 w
.46365 .4928 m
.59973 .39394 L
s
P
p
.2 0 1 r
.02 w
.46365 .4928 m
.51563 .33283 L
s
P
p
.2 0 1 r
.02 w
.37737 .52083 m
.2413 .42197 L
s
P
p
.2 0 1 r
.02 w
.37737 .52083 m
.20917 .52083 L
s
P
p
0 .4 1 r
.018 w
.4307 .53816 m
.46365 .4928 L
s
P
p
0 .4 1 r
.018 w
.4307 .53816 m
.37737 .52083 L
s
P
p
.2 0 1 r
.02 w
.45464 1.00868 m
.29467 1.06065 L
s
P
p
.2 0 1 r
.02 w
.45464 1.00868 m
.35577 1.14475 L
s
P
p
.2 0 1 r
.02 w
.54536 1.00868 m
.64423 1.14475 L
s
P
p
.2 0 1 r
.02 w
.54536 1.00868 m
.70533 1.06065 L
s
P
p
0 .4 1 r
.018 w
.5 .97572 m
.45464 1.00868 L
s
P
p
0 .4 1 r
.018 w
.5 .97572 m
.54536 1.00868 L
s
P
p
.2 0 1 r
.02 w
.62263 .52083 m
.79083 .52083 L
s
P
p
.2 0 1 r
.02 w
.62263 .52083 m
.7587 .42197 L
s
P
p
.2 0 1 r
.02 w
.53635 .4928 m
.48437 .33283 L
s
P
p
.2 0 1 r
.02 w
.53635 .4928 m
.40027 .39394 L
s
P
p
0 .4 1 r
.018 w
.5693 .53816 m
.62263 .52083 L
s
P
p
0 .4 1 r
.018 w
.5693 .53816 m
.53635 .4928 L
s
P
p
.2 0 1 r
.02 w
.31211 .93289 m
.15214 .88091 L
s
P
p
.2 0 1 r
.02 w
.31211 .93289 m
.15214 .98487 L
s
P
p
.2 0 1 r
.02 w
.3855 .98621 m
.3855 1.15441 L
s
P
p
.2 0 1 r
.02 w
.3855 .98621 m
.48437 1.12229 L
s
P
p
0 .4 1 r
.018 w
.36818 .93289 m
.31211 .93289 L
s
P
p
0 .4 1 r
.018 w
.36818 .93289 m
.3855 .98621 L
s
P
p
.2 0 1 r
.016 w
.5 .75145 m
.63182 .93289 L
s
P
p
.2 0 1 r
.016 w
.5 .75145 m
.4307 .53816 L
s
P
p
.2 0 1 r
.016 w
.5 .75145 m
.5 .97572 L
s
P
p
.2 0 1 r
.016 w
.5 .75145 m
.5693 .53816 L
s
P
p
.2 0 1 r
.016 w
.5 .75145 m
.36818 .93289 L
s
P
p
.2 0 1 r
.02 w
.27525 .29009 m
.32723 .13012 L
s
P
p
.2 0 1 r
.02 w
.27525 .29009 m
.22327 .13012 L
s
P
p
.2 0 1 r
.02 w
.22193 .36348 m
.05373 .36348 L
s
P
p
.2 0 1 r
.02 w
.22193 .36348 m
.08585 .46235 L
s
P
p
0 .4 1 r
.018 w
.27525 .34616 m
.27525 .29009 L
s
P
p
0 .4 1 r
.018 w
.27525 .34616 m
.22193 .36348 L
s
P
p
.2 0 1 r
.02 w
.57118 .71274 m
.47232 .84881 L
s
P
p
.2 0 1 r
.02 w
.57118 .71274 m
.57118 .88094 L
s
P
p
.2 0 1 r
.02 w
.64457 .65941 m
.80454 .71139 L
s
P
p
.2 0 1 r
.02 w
.64457 .65941 m
.80454 .60744 L
s
P
p
0 .4 1 r
.018 w
.58851 .65941 m
.57118 .71274 L
s
P
p
0 .4 1 r
.018 w
.58851 .65941 m
.64457 .65941 L
s
P
p
.2 0 1 r
.02 w
.42034 .21933 m
.55642 .12046 L
s
P
p
.2 0 1 r
.02 w
.42034 .21933 m
.47232 .05936 L
s
P
p
.2 0 1 r
.02 w
.33406 .24736 m
.19798 .14849 L
s
P
p
.2 0 1 r
.02 w
.33406 .24736 m
.16586 .24736 L
s
P
p
0 .4 1 r
.018 w
.38738 .26469 m
.42034 .21933 L
s
P
p
0 .4 1 r
.018 w
.38738 .26469 m
.33406 .24736 L
s
P
p
.2 0 1 r
.02 w
.41133 .7352 m
.25136 .78718 L
s
P
p
.2 0 1 r
.02 w
.41133 .7352 m
.31246 .87128 L
s
P
p
.2 0 1 r
.02 w
.50205 .7352 m
.60091 .87128 L
s
P
p
.2 0 1 r
.02 w
.50205 .7352 m
.66201 .78718 L
s
P
p
0 .4 1 r
.018 w
.45669 .70225 m
.41133 .7352 L
s
P
p
0 .4 1 r
.018 w
.45669 .70225 m
.50205 .7352 L
s
P
p
.2 0 1 r
.02 w
.57931 .24736 m
.74751 .24736 L
s
P
p
.2 0 1 r
.02 w
.57931 .24736 m
.71539 .14849 L
s
P
p
.2 0 1 r
.02 w
.49303 .21933 m
.44106 .05936 L
s
P
p
.2 0 1 r
.02 w
.49303 .21933 m
.35696 .12046 L
s
P
p
0 .4 1 r
.018 w
.52599 .26469 m
.57931 .24736 L
s
P
p
0 .4 1 r
.018 w
.52599 .26469 m
.49303 .21933 L
s
P
p
.2 0 1 r
.016 w
.45669 .47798 m
.27525 .34616 L
s
P
p
.2 0 1 r
.016 w
.45669 .47798 m
.58851 .65941 L
s
P
p
.2 0 1 r
.016 w
.45669 .47798 m
.38738 .26469 L
s
P
p
.2 0 1 r
.016 w
.45669 .47798 m
.45669 .70225 L
s
P
p
.2 0 1 r
.016 w
.45669 .47798 m
.52599 .26469 L
s
P
p
1 .6 0 r
.016 w
.5 .61128 m
.54331 .47798 L
s
P
p
1 .6 0 r
.016 w
.5 .61128 m
.5 .75145 L
s
P
p
1 .6 0 r
.016 w
.5 .61128 m
.45669 .47798 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{152, 184},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002H0000^0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP0009P0002H0000V00009P0002H0000V00009P0
002H0000@@03C0800d`500=<0P03C480001100==0P03C@D00dd200==@P0004400d`200=<1@03C080
0da20000@@08C@D024e20000@@08C0D024a20000@P06C@L01Te30000@P06C0L01Ta30000@P06C@L0
1Te30000@`04C0T014a40000@`04C@T014e40000=004C0T01T`900I<2@04C3D0000P00==3@03C@03
04e=00==2006C@T01Td800E=00@0CDe=3@03CB40000P00=<3@03C00304a<00E<1P07C0L01d`600M<
00@0C4a<3@03C240000P00A=2`04C@<01Td600M=1@07C@H01Td300A=2`04CB40000L00Q<1P04C003
04a<009<1006C0D024`300Q<1@06C0@014`00`1<C002C0H024`M00007008C@H024d700I=0P0EC@80
1Td700Q=1P08CAd0000L00U<1@08C0P01T`00`1<C00CC00304a<00A<2008C0D02D`M00007P07C@L0
1Td900U=0P0;C@802Dd900I=1`07CAl0000O00I<2006C0X01d`200]<0P07C0X01T`800I<80000240
1Td600M=2P06C@802dd200I=2P07C@H01TdR00008P06C0D02D`:00Y<0`0:C0X02D`500I<8`0002<0
1dd300==00<0CDd014d800a=00<0CDd02Td800I=00@0CDe=0`07CB@0000S00Q<00<0C4`00T`200I<
1`0<C00304a<00Y<1`06C08014`00`1<C006C2@0000S00e=1006C@D034d00`1=C@0:C@D01Td400e=
900002@00d`00`1<C005C0H01T`301]<0`06C0H01d`0101<C4`U00009004C@0304e=00A=1`06C@80
1Dd400U=1005C@801Td700I=00<0CDd00TdU00009004C0801d`700I<0/H2C0H000E<a/I<aP02C0H0
00=<a/H01d`700M<0P04C2D0000U00==0`07C@L01Dd2aP03C@0000H00/H00dg6C@0800;61Td700M=
0`03CBH0000U00A<00<0C4`01d`700=<0lH900C62@000lI<C004C0L02D`00`1<C002C2H0000H02A=
0lH2C@P01<H902U=6@0001P06D`4aPI<1lH600K61P04aRM<6@0001P06Dd8aP05CLK6aTd02<H01036
a/H200?600<0a/H01/HWCAT0000V00M<1`05aP9<00?600000`05aP9<00?600000P000lI<C005aPD0
00?6C4`01LH800M<9`0002L01Dd<0003aTe=00X000?6CDd01P02C@03aP0000P00Td00lH0000;00E=
:00002L01D`=009<2`03C0@00d`;009<3P05C2P0000W00E=3@03C@/00Td4009=2`03C@h01DdX0000
:002aP03C00000d00T`;009<1002C0/00T`@00;600=<00009`0002P00/H00dd0000=009=2`03C@80
0dd;009=4002aP03C@0002L0000X00;64003C0/00T`2009<2`03C1000/HZ0000:002aQ400Td;009=
0P02C@/00TdA00;6:P0002P00/HA009<2`06C0/00T`A00;6:P0002P00/HA00==2`04C@/00ddA00;6
:P0002P00/HB009<2P07C0T00T`B00;6:P0002P00/HB009=2P07C@T00TdB00;6:P0002P00/HB009<
2P07C0T00T`B00;6:P0002H00/H3CA400dd900M=2003CA400dd2aRP0000701]<1/H4C1400T`900M<
2002C14014`6aQa<200000L06Dd7aP<00dd@009=2P05C@T00Td@00==0`07aQY=200000L06D`3aPP0
14`>00=<2@05C0P00d`>00A<2003aQY<200001/01Td;00A=3P02C@P01Td8009=3P04C@`01TdL0000
6P06C0h00d`=009<2006C0P00T`=00=<3`06C1/0000I00I=4004C@P01Td700I=1`07C@L014dA00I=
6P0001L01T`C00A<1`06C0H024`600M<1P04C1@01T`H00005P06CAH00dd600I=1P08C@H01dd500==
5`06CAL0000E00I<6004C0H01T`400Q<1@06C0D014`I00I<5P0001<01Td:00A=3@04C@H01Td200Y=
0`06C@D014d>00A=2P06CA@0000B00I<2`05C0h014`500I<00<0C4`024`200I<1004C0l01D`;00I<
4`0001401Td<00M=3@04C@D02dd00`1=C@08C@D014d>00M=3006CA80000?00I<4006C0h00d`400]<
00<0C4`024`400=<3`06C1001T`@00003P06CA801Td>00A=0`0:C@0304e=00M=0`04C@l01TdB00I=
3`0000d01T`E00I<3@04C0800T`200I<00<0C4`014`00`1<C00200A<3P06C1D01T`>00003005CAP0
1Td>00==00<0CDd04Td0101=CDd?00I=6005C@d0000<00A<6P07C0d06T`>00M<6P04C0d0000<00==
7@06C@d064d>00I=7@03C@d0000]00I<3P0DC0l01T`^0000;`06C@d000==4A4034d24@03C@0000`0
1Td`0000<006C0d00Q45C0<014`24@h01T`a0000<@07C@/00a400lI=C@050003CLHA008A3007CC80
000c00I<2P000d`A4@02C0L000C64A5<2`06C3@0000d00I=2@000ddA4@02C@H000E=aQ4AC@0:00I=
=@0001h07D`80005C14A4D`01P001D`A4A7600T07D`O00007P0JC@?61`000lI=C@024@9=1002C@8A
0lH700?66ddO00007P0JC0K610000lI<C0024@=<0P03C08A00=<a/H01006aQ]<7`0003X02LH2C@<A
1Td34@03CLK600S6?00003d00lH2C004aTa<008A00<0C4`00T`0100A4@02C003aTa<00?6?`000400
0Td0101=C@024@0304e=009=00@04A400Td00`1=C@120000@002C00404a<00<A14`34@0404a<009<
@P0004001Dd2008A14d24@801De20000@@04C0800Q4014`004`24@8014a30000@@04C@800a4200<A
0P04CD<0001100A<00<0C4`00Q42008A0T`00`1<C002C4<0001200==00<0CDd00Q42008A0Td0101=
CDe40000@P06C0HA1Ta400007005CB401Dd200@A0P05CB<014dM00007008C1l00d`300@A0`03C240
1d`M0000700;CA`00Td400@A1002CAh02TdM00007`0;C1P014`4008A1004C1X02d`O00008P0;CA@0
1Dd4008A1005CAH02ddR00009@0;C1001T`4008A1006C1802d`U0000:00;C@d00Td00`1=C@02C@<0
0Q4300A=00<0CDd03`0;CBP0000[00]<2@03C00304a<009<0`024@<014`0101<C4`;00]<:`0002h0
2Dd700==0P04C@<00Q4300A=0P03C@P02Td^0000<004C0W60d`300A<0`024@<014`300=<2LH6C300
000]00M=2LH2C@@01Dd2008A0P05C@@00Td9aPU=;@0002X02d`800;61002C00304a<00800Q42009<
00<0C4`01002aPX02d`Z00009`0;C@/00lH3009=00<0CDd00P024@800Td00`1=C@0300?63@0;CBL0
000T00]<3`02aP<00T`01@1<C4`0008A00D0C4a<0002C0<00/HA00]<900002402ddB00;60`02C@80
0Td0100A4@02C@800Td300;6500;CB40000N00]<5@02aP8000G6C4c60002C004014A009<00D0aTa<
aP0200;65`0;C1h0000L00Y=6005aP9=0/H3C@8A0dd2aP9=1LHJ00U=7@0001`01d`L00C60P04aP03
C14A009<0lH200C600=<00006`06C1d0000L00A=7`03aP04C@0000C60Q42C@;6100014g6aTdP00==
7@0003`00T`3aP=<1002aP8A0d`400U<?00003T014d3aPE=00D0CDe=aP024@a=00?6CDd014di0000
=P07C0;62d`24@a<00?6C4`01d`f0000<`0GC@8A6Ddc0000<00JC08A74``0000;@0;C@8044d24A9=
0P0;CBd0000Z00]<0P0;C0803d`200a<0P0;C2X0000W00]=0P0>C@<03Dd300==00<0CDd02Dd200]=
9`0002D02T`300Y<0`03C0<03D`300=<0`0:C0@02D`V00009@07C@H02Dd400==0P0?C@800dd400U=
1`06CBH0000U00A<2@09C0@00d`00`1<C00?C00404a<C0@01D`0101<C4`:00=<9P0003D01Dd501U=
1@05CCH0000e00A<1P08C00304a<00i<1P04C3H0000d00A=1`07C@<01Dd200Q=1`04CCD0000c00E<
1`07C0<01D`200Q<1`05C3@0000c00A=2006C@<01dd200M=2004CC@0000b00A<2@05C0<02D`200I<
2@04C3<0000a00E=2005C@<02dd200I=2005CC80000`00E<2006C0<01T`00`1<C002C0801d`800E<
<@00030014d900E=1003C@0304e=00800dd300I=2@04CC40000_00A<2@06C0P00T`900I<2@04C300
000^00E=2007C@P00Td900M=2005CBl0000F00E<4`04C0T01d`8009<2@07C0T014`D00A<5`0001H0
24d@00==2P07C@P00Td900M=2P03CA401ddG00005P0;C1/00T`0101<C4`8009<2@05C1d02T`G0000
6@0;CAL00dd<009=3003CAT02ddI0000700;C1<00d`=009<3@03C1D02d`L00007`0;C@l00dd>009=
3P03CA402ddO00008P0;C0`00T`?009<3`02C0h02d`R00009@0;C@P00dd?009=3`03C@X02ddU0000
:009C0H00d`@009<4003C0L02T`X0000:P04C@S60ddA009=4@03C@S61TdZ00009`07C0S60T`B009<
4P02C0S62D`W0000900;C@L00lHA009=4@03aPT02ddT00008@0;C0/00/HA009<4@02aPd02d`Q0000
7P0;C@h00/HA009=4@02aQ002ddN00006`0;C1400lH@009<4003aQ<02d`K0000600;CAD00/H@009=
4002aQL02ddH00005P0:C1P00/H2C0d000C6C4c63P000dc6aP0J00U<5`0001H01ddK00?600==0000
2P02aP9=0/H=00?67@06CAL0000F00A<7`02aP9<2@04aP801<H:0004C<K6C2000d`G0000>@05C@L0
1<H400C62005CCX0000i00I<0P03C0?62003aPA<0P06C3X0000i00Y=0lH:00?62ddj0000>@0:C0;6
00=<00002@02aP]<>P0003L03dd;00m=>00003@04D`=015<=@00030034d200I=3`06C@8034da0000
;@0?C0801D`A00E<0P0?C2h0000[00]=0`03C@801Td?00I=0P03C@<02dd/0000:`07C0L00d`00`1<
C005C0l01d`0101<C4`700M<;00002/014d:00==00<0CDd01Td=00Q=00@0CDe=2P04CB`0000i00M<
00<0C4`00d`;00E<00<0C4`01D`j0000>@07C@8014d;00A=0P07CCX0000i00I<1004C0T014`400I<
>P0003T01Dd500E=1`05C@D01Ddj0000>@04C0L01D`500E<1`04C3X0000h00E=2004C@D014d800E=
>@0003L01D`:00A<0`04C0X01D`h0000=`05C@X01Dd00`1=C@03C@X01Ddh0000=P06C0/014`00`1<
C002C0/01T`g0000=@07C@`00dd0101=CDd<00M==P0003@024`O00Q<=@0003@014d0101=CDdO00==
00<0CDd00Tde0000=003C0800d`O00=<0P03C3D0000i00==7`03CCX0000i00=<7`03C3X0002H0000
V00009P0002H0000V00009P0002H0000\
\>"],
  ImageRangeCache->{{{0, 151}, {183, 0}} -> {0.0667993, -0.0250053, 
  0.00573777, 0.00573777}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.016 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.016 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.016 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.016 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.016 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.016 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.016 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.016 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.016 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.016 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.016 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.016 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.016 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.016 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.016 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.016 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.016 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.016 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.016 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.016 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.016 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.016 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.016 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.016 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.016 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.016 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.016 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.016 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.016 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.016 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 1 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 1 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 1 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 1 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 1 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 1 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 1 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 1 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 1 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 1 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 1 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 1 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 1 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 1 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 1 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 1 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 1 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 1 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 1 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 1 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 1 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 1 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 1 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 1 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 1 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 1 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 1 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 1 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 1 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 1 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0195479 0.952381 [
[ 0 0 0 0 ]
[ 1 .91329 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .91329 L
0 .91329 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49284 .71912 m
.39116 .85906 L
s
P
p
.2 0 1 r
.02 w
.58157 .69029 m
.74608 .74374 L
s
P
p
0 .4 1 r
.018 w
.52673 .67247 m
.49284 .71912 L
s
P
p
0 .4 1 r
.018 w
.52673 .67247 m
.58157 .69029 L
s
P
p
.2 0 1 r
.02 w
.5021 .18858 m
.64205 .08691 L
s
P
p
.2 0 1 r
.02 w
.40881 .18858 m
.26886 .08691 L
s
P
p
0 .4 1 r
.018 w
.45545 .22247 m
.5021 .18858 L
s
P
p
0 .4 1 r
.018 w
.45545 .22247 m
.40881 .18858 L
s
P
p
.2 0 1 r
.02 w
.32934 .69029 m
.16483 .74374 L
s
P
p
.2 0 1 r
.02 w
.41807 .71912 m
.51975 .85906 L
s
P
p
0 .4 1 r
.018 w
.38418 .67247 m
.32934 .69029 L
s
P
p
0 .4 1 r
.018 w
.38418 .67247 m
.41807 .71912 L
s
P
p
.2 0 1 r
.02 w
.64868 .26652 m
.82166 .26652 L
s
P
p
.2 0 1 r
.02 w
.5732 .21168 m
.51975 .04717 L
s
P
p
0 .4 1 r
.018 w
.59102 .26652 m
.64868 .26652 L
s
P
p
0 .4 1 r
.018 w
.59102 .26652 m
.5732 .21168 L
s
P
p
.2 0 1 r
.02 w
.21402 .57086 m
.04951 .51741 L
s
P
p
.2 0 1 r
.02 w
.26886 .64634 m
.26886 .81932 L
s
P
p
0 .4 1 r
.018 w
.26886 .58868 m
.21402 .57086 L
s
P
p
0 .4 1 r
.018 w
.26886 .58868 m
.26886 .64634 L
s
P
p
.2 0 1 r
.016 w
.45545 .45311 m
.52673 .67247 L
s
P
p
.2 0 1 r
.016 w
.45545 .45311 m
.45545 .22247 L
s
P
p
.2 0 1 r
.016 w
.45545 .45311 m
.38418 .67247 L
s
P
p
.2 0 1 r
.016 w
.45545 .45311 m
.59102 .26652 L
s
P
p
.2 0 1 r
.016 w
.45545 .45311 m
.26886 .58868 L
s
P
p
.2 0 1 r
.02 w
.61775 .7016 m
.5643 .86612 L
s
P
p
.2 0 1 r
.02 w
.69323 .64676 m
.86621 .64676 L
s
P
p
0 .4 1 r
.018 w
.63557 .64676 m
.61775 .7016 L
s
P
p
0 .4 1 r
.018 w
.63557 .64676 m
.69323 .64676 L
s
P
p
.2 0 1 r
.02 w
.46262 .19417 m
.5643 .05422 L
s
P
p
.2 0 1 r
.02 w
.37389 .223 m
.20937 .16954 L
s
P
p
0 .4 1 r
.018 w
.42873 .24082 m
.46262 .19417 L
s
P
p
0 .4 1 r
.018 w
.42873 .24082 m
.37389 .223 L
s
P
p
.2 0 1 r
.02 w
.45335 .7247 m
.31341 .82638 L
s
P
p
.2 0 1 r
.02 w
.54665 .7247 m
.68659 .82638 L
s
P
p
0 .4 1 r
.018 w
.5 .69081 m
.45335 .7247 L
s
P
p
0 .4 1 r
.018 w
.5 .69081 m
.54665 .7247 L
s
P
p
.2 0 1 r
.02 w
.62611 .223 m
.79063 .16954 L
s
P
p
.2 0 1 r
.02 w
.53738 .19417 m
.4357 .05422 L
s
P
p
0 .4 1 r
.018 w
.57127 .24082 m
.62611 .223 L
s
P
p
0 .4 1 r
.018 w
.57127 .24082 m
.53738 .19417 L
s
P
p
.2 0 1 r
.02 w
.30677 .64676 m
.13379 .64676 L
s
P
p
.2 0 1 r
.02 w
.38225 .7016 m
.4357 .86612 L
s
P
p
0 .4 1 r
.018 w
.36443 .64676 m
.30677 .64676 L
s
P
p
0 .4 1 r
.018 w
.36443 .64676 m
.38225 .7016 L
s
P
p
.2 0 1 r
.016 w
.5 .46017 m
.63557 .64676 L
s
P
p
.2 0 1 r
.016 w
.5 .46017 m
.42873 .24082 L
s
P
p
.2 0 1 r
.016 w
.5 .46017 m
.5 .69081 L
s
P
p
.2 0 1 r
.016 w
.5 .46017 m
.57127 .24082 L
s
P
p
.2 0 1 r
.016 w
.5 .46017 m
.36443 .64676 L
s
P
p
.2 0 1 r
.02 w
.73114 .64634 m
.73114 .81932 L
s
P
p
.2 0 1 r
.02 w
.78598 .57086 m
.95049 .51741 L
s
P
p
0 .4 1 r
.018 w
.73114 .58868 m
.73114 .64634 L
s
P
p
0 .4 1 r
.018 w
.73114 .58868 m
.78598 .57086 L
s
P
p
.2 0 1 r
.02 w
.4268 .21168 m
.48025 .04717 L
s
P
p
.2 0 1 r
.02 w
.35132 .26652 m
.17834 .26652 L
s
P
p
0 .4 1 r
.018 w
.40898 .26652 m
.4268 .21168 L
s
P
p
0 .4 1 r
.018 w
.40898 .26652 m
.35132 .26652 L
s
P
p
.2 0 1 r
.02 w
.58193 .71912 m
.48025 .85906 L
s
P
p
.2 0 1 r
.02 w
.67066 .69029 m
.83517 .74374 L
s
P
p
0 .4 1 r
.018 w
.61582 .67247 m
.58193 .71912 L
s
P
p
0 .4 1 r
.018 w
.61582 .67247 m
.67066 .69029 L
s
P
p
.2 0 1 r
.02 w
.59119 .18858 m
.73114 .08691 L
s
P
p
.2 0 1 r
.02 w
.4979 .18858 m
.35795 .08691 L
s
P
p
0 .4 1 r
.018 w
.54455 .22247 m
.59119 .18858 L
s
P
p
0 .4 1 r
.018 w
.54455 .22247 m
.4979 .18858 L
s
P
p
.2 0 1 r
.02 w
.41843 .69029 m
.25392 .74374 L
s
P
p
.2 0 1 r
.02 w
.50716 .71912 m
.60884 .85906 L
s
P
p
0 .4 1 r
.018 w
.47327 .67247 m
.41843 .69029 L
s
P
p
0 .4 1 r
.018 w
.47327 .67247 m
.50716 .71912 L
s
P
p
.2 0 1 r
.016 w
.54455 .45311 m
.73114 .58868 L
s
P
p
.2 0 1 r
.016 w
.54455 .45311 m
.40898 .26652 L
s
P
p
.2 0 1 r
.016 w
.54455 .45311 m
.61582 .67247 L
s
P
p
.2 0 1 r
.016 w
.54455 .45311 m
.54455 .22247 L
s
P
p
.2 0 1 r
.016 w
.54455 .45311 m
.47327 .67247 L
s
P
p
1 .6 0 r
.016 w
.5 .31602 m
.45545 .45311 L
s
P
p
1 .6 0 r
.016 w
.5 .31602 m
.5 .46017 L
s
P
p
1 .6 0 r
.016 w
.5 .31602 m
.54455 .45311 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0181222 0.952381 [
[ 0 0 0 0 ]
[ 1 .91614 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .91614 L
0 .91614 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49293 .71693 m
.3723 .83756 L
s
P
p
.2 0 1 r
.02 w
.49293 .71693 m
.41548 .86893 L
s
P
p
.2 0 1 r
.02 w
.58044 .68849 m
.73245 .76594 L
s
P
p
.2 0 1 r
.02 w
.58044 .68849 m
.74894 .71518 L
s
P
p
0 .4 1 r
.018 w
.52636 .67092 m
.49293 .71693 L
s
P
p
0 .4 1 r
.018 w
.52636 .67092 m
.58044 .68849 L
s
P
p
.2 0 1 r
.02 w
.50207 .1937 m
.65408 .11625 L
s
P
p
.2 0 1 r
.02 w
.50207 .1937 m
.6227 .07307 L
s
P
p
.2 0 1 r
.02 w
.41006 .1937 m
.28943 .07307 L
s
P
p
.2 0 1 r
.02 w
.41006 .1937 m
.25806 .11625 L
s
P
p
0 .4 1 r
.018 w
.45607 .22713 m
.50207 .1937 L
s
P
p
0 .4 1 r
.018 w
.45607 .22713 m
.41006 .1937 L
s
P
p
.2 0 1 r
.02 w
.3317 .68849 m
.1632 .71518 L
s
P
p
.2 0 1 r
.02 w
.3317 .68849 m
.17969 .76594 L
s
P
p
.2 0 1 r
.02 w
.4192 .71693 m
.49665 .86893 L
s
P
p
.2 0 1 r
.02 w
.4192 .71693 m
.53983 .83756 L
s
P
p
0 .4 1 r
.018 w
.38578 .67092 m
.3317 .68849 L
s
P
p
0 .4 1 r
.018 w
.38578 .67092 m
.4192 .71693 L
s
P
p
.2 0 1 r
.02 w
.64663 .27057 m
.81513 .29725 L
s
P
p
.2 0 1 r
.02 w
.64663 .27057 m
.81513 .24388 L
s
P
p
.2 0 1 r
.02 w
.5722 .21648 m
.54551 .04799 L
s
P
p
.2 0 1 r
.02 w
.5722 .21648 m
.49475 .06448 L
s
P
p
0 .4 1 r
.018 w
.58977 .27057 m
.64663 .27057 L
s
P
p
0 .4 1 r
.018 w
.58977 .27057 m
.5722 .21648 L
s
P
p
.2 0 1 r
.02 w
.21796 .57072 m
.06596 .49327 L
s
P
p
.2 0 1 r
.02 w
.21796 .57072 m
.04947 .54403 L
s
P
p
.2 0 1 r
.02 w
.27205 .64515 m
.24536 .81365 L
s
P
p
.2 0 1 r
.02 w
.27205 .64515 m
.29873 .81365 L
s
P
p
0 .4 1 r
.018 w
.27205 .58829 m
.21796 .57072 L
s
P
p
0 .4 1 r
.018 w
.27205 .58829 m
.27205 .64515 L
s
P
p
.2 0 1 r
.016 w
.45607 .45459 m
.52636 .67092 L
s
P
p
.2 0 1 r
.016 w
.45607 .45459 m
.45607 .22713 L
s
P
p
.2 0 1 r
.016 w
.45607 .45459 m
.38578 .67092 L
s
P
p
.2 0 1 r
.016 w
.45607 .45459 m
.58977 .27057 L
s
P
p
.2 0 1 r
.016 w
.45607 .45459 m
.27205 .58829 L
s
P
p
.2 0 1 r
.02 w
.61613 .69965 m
.53868 .85166 L
s
P
p
.2 0 1 r
.02 w
.61613 .69965 m
.58944 .86815 L
s
P
p
.2 0 1 r
.02 w
.69057 .64557 m
.85906 .67226 L
s
P
p
.2 0 1 r
.02 w
.69057 .64557 m
.85906 .61888 L
s
P
p
0 .4 1 r
.018 w
.6337 .64557 m
.61613 .69965 L
s
P
p
0 .4 1 r
.018 w
.6337 .64557 m
.69057 .64557 L
s
P
p
.2 0 1 r
.02 w
.46313 .19921 m
.58377 .07858 L
s
P
p
.2 0 1 r
.02 w
.46313 .19921 m
.54058 .04721 L
s
P
p
.2 0 1 r
.02 w
.37563 .22764 m
.22362 .15019 L
s
P
p
.2 0 1 r
.02 w
.37563 .22764 m
.20713 .20096 L
s
P
p
0 .4 1 r
.018 w
.42971 .24522 m
.46313 .19921 L
s
P
p
0 .4 1 r
.018 w
.42971 .24522 m
.37563 .22764 L
s
P
p
.2 0 1 r
.02 w
.45399 .72244 m
.30199 .79989 L
s
P
p
.2 0 1 r
.02 w
.45399 .72244 m
.33336 .84307 L
s
P
p
.2 0 1 r
.02 w
.54601 .72244 m
.66664 .84307 L
s
P
p
.2 0 1 r
.02 w
.54601 .72244 m
.69801 .79989 L
s
P
p
0 .4 1 r
.018 w
.5 .68901 m
.45399 .72244 L
s
P
p
0 .4 1 r
.018 w
.5 .68901 m
.54601 .72244 L
s
P
p
.2 0 1 r
.02 w
.62437 .22764 m
.79287 .20096 L
s
P
p
.2 0 1 r
.02 w
.62437 .22764 m
.77638 .15019 L
s
P
p
.2 0 1 r
.02 w
.53687 .19921 m
.45942 .04721 L
s
P
p
.2 0 1 r
.02 w
.53687 .19921 m
.41623 .07858 L
s
P
p
0 .4 1 r
.018 w
.57029 .24522 m
.62437 .22764 L
s
P
p
0 .4 1 r
.018 w
.57029 .24522 m
.53687 .19921 L
s
P
p
.2 0 1 r
.02 w
.30943 .64557 m
.14094 .61888 L
s
P
p
.2 0 1 r
.02 w
.30943 .64557 m
.14094 .67226 L
s
P
p
.2 0 1 r
.02 w
.38387 .69965 m
.41056 .86815 L
s
P
p
.2 0 1 r
.02 w
.38387 .69965 m
.46132 .85166 L
s
P
p
0 .4 1 r
.018 w
.3663 .64557 m
.30943 .64557 L
s
P
p
0 .4 1 r
.018 w
.3663 .64557 m
.38387 .69965 L
s
P
p
.2 0 1 r
.016 w
.5 .46155 m
.6337 .64557 L
s
P
p
.2 0 1 r
.016 w
.5 .46155 m
.42971 .24522 L
s
P
p
.2 0 1 r
.016 w
.5 .46155 m
.5 .68901 L
s
P
p
.2 0 1 r
.016 w
.5 .46155 m
.57029 .24522 L
s
P
p
.2 0 1 r
.016 w
.5 .46155 m
.3663 .64557 L
s
P
p
.2 0 1 r
.02 w
.72795 .64515 m
.70127 .81365 L
s
P
p
.2 0 1 r
.02 w
.72795 .64515 m
.75464 .81365 L
s
P
p
.2 0 1 r
.02 w
.78204 .57072 m
.95053 .54403 L
s
P
p
.2 0 1 r
.02 w
.78204 .57072 m
.93404 .49327 L
s
P
p
0 .4 1 r
.018 w
.72795 .58829 m
.72795 .64515 L
s
P
p
0 .4 1 r
.018 w
.72795 .58829 m
.78204 .57072 L
s
P
p
.2 0 1 r
.02 w
.4278 .21648 m
.50525 .06448 L
s
P
p
.2 0 1 r
.02 w
.4278 .21648 m
.45449 .04799 L
s
P
p
.2 0 1 r
.02 w
.35337 .27057 m
.18487 .24388 L
s
P
p
.2 0 1 r
.02 w
.35337 .27057 m
.18487 .29725 L
s
P
p
0 .4 1 r
.018 w
.41023 .27057 m
.4278 .21648 L
s
P
p
0 .4 1 r
.018 w
.41023 .27057 m
.35337 .27057 L
s
P
p
.2 0 1 r
.02 w
.5808 .71693 m
.46017 .83756 L
s
P
p
.2 0 1 r
.02 w
.5808 .71693 m
.50335 .86893 L
s
P
p
.2 0 1 r
.02 w
.6683 .68849 m
.82031 .76594 L
s
P
p
.2 0 1 r
.02 w
.6683 .68849 m
.8368 .71518 L
s
P
p
0 .4 1 r
.018 w
.61422 .67092 m
.5808 .71693 L
s
P
p
0 .4 1 r
.018 w
.61422 .67092 m
.6683 .68849 L
s
P
p
.2 0 1 r
.02 w
.58994 .1937 m
.74194 .11625 L
s
P
p
.2 0 1 r
.02 w
.58994 .1937 m
.71057 .07307 L
s
P
p
.2 0 1 r
.02 w
.49793 .1937 m
.3773 .07307 L
s
P
p
.2 0 1 r
.02 w
.49793 .1937 m
.34592 .11625 L
s
P
p
0 .4 1 r
.018 w
.54393 .22713 m
.58994 .1937 L
s
P
p
0 .4 1 r
.018 w
.54393 .22713 m
.49793 .1937 L
s
P
p
.2 0 1 r
.02 w
.41956 .68849 m
.25106 .71518 L
s
P
p
.2 0 1 r
.02 w
.41956 .68849 m
.26755 .76594 L
s
P
p
.2 0 1 r
.02 w
.50707 .71693 m
.58452 .86893 L
s
P
p
.2 0 1 r
.02 w
.50707 .71693 m
.6277 .83756 L
s
P
p
0 .4 1 r
.018 w
.47364 .67092 m
.41956 .68849 L
s
P
p
0 .4 1 r
.018 w
.47364 .67092 m
.50707 .71693 L
s
P
p
.2 0 1 r
.016 w
.54393 .45459 m
.72795 .58829 L
s
P
p
.2 0 1 r
.016 w
.54393 .45459 m
.41023 .27057 L
s
P
p
.2 0 1 r
.016 w
.54393 .45459 m
.61422 .67092 L
s
P
p
.2 0 1 r
.016 w
.54393 .45459 m
.54393 .22713 L
s
P
p
.2 0 1 r
.016 w
.54393 .45459 m
.47364 .67092 L
s
P
p
1 .6 0 r
.016 w
.5 .31938 m
.45607 .45459 L
s
P
p
1 .6 0 r
.016 w
.5 .31938 m
.5 .46155 L
s
P
p
1 .6 0 r
.016 w
.5 .31938 m
.54393 .45459 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00877678 0.952381 [
[ 0 0 0 0 ]
[ 1 .93483 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93483 L
0 .93483 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49338 .70994 m
.34252 .81955 L
s
P
p
.2 0 1 r
.02 w
.49338 .70994 m
.43576 .88729 L
s
P
p
.2 0 1 r
.02 w
.57537 .6833 m
.72623 .79291 L
s
P
p
.2 0 1 r
.02 w
.57537 .6833 m
.76184 .6833 L
s
P
p
0 .4 1 r
.018 w
.5247 .66684 m
.49338 .70994 L
s
P
p
0 .4 1 r
.018 w
.5247 .66684 m
.57537 .6833 L
s
P
p
.2 0 1 r
.02 w
.50194 .21972 m
.67929 .1621 L
s
P
p
.2 0 1 r
.02 w
.50194 .21972 m
.61155 .06886 L
s
P
p
.2 0 1 r
.02 w
.41574 .21972 m
.30613 .06886 L
s
P
p
.2 0 1 r
.02 w
.41574 .21972 m
.23839 .1621 L
s
P
p
0 .4 1 r
.018 w
.45884 .25104 m
.50194 .21972 L
s
P
p
0 .4 1 r
.018 w
.45884 .25104 m
.41574 .21972 L
s
P
p
.2 0 1 r
.02 w
.34231 .6833 m
.15584 .6833 L
s
P
p
.2 0 1 r
.02 w
.34231 .6833 m
.19145 .79291 L
s
P
p
.2 0 1 r
.02 w
.4243 .70994 m
.48192 .88729 L
s
P
p
.2 0 1 r
.02 w
.4243 .70994 m
.57516 .81955 L
s
P
p
0 .4 1 r
.018 w
.39298 .66684 m
.34231 .6833 L
s
P
p
0 .4 1 r
.018 w
.39298 .66684 m
.4243 .70994 L
s
P
p
.2 0 1 r
.02 w
.63739 .29174 m
.81473 .34936 L
s
P
p
.2 0 1 r
.02 w
.63739 .29174 m
.81473 .23412 L
s
P
p
.2 0 1 r
.02 w
.56764 .24107 m
.56764 .05459 L
s
P
p
.2 0 1 r
.02 w
.56764 .24107 m
.45803 .09021 L
s
P
p
0 .4 1 r
.018 w
.58411 .29174 m
.63739 .29174 L
s
P
p
0 .4 1 r
.018 w
.58411 .29174 m
.56764 .24107 L
s
P
p
.2 0 1 r
.02 w
.23575 .57296 m
.08489 .46335 L
s
P
p
.2 0 1 r
.02 w
.23575 .57296 m
.04928 .57296 L
s
P
p
.2 0 1 r
.02 w
.28643 .6427 m
.2288 .82005 L
s
P
p
.2 0 1 r
.02 w
.28643 .6427 m
.34405 .82005 L
s
P
p
0 .4 1 r
.018 w
.28643 .58942 m
.23575 .57296 L
s
P
p
0 .4 1 r
.018 w
.28643 .58942 m
.28643 .6427 L
s
P
p
.2 0 1 r
.016 w
.45884 .46415 m
.5247 .66684 L
s
P
p
.2 0 1 r
.016 w
.45884 .46415 m
.45884 .25104 L
s
P
p
.2 0 1 r
.016 w
.45884 .46415 m
.39298 .66684 L
s
P
p
.2 0 1 r
.016 w
.45884 .46415 m
.58411 .29174 L
s
P
p
.2 0 1 r
.016 w
.45884 .46415 m
.28643 .58942 L
s
P
p
.2 0 1 r
.02 w
.6088 .69376 m
.49919 .84462 L
s
P
p
.2 0 1 r
.02 w
.6088 .69376 m
.6088 .88024 L
s
P
p
.2 0 1 r
.02 w
.67855 .64309 m
.8559 .70071 L
s
P
p
.2 0 1 r
.02 w
.67855 .64309 m
.8559 .58546 L
s
P
p
0 .4 1 r
.018 w
.62527 .64309 m
.6088 .69376 L
s
P
p
0 .4 1 r
.018 w
.62527 .64309 m
.67855 .64309 L
s
P
p
.2 0 1 r
.02 w
.46546 .22488 m
.61632 .11528 L
s
P
p
.2 0 1 r
.02 w
.46546 .22488 m
.52308 .04753 L
s
P
p
.2 0 1 r
.02 w
.38347 .25152 m
.23261 .14192 L
s
P
p
.2 0 1 r
.02 w
.38347 .25152 m
.197 .25152 L
s
P
p
0 .4 1 r
.018 w
.43414 .26799 m
.46546 .22488 L
s
P
p
0 .4 1 r
.018 w
.43414 .26799 m
.38347 .25152 L
s
P
p
.2 0 1 r
.02 w
.4569 .71511 m
.27955 .77273 L
s
P
p
.2 0 1 r
.02 w
.4569 .71511 m
.34729 .86597 L
s
P
p
.2 0 1 r
.02 w
.5431 .71511 m
.65271 .86597 L
s
P
p
.2 0 1 r
.02 w
.5431 .71511 m
.72045 .77273 L
s
P
p
0 .4 1 r
.018 w
.5 .68379 m
.4569 .71511 L
s
P
p
0 .4 1 r
.018 w
.5 .68379 m
.5431 .71511 L
s
P
p
.2 0 1 r
.02 w
.61653 .25152 m
.803 .25152 L
s
P
p
.2 0 1 r
.02 w
.61653 .25152 m
.76739 .14192 L
s
P
p
.2 0 1 r
.02 w
.53454 .22488 m
.47692 .04753 L
s
P
p
.2 0 1 r
.02 w
.53454 .22488 m
.38368 .11528 L
s
P
p
0 .4 1 r
.018 w
.56586 .26799 m
.61653 .25152 L
s
P
p
0 .4 1 r
.018 w
.56586 .26799 m
.53454 .22488 L
s
P
p
.2 0 1 r
.02 w
.32145 .64309 m
.1441 .58546 L
s
P
p
.2 0 1 r
.02 w
.32145 .64309 m
.1441 .70071 L
s
P
p
.2 0 1 r
.02 w
.3912 .69376 m
.3912 .88024 L
s
P
p
.2 0 1 r
.02 w
.3912 .69376 m
.50081 .84462 L
s
P
p
0 .4 1 r
.018 w
.37473 .64309 m
.32145 .64309 L
s
P
p
0 .4 1 r
.018 w
.37473 .64309 m
.3912 .69376 L
s
P
p
.2 0 1 r
.016 w
.5 .47067 m
.62527 .64309 L
s
P
p
.2 0 1 r
.016 w
.5 .47067 m
.43414 .26799 L
s
P
p
.2 0 1 r
.016 w
.5 .47067 m
.5 .68379 L
s
P
p
.2 0 1 r
.016 w
.5 .47067 m
.56586 .26799 L
s
P
p
.2 0 1 r
.016 w
.5 .47067 m
.37473 .64309 L
s
P
p
.2 0 1 r
.02 w
.71357 .6427 m
.65595 .82005 L
s
P
p
.2 0 1 r
.02 w
.71357 .6427 m
.7712 .82005 L
s
P
p
.2 0 1 r
.02 w
.76425 .57296 m
.95072 .57296 L
s
P
p
.2 0 1 r
.02 w
.76425 .57296 m
.91511 .46335 L
s
P
p
0 .4 1 r
.018 w
.71357 .58942 m
.71357 .6427 L
s
P
p
0 .4 1 r
.018 w
.71357 .58942 m
.76425 .57296 L
s
P
p
.2 0 1 r
.02 w
.43236 .24107 m
.54197 .09021 L
s
P
p
.2 0 1 r
.02 w
.43236 .24107 m
.43236 .05459 L
s
P
p
.2 0 1 r
.02 w
.36261 .29174 m
.18527 .23412 L
s
P
p
.2 0 1 r
.02 w
.36261 .29174 m
.18527 .34936 L
s
P
p
0 .4 1 r
.018 w
.41589 .29174 m
.43236 .24107 L
s
P
p
0 .4 1 r
.018 w
.41589 .29174 m
.36261 .29174 L
s
P
p
.2 0 1 r
.02 w
.5757 .70994 m
.42484 .81955 L
s
P
p
.2 0 1 r
.02 w
.5757 .70994 m
.51808 .88729 L
s
P
p
.2 0 1 r
.02 w
.65769 .6833 m
.80855 .79291 L
s
P
p
.2 0 1 r
.02 w
.65769 .6833 m
.84416 .6833 L
s
P
p
0 .4 1 r
.018 w
.60702 .66684 m
.5757 .70994 L
s
P
p
0 .4 1 r
.018 w
.60702 .66684 m
.65769 .6833 L
s
P
p
.2 0 1 r
.02 w
.58426 .21972 m
.76161 .1621 L
s
P
p
.2 0 1 r
.02 w
.58426 .21972 m
.69387 .06886 L
s
P
p
.2 0 1 r
.02 w
.49806 .21972 m
.38845 .06886 L
s
P
p
.2 0 1 r
.02 w
.49806 .21972 m
.32071 .1621 L
s
P
p
0 .4 1 r
.018 w
.54116 .25104 m
.58426 .21972 L
s
P
p
0 .4 1 r
.018 w
.54116 .25104 m
.49806 .21972 L
s
P
p
.2 0 1 r
.02 w
.42463 .6833 m
.23816 .6833 L
s
P
p
.2 0 1 r
.02 w
.42463 .6833 m
.27377 .79291 L
s
P
p
.2 0 1 r
.02 w
.50662 .70994 m
.56424 .88729 L
s
P
p
.2 0 1 r
.02 w
.50662 .70994 m
.65748 .81955 L
s
P
p
0 .4 1 r
.018 w
.4753 .66684 m
.42463 .6833 L
s
P
p
0 .4 1 r
.018 w
.4753 .66684 m
.50662 .70994 L
s
P
p
.2 0 1 r
.016 w
.54116 .46415 m
.71357 .58942 L
s
P
p
.2 0 1 r
.016 w
.54116 .46415 m
.41589 .29174 L
s
P
p
.2 0 1 r
.016 w
.54116 .46415 m
.60702 .66684 L
s
P
p
.2 0 1 r
.016 w
.54116 .46415 m
.54116 .25104 L
s
P
p
.2 0 1 r
.016 w
.54116 .46415 m
.4753 .66684 L
s
P
p
1 .6 0 r
.016 w
.5 .33748 m
.45884 .46415 L
s
P
p
1 .6 0 r
.016 w
.5 .33748 m
.5 .47067 L
s
P
p
1 .6 0 r
.016 w
.5 .33748 m
.54116 .46415 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.018 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.018 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.018 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.018 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.018 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.018 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.018 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.018 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.018 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.018 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.018 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.018 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.018 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.018 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.018 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.018 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.018 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.018 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.018 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.018 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.018 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.018 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.018 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.018 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.018 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.018 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.018 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.018 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.018 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.018 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.018 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.018 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.018 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.018 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.018 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.018 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.018 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.018 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.018 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.018 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.018 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.018 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.018 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.018 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.018 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.018 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.018 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.018 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.018 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.018 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.018 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.018 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.018 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.018 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.018 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.018 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.018 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.018 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.018 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.018 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
0 .4 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
0 .4 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
0 .4 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
0 .4 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
0 .4 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
0 .4 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
0 .4 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
0 .4 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
0 .4 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
0 .4 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
0 .4 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
0 .4 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
0 .4 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
0 .4 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
0 .4 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
0 .4 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
0 .4 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
0 .4 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
0 .4 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
0 .4 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
0 .4 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
0 .4 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
0 .4 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
0 .4 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
0 .4 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
0 .4 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
0 .4 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
0 .4 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
0 .4 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
0 .4 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
0 .4 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
0 .4 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
0 .4 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
0 .4 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
0 .4 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
0 .4 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
0 .4 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
0 .4 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
0 .4 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
0 .4 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
0 .4 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
0 .4 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
0 .4 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
0 .4 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
0 .4 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
0 .4 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
0 .4 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
0 .4 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
0 .4 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
0 .4 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
0 .4 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
0 .4 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
0 .4 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
0 .4 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
0 .4 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
0 .4 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
0 .4 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
0 .4 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
0 .4 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0894858 1.17897 0.0294743 1.17897 [
[ 0 0 0 0 ]
[ 1 1.23792 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.23792 L
0 1.23792 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.27901 .92609 m
.05501 .92609 L
s
P
p
.2 0 1 r
.02 w
.27901 .92609 m
.09779 1.05775 L
s
P
p
.2 0 1 r
.02 w
.39391 .96342 m
.46313 1.17646 L
s
P
p
.2 0 1 r
.02 w
.39391 .96342 m
.57513 1.09509 L
s
P
p
0 .4 1 r
.018 w
.35002 .90301 m
.27901 .92609 L
s
P
p
0 .4 1 r
.018 w
.35002 .90301 m
.39391 .96342 L
s
P
p
.2 0 1 r
.02 w
.60562 .31183 m
.82963 .31183 L
s
P
p
.2 0 1 r
.02 w
.60562 .31183 m
.78685 .18017 L
s
P
p
.2 0 1 r
.02 w
.49072 .2745 m
.4215 .06146 L
s
P
p
.2 0 1 r
.02 w
.49072 .2745 m
.3095 .14284 L
s
P
p
0 .4 1 r
.018 w
.53461 .33491 m
.60562 .31183 L
s
P
p
0 .4 1 r
.018 w
.53461 .33491 m
.49072 .2745 L
s
P
p
.2 0 1 r
.016 w
.44232 .61896 m
.35002 .90301 L
s
P
p
.2 0 1 r
.016 w
.44232 .61896 m
.53461 .33491 L
s
P
p
.2 0 1 r
.02 w
.43959 .97066 m
.22655 1.03988 L
s
P
p
.2 0 1 r
.02 w
.43959 .97066 m
.30793 1.15188 L
s
P
p
.2 0 1 r
.02 w
.56041 .97066 m
.69207 1.15188 L
s
P
p
.2 0 1 r
.02 w
.56041 .97066 m
.77345 1.03988 L
s
P
p
0 .4 1 r
.018 w
.5 .92677 m
.43959 .97066 L
s
P
p
0 .4 1 r
.018 w
.5 .92677 m
.56041 .97066 L
s
P
p
.2 0 1 r
.02 w
.56041 .28554 m
.77345 .21632 L
s
P
p
.2 0 1 r
.02 w
.56041 .28554 m
.69207 .10432 L
s
P
p
.2 0 1 r
.02 w
.43959 .28554 m
.30793 .10432 L
s
P
p
.2 0 1 r
.02 w
.43959 .28554 m
.22655 .21632 L
s
P
p
0 .4 1 r
.018 w
.5 .32943 m
.56041 .28554 L
s
P
p
0 .4 1 r
.018 w
.5 .32943 m
.43959 .28554 L
s
P
p
.2 0 1 r
.016 w
.5 .6281 m
.5 .92677 L
s
P
p
.2 0 1 r
.016 w
.5 .6281 m
.5 .32943 L
s
P
p
.2 0 1 r
.02 w
.60609 .96342 m
.42487 1.09509 L
s
P
p
.2 0 1 r
.02 w
.60609 .96342 m
.53687 1.17646 L
s
P
p
.2 0 1 r
.02 w
.72099 .92609 m
.90221 1.05775 L
s
P
p
.2 0 1 r
.02 w
.72099 .92609 m
.94499 .92609 L
s
P
p
0 .4 1 r
.018 w
.64998 .90301 m
.60609 .96342 L
s
P
p
0 .4 1 r
.018 w
.64998 .90301 m
.72099 .92609 L
s
P
p
.2 0 1 r
.02 w
.50928 .2745 m
.6905 .14284 L
s
P
p
.2 0 1 r
.02 w
.50928 .2745 m
.5785 .06146 L
s
P
p
.2 0 1 r
.02 w
.39438 .31183 m
.21315 .18017 L
s
P
p
.2 0 1 r
.02 w
.39438 .31183 m
.17037 .31183 L
s
P
p
0 .4 1 r
.018 w
.46539 .33491 m
.50928 .2745 L
s
P
p
0 .4 1 r
.018 w
.46539 .33491 m
.39438 .31183 L
s
P
p
.2 0 1 r
.016 w
.55768 .61896 m
.64998 .90301 L
s
P
p
.2 0 1 r
.016 w
.55768 .61896 m
.46539 .33491 L
s
P
p
1 .6 0 r
.016 w
.5 .44143 m
.44232 .61896 L
s
P
p
1 .6 0 r
.016 w
.5 .44143 m
.5 .6281 L
s
P
p
1 .6 0 r
.016 w
.5 .44143 m
.55768 .61896 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00371227 0.952381 [
[ 0 0 0 0 ]
[ 1 .94496 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .94496 L
0 .94496 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.50163 .74338 m
.37085 .8384 L
s
P
p
.2 0 1 r
.02 w
.50163 .74338 m
.45168 .89712 L
s
P
p
.2 0 1 r
.02 w
.58455 .71644 m
.71533 .81146 L
s
P
p
.2 0 1 r
.02 w
.58455 .71644 m
.7462 .71644 L
s
P
p
0 .4 1 r
.018 w
.5333 .69979 m
.50163 .74338 L
s
P
p
0 .4 1 r
.018 w
.5333 .69979 m
.58455 .71644 L
s
P
p
.2 0 1 r
.02 w
.50197 .19503 m
.6557 .14508 L
s
P
p
.2 0 1 r
.02 w
.50197 .19503 m
.59698 .06426 L
s
P
p
.2 0 1 r
.02 w
.41478 .19503 m
.31976 .06426 L
s
P
p
.2 0 1 r
.02 w
.41478 .19503 m
.26104 .14508 L
s
P
p
0 .4 1 r
.018 w
.45837 .22671 m
.50197 .19503 L
s
P
p
0 .4 1 r
.018 w
.45837 .22671 m
.41478 .19503 L
s
P
p
.2 0 1 r
.02 w
.3322 .71644 m
.17055 .71644 L
s
P
p
.2 0 1 r
.02 w
.3322 .71644 m
.20142 .81146 L
s
P
p
.2 0 1 r
.02 w
.41512 .74338 m
.46507 .89712 L
s
P
p
.2 0 1 r
.02 w
.41512 .74338 m
.54589 .8384 L
s
P
p
0 .4 1 r
.018 w
.38344 .69979 m
.3322 .71644 L
s
P
p
0 .4 1 r
.018 w
.38344 .69979 m
.41512 .74338 L
s
P
p
.2 0 1 r
.02 w
.65478 .27301 m
.80852 .32297 L
s
P
p
.2 0 1 r
.02 w
.65478 .27301 m
.80852 .22306 L
s
P
p
.2 0 1 r
.02 w
.58425 .22177 m
.58425 .06012 L
s
P
p
.2 0 1 r
.02 w
.58425 .22177 m
.48923 .09099 L
s
P
p
0 .4 1 r
.018 w
.6009 .27301 m
.65478 .27301 L
s
P
p
0 .4 1 r
.018 w
.6009 .27301 m
.58425 .22177 L
s
P
p
.2 0 1 r
.02 w
.21096 .59505 m
.08018 .50004 L
s
P
p
.2 0 1 r
.02 w
.21096 .59505 m
.04931 .59505 L
s
P
p
.2 0 1 r
.02 w
.26221 .66559 m
.21225 .81933 L
s
P
p
.2 0 1 r
.02 w
.26221 .66559 m
.31216 .81933 L
s
P
p
0 .4 1 r
.018 w
.26221 .61171 m
.21096 .59505 L
s
P
p
0 .4 1 r
.018 w
.26221 .61171 m
.26221 .66559 L
s
P
p
.2 0 1 r
.016 w
.45837 .46918 m
.5333 .69979 L
s
P
p
.2 0 1 r
.016 w
.45837 .46918 m
.45837 .22671 L
s
P
p
.2 0 1 r
.016 w
.45837 .46918 m
.38344 .69979 L
s
P
p
.2 0 1 r
.016 w
.45837 .46918 m
.6009 .27301 L
s
P
p
.2 0 1 r
.016 w
.45837 .46918 m
.26221 .61171 L
s
P
p
.2 0 1 r
.02 w
.62587 .72319 m
.53086 .85397 L
s
P
p
.2 0 1 r
.02 w
.62587 .72319 m
.62587 .88484 L
s
P
p
.2 0 1 r
.02 w
.69641 .67194 m
.85015 .72189 L
s
P
p
.2 0 1 r
.02 w
.69641 .67194 m
.85015 .62199 L
s
P
p
0 .4 1 r
.018 w
.64252 .67194 m
.62587 .72319 L
s
P
p
0 .4 1 r
.018 w
.64252 .67194 m
.69641 .67194 L
s
P
p
.2 0 1 r
.02 w
.45674 .20157 m
.58752 .10656 L
s
P
p
.2 0 1 r
.02 w
.45674 .20157 m
.5067 .04784 L
s
P
p
.2 0 1 r
.02 w
.37382 .22852 m
.24305 .1335 L
s
P
p
.2 0 1 r
.02 w
.37382 .22852 m
.21217 .22852 L
s
P
p
0 .4 1 r
.018 w
.42507 .24517 m
.45674 .20157 L
s
P
p
0 .4 1 r
.018 w
.42507 .24517 m
.37382 .22852 L
s
P
p
.2 0 1 r
.02 w
.45641 .74992 m
.30267 .79987 L
s
P
p
.2 0 1 r
.02 w
.45641 .74992 m
.36139 .8807 L
s
P
p
.2 0 1 r
.02 w
.54359 .74992 m
.63861 .8807 L
s
P
p
.2 0 1 r
.02 w
.54359 .74992 m
.69733 .79987 L
s
P
p
0 .4 1 r
.018 w
.5 .71825 m
.45641 .74992 L
s
P
p
0 .4 1 r
.018 w
.5 .71825 m
.54359 .74992 L
s
P
p
.2 0 1 r
.02 w
.62618 .22852 m
.78783 .22852 L
s
P
p
.2 0 1 r
.02 w
.62618 .22852 m
.75695 .1335 L
s
P
p
.2 0 1 r
.02 w
.54326 .20157 m
.4933 .04784 L
s
P
p
.2 0 1 r
.02 w
.54326 .20157 m
.41248 .10656 L
s
P
p
0 .4 1 r
.018 w
.57493 .24517 m
.62618 .22852 L
s
P
p
0 .4 1 r
.018 w
.57493 .24517 m
.54326 .20157 L
s
P
p
.2 0 1 r
.02 w
.30359 .67194 m
.14985 .62199 L
s
P
p
.2 0 1 r
.02 w
.30359 .67194 m
.14985 .72189 L
s
P
p
.2 0 1 r
.02 w
.37413 .72319 m
.37413 .88484 L
s
P
p
.2 0 1 r
.02 w
.37413 .72319 m
.46914 .85397 L
s
P
p
0 .4 1 r
.018 w
.35748 .67194 m
.30359 .67194 L
s
P
p
0 .4 1 r
.018 w
.35748 .67194 m
.37413 .72319 L
s
P
p
.2 0 1 r
.016 w
.5 .47577 m
.64252 .67194 L
s
P
p
.2 0 1 r
.016 w
.5 .47577 m
.42507 .24517 L
s
P
p
.2 0 1 r
.016 w
.5 .47577 m
.5 .71825 L
s
P
p
.2 0 1 r
.016 w
.5 .47577 m
.57493 .24517 L
s
P
p
.2 0 1 r
.016 w
.5 .47577 m
.35748 .67194 L
s
P
p
.2 0 1 r
.02 w
.73779 .66559 m
.68784 .81933 L
s
P
p
.2 0 1 r
.02 w
.73779 .66559 m
.78775 .81933 L
s
P
p
.2 0 1 r
.02 w
.78904 .59505 m
.95069 .59505 L
s
P
p
.2 0 1 r
.02 w
.78904 .59505 m
.91982 .50004 L
s
P
p
0 .4 1 r
.018 w
.73779 .61171 m
.73779 .66559 L
s
P
p
0 .4 1 r
.018 w
.73779 .61171 m
.78904 .59505 L
s
P
p
.2 0 1 r
.02 w
.41575 .22177 m
.51077 .09099 L
s
P
p
.2 0 1 r
.02 w
.41575 .22177 m
.41575 .06012 L
s
P
p
.2 0 1 r
.02 w
.34522 .27301 m
.19148 .22306 L
s
P
p
.2 0 1 r
.02 w
.34522 .27301 m
.19148 .32297 L
s
P
p
0 .4 1 r
.018 w
.3991 .27301 m
.41575 .22177 L
s
P
p
0 .4 1 r
.018 w
.3991 .27301 m
.34522 .27301 L
s
P
p
.2 0 1 r
.02 w
.58488 .74338 m
.45411 .8384 L
s
P
p
.2 0 1 r
.02 w
.58488 .74338 m
.53493 .89712 L
s
P
p
.2 0 1 r
.02 w
.6678 .71644 m
.79858 .81146 L
s
P
p
.2 0 1 r
.02 w
.6678 .71644 m
.82945 .71644 L
s
P
p
0 .4 1 r
.018 w
.61656 .69979 m
.58488 .74338 L
s
P
p
0 .4 1 r
.018 w
.61656 .69979 m
.6678 .71644 L
s
P
p
.2 0 1 r
.02 w
.58522 .19503 m
.73896 .14508 L
s
P
p
.2 0 1 r
.02 w
.58522 .19503 m
.68024 .06426 L
s
P
p
.2 0 1 r
.02 w
.49803 .19503 m
.40302 .06426 L
s
P
p
.2 0 1 r
.02 w
.49803 .19503 m
.3443 .14508 L
s
P
p
0 .4 1 r
.018 w
.54163 .22671 m
.58522 .19503 L
s
P
p
0 .4 1 r
.018 w
.54163 .22671 m
.49803 .19503 L
s
P
p
.2 0 1 r
.02 w
.41545 .71644 m
.2538 .71644 L
s
P
p
.2 0 1 r
.02 w
.41545 .71644 m
.28467 .81146 L
s
P
p
.2 0 1 r
.02 w
.49837 .74338 m
.54832 .89712 L
s
P
p
.2 0 1 r
.02 w
.49837 .74338 m
.62915 .8384 L
s
P
p
0 .4 1 r
.018 w
.4667 .69979 m
.41545 .71644 L
s
P
p
0 .4 1 r
.018 w
.4667 .69979 m
.49837 .74338 L
s
P
p
.2 0 1 r
.016 w
.54163 .46918 m
.73779 .61171 L
s
P
p
.2 0 1 r
.016 w
.54163 .46918 m
.3991 .27301 L
s
P
p
.2 0 1 r
.016 w
.54163 .46918 m
.61656 .69979 L
s
P
p
.2 0 1 r
.016 w
.54163 .46918 m
.54163 .22671 L
s
P
p
.2 0 1 r
.016 w
.54163 .46918 m
.4667 .69979 L
s
P
p
1 .6 0 r
.016 w
.5 .34107 m
.45837 .46918 L
s
P
p
1 .6 0 r
.016 w
.5 .34107 m
.5 .47577 L
s
P
p
1 .6 0 r
.016 w
.5 .34107 m
.54163 .46918 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.014 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.014 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.014 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.014 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.014 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.014 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.014 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.014 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.014 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.014 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.014 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.014 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.014 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.014 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.014 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
0 .4 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
0 .4 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
0 .4 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
0 .4 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
0 .4 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
0 .4 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
0 .4 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
0 .4 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
0 .4 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
0 .4 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
0 .4 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
0 .4 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
0 .4 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
0 .4 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
0 .4 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00943193 0.981136 0.0245284 0.981136 [
[ 0 0 0 0 ]
[ 1 1.03019 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.03019 L
0 1.03019 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.46854 .73461 m
.30122 .68024 L
s
P
p
.2 0 1 r
.02 w
.46854 .73461 m
.30122 .78897 L
s
P
p
.2 0 1 r
.02 w
.54531 .79038 m
.54531 .96631 L
s
P
p
.2 0 1 r
.02 w
.54531 .79038 m
.64872 .93271 L
s
P
p
.2 0 1 r
.02 w
.57463 .70014 m
.74195 .64577 L
s
P
p
.2 0 1 r
.02 w
.57463 .70014 m
.67804 .5578 L
s
P
p
0 .4 1 r
.018 w
.52718 .73461 m
.46854 .73461 L
s
P
p
0 .4 1 r
.018 w
.52718 .73461 m
.54531 .79038 L
s
P
p
0 .4 1 r
.018 w
.52718 .73461 m
.57463 .70014 L
s
P
p
.2 0 1 r
.02 w
.51047 .29505 m
.6528 .39846 L
s
P
p
.2 0 1 r
.02 w
.51047 .29505 m
.6864 .29505 L
s
P
p
.2 0 1 r
.02 w
.45469 .21829 m
.50906 .05096 L
s
P
p
.2 0 1 r
.02 w
.45469 .21829 m
.40033 .05096 L
s
P
p
.2 0 1 r
.02 w
.39892 .29505 m
.22299 .29505 L
s
P
p
.2 0 1 r
.02 w
.39892 .29505 m
.25659 .39846 L
s
P
p
0 .4 1 r
.018 w
.45469 .27693 m
.51047 .29505 L
s
P
p
0 .4 1 r
.018 w
.45469 .27693 m
.45469 .21829 L
s
P
p
0 .4 1 r
.018 w
.45469 .27693 m
.39892 .29505 L
s
P
p
.2 0 1 r
.02 w
.33476 .70014 m
.23135 .5578 L
s
P
p
.2 0 1 r
.02 w
.33476 .70014 m
.16744 .64577 L
s
P
p
.2 0 1 r
.02 w
.36408 .79038 m
.26067 .93271 L
s
P
p
.2 0 1 r
.02 w
.36408 .79038 m
.36408 .96631 L
s
P
p
.2 0 1 r
.02 w
.44085 .73461 m
.60817 .78897 L
s
P
p
.2 0 1 r
.02 w
.44085 .73461 m
.60817 .68024 L
s
P
p
0 .4 1 r
.018 w
.38221 .73461 m
.33476 .70014 L
s
P
p
0 .4 1 r
.018 w
.38221 .73461 m
.36408 .79038 L
s
P
p
0 .4 1 r
.018 w
.38221 .73461 m
.44085 .73461 L
s
P
p
.2 0 1 r
.02 w
.62705 .36918 m
.68141 .5365 L
s
P
p
.2 0 1 r
.02 w
.62705 .36918 m
.76938 .47259 L
s
P
p
.2 0 1 r
.02 w
.62705 .27429 m
.76938 .17088 L
s
P
p
.2 0 1 r
.02 w
.62705 .27429 m
.68141 .10696 L
s
P
p
.2 0 1 r
.02 w
.5368 .30361 m
.39447 .2002 L
s
P
p
.2 0 1 r
.02 w
.5368 .30361 m
.36087 .30361 L
s
P
p
0 .4 1 r
.018 w
.59258 .32173 m
.62705 .36918 L
s
P
p
0 .4 1 r
.018 w
.59258 .32173 m
.62705 .27429 L
s
P
p
0 .4 1 r
.018 w
.59258 .32173 m
.5368 .30361 L
s
P
p
.2 0 1 r
.02 w
.24679 .59362 m
.24679 .41768 L
s
P
p
.2 0 1 r
.02 w
.24679 .59362 m
.14338 .45128 L
s
P
p
.2 0 1 r
.02 w
.21747 .68386 m
.05015 .73823 L
s
P
p
.2 0 1 r
.02 w
.21747 .68386 m
.11406 .82619 L
s
P
p
.2 0 1 r
.02 w
.31236 .68386 m
.41577 .82619 L
s
P
p
.2 0 1 r
.02 w
.31236 .68386 m
.47968 .73823 L
s
P
p
0 .4 1 r
.018 w
.26492 .64939 m
.24679 .59362 L
s
P
p
0 .4 1 r
.018 w
.26492 .64939 m
.21747 .68386 L
s
P
p
0 .4 1 r
.018 w
.26492 .64939 m
.31236 .68386 L
s
P
p
.2 0 1 r
.016 w
.45469 .51151 m
.52718 .73461 L
s
P
p
.2 0 1 r
.016 w
.45469 .51151 m
.45469 .27693 L
s
P
p
.2 0 1 r
.016 w
.45469 .51151 m
.38221 .73461 L
s
P
p
.2 0 1 r
.016 w
.45469 .51151 m
.59258 .32173 L
s
P
p
.2 0 1 r
.016 w
.45469 .51151 m
.26492 .64939 L
s
P
p
.2 0 1 r
.02 w
.58211 .72658 m
.40617 .72658 L
s
P
p
.2 0 1 r
.02 w
.58211 .72658 m
.43977 .83 L
s
P
p
.2 0 1 r
.02 w
.67235 .75591 m
.72672 .92323 L
s
P
p
.2 0 1 r
.02 w
.67235 .75591 m
.81469 .85932 L
s
P
p
.2 0 1 r
.02 w
.67235 .66102 m
.81469 .55761 L
s
P
p
.2 0 1 r
.02 w
.67235 .66102 m
.72672 .49369 L
s
P
p
0 .4 1 r
.018 w
.63788 .70846 m
.58211 .72658 L
s
P
p
0 .4 1 r
.018 w
.63788 .70846 m
.67235 .75591 L
s
P
p
0 .4 1 r
.018 w
.63788 .70846 m
.67235 .66102 L
s
P
p
.2 0 1 r
.02 w
.48616 .29559 m
.65348 .34995 L
s
P
p
.2 0 1 r
.02 w
.48616 .29559 m
.65348 .24122 L
s
P
p
.2 0 1 r
.02 w
.40939 .23981 m
.40939 .06388 L
s
P
p
.2 0 1 r
.02 w
.40939 .23981 m
.30598 .09748 L
s
P
p
.2 0 1 r
.02 w
.38007 .33006 m
.21274 .38442 L
s
P
p
.2 0 1 r
.02 w
.38007 .33006 m
.27666 .47239 L
s
P
p
0 .4 1 r
.018 w
.42751 .29559 m
.48616 .29559 L
s
P
p
0 .4 1 r
.018 w
.42751 .29559 m
.40939 .23981 L
s
P
p
0 .4 1 r
.018 w
.42751 .29559 m
.38007 .33006 L
s
P
p
.2 0 1 r
.02 w
.44423 .73514 m
.30189 .63173 L
s
P
p
.2 0 1 r
.02 w
.44423 .73514 m
.26829 .73514 L
s
P
p
.2 0 1 r
.02 w
.5 .81191 m
.44563 .97923 L
s
P
p
.2 0 1 r
.02 w
.5 .81191 m
.55437 .97923 L
s
P
p
.2 0 1 r
.02 w
.55577 .73514 m
.73171 .73514 L
s
P
p
.2 0 1 r
.02 w
.55577 .73514 m
.69811 .63173 L
s
P
p
0 .4 1 r
.018 w
.5 .75326 m
.44423 .73514 L
s
P
p
0 .4 1 r
.018 w
.5 .75326 m
.5 .81191 L
s
P
p
0 .4 1 r
.018 w
.5 .75326 m
.55577 .73514 L
s
P
p
.2 0 1 r
.02 w
.61993 .33006 m
.72334 .47239 L
s
P
p
.2 0 1 r
.02 w
.61993 .33006 m
.78726 .38442 L
s
P
p
.2 0 1 r
.02 w
.59061 .23981 m
.69402 .09748 L
s
P
p
.2 0 1 r
.02 w
.59061 .23981 m
.59061 .06388 L
s
P
p
.2 0 1 r
.02 w
.51384 .29559 m
.34652 .24122 L
s
P
p
.2 0 1 r
.02 w
.51384 .29559 m
.34652 .34995 L
s
P
p
0 .4 1 r
.018 w
.57249 .29559 m
.61993 .33006 L
s
P
p
0 .4 1 r
.018 w
.57249 .29559 m
.59061 .23981 L
s
P
p
0 .4 1 r
.018 w
.57249 .29559 m
.51384 .29559 L
s
P
p
.2 0 1 r
.02 w
.32765 .66102 m
.27328 .49369 L
s
P
p
.2 0 1 r
.02 w
.32765 .66102 m
.18531 .55761 L
s
P
p
.2 0 1 r
.02 w
.32765 .75591 m
.18531 .85932 L
s
P
p
.2 0 1 r
.02 w
.32765 .75591 m
.27328 .92323 L
s
P
p
.2 0 1 r
.02 w
.41789 .72658 m
.56023 .83 L
s
P
p
.2 0 1 r
.02 w
.41789 .72658 m
.59383 .72658 L
s
P
p
0 .4 1 r
.018 w
.36212 .70846 m
.32765 .66102 L
s
P
p
0 .4 1 r
.018 w
.36212 .70846 m
.32765 .75591 L
s
P
p
0 .4 1 r
.018 w
.36212 .70846 m
.41789 .72658 L
s
P
p
.2 0 1 r
.016 w
.5 .51868 m
.63788 .70846 L
s
P
p
.2 0 1 r
.016 w
.5 .51868 m
.42751 .29559 L
s
P
p
.2 0 1 r
.016 w
.5 .51868 m
.5 .75326 L
s
P
p
.2 0 1 r
.016 w
.5 .51868 m
.57249 .29559 L
s
P
p
.2 0 1 r
.016 w
.5 .51868 m
.36212 .70846 L
s
P
p
.2 0 1 r
.02 w
.68764 .68386 m
.52032 .73823 L
s
P
p
.2 0 1 r
.02 w
.68764 .68386 m
.58423 .82619 L
s
P
p
.2 0 1 r
.02 w
.78253 .68386 m
.88594 .82619 L
s
P
p
.2 0 1 r
.02 w
.78253 .68386 m
.94985 .73823 L
s
P
p
.2 0 1 r
.02 w
.75321 .59362 m
.85662 .45128 L
s
P
p
.2 0 1 r
.02 w
.75321 .59362 m
.75321 .41768 L
s
P
p
0 .4 1 r
.018 w
.73508 .64939 m
.68764 .68386 L
s
P
p
0 .4 1 r
.018 w
.73508 .64939 m
.78253 .68386 L
s
P
p
0 .4 1 r
.018 w
.73508 .64939 m
.75321 .59362 L
s
P
p
.2 0 1 r
.02 w
.4632 .30361 m
.63913 .30361 L
s
P
p
.2 0 1 r
.02 w
.4632 .30361 m
.60553 .2002 L
s
P
p
.2 0 1 r
.02 w
.37295 .27429 m
.31859 .10696 L
s
P
p
.2 0 1 r
.02 w
.37295 .27429 m
.23062 .17088 L
s
P
p
.2 0 1 r
.02 w
.37295 .36918 m
.23062 .47259 L
s
P
p
.2 0 1 r
.02 w
.37295 .36918 m
.31859 .5365 L
s
P
p
0 .4 1 r
.018 w
.40742 .32173 m
.4632 .30361 L
s
P
p
0 .4 1 r
.018 w
.40742 .32173 m
.37295 .27429 L
s
P
p
0 .4 1 r
.018 w
.40742 .32173 m
.37295 .36918 L
s
P
p
.2 0 1 r
.02 w
.55915 .73461 m
.39183 .68024 L
s
P
p
.2 0 1 r
.02 w
.55915 .73461 m
.39183 .78897 L
s
P
p
.2 0 1 r
.02 w
.63592 .79038 m
.63592 .96631 L
s
P
p
.2 0 1 r
.02 w
.63592 .79038 m
.73933 .93271 L
s
P
p
.2 0 1 r
.02 w
.66524 .70014 m
.83256 .64577 L
s
P
p
.2 0 1 r
.02 w
.66524 .70014 m
.76865 .5578 L
s
P
p
0 .4 1 r
.018 w
.61779 .73461 m
.55915 .73461 L
s
P
p
0 .4 1 r
.018 w
.61779 .73461 m
.63592 .79038 L
s
P
p
0 .4 1 r
.018 w
.61779 .73461 m
.66524 .70014 L
s
P
p
.2 0 1 r
.02 w
.60108 .29505 m
.74341 .39846 L
s
P
p
.2 0 1 r
.02 w
.60108 .29505 m
.77701 .29505 L
s
P
p
.2 0 1 r
.02 w
.54531 .21829 m
.59967 .05096 L
s
P
p
.2 0 1 r
.02 w
.54531 .21829 m
.49094 .05096 L
s
P
p
.2 0 1 r
.02 w
.48953 .29505 m
.3136 .29505 L
s
P
p
.2 0 1 r
.02 w
.48953 .29505 m
.3472 .39846 L
s
P
p
0 .4 1 r
.018 w
.54531 .27693 m
.60108 .29505 L
s
P
p
0 .4 1 r
.018 w
.54531 .27693 m
.54531 .21829 L
s
P
p
0 .4 1 r
.018 w
.54531 .27693 m
.48953 .29505 L
s
P
p
.2 0 1 r
.02 w
.42537 .70014 m
.32196 .5578 L
s
P
p
.2 0 1 r
.02 w
.42537 .70014 m
.25805 .64577 L
s
P
p
.2 0 1 r
.02 w
.45469 .79038 m
.35128 .93271 L
s
P
p
.2 0 1 r
.02 w
.45469 .79038 m
.45469 .96631 L
s
P
p
.2 0 1 r
.02 w
.53146 .73461 m
.69878 .78897 L
s
P
p
.2 0 1 r
.02 w
.53146 .73461 m
.69878 .68024 L
s
P
p
0 .4 1 r
.018 w
.47282 .73461 m
.42537 .70014 L
s
P
p
0 .4 1 r
.018 w
.47282 .73461 m
.45469 .79038 L
s
P
p
0 .4 1 r
.018 w
.47282 .73461 m
.53146 .73461 L
s
P
p
.2 0 1 r
.016 w
.54531 .51151 m
.73508 .64939 L
s
P
p
.2 0 1 r
.016 w
.54531 .51151 m
.40742 .32173 L
s
P
p
.2 0 1 r
.016 w
.54531 .51151 m
.61779 .73461 L
s
P
p
.2 0 1 r
.016 w
.54531 .51151 m
.54531 .27693 L
s
P
p
.2 0 1 r
.016 w
.54531 .51151 m
.47282 .73461 L
s
P
p
1 .6 0 r
.016 w
.5 .37207 m
.45469 .51151 L
s
P
p
1 .6 0 r
.016 w
.5 .37207 m
.5 .51868 L
s
P
p
1 .6 0 r
.016 w
.5 .37207 m
.54531 .51151 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.019273 0.952381 [
[ 0 0 0 0 ]
[ 1 .91383 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .91383 L
0 .91383 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.48604 .7119 m
.33289 .78994 L
s
P
p
.2 0 1 r
.02 w
.48604 .7119 m
.40801 .86506 L
s
P
p
.2 0 1 r
.02 w
.58315 .68035 m
.73631 .75838 L
s
P
p
.2 0 1 r
.02 w
.58315 .68035 m
.75293 .65346 L
s
P
p
0 .4 1 r
.018 w
.52656 .67138 m
.48604 .7119 L
s
P
p
0 .4 1 r
.018 w
.52656 .67138 m
.58315 .68035 L
s
P
p
.2 0 1 r
.02 w
.50679 .19821 m
.67656 .17132 L
s
P
p
.2 0 1 r
.02 w
.50679 .19821 m
.62833 .07666 L
s
P
p
.2 0 1 r
.02 w
.40468 .19821 m
.28314 .07666 L
s
P
p
.2 0 1 r
.02 w
.40468 .19821 m
.23491 .17132 L
s
P
p
0 .4 1 r
.018 w
.45574 .22422 m
.50679 .19821 L
s
P
p
0 .4 1 r
.018 w
.45574 .22422 m
.40468 .19821 L
s
P
p
.2 0 1 r
.02 w
.32832 .68035 m
.15854 .65346 L
s
P
p
.2 0 1 r
.02 w
.32832 .68035 m
.17516 .75838 L
s
P
p
.2 0 1 r
.02 w
.42543 .7119 m
.50346 .86506 L
s
P
p
.2 0 1 r
.02 w
.42543 .7119 m
.57858 .78994 L
s
P
p
0 .4 1 r
.018 w
.38491 .67138 m
.32832 .68035 L
s
P
p
0 .4 1 r
.018 w
.38491 .67138 m
.42543 .7119 L
s
P
p
.2 0 1 r
.02 w
.64704 .27696 m
.8002 .35499 L
s
P
p
.2 0 1 r
.02 w
.64704 .27696 m
.81682 .25007 L
s
P
p
.2 0 1 r
.02 w
.56444 .21694 m
.53755 .04717 L
s
P
p
.2 0 1 r
.02 w
.56444 .21694 m
.44289 .0954 L
s
P
p
0 .4 1 r
.018 w
.59045 .26799 m
.64704 .27696 L
s
P
p
0 .4 1 r
.018 w
.59045 .26799 m
.56444 .21694 L
s
P
p
.2 0 1 r
.02 w
.21927 .56211 m
.09772 .44057 L
s
P
p
.2 0 1 r
.02 w
.21927 .56211 m
.04949 .53522 L
s
P
p
.2 0 1 r
.02 w
.27928 .64472 m
.25239 .81449 L
s
P
p
.2 0 1 r
.02 w
.27928 .64472 m
.35732 .79787 L
s
P
p
0 .4 1 r
.018 w
.27032 .58813 m
.21927 .56211 L
s
P
p
0 .4 1 r
.018 w
.27032 .58813 m
.27928 .64472 L
s
P
p
.2 0 1 r
.016 w
.45574 .45341 m
.52656 .67138 L
s
P
p
.2 0 1 r
.016 w
.45574 .45341 m
.45574 .22422 L
s
P
p
.2 0 1 r
.016 w
.45574 .45341 m
.38491 .67138 L
s
P
p
.2 0 1 r
.016 w
.45574 .45341 m
.59045 .26799 L
s
P
p
.2 0 1 r
.016 w
.45574 .45341 m
.27032 .58813 L
s
P
p
.2 0 1 r
.02 w
.6087 .69689 m
.48716 .81844 L
s
P
p
.2 0 1 r
.02 w
.6087 .69689 m
.58181 .86667 L
s
P
p
.2 0 1 r
.02 w
.69131 .63688 m
.86108 .66377 L
s
P
p
.2 0 1 r
.02 w
.69131 .63688 m
.84446 .55884 L
s
P
p
0 .4 1 r
.018 w
.63471 .64584 m
.6087 .69689 L
s
P
p
0 .4 1 r
.018 w
.63471 .64584 m
.69131 .63688 L
s
P
p
.2 0 1 r
.02 w
.46969 .20194 m
.62285 .1239 L
s
P
p
.2 0 1 r
.02 w
.46969 .20194 m
.54773 .04878 L
s
P
p
.2 0 1 r
.02 w
.37258 .23349 m
.21943 .15545 L
s
P
p
.2 0 1 r
.02 w
.37258 .23349 m
.20281 .26038 L
s
P
p
0 .4 1 r
.018 w
.42918 .24245 m
.46969 .20194 L
s
P
p
0 .4 1 r
.018 w
.42918 .24245 m
.37258 .23349 L
s
P
p
.2 0 1 r
.02 w
.44895 .71562 m
.27917 .74251 L
s
P
p
.2 0 1 r
.02 w
.44895 .71562 m
.3274 .83717 L
s
P
p
.2 0 1 r
.02 w
.55105 .71562 m
.6726 .83717 L
s
P
p
.2 0 1 r
.02 w
.55105 .71562 m
.72083 .74251 L
s
P
p
0 .4 1 r
.018 w
.5 .68961 m
.44895 .71562 L
s
P
p
0 .4 1 r
.018 w
.5 .68961 m
.55105 .71562 L
s
P
p
.2 0 1 r
.02 w
.62742 .23349 m
.79719 .26038 L
s
P
p
.2 0 1 r
.02 w
.62742 .23349 m
.78057 .15545 L
s
P
p
.2 0 1 r
.02 w
.53031 .20194 m
.45227 .04878 L
s
P
p
.2 0 1 r
.02 w
.53031 .20194 m
.37715 .1239 L
s
P
p
0 .4 1 r
.018 w
.57082 .24245 m
.62742 .23349 L
s
P
p
0 .4 1 r
.018 w
.57082 .24245 m
.53031 .20194 L
s
P
p
.2 0 1 r
.02 w
.30869 .63688 m
.15554 .55884 L
s
P
p
.2 0 1 r
.02 w
.30869 .63688 m
.13892 .66377 L
s
P
p
.2 0 1 r
.02 w
.3913 .69689 m
.41819 .86667 L
s
P
p
.2 0 1 r
.02 w
.3913 .69689 m
.51284 .81844 L
s
P
p
0 .4 1 r
.018 w
.36529 .64584 m
.30869 .63688 L
s
P
p
0 .4 1 r
.018 w
.36529 .64584 m
.3913 .69689 L
s
P
p
.2 0 1 r
.016 w
.5 .46042 m
.63471 .64584 L
s
P
p
.2 0 1 r
.016 w
.5 .46042 m
.42918 .24245 L
s
P
p
.2 0 1 r
.016 w
.5 .46042 m
.5 .68961 L
s
P
p
.2 0 1 r
.016 w
.5 .46042 m
.57082 .24245 L
s
P
p
.2 0 1 r
.016 w
.5 .46042 m
.36529 .64584 L
s
P
p
.2 0 1 r
.02 w
.72072 .64472 m
.64268 .79787 L
s
P
p
.2 0 1 r
.02 w
.72072 .64472 m
.74761 .81449 L
s
P
p
.2 0 1 r
.02 w
.78073 .56211 m
.95051 .53522 L
s
P
p
.2 0 1 r
.02 w
.78073 .56211 m
.90228 .44057 L
s
P
p
0 .4 1 r
.018 w
.72968 .58813 m
.72072 .64472 L
s
P
p
0 .4 1 r
.018 w
.72968 .58813 m
.78073 .56211 L
s
P
p
.2 0 1 r
.02 w
.43556 .21694 m
.55711 .0954 L
s
P
p
.2 0 1 r
.02 w
.43556 .21694 m
.46245 .04717 L
s
P
p
.2 0 1 r
.02 w
.35296 .27696 m
.18318 .25007 L
s
P
p
.2 0 1 r
.02 w
.35296 .27696 m
.1998 .35499 L
s
P
p
0 .4 1 r
.018 w
.40955 .26799 m
.43556 .21694 L
s
P
p
0 .4 1 r
.018 w
.40955 .26799 m
.35296 .27696 L
s
P
p
.2 0 1 r
.02 w
.57457 .7119 m
.42142 .78994 L
s
P
p
.2 0 1 r
.02 w
.57457 .7119 m
.49654 .86506 L
s
P
p
.2 0 1 r
.02 w
.67168 .68035 m
.82484 .75838 L
s
P
p
.2 0 1 r
.02 w
.67168 .68035 m
.84146 .65346 L
s
P
p
0 .4 1 r
.018 w
.61509 .67138 m
.57457 .7119 L
s
P
p
0 .4 1 r
.018 w
.61509 .67138 m
.67168 .68035 L
s
P
p
.2 0 1 r
.02 w
.59532 .19821 m
.76509 .17132 L
s
P
p
.2 0 1 r
.02 w
.59532 .19821 m
.71686 .07666 L
s
P
p
.2 0 1 r
.02 w
.49321 .19821 m
.37167 .07666 L
s
P
p
.2 0 1 r
.02 w
.49321 .19821 m
.32344 .17132 L
s
P
p
0 .4 1 r
.018 w
.54426 .22422 m
.59532 .19821 L
s
P
p
0 .4 1 r
.018 w
.54426 .22422 m
.49321 .19821 L
s
P
p
.2 0 1 r
.02 w
.41685 .68035 m
.24707 .65346 L
s
P
p
.2 0 1 r
.02 w
.41685 .68035 m
.26369 .75838 L
s
P
p
.2 0 1 r
.02 w
.51396 .7119 m
.59199 .86506 L
s
P
p
.2 0 1 r
.02 w
.51396 .7119 m
.66711 .78994 L
s
P
p
0 .4 1 r
.018 w
.47344 .67138 m
.41685 .68035 L
s
P
p
0 .4 1 r
.018 w
.47344 .67138 m
.51396 .7119 L
s
P
p
.2 0 1 r
.016 w
.54426 .45341 m
.72968 .58813 L
s
P
p
.2 0 1 r
.016 w
.54426 .45341 m
.40955 .26799 L
s
P
p
.2 0 1 r
.016 w
.54426 .45341 m
.61509 .67138 L
s
P
p
.2 0 1 r
.016 w
.54426 .45341 m
.54426 .22422 L
s
P
p
.2 0 1 r
.016 w
.54426 .45341 m
.47344 .67138 L
s
P
p
1 .6 0 r
.016 w
.5 .31718 m
.45574 .45341 L
s
P
p
1 .6 0 r
.016 w
.5 .31718 m
.5 .46042 L
s
P
p
1 .6 0 r
.016 w
.5 .31718 m
.54426 .45341 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0114991 0.952381 [
[ 0 0 0 0 ]
[ 1 .92938 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .92938 L
0 .92938 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.47766 .72953 m
.34797 .82375 L
s
P
p
.2 0 1 r
.02 w
.47766 .72953 m
.42812 .88199 L
s
P
p
.2 0 1 r
.02 w
.60099 .68946 m
.73068 .78368 L
s
P
p
.2 0 1 r
.02 w
.60099 .68946 m
.76129 .68946 L
s
P
p
0 .4 1 r
.018 w
.52477 .66469 m
.47766 .72953 L
s
P
p
0 .4 1 r
.018 w
.52477 .66469 m
.60099 .68946 L
s
P
p
.2 0 1 r
.02 w
.52356 .20058 m
.67602 .15105 L
s
P
p
.2 0 1 r
.02 w
.52356 .20058 m
.61778 .0709 L
s
P
p
.2 0 1 r
.02 w
.39388 .20058 m
.29966 .0709 L
s
P
p
.2 0 1 r
.02 w
.39388 .20058 m
.24143 .15105 L
s
P
p
0 .4 1 r
.018 w
.45872 .24769 m
.52356 .20058 L
s
P
p
0 .4 1 r
.018 w
.45872 .24769 m
.39388 .20058 L
s
P
p
.2 0 1 r
.02 w
.31645 .68946 m
.15615 .68946 L
s
P
p
.2 0 1 r
.02 w
.31645 .68946 m
.18676 .78368 L
s
P
p
.2 0 1 r
.02 w
.43979 .72953 m
.48932 .88199 L
s
P
p
.2 0 1 r
.02 w
.43979 .72953 m
.56947 .82375 L
s
P
p
0 .4 1 r
.018 w
.39267 .66469 m
.31645 .68946 L
s
P
p
0 .4 1 r
.018 w
.39267 .66469 m
.43979 .72953 L
s
P
p
.2 0 1 r
.02 w
.6645 .28851 m
.81695 .33805 L
s
P
p
.2 0 1 r
.02 w
.6645 .28851 m
.81695 .23898 L
s
P
p
.2 0 1 r
.02 w
.55958 .21228 m
.55958 .05199 L
s
P
p
.2 0 1 r
.02 w
.55958 .21228 m
.46536 .0826 L
s
P
p
0 .4 1 r
.018 w
.58435 .28851 m
.6645 .28851 L
s
P
p
0 .4 1 r
.018 w
.58435 .28851 m
.55958 .21228 L
s
P
p
.2 0 1 r
.02 w
.20958 .56228 m
.0799 .46806 L
s
P
p
.2 0 1 r
.02 w
.20958 .56228 m
.04929 .56228 L
s
P
p
.2 0 1 r
.02 w
.28581 .6672 m
.23627 .81965 L
s
P
p
.2 0 1 r
.02 w
.28581 .6672 m
.33534 .81965 L
s
P
p
0 .4 1 r
.018 w
.28581 .58705 m
.20958 .56228 L
s
P
p
0 .4 1 r
.018 w
.28581 .58705 m
.28581 .6672 L
s
P
p
.2 0 1 r
.016 w
.45872 .46142 m
.52477 .66469 L
s
P
p
.2 0 1 r
.016 w
.45872 .46142 m
.45872 .24769 L
s
P
p
.2 0 1 r
.016 w
.45872 .46142 m
.39267 .66469 L
s
P
p
.2 0 1 r
.016 w
.45872 .46142 m
.58435 .28851 L
s
P
p
.2 0 1 r
.016 w
.45872 .46142 m
.28581 .58705 L
s
P
p
.2 0 1 r
.02 w
.60086 .7171 m
.50664 .84678 L
s
P
p
.2 0 1 r
.02 w
.60086 .7171 m
.60086 .8774 L
s
P
p
.2 0 1 r
.02 w
.70578 .64087 m
.85823 .69041 L
s
P
p
.2 0 1 r
.02 w
.70578 .64087 m
.85823 .59134 L
s
P
p
0 .4 1 r
.018 w
.62563 .64087 m
.60086 .7171 L
s
P
p
0 .4 1 r
.018 w
.62563 .64087 m
.70578 .64087 L
s
P
p
.2 0 1 r
.02 w
.48106 .19985 m
.61075 .10563 L
s
P
p
.2 0 1 r
.02 w
.48106 .19985 m
.5306 .0474 L
s
P
p
.2 0 1 r
.02 w
.35773 .23992 m
.22804 .1457 L
s
P
p
.2 0 1 r
.02 w
.35773 .23992 m
.19743 .23992 L
s
P
p
0 .4 1 r
.018 w
.43395 .26469 m
.48106 .19985 L
s
P
p
0 .4 1 r
.018 w
.43395 .26469 m
.35773 .23992 L
s
P
p
.2 0 1 r
.02 w
.43516 .7288 m
.28271 .77834 L
s
P
p
.2 0 1 r
.02 w
.43516 .7288 m
.34094 .85848 L
s
P
p
.2 0 1 r
.02 w
.56484 .7288 m
.65906 .85848 L
s
P
p
.2 0 1 r
.02 w
.56484 .7288 m
.71729 .77834 L
s
P
p
0 .4 1 r
.018 w
.5 .68169 m
.43516 .7288 L
s
P
p
0 .4 1 r
.018 w
.5 .68169 m
.56484 .7288 L
s
P
p
.2 0 1 r
.02 w
.64227 .23992 m
.80257 .23992 L
s
P
p
.2 0 1 r
.02 w
.64227 .23992 m
.77196 .1457 L
s
P
p
.2 0 1 r
.02 w
.51894 .19985 m
.4694 .0474 L
s
P
p
.2 0 1 r
.02 w
.51894 .19985 m
.38925 .10563 L
s
P
p
0 .4 1 r
.018 w
.56605 .26469 m
.64227 .23992 L
s
P
p
0 .4 1 r
.018 w
.56605 .26469 m
.51894 .19985 L
s
P
p
.2 0 1 r
.02 w
.29422 .64087 m
.14177 .59134 L
s
P
p
.2 0 1 r
.02 w
.29422 .64087 m
.14177 .69041 L
s
P
p
.2 0 1 r
.02 w
.39914 .7171 m
.39914 .8774 L
s
P
p
.2 0 1 r
.02 w
.39914 .7171 m
.49336 .84678 L
s
P
p
0 .4 1 r
.018 w
.37437 .64087 m
.29422 .64087 L
s
P
p
0 .4 1 r
.018 w
.37437 .64087 m
.39914 .7171 L
s
P
p
.2 0 1 r
.016 w
.5 .46796 m
.62563 .64087 L
s
P
p
.2 0 1 r
.016 w
.5 .46796 m
.43395 .26469 L
s
P
p
.2 0 1 r
.016 w
.5 .46796 m
.5 .68169 L
s
P
p
.2 0 1 r
.016 w
.5 .46796 m
.56605 .26469 L
s
P
p
.2 0 1 r
.016 w
.5 .46796 m
.37437 .64087 L
s
P
p
.2 0 1 r
.02 w
.71419 .6672 m
.66466 .81965 L
s
P
p
.2 0 1 r
.02 w
.71419 .6672 m
.76373 .81965 L
s
P
p
.2 0 1 r
.02 w
.79042 .56228 m
.95071 .56228 L
s
P
p
.2 0 1 r
.02 w
.79042 .56228 m
.9201 .46806 L
s
P
p
0 .4 1 r
.018 w
.71419 .58705 m
.71419 .6672 L
s
P
p
0 .4 1 r
.018 w
.71419 .58705 m
.79042 .56228 L
s
P
p
.2 0 1 r
.02 w
.44042 .21228 m
.53464 .0826 L
s
P
p
.2 0 1 r
.02 w
.44042 .21228 m
.44042 .05199 L
s
P
p
.2 0 1 r
.02 w
.3355 .28851 m
.18305 .23898 L
s
P
p
.2 0 1 r
.02 w
.3355 .28851 m
.18305 .33805 L
s
P
p
0 .4 1 r
.018 w
.41565 .28851 m
.44042 .21228 L
s
P
p
0 .4 1 r
.018 w
.41565 .28851 m
.3355 .28851 L
s
P
p
.2 0 1 r
.02 w
.56021 .72953 m
.43053 .82375 L
s
P
p
.2 0 1 r
.02 w
.56021 .72953 m
.51068 .88199 L
s
P
p
.2 0 1 r
.02 w
.68355 .68946 m
.81324 .78368 L
s
P
p
.2 0 1 r
.02 w
.68355 .68946 m
.84385 .68946 L
s
P
p
0 .4 1 r
.018 w
.60733 .66469 m
.56021 .72953 L
s
P
p
0 .4 1 r
.018 w
.60733 .66469 m
.68355 .68946 L
s
P
p
.2 0 1 r
.02 w
.60612 .20058 m
.75857 .15105 L
s
P
p
.2 0 1 r
.02 w
.60612 .20058 m
.70034 .0709 L
s
P
p
.2 0 1 r
.02 w
.47644 .20058 m
.38222 .0709 L
s
P
p
.2 0 1 r
.02 w
.47644 .20058 m
.32398 .15105 L
s
P
p
0 .4 1 r
.018 w
.54128 .24769 m
.60612 .20058 L
s
P
p
0 .4 1 r
.018 w
.54128 .24769 m
.47644 .20058 L
s
P
p
.2 0 1 r
.02 w
.39901 .68946 m
.23871 .68946 L
s
P
p
.2 0 1 r
.02 w
.39901 .68946 m
.26932 .78368 L
s
P
p
.2 0 1 r
.02 w
.52234 .72953 m
.57188 .88199 L
s
P
p
.2 0 1 r
.02 w
.52234 .72953 m
.65203 .82375 L
s
P
p
0 .4 1 r
.018 w
.47523 .66469 m
.39901 .68946 L
s
P
p
0 .4 1 r
.018 w
.47523 .66469 m
.52234 .72953 L
s
P
p
.2 0 1 r
.016 w
.54128 .46142 m
.71419 .58705 L
s
P
p
.2 0 1 r
.016 w
.54128 .46142 m
.41565 .28851 L
s
P
p
.2 0 1 r
.016 w
.54128 .46142 m
.60733 .66469 L
s
P
p
.2 0 1 r
.016 w
.54128 .46142 m
.54128 .24769 L
s
P
p
.2 0 1 r
.016 w
.54128 .46142 m
.47523 .66469 L
s
P
p
1 .6 0 r
.016 w
.5 .33438 m
.45872 .46142 L
s
P
p
1 .6 0 r
.016 w
.5 .33438 m
.5 .46796 L
s
P
p
1 .6 0 r
.016 w
.5 .33438 m
.54128 .46142 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.248465 1.49693 0.0374232 1.49693 [
[ 0 0 0 0 ]
[ 1 1.57178 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.57178 L
0 1.57178 L
closepath
clip
newpath
p
P
p
1 .6 0 r
.016 w
.5 .10277 m
.07781 1.40214 L
s
P
p
1 .6 0 r
.016 w
.5 .10277 m
.5 1.46901 L
s
P
p
1 .6 0 r
.016 w
.5 .10277 m
.92219 1.40214 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0492176 0.952381 [
[ 0 0 0 0 ]
[ 1 .85395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85395 L
0 .85395 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.24108 .70023 L
s
P
p
.2 0 1 r
.02 w
.38504 .65346 m
.29606 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.55565 .77592 L
s
P
p
.2 0 1 r
.02 w
.46668 .65346 m
.61064 .70023 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.38504 .65346 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.46668 .65346 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.68758 .21443 L
s
P
p
.2 0 1 r
.02 w
.53621 .21443 m
.65867 .12546 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.41179 .04525 L
s
P
p
.2 0 1 r
.02 w
.45857 .18921 m
.33611 .10023 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.53621 .21443 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.45857 .18921 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .53848 L
s
P
p
.2 0 1 r
.02 w
.25677 .58525 m
.11281 .63203 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.32282 .78461 L
s
P
p
.2 0 1 r
.02 w
.32282 .63324 m
.41179 .7557 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.25677 .58525 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.32282 .63324 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.75958 .40791 L
s
P
p
.2 0 1 r
.02 w
.63712 .31894 m
.78849 .31894 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.63591 .10893 L
s
P
p
.2 0 1 r
.02 w
.58914 .25289 m
.54236 .10893 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.63712 .31894 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.58914 .25289 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.10412 .33222 L
s
P
p
.2 0 1 r
.02 w
.19309 .45468 m
.04913 .40791 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.12934 .65479 L
s
P
p
.2 0 1 r
.02 w
.21832 .53233 m
.21832 .6837 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.19309 .45468 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.21832 .53233 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.42586 .6238 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.48822 .23003 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.30723 .58525 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.58914 .30334 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.23391 .48434 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.51407 .77979 L
s
P
p
.2 0 1 r
.02 w
.60304 .65733 m
.60304 .8087 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .65612 L
s
P
p
.2 0 1 r
.02 w
.66909 .60934 m
.81305 .56257 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.60304 .65733 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.66909 .60934 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.58975 .12432 L
s
P
p
.2 0 1 r
.02 w
.46729 .2133 m
.51407 .06934 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.26719 .14955 L
s
P
p
.2 0 1 r
.02 w
.38965 .23853 m
.23828 .23853 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.46729 .2133 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.38965 .23853 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.31522 .72432 L
s
P
p
.2 0 1 r
.02 w
.45918 .67755 m
.37021 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.62979 .80001 L
s
P
p
.2 0 1 r
.02 w
.54082 .67755 m
.68478 .72432 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.45918 .67755 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.54082 .67755 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.76172 .23853 L
s
P
p
.2 0 1 r
.02 w
.61035 .23853 m
.73281 .14955 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.48593 .06934 L
s
P
p
.2 0 1 r
.02 w
.53271 .2133 m
.41025 .12432 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.61035 .23853 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.53271 .2133 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .56257 L
s
P
p
.2 0 1 r
.02 w
.33091 .60934 m
.18695 .65612 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.39696 .8087 L
s
P
p
.2 0 1 r
.02 w
.39696 .65733 m
.48593 .77979 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.33091 .60934 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.39696 .65733 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.61863 .60934 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.43763 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.5 .64789 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.56237 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.38137 .60934 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.78168 .6837 L
s
P
p
.2 0 1 r
.02 w
.78168 .53233 m
.87066 .65479 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.95087 .40791 L
s
P
p
.2 0 1 r
.02 w
.80691 .45468 m
.89588 .33222 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.78168 .53233 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.80691 .45468 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.45764 .10893 L
s
P
p
.2 0 1 r
.02 w
.41086 .25289 m
.36409 .10893 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.21151 .31894 L
s
P
p
.2 0 1 r
.02 w
.36288 .31894 m
.24042 .40791 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.41086 .25289 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.36288 .31894 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.58821 .7557 L
s
P
p
.2 0 1 r
.02 w
.67718 .63324 m
.67718 .78461 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .63203 L
s
P
p
.2 0 1 r
.02 w
.74323 .58525 m
.88719 .53848 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.67718 .63324 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.74323 .58525 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.66389 .10023 L
s
P
p
.2 0 1 r
.02 w
.54143 .18921 m
.58821 .04525 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.34133 .12546 L
s
P
p
.2 0 1 r
.02 w
.46379 .21443 m
.31242 .21443 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.54143 .18921 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.46379 .21443 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.38936 .70023 L
s
P
p
.2 0 1 r
.02 w
.53332 .65346 m
.44435 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.70394 .77592 L
s
P
p
.2 0 1 r
.02 w
.61496 .65346 m
.75892 .70023 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.53332 .65346 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.61496 .65346 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.76609 .48434 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.41086 .30334 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.69277 .58525 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.51178 .23003 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.57414 .6238 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.42586 .42197 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.5 .44606 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.57414 .42197 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.000156707 0.952381 [
[ 0 0 0 0 ]
[ 1 .95269 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .95269 L
0 .95269 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.50175 .73978 m
.36166 .84156 L
s
P
p
.2 0 1 r
.02 w
.50175 .73978 m
.44824 .90446 L
s
P
p
.2 0 1 r
.02 w
.59056 .71093 m
.73064 .8127 L
s
P
p
.2 0 1 r
.02 w
.59056 .71093 m
.76371 .71093 L
s
P
p
0 .4 1 r
.018 w
.53567 .69309 m
.50175 .73978 L
s
P
p
0 .4 1 r
.018 w
.53567 .69309 m
.59056 .71093 L
s
P
p
.2 0 1 r
.02 w
.51102 .20873 m
.6757 .15522 L
s
P
p
.2 0 1 r
.02 w
.51102 .20873 m
.6128 .06865 L
s
P
p
.2 0 1 r
.02 w
.41764 .20873 m
.31586 .06865 L
s
P
p
.2 0 1 r
.02 w
.41764 .20873 m
.25296 .15522 L
s
P
p
0 .4 1 r
.018 w
.46433 .24266 m
.51102 .20873 L
s
P
p
0 .4 1 r
.018 w
.46433 .24266 m
.41764 .20873 L
s
P
p
.2 0 1 r
.02 w
.3381 .71093 m
.16495 .71093 L
s
P
p
.2 0 1 r
.02 w
.3381 .71093 m
.19801 .8127 L
s
P
p
.2 0 1 r
.02 w
.42691 .73978 m
.48042 .90446 L
s
P
p
.2 0 1 r
.02 w
.42691 .73978 m
.56699 .84156 L
s
P
p
0 .4 1 r
.018 w
.39299 .69309 m
.3381 .71093 L
s
P
p
0 .4 1 r
.018 w
.39299 .69309 m
.42691 .73978 L
s
P
p
.2 0 1 r
.02 w
.65775 .28675 m
.82242 .34025 L
s
P
p
.2 0 1 r
.02 w
.65775 .28675 m
.82242 .23324 L
s
P
p
.2 0 1 r
.02 w
.58219 .23186 m
.58219 .0587 L
s
P
p
.2 0 1 r
.02 w
.58219 .23186 m
.48042 .09177 L
s
P
p
0 .4 1 r
.018 w
.60003 .28675 m
.65775 .28675 L
s
P
p
0 .4 1 r
.018 w
.60003 .28675 m
.58219 .23186 L
s
P
p
.2 0 1 r
.02 w
.22266 .59139 m
.08258 .48961 L
s
P
p
.2 0 1 r
.02 w
.22266 .59139 m
.04951 .59139 L
s
P
p
.2 0 1 r
.02 w
.27755 .66694 m
.22405 .83162 L
s
P
p
.2 0 1 r
.02 w
.27755 .66694 m
.33106 .83162 L
s
P
p
0 .4 1 r
.018 w
.27755 .60922 m
.22266 .59139 L
s
P
p
0 .4 1 r
.018 w
.27755 .60922 m
.27755 .66694 L
s
P
p
.2 0 1 r
.016 w
.46433 .47352 m
.53567 .69309 L
s
P
p
.2 0 1 r
.016 w
.46433 .47352 m
.46433 .24266 L
s
P
p
.2 0 1 r
.016 w
.46433 .47352 m
.39299 .69309 L
s
P
p
.2 0 1 r
.016 w
.46433 .47352 m
.60003 .28675 L
s
P
p
.2 0 1 r
.016 w
.46433 .47352 m
.27755 .60922 L
s
P
p
.2 0 1 r
.02 w
.61786 .72084 m
.51609 .86092 L
s
P
p
.2 0 1 r
.02 w
.61786 .72084 m
.61786 .89399 L
s
P
p
.2 0 1 r
.02 w
.69342 .66595 m
.85809 .71945 L
s
P
p
.2 0 1 r
.02 w
.69342 .66595 m
.85809 .61244 L
s
P
p
0 .4 1 r
.018 w
.6357 .66595 m
.61786 .72084 L
s
P
p
0 .4 1 r
.018 w
.6357 .66595 m
.69342 .66595 L
s
P
p
.2 0 1 r
.02 w
.46258 .21291 m
.60266 .11114 L
s
P
p
.2 0 1 r
.02 w
.46258 .21291 m
.51609 .04823 L
s
P
p
.2 0 1 r
.02 w
.37377 .24177 m
.23368 .13999 L
s
P
p
.2 0 1 r
.02 w
.37377 .24177 m
.20062 .24177 L
s
P
p
0 .4 1 r
.018 w
.42866 .2596 m
.46258 .21291 L
s
P
p
0 .4 1 r
.018 w
.42866 .2596 m
.37377 .24177 L
s
P
p
.2 0 1 r
.02 w
.45331 .74396 m
.28863 .79747 L
s
P
p
.2 0 1 r
.02 w
.45331 .74396 m
.35153 .88405 L
s
P
p
.2 0 1 r
.02 w
.54669 .74396 m
.64847 .88405 L
s
P
p
.2 0 1 r
.02 w
.54669 .74396 m
.71137 .79747 L
s
P
p
0 .4 1 r
.018 w
.5 .71004 m
.45331 .74396 L
s
P
p
0 .4 1 r
.018 w
.5 .71004 m
.54669 .74396 L
s
P
p
.2 0 1 r
.02 w
.62623 .24177 m
.79938 .24177 L
s
P
p
.2 0 1 r
.02 w
.62623 .24177 m
.76632 .13999 L
s
P
p
.2 0 1 r
.02 w
.53742 .21291 m
.48391 .04823 L
s
P
p
.2 0 1 r
.02 w
.53742 .21291 m
.39734 .11114 L
s
P
p
0 .4 1 r
.018 w
.57134 .2596 m
.62623 .24177 L
s
P
p
0 .4 1 r
.018 w
.57134 .2596 m
.53742 .21291 L
s
P
p
.2 0 1 r
.02 w
.30658 .66595 m
.14191 .61244 L
s
P
p
.2 0 1 r
.02 w
.30658 .66595 m
.14191 .71945 L
s
P
p
.2 0 1 r
.02 w
.38214 .72084 m
.38214 .89399 L
s
P
p
.2 0 1 r
.02 w
.38214 .72084 m
.48391 .86092 L
s
P
p
0 .4 1 r
.018 w
.3643 .66595 m
.30658 .66595 L
s
P
p
0 .4 1 r
.018 w
.3643 .66595 m
.38214 .72084 L
s
P
p
.2 0 1 r
.016 w
.5 .47917 m
.6357 .66595 L
s
P
p
.2 0 1 r
.016 w
.5 .47917 m
.42866 .2596 L
s
P
p
.2 0 1 r
.016 w
.5 .47917 m
.5 .71004 L
s
P
p
.2 0 1 r
.016 w
.5 .47917 m
.57134 .2596 L
s
P
p
.2 0 1 r
.016 w
.5 .47917 m
.3643 .66595 L
s
P
p
.2 0 1 r
.02 w
.72245 .66694 m
.66894 .83162 L
s
P
p
.2 0 1 r
.02 w
.72245 .66694 m
.77595 .83162 L
s
P
p
.2 0 1 r
.02 w
.77734 .59139 m
.95049 .59139 L
s
P
p
.2 0 1 r
.02 w
.77734 .59139 m
.91742 .48961 L
s
P
p
0 .4 1 r
.018 w
.72245 .60922 m
.72245 .66694 L
s
P
p
0 .4 1 r
.018 w
.72245 .60922 m
.77734 .59139 L
s
P
p
.2 0 1 r
.02 w
.41781 .23186 m
.51958 .09177 L
s
P
p
.2 0 1 r
.02 w
.41781 .23186 m
.41781 .0587 L
s
P
p
.2 0 1 r
.02 w
.34225 .28675 m
.17758 .23324 L
s
P
p
.2 0 1 r
.02 w
.34225 .28675 m
.17758 .34025 L
s
P
p
0 .4 1 r
.018 w
.39997 .28675 m
.41781 .23186 L
s
P
p
0 .4 1 r
.018 w
.39997 .28675 m
.34225 .28675 L
s
P
p
.2 0 1 r
.02 w
.57309 .73978 m
.43301 .84156 L
s
P
p
.2 0 1 r
.02 w
.57309 .73978 m
.51958 .90446 L
s
P
p
.2 0 1 r
.02 w
.6619 .71093 m
.80199 .8127 L
s
P
p
.2 0 1 r
.02 w
.6619 .71093 m
.83505 .71093 L
s
P
p
0 .4 1 r
.018 w
.60701 .69309 m
.57309 .73978 L
s
P
p
0 .4 1 r
.018 w
.60701 .69309 m
.6619 .71093 L
s
P
p
.2 0 1 r
.02 w
.58236 .20873 m
.74704 .15522 L
s
P
p
.2 0 1 r
.02 w
.58236 .20873 m
.68414 .06865 L
s
P
p
.2 0 1 r
.02 w
.48898 .20873 m
.3872 .06865 L
s
P
p
.2 0 1 r
.02 w
.48898 .20873 m
.3243 .15522 L
s
P
p
0 .4 1 r
.018 w
.53567 .24266 m
.58236 .20873 L
s
P
p
0 .4 1 r
.018 w
.53567 .24266 m
.48898 .20873 L
s
P
p
.2 0 1 r
.02 w
.40944 .71093 m
.23629 .71093 L
s
P
p
.2 0 1 r
.02 w
.40944 .71093 m
.26936 .8127 L
s
P
p
.2 0 1 r
.02 w
.49825 .73978 m
.55176 .90446 L
s
P
p
.2 0 1 r
.02 w
.49825 .73978 m
.63834 .84156 L
s
P
p
0 .4 1 r
.018 w
.46433 .69309 m
.40944 .71093 L
s
P
p
0 .4 1 r
.018 w
.46433 .69309 m
.49825 .73978 L
s
P
p
.2 0 1 r
.016 w
.53567 .47352 m
.72245 .60922 L
s
P
p
.2 0 1 r
.016 w
.53567 .47352 m
.39997 .28675 L
s
P
p
.2 0 1 r
.016 w
.53567 .47352 m
.60701 .69309 L
s
P
p
.2 0 1 r
.016 w
.53567 .47352 m
.53567 .24266 L
s
P
p
.2 0 1 r
.016 w
.53567 .47352 m
.46433 .69309 L
s
P
p
1 .6 0 r
.016 w
.5 .36374 m
.46433 .47352 L
s
P
p
1 .6 0 r
.016 w
.5 .36374 m
.5 .47917 L
s
P
p
1 .6 0 r
.016 w
.5 .36374 m
.53567 .47352 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.018 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.018 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.018 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.02 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.02 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.02 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.02 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.02 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.02 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.02 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.02 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.02 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.02 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.02 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.02 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.02 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.02 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.02 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.02 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.02 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.02 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.02 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.02 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.02 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.02 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.02 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.02 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.02 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.02 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.02 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.02 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.02 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.02 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0591002 0.952381 [
[ 0 0 0 0 ]
[ 1 .83418 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .83418 L
0 .83418 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.27675 .53543 m
.05045 .53543 L
s
P
p
.2 0 1 r
.02 w
.27675 .53543 m
.09367 .66845 L
s
P
p
.2 0 1 r
.02 w
.39282 .57315 m
.46275 .78837 L
s
P
p
.2 0 1 r
.02 w
.39282 .57315 m
.5759 .70616 L
s
P
p
0 .4 1 r
.018 w
.34849 .51212 m
.27675 .53543 L
s
P
p
0 .4 1 r
.018 w
.34849 .51212 m
.39282 .57315 L
s
P
p
.2 0 1 r
.016 w
.44173 .22516 m
.34849 .51212 L
s
P
p
.2 0 1 r
.02 w
.43897 .58046 m
.22375 .65039 L
s
P
p
.2 0 1 r
.02 w
.43897 .58046 m
.30596 .76354 L
s
P
p
.2 0 1 r
.02 w
.56103 .58046 m
.69404 .76354 L
s
P
p
.2 0 1 r
.02 w
.56103 .58046 m
.77625 .65039 L
s
P
p
0 .4 1 r
.018 w
.5 .53612 m
.43897 .58046 L
s
P
p
0 .4 1 r
.018 w
.5 .53612 m
.56103 .58046 L
s
P
p
.2 0 1 r
.016 w
.5 .23439 m
.5 .53612 L
s
P
p
.2 0 1 r
.02 w
.60718 .57315 m
.4241 .70616 L
s
P
p
.2 0 1 r
.02 w
.60718 .57315 m
.53725 .78837 L
s
P
p
.2 0 1 r
.02 w
.72325 .53543 m
.90633 .66845 L
s
P
p
.2 0 1 r
.02 w
.72325 .53543 m
.94955 .53543 L
s
P
p
0 .4 1 r
.018 w
.65151 .51212 m
.60718 .57315 L
s
P
p
0 .4 1 r
.018 w
.65151 .51212 m
.72325 .53543 L
s
P
p
.2 0 1 r
.016 w
.55827 .22516 m
.65151 .51212 L
s
P
p
1 .6 0 r
.016 w
.5 .04581 m
.44173 .22516 L
s
P
p
1 .6 0 r
.016 w
.5 .04581 m
.5 .23439 L
s
P
p
1 .6 0 r
.016 w
.5 .04581 m
.55827 .22516 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`00014000=<000014`00`1<C0020003C00001@000=<000014`00`1<C0020003C00001P0
0T`00`1<C00O00=<6`0014`0C002C00704a<04`0C00F0003C000009<00<0C4`00T`20003C00001@0
00?600000/H00`36aP02aP8000?600004000014000==00001dd20003C@0001@000==00001dd20003
C@0001<014d0101=C@04C@0304e=01@000==00000Td01@1=CDd0009=0P000dd0000C0004C@1=009=
00L0CDd0C@1=01H000==00001dd20003C@0001@000?600001lH20003aP000100000B0003C01<00I<
00<0C0005`000d`0C006C00304`001L000=<04`00T`00`1<C0020003C00001<04D`E00]<60000d`0
C006C00304`001L000?60<H01/H00`36000B00003`02C@0404e=00E=00@0CDd00TdB009=00@0CDd0
1Dd0101=C@02CAH000==04d014d00`1=000D009=00@0CDd01dd0101=C@02CA001Td00`1=C@03C@03
04e=00A=4@02C@0404e=00E=00@0CDd00TdB00;600@0a/H01LH01036aP02aQ00000A00e<5P0=C1<0
0T`40007aT`0aP1<aP04009<4P02C00304`000E<00<0C0000T`D00m<5@0=C1H03LHB00003@02C@<0
00==0<H01/H00`1=0002009=3P02C@<000==0;@01[@00`1=0002009=4@03C@801LH200==4P05C@03
0<K600G600<0C@000ddD0003C@36009=1<H00`1=000B009=0`000dd0aP06aP0304d000800Td>00;6
0`000lH0aP06aP030<H000800/H>00003P05C0?60P02C0;61D`@00E<0k@014`0C4`2]0E<5@03aP04
C01<C0;65004C00304c600;600A<04a<0/H2C00404a<C0h01T`4aP0304c600;61T`?00E<0lH014`0
C4`2aPE<4008aP04C01<C0O63`00014000==a/H00Td200==0/H00dd0000D0003CKBd00==00@0CDe=
0[@00dd0000@00E=0/H3C@0404e=C@;61DdA009=0/H3C@0404e=C@;60ddD009=00G6CDe=0003C@03
aTe=01H000==a/H00dd0101=CDd2aP03C@0001@00lH3C@0404e=C@?64P0000h00d`3009<0P03C0<0
0d`@00=<0`03C00404a<C0<00d`F00=<00@0C4a<5@03C0@00d`0101<C4`5009<4003C0800d`0101<
C4`300=<4003C0<00d`0101<C4`300=<4003aP<00d`0101<C4`300?63`0000d000==00001@02C@03
4De=00L000==000030000dd00005009=00<ACDd01`000dd0000D009=00<ACDd07P02C@034De=01H0
0Td6009=00<ACDd01`000dd0000<0003C@0000D00Td00a5=C@070003C@0000`000?600001@02C@03
4De=00L000?60000300001D00T`00a5<000O0003C15<020000=<4D`080000d`AC00P0003C15<0200
00=<4D`080000d`AC00G00005@0014dA4DdP0003CA5=020000==4Dd080000ddAC@0P0003CA5=0200
00==4Dd080000ddAC@0G00005@0014`A4A4P00<A80034B000a4P00<A80034B000a4G00002P000dd0
00070003CA40008A00==000020000dd000060003C@0000P000E=4A4AC@0:0003C@00014000E=4A4A
C@0N0005CA4A4Dd04`02C@T000E=4A4AC@09009=20000dd000080005CA4A4Dd02P000dd000060003
aP0000P000E=4A4AC@0:0003aP0000T0000;0003C00000D000A<04`00T`00`1<00070003C00000P0
00=<00001P000d`0C002C00304`000L000=<00004@000d`0C002C00304`001000T`90003C01<009<
00<0C0002002C0T00T`60003C01<009<00<0C0001@02C0/000=<00001P000d`0C002C00304`000L0
00=<000020000lH000060003C01<009<00<0C0001`000lH0000:000030000dd000030003C@0000E=
00<0CDd01@000dd0000:0003C@0000<00Td00`1=C@03C@0304e=00D000==00001`02C@L00Td00`1=
C@03C@0304e=00L00Td8009=1@02C@0304e=00==00<0CDd01@02C@d000A=00000Td00`1=C@03C@03
04e=00<000==000030000dd00003009=00<0CDd00dd00`1=C@050003C@0000X000?600000`02C@03
04e=00==00<0CDd01@000lH0000;00003@001D`0001<008014`00`1<00020005C00004`03P001D`0
001<00<000E<04`0C0030005C00004`03003C0<000U<0000C01<04`00`0014`00003C0P01D`30009
C00004`0C01<00<000I<0000C003C0H01T`00lH0C0030005C01<04`00`000d`0aP06C0X000E<0000
C0030005C01<04`00`001D`0001<00h000G60000C0030005C01<04`00`001D`0003600h0000900E=
0/H014d00002C@0304d0009=0`000dg6aP05C@H01Dd2]004C@00009=00<0C@000Td30003CKBd00E=
2`02aP04C@00009=00<0C@000Td30003CLK600l000A=a/I=0`02C@0304d0009=0`000dg6aP02C@`0
0Td20003C@00008000E=04d0C@040003C@00009=2@05C@;600A=00000Td00`1=0002C@<000==a/H0
1Dd600O600A=00000Td00`1=0002C@<000==a/H01LH:00003P03C0<000A<001<0P001D`00036009<
4003C0<000A<001<0P001D`0002d009<4P001LH0001<008000A<001<0`000lH0000>00A<00G60000
C0020004C000C0<000?604`00T`>00=<0`000d`0C002C00304`0008000?6C4`04003C0<000A<001<
0P001D`00036009<4003aP<000A<001<0P0014`00003aPl0000@0004CLK6C@800Td2009=0lHD0003
CKBd009=00D0CDe=0002C@>d3`06C@;60Td01@1=CDd0009=0lH5C@h00Td2aP9=00D0CDe=0002C@?6
0TdA009=0/H2C@0604e=C@1=1<H2CA8000==a/H00Td01@1=CDd0009=0lHD00?60Td01@1=CDd0009=
0lHA00003008C0;60d`2aP03C<I<00E<3008C0:d0d`2]003C;A<00E<400014c6aT`2aP=<0/H014c6
C4`@00Q<0/H3C0;600=<aT`00T`00`1<C00<00U<0/H01Tc6a/I<aPI<3008C0;60d`2aP03C<I<00E<
300:aP9<0lH00dc6aP05aPd0000<0003C@00009=00/0CLI=aTg6CLH0aP04C@8000==00002P000dd0
0002C@0;04fdCKA=]4fdCK@014d20003C@0000/01Td2aP030<K600800/H6C@d01dd2aP05CLK6aTd0
0/H00dd0C@04C@l01dd2aP03CLI=00E=3`000dd00002C@0504g6aTd00/H2C@;600A=04e=0P000dd0
000:0003aP0000G600<0a/H01/H00`36aP020003aP0000/0000>009<00<0C4`02d`00`1<C00@009<
00<0C4`02d`00`1<C00>0003C000009<0P02C004aP1<aP=<0P02C08000=<00003002C00304`000U<
00<0C0000T`@009<00<0C4`02d`00`1<C00@009<00<0C4`02d`00`1<C00@00;600<0a/H02lH00`36
aP0?00003@000dd0C@02C@0304e=009=00<0CDd00Td01P1=CDd0C@h000==04d00Td00`1=C@02C@06
04e=04d00dd00`1=000@0003C@0000A=00<0CDd00Td20003C@0000l000==04d01dd00`1=C@06C@03
04d000d000==04d00Td00`1=C@02C@0304e=009=00H0CDe=04d>0003C@1=009=00<0C@000Td00`1=
C@02C@0604e=C@1=3P000lH0aP02aP030<H000;600<0a/H00/H01P36a/H0aPh0000>0003C00000=<
00@0C4`01D`30003C00000h000=<00000d`0101<C005C0<000=<0000400014`0C003C00804a<C01<
04`C0004C01<00U<00@0C01<4@001T`0001<00=<00H0C4a<04`30003C00000h000=<00001T`00`1<
C004C08000=<00003P001<H00005aP040<K600?60P000lH0000=00004`000dd0C@03C@8000==0000
60000dd0C@03C@8000==00005@02C@8000E=001=0002C@800TdF00E=00<0CDd00ddI009=00D0CDe=
0002CAX000==04d014d00`1=000I0003aP0000C600<0aP004`0001800T`0101<C002C00304a<01P0
0T`0101<C002C00304a<01T000E<04a<0003C1`000=<04`00T`00`1<000I0003C01<009<00H0C4a<
04`H009<00@0C4`00T`00`1<C00H00;600@0a/H00/H00`36aP0C0000o`030000o`030000o`030000
o`030000o`030000o`030000o`0300005@001D`0001<08H000A<001<0P000d`0001I00004P0014d0
04d30004C@00CAL000A=001=0P0014d004d20003C@0001@000==000014d00`1=C@020003C@0001@0
00==000014d00`1=C@020003C@0001@000A=001=0P0014d004d20003C@0001T000A=04e=6P0014d0
C@02C@0704e=04d0C@0B00004P02C08000=<04`00P02C1L000=<00000T`00`1<0002C08000=<0000
50000d`00007C08000=<000050000d`00007C08000=<000050000d`00002C00304`0009<0P000d`0
000C0004C000C08000I<04a<04`20003C00001<000A<04`00T`01`1<C01<04`04P0001000Td00`1=
C@02C@0404e=C@800TdC009=00<0C@001dd00`1=0002CAD000==04d01Td00`1=000G0003C@1=00I=
00<0C@0050001Dd004d000==00H0CDe=04d20003C@00018000==04d024d00`1=000F0003C@1=00Q=
4`0001001D`00`1<0002C00304a<009<4`0:C00304a<00A<4P02C00404a<00E<00@0C4`00T`B009<
00@0C4`01D`0101<C002C1<000=<04`014`00`1<C003C00304`001400T`20003C00000E<0P000d`0
0002C1001T`00`1<C003C00304a<00A<3`0001<00Td01<H0a/H3CAT01Dd4aP9=5`0=CAH03DdF00A=
00D0C@360004CA@04DdC00m=4@0000h01T`7aPE<4006C0;600D0aP1<0002aPI<3P02C0<000=<0<H0
1/H00`1<0002009<3P02C0<000=<0<H01/H00`1<0002009<4`04C005aTc60<H00T`H009<00?6C4`0
1<H2C1P000=<0<H01/H20003C0000100000F00==6@03C@8000C6CDd00Td00lH00003CA401Dd3aP04
C@1=C@;61Dd@00E=1<H00`36aP02aPE=4009C@04aTg6aPI=3`06C@?600A=04e=0/H6C@h01Td4aP04
04g600;61Dd>00005P03C1X00T`2aP=<00@0C4a<0/H3C1@000=<a/H00d`0101<C4`2aP03C00001@0
00=<a/H00lH00`36aP03aP03C00001@01T`01@1<C4c6009<4`04C0;60d`0101<C4`2aPA<4`000dc6
aP03C00304a<00?60T`A00005P000ddA000G00==1003C@0404e=C@D00Td?00==0`03C@0404e=C@<0
0dd@00==0`03aP040<K6aP<00ddA00Q=00<0CDd01TdB009=0`03C@0404e=C@<00TdA00==0`03C@04
04e=C@<00dd?00005`000a40000N009<00<AC4`05P000d`00005009<00<AC4`01`000d`0000<0003
C00000D00/H00a76aP070003C00000d00T`20003C<H0009<00HAC4`0aT`2009<40000d`00004009<
00<AC4`01P000d`0000=0003C00000D00T`00a5<C0070003C00000`0000F008A8@000ddAC@0P0003
CA5=020000?64LH06@001Dd0C@1=008000==4Dd00P001Dd0C@1=010000==00001P000ddAC@080003
C@0001D000==4Dd05`0001H00a4P0003C15<020000=<4D`080000lHAaP0F0003C00000A<0`000d`A
C00300A<0P000d`0000D0003C15<020000=<4D`05`0001H00a4P00<A80034B000a4F0003C@00009=
00<0C@000P034@<000A=04e=0P000dd0000D00<A80034AL0000E00044@0A4Al000E<4A4AC00C0003
C00000P000E<4A4AC00:0003C00000H000=<000020001LHA4A7600X000=<00002@001T`0C4`0C080
00E<4A4AC0020006C01<C01<2`02C0T000E<4A4AC009009<2002C0T000E<4A4AC009009<2`0001D0
00A=04e=5002C@L00Td01P1=CDd0C@P00Td90003C@0000H000==04d00Td00`1=00070003C@0000P0
00==00001P000lH0aP02aP030<H000L000==00002P03C@0604e=04d00dd00`1=0002C@0404e=C@d0
00==00001@000dd0C@02C@0304d000H000==00002P000dd000050003C@1=009=00<0C@001P000dd0
000;00005@001D`0C01<01D000=<00000`000d`00005C00304a<00D000=<00002P000d`00003009<
00<0C4`00d`00`1<C0050003C00000X000=<00000`02aP030<K600?600<0a/H01@000d`0000=0003
C01<009<00<0C4`00d`01P1<C4`0C10000=<00000P02C00304a<00=<00<0C4`010000d`0000<0003
C00000800T`00`1<C003C00304a<00@000=<0000300001@000I=001=04dF0003C@00009=0`001Dd0
C@1=00<000E=0000C@0>0005C@0004d00`001Dd0C@1=00<000E=0000C@0>0005C@000<H00`001LH0
aP3600<000G60000C@0@000>aTe=04d0C@1=04d0C@02C@03aP0000X01Dd2aP0304d0008000E=04d0
C@030004C@36aPE=1P05C@;600<0C@000P001Dd0C@1=00<000A=0<K61Dd:0000500014`004`20003
C00000l01D`00lI<00030005C000C0000T`30003C<K600E<1P05C0;600A<00000T`00`1<0002C0<0
00=<a/H01D`600E<0lH300;600<0aP000/H300?61D`:009<00G6C4a<0002C00304`0009<00D0C4a<
aP02C0l00d`3009<00<0C0000T`300=<3P02C08000=<00000P001D`0C01<00@000=<00000T`=0000
500014d004d20003C@00018014d3009=0P0014d004d30003aP1=009=3P03C@<000A=001=0P001Dd0
0036009=4003C@<000C600360P001LH00036009=3`001Dg6CDg600A=00<0C@001dd00lI=000@0005
C@0004d00P0014d004d30003aP0001000dd30003C@1=009=00<0C@000P000lI=C@0?00004`001D`0
001<008000=<00005@001lI<aT`0C0000d`00`1<C003aP03C000014000=<a/H00T`01@1<C4`0009<
0lHD0003C<K600;600D0a/K60005aPh00d`01P1<001<aP9<00?6C4`014`01/I<001<00=<2P09C005
04a<C0000T`3aPA<3`02C0;60T`01/I<C4c6C0C60T`?00004P000lI=00020006C@0004g64`03C@80
00C6C@360dd00lH0C@0200A=3@08C@;60dd01<I=CLH6C@`024d9aPI=2@001Dd0001=00800Td00lI=
aP02C@;61Td20005C@0004d02@03C@0504e=aTd00/H2C@?600A=aTe=0P03C@/024d00lH0aP02aP05
0<K6CLH01Dd=00002`06C003aP36008000?6C0000P000lH0aP05C0`024`01/H0aTc600?61T`<0003
C000009<0P02C003aTc6009<0/H0101<C4`20003C00000X000=<00000T`20003C<I<00;60T`2aP80
0T`20003C00000X000A<00001T`00lI<C002C004aTa<C0<000=<00003@05C0;600A<aTc61T`B00A<
00H0a/I<0<H2C00304a<009<400000l000==00000P001dg60036CLH010000dd0000?00==00<0CDd0
0Td2aP9=00?6CDd00ddB0003C@1=00a=00<0C@004@000dd0C@0<C@0304d000h000Q=001=04d0C@80
0/H024d00<H0C@1=0P000dd0000<00E=00@0CDd014d200A=4002C@0304e=00]=00<0CDd03`0000h0
00=<000024`00`1<C002C08000=<00003P000d`0C00=C00304`0010014`00`1<C002C00604a<04`0
14`@00A<00<0C4`00T`01P1<C01<00A<3@0014`004`20003C01<00Q<00D0C000C0020003C00000X0
00=<04`00T`00`1<C002C00304a<009<00H0C01<04`>0003C01<009<00<0C4`00T`00`1<C002C006
04a<C01<3P0000d000A=001=0`03C@0304e=00@000A=001=3P02C@0404e=00E=00D0CDe=0002C@03
04d000h00Td00`1=C@02C@0404e=00E=00<0C@000Td>009=00<0CDd01Dd00`1=C@05C@0304e=00h0
00A=000014d01@1=04d000A=0`000dd0000>0003C@0000E=00H0CDe=04d20003C@00010000==0000
1Dd00`1=C@03C@8000==00003P0001<000=<04`00`02C1/000E<04a<0004C1X000=<04`014`00`1<
000I0003C01<00A<00<0C0005P02C00704`004`0C0020004C01<C1H000=<04`01T`20003C00001H0
2D`D00004`000dd0C@030003C@1=01T00Td0101=C@02C@0304d001P00Td0101=C@02C@0304e=01P0
0Td0101=C@02C@0304e=01H000A=04e=0P000dd0C@02009=00<0C@005`0014d004d20003C@0001P0
00M=04e=04d0009=00<0C@004P00018000M<0000C01<00<000=<00006@02C00304`0068000E<04a<
0002C00304`005T0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0000G00034@0006D0
0Tf100005`000a40000L0003C00000D000=<0000>@001D`0C4`0009<0P02C00304`001D000=<0000
0d`0101<C4`20003C00001@000=<00000T`00`1<C002C08000=<0000<`0001H00Q4N00A=00<0CDd0
0TdK0003C@0000<000==00005`001Dd0CDd000==00D0CDd0C@0F0003C@0000==00@0CDe=0P000dd0
000D0003C@0000M=0P000dd0000J00034@0001H0000F00<A6P000d`00009C08000=<00005P0014`0
C4`20003C00001@00T`20007C01<C01<0002C00504`004`05@000d`0C006C00304`001L000=<04`0
1T`00`1<000L00034@0001H0000F00<A6P02C@0404e=00==00<0CDd00TdG00]=5@0ACA800Td0101=
C@05C@0404e=009=4P02C@0404e=00E=00@0CDd00TdI00<A5`0001D000@A014A700;C1H000=<0000
2D`00`1<C00E00e<5P0=C1H03D`K00<A5`0001D000DA01404@0G00Q=0/H00dg6C@05CA@000A=04d0
0dd00lI=0002CA<00Td30003C@3600K600<0C@000P02C@h00Td30003C@3600K600<0C@000P02C@h0
0Td30003C@3600K600<0C@000P02CAL00a4G00005@001A404@0A01T014`3aP0404c6aP=<5P05C003
aP3600E<4P06C0;60T`00`1<C002aPE<4005C0?600A<04a<0/H5C1001D`3aP04C01<C0;61D`G0005
4@0A01405P0001@000HA000A014J009=0/H2C@0304e=00;60ddC00A=00S6CDg6CLI=aPE=50000dg6
aP03C@0404e=C@;600==000050000dg6aP03C@0404e=C@;600==000050000dg6aP03C@0404e=C@;6
00==000060001A404@0A01H0000D00044@004@8000<A00004`05C0;60d`01@1<C4c600E<5P001lI<
04`0C<H05P03C0<00d`0101<C4`300=<4003C0<00d`0101<C4`300=<4003C0<00d`0101<C4`300=<
5`001D`0C01<01H0000D00044@004@8000<A00005P000dd00002009=00<ACDd00`02CAP00dd0101=
CDdE0003C@0000D00Td00a5=C@070003C@0000`000==00001@02C@034De=00L000==000030000dd0
0005009=00<ACDd01`000dd0000C0004C@00C@8000==00004`0001<000DA00004@0200034@0001D0
00=<00000`02C0034Da<00D000=<00002`0014`00005C006aP00C15<0P000lI<C003C0<000=<0000
4P000d`AC00P0003C15<020000=<4D`07P0014`004`20003C00001<0000C00054@0001400P000a40
000D0003C@0000@000E=4A4AC@060003C@0000X000==00000`02C@@000==4Dd01002C@D000==0000
4P000ddAC@0P0003CA5=020000==4Dd07P0014d004d20003C@0001<0000C00054@0001400`000a40
000?009<2@001D`AC15<00T00T`700=<0`000d`000030005C14A4D`01@0014`00003C1<00a4P00<A
80034Ad000E<0000C0030003C0000180000B00034@00008000DA00004@0C0003C@0000D000A=4A40
0Q400dd000050003C@0000T00Td6009=00DA01404@02C@H00Td90003C@0000P000E=4A4AC@0:0003
C@0000H000==000020001DdA4A5=00X000==00001P000dd000080005CA4A4Dd02P000dd0000?0005
C@0004d00`000dd0000B00004P000a40000200054@0001404005C0@00T`0101<C002C00304a<00@0
00=<04`00T`:0003aP0000=<0P001D`04@1<00800d`00`36aP0<0003C00000H000=<04`00T`00`1<
00070003C00000P000=<00001P000d`0C002C00304`000L000=<000020000d`000060003C01<009<
00<0C0001`000d`0000@0005C00004`00`000d`0000B00004P000a40000200034@00008000<A0000
3`03C@04aP1=C@801dd2009=00@0aTe=3P02C@@00Td00`1=0002C@@000==00003@000dd00003009=
0P03C@800Td50003C@0000X000==00000`02C@0304e=00==00<0CDd01@000dd0000:0003C@0000<0
0Td00`1=C@03C@0304e=00D000==000040000dd000020003C@00008000==00004@00014000<A0000
0`000a40000200034@0001400d`400M<1002C10000?600000P000d`0C004C00304`000<000?60000
3@001D`0001<00<000E<04`0C0030005C00004`03P001D`0001<00<000E<04`0C0030005C00004`0
3P001D`0001<00<000E<04`0C0030005C00004`04P000lI<00030003C000008000=<aP004@000140
00<A00000`000a40000200034@0001<000I=0000C@02C@0504e=04d00`000lH0000<00A=0`0024d0
04d0C@1=0P0014d00004C@P01Dd2aP03C@00008000E=04d0C@040003CLK600E=1P05C@;600A=0000
0Td00`1=0002C@<000==a/H01Dd600E=0/H014d00002C@0304d0009=0`000dg6aP05C@H01dd01<H0
0<H20003aTg6008000C600361dd:00004@000a40000300034@00008000<A00003`05C0;60T`0101<
C002C00304a<00;61D`<00E<0P02C00304`0009<0P000dc6aP02C0l00d`3009<00<0C0000T`30003
aTa<01000d`30004C000C08000E<0000aP02C1000d`30004C000C08000E<0000aP02C10000=<0000
0P02C007aP0004c6C0040003C00000d0000@00034@0000@000<A00000`000a40000A00E=0/H2C@03
aTe=00;600==a/H00Td>00==00d0CDg6CLI=04d0CLI=00;61Dd@0003CLK6009=00D0CDe=0002C@?6
50000dg6aP02C@0504e=C@000Td3aQ@000==a/H00Td01@1=CDd0009=0lH@009=0P03C@0504e=C@00
0dd0101=CDd2009=3@00010000<A000010000a40000300034@0001000T`00`1<C002aP9<00?60<H0
0T`2aP9<00<0C4`030000d`0C002C0030<I<00;600D0aTc60002aP04C<H0009<00<0C0002`04C080
00?6C<H00d`00lI<aP0200A<3@08C0;60d`2aP03C<I<00E<3008C0;60d`2aP03C<I<00E<2`000d`0
0002C0@000A<001<0P000d`00002009<0P000d`0000:000040000a40000400034@0000<000<A0000
3`02C@0304e=00==0/H014g6CLH7C@0304d000d000E=04e=0004C@0304e=009=00D0CDd0C@0>00Q=
1<H00`36aP02aPI=30000dd00002C@8000==aTd00/H2C@;60P02C@8000==00002P000dd00002C@80
00==aTd00/H2C@;60P02C@8000==000020000dd000060005C@1=C@000Td00`1=00070003C@0000T0
000?00034@0000D000<A000010000a40000>0004C01<00e<00D0C4`0C00@0003C01<00a<00<0C000
4@06C003aTa<00Q<4P000d`0C00<C00304`0014000=<04`034`00`1<000E0003C01<00<000=<04`0
500000l000<A00001@000a40000400034@0001800Td00`1=C@07C@0304d001D000==04d00dd00`1=
C@04CA<034d00`1=C@04CA0014d00`1=C@02C@0304e=009=00<0CDd00Td@00A=00<0C@000Td00`1=
C@02C@0304e=009=500014d004d30004C@00CA<0000?00034@0000D000<A000010000a40000B009<
00<0C4`00T`00`1<C002C00304a<01@00T`200A<00<0C4`00P000d`0000@009<00<0C0001D`00`1<
C003C00304`0009<3P02C00304a<00E<00<0C4`01D`00`1<C00>009<00<0C4`01D`00`1<C005C003
04a<018000=<00000P000d`0C0040003C0000100000>00034@0000H000<A00001@000a40000B0003
C@1=00==00<0CDd00Td00`1=000G009=1@02CAX000==04d014d00`1=000I0005C@1=C@000Td00`1=
000I0003C@1=00A=00<0C@0070000dd0C@0G00003P000a40000600034@0000D000<A00005`000d`0
C00o009<00@0C4`00T`00`1<C00H009<00@0C4`00T`00`1<C00H009<00@0C4`00T`00`1<C00f0000
5`000a40001T009=00<0CDd0O`000?l00`000?l00`000?l00`000?l00`000001\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.109419,
   0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110616, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.109415, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.74027, -0.110613, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.109416, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277,
   -0.110616, 0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.1939, -0.109419, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.271513, -1.26685, 0.0330059, 0.0330059}, {{42.5, 74.3125},
   {69.375, 37.5625}} -> {-1.42777, -1.26686, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26687, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.8965, -1.26686, 
  0.0330061, 0.0330061}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277,
   -1.26687, 0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.1939, -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.270009, -2.41739, 0.0329416, 0.0329416}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.74027, -2.42312, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277,
   -2.42311, 0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1939, -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .88222 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{179, 157},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002c0000W@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000;<0002c0000/`000;<0002c0000/`000;<0
002c0000?`03CBh00de00000?`03C1400d`600=<4@03C400000o00A=2`03C@800dd600==0P03C@/0
14e00000?`04C0/00d`200=<1P03C0800d`;00A<@000040014d:00A=00@0CDe=1P03C@0304e=009=
2P04CD40001000A<00@0C4a<1P08C0H024`600=<00<0C4`00Ta10000@@07C@L01dd600M=1`07CD80
001000Q<1`06C00304a<00A<00<0C4`014`700Q<@@00040024d800E=00<0CDd014d00`1=C@03C@P0
24e10000<P03C0/02D`401Q<1009C0/00d`c0000<P04C@/024d401Q=1008C@/014dc0000<P05C0/0
1d`400]<0P0;C0@01d`;00E<<`0003<01Dd;00I=1@0:C@802Td500I=2`05CC@0000c00I<2`05C0H0
24`400Q<1P05C0/01T`d0000<`08C@H02Dd600M=1007C@H02Dd600Q==00003D024`400Y<1P06C0@0
1T`600Y<1008C3H0000g00Q=0P0;C@@01dd400M=100;C@8024dh0000>009C0802T`300Q<0P08C0<0
2T`200U<>@0003T02Td200U=0P0BC@802Dd200Y=>P0003X02T`300Q<00<0C4`00T`00`1<C006C003
04a<009<00<0C4`01T`300Y<>`0003/02dd00`1=C@0;C@0304e=00I=00<0CDd02dd00`1=C@09CC`0
000l01M<0`06C0<05d`m0000?@0GC@0304e=00I=00<0CDd05Ddn0000:004C0`02d`00`1<C00XC003
04a<00U<3004C2T0000X00I=2P0dC@0304e=00]=2P06CBT0000X00U<1`0ZC0C654`800Q<:@0002X0
3Td502A=1LH@C@D03Dd[0000:P0EC0<04T`4aP9<1<H2C0K62T`401A<:`0002h09Td@aR1=;`000300
5T`2aPM<0/H3C13614`4aQI<<@0003801dd400U=0/H6C@?600==a/H04<H2C@K62Td300M=<`0003@0
1d`9009<0/H6C1k60d`800M<=@0003H01dd;00C600==a/H01LH014g6a/H200;60Td<aP/01ddg0000
=`08C0X00lH00dc6aP04aP9<00?600001002C0_62P08C3P0000i00Q=2009aP0304e=00L00Td20003
aTe=00K62008CCX0000k00Q<1P06aP04C<H0009<1`02C0<00T`6aPH024`l0000?@04C@k600==0000
0dd700==0P02C@K600<0a/H01LH4CCh0000g00Y<3LH2C0800T`9009<0P02C0030<K600_62d`g0000
<00AC@g60dd00`1=C@09009=00H0CDe=0<H2C@[64Td`00008`0MC0L01/H2009<00<0C4`02@02C003
04a<00<00T`5aPL074`T00008`0FC@l00lH2C@800Td00`1=C@09009=00<0CDd00P03C@?6400ECB@0
000S01E<4003aP9<0P02C00304a<00T00T`00`1<C002009<00@0a/K64@0DC2@0000U01Y=1@07aP==
00<0CDd00dd900E=00D0CDe=0008aPD06DdV0000;`0@C0W60T`01LH0C4`000A<2`04C00304a<0080
0T`:aQ5<;`0003H02Dd9aP==00<0CDd01Dd;00M=00@0CDe=2/H:CCH0000j00E<1lH300=<00@0C4`0
0d`;00=<00@0C4`00d`500K61D`k0000>008C@X02Dd;00U=2`08CCT0000f00Q<3@08C0/024`>00Q<
=`0003@024d@00M=1@024@@01ddA00Q==@00038024`C00E<1P024@D01D`D00Q<<`0003401ddF00E=
10044@<01DdG00M=<P0002l01d`I00A<10044@<014`J00M<<00002d01ddL00==0`064@800ddM00M=
;P0002/024`M00A<0P064@0304a<009<7P08C2`0000Y00Q=7`05C@PA14dP00Q=:P0002L024`P00I<
2145C24024`X00009P07CB801Dd:4@A=8`07CBL0000V00E<9005C08A00=<4A400Q400d`A4@04C2D0
1D`W00009P03CBH00Td00`1=4@074@05CA4A4@000TdW00==9`0004l00T`01@0A4A5<008A00=<4A40
0T`24@0304a<0540001?009=00D04A40C@024@05CA4A4@000Q400`1=C@1A00004003C3/00d`34@06
04`A4@1<0Q40100A4A43C3`00d`A00004003CC/00Td00`0A4@03C@8A00@0CA4A0Td24@0304e=03`0
0ddA00004004C3X00T`34@9<0a42C08A0T`34@9<>`04C140000@00E=>@02C@8A0dd24@==0Q43C@8A
0Tdj00E=4@0001401D`h0004C14A4@=<0Q43C08A0d`34@03C00003L01D`B00004P05CCL000==4A40
14d24@==0Q44C@8A00==0000=P05CA<0000C00E<=@001T`A4A5<009<0Q43C08A0T`00`1<4@024@03
C00003@01D`D00005005CC@000A=4A5=0P02C@8A00==04d00a4014d004d24@03C@0003<01DdE0000
5@05C38000A<4A4A0`001T`A4A5<009<0Q4014`000034@03C00003401D`F00005P05CBl00dd24@D0
0Q401Dd0001=008A1@024@==<005CAL0000G00E<;007C0D00Q401D`0001<008A1@07C2d01D`H0000
6005CBT01Dd0101=CDd5008A1@024@03C@0000800dd00`1=C@03CBX01DdI00006@05C2H01D`200E<
0`04C0<01D`200E<0P05C2L01D`J00006P05CB<01Dd4009=00<0CDd00P05C@<01Td0101=C@02C@@0
1DdT00E=6`0001/01D`P00E<1@03C00404a<00M<00<0C4`024`0101<C4`500E<8@05C1`0000800I=
3P05CAd01Dd7009=0P07C@0404e=009=00@0CDd014d2009=1`05CAh01Dd>00I=2@0000P02d`:00E<
6P05C0P00d`200A<00@0C4`01D`00`1<C00200=<0P03C0P01D`K00E<2P0;C0T00008015=1@05CAP0
14d:009=0`03C@800Td200==0P02C@<00dd2009=2P04CAT01Dd5015=2@0000`04T`00`1<C003C1D0
14`;00=<0P04C0800T`200=<0P02C0801D`0101<C4`;00A<5P05C00304a<011<3@00014054dB00E=
3002C@801Dd2009=0P03C@800Td2009=00D0CDe=0002C@`01DdC01A=4P0001L034`4aPh01D`=00=<
00D0C4a<0002C00504a<C0001D`01@1<C4`0009<0P06C0d01D`?00C634`H00005`04C@0304e=00E=
1/H:00E=3`02C@0404e=C@800Td00`1=C@02009=00<0CDd00P02C@0304e=00<01Dd?00E=2`06aPM=
00<0CDd00TdH00005`06C0@00T`9aPD01D`@00I<0`02C00404a<00=<00D0C4a<0002C00304a<00@0
1D`@00E<1P09aP9<1006C1P0000G00Q=1P09aP0304e=00==4P05C@@00Td0101=C@02C@<00Td0101=
C@02C@D014dB00E=0P09aPH024dH00006@08C0H01/H5C1<01D`500Q<0`08C0H014`C00E<1lH600Q<
6P0001/024d700;614dD00E=1`06C@D01Td800A=5004C@?61`08CA`0000M00Q<1`02C003aP0001<0
14`800I<1@06C0T00d`F009<00?600001@08C1h0000O00Q=1004aQ@014d900E=1`05C@X00ddE00C6
1008CB00000Q00M<0`04aQ@00d`:00A<2@04C0/00d`D00C60`07C280000S00M=00@0a/K65003C@/0
14d900A=2`04CA@00lH00`1=C@05CB@0000U00M<0/HC00=<3003C0/00d`<00A<4`03aPI<9P0002H0
24dB00A=3003C@/00dd<00E=4P03aPE=9`0002P024`?00A<3@03C0/00d`=00E<3`02C0C60T`Y0000
:P08C@`01Dd<00A=2`04C@`01Td<00A=1<H[0000:P02aPA<1/H700E<3@04C0/014`=009<00@0C4a<
2005aP=<0lH[00009P0:C@_600<0CDd014d<00E=2`05C@`00dd0101=CDd200[60dd3aPA=9`0001l0
4D`;aP=<00<0C4`03@05C0/01D`=009<0P03C0_64D`P00005`0HC@D01/H3C@0404e=C@`01dd900M=
3003C@800dd7aP@064dH00005@0IC0/000G6C4c60002C0d00T`00`1<C002C0T014`00`1<C00=009<
0`02C0;62P0IC1H0000E01U=3003aP==3008C@T024d<00==00<0a/H00/H;01U=5P0001D01D`00`1<
C00AC0`00lH2C0d00T`0101<C002C0T00T`0101<C002C0d00T`5aP/04d`00`1<C003C1H0000P01==
0P09aP03C@0000X00dd0101=C@02C@T00Td0101=C@03C@`00dd8aP804ddQ00009@0EC0K62003aP9<
0P02C00304a<00T00T`00`1<C002009<1<H80003aTa<00[63T`V00009@04C@0304e=01E=0P07aP==
0P02C@0404e=C@L00dd00`1=C@0200==2<H300g63TdV00009@04C0<05D`9aP9<0/H01@1<C036009<
0/H40003aTa<00;60T`20003aTa<01760d`4aPM<0`04C2H0000T00A=1008C@@02Dd=aP==0/H2C@O6
0Td3aP9=00<0a/H04/H3C@<024d400A=9@0002@014`200Q<2@000lI<C003C0C61P04aP04C<K6aP9<
1lH2C0C600=<a/H00/H600[62@08C08014`U00009003C@0304e=00I=2P08C@T01<H00dg6aP02aP03
0<K600K600<0a/H01lH900O600==00002008C@0404e=CBD0000S00e<2008C0?61P06aP03C<I<009<
2/H00dc6aP08aPH01<H7C0P03D`T00008`0=C@H02Td3aP04C@0000?62TdGaP<000==a/H00/H9C@H0
3DdT00008@09C0<00d`400a<0lHAC0?6100;aP03C<K600?60d`3aPa<1003C0<02D`R00007`08C@H0
0dd302==1P0:aP==0lHCC@<00dd600Q=800001d024`800=<00<0C4`06D`4aPE<0/H400G600=<a/H0
0lHKC00404a<C0P024`N00006`0:C@P08Dd00lI=C@03C@C60Td5aP9=0/HRC@P02TdL00006P0:C0T0
9d`3aP=<1<HWC0T02T`K00006P05C@0304e=009=1P0CC@806dd3aQI=0P0CC@H014d00`1=C@03CA/0
000J00=<0P04C0H02d`500A<0P0dC08014`500]<1P04C0800d`K00007`04C@D02Dd800A=00<0CDd0
1Dd202A=0P07C@0304e=009=2009C@D014dP00007P04C0H01D`0101<C4`800a<0`0RC0<034`800=<
00<0C4`00d`600A<7`0001h014d600==0`04C@L034d3029=0`0<C@L014d300==1P04CAl0000N00=<
3@04C0H02D`00`1<C002C00304a<00Y<0P08C08034`00`1<C002C00304a<00M<1P04C0d00d`O0000
;`03C@@02Td200A=00<0CDd02Td300I=0`0<C@0304e=009=0P0:C@@00dd`0000;`03C0802d`3015<
0`06C0<04D`300]<0P03C300000_00==00<0CDd02Dd400Y=00<0CDd014d200Q=0P06C@0304e=00Q=
100;C@0404e=CC00000c00Y<1@08C0@01D`00`1<C008C00304a<00=<1008C0D02T`d0000<`03C@03
04e=00==1@07C@L02Dd200U=1`07C@D01Dd0101=CDdd0000=P05C0H024`700Q<0P08C0L024`600E<
=`0003D01Td600Q=2006C@@01Td800Q=1P06CCH0000d00M<1@0:C0H01d`400M<1P0:C0D01d`e0000
<`08C@D02Td500Q=1008C@D02Td500Q==00003802D`500]<0`09C0@02D`300]<1@09C3<0000b00A=
00<0CDd00Td600Y=0P09C@H02Dd200Y=1P04C@0304e=009=<`0003800d`200=<1`06C00404a<C080
24`800Q<0P03C00304a<00A<1`03C0800d`c0000=`03C@H01dd600==00<0CDd00Td800A=00@0CDe=
1P07C@H00ddh0000=`03C0H024`800E<2005C0P024`600=<>00003l014d00`1=C@02C@P01Dd800E=
2004C@0304e=009=@00003l014`200=<1`07C0H01d`700=<0P04C400000o00==0`03C@L01dd600M=
1`03C@<00de00000A@03C0H014`0101<C4`600=<00<0C4`00T`600=<AP0004h014d0101=CDd600==
00<0CDd00Te?0000CP03C0800d`600=<0P03C4l0002c0000/`000;<0002c0000/`000;<0002c0000
\
\>"],
  ImageRangeCache->{{{0, 178}, {156, 0}} -> {-0.028489, 0.0368288, 0.00593808,
   0.00593808}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.016 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.016 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.016 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.016 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.016 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.016 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.016 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.016 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.016 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.016 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.016 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.016 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.016 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.016 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.016 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.016 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.016 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.016 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.016 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.016 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.016 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.016 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.016 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.016 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.016 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.016 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.016 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.016 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.016 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.016 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.016 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.016 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.016 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.016 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.016 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.016 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.016 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.016 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.016 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.016 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.67628 .68931 L
s
P
p
.2 0 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
.2 0 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.29503 .11519 L
s
P
p
.2 0 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
.2 0 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.4802 .77902 L
s
P
p
.2 0 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
.2 0 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.50922 .09046 L
s
P
p
.2 0 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
.2 0 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.26885 .73635 L
s
P
p
.2 0 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
.2 0 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.7833 .61652 L
s
P
p
.2 0 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
.2 0 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.2433 .18832 L
s
P
p
.2 0 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
.2 0 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.62455 .76243 L
s
P
p
.2 0 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
.2 0 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.43937 .0986 L
s
P
p
.2 0 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
.2 0 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.41035 .78716 L
s
P
p
.2 0 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
.2 0 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.86259 .51422 L
s
P
p
.2 0 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
.2 0 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.2167 .27384 L
s
P
p
.2 0 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
.2 0 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.7567 .70205 L
s
P
p
.2 0 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
.2 0 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.37545 .12793 L
s
P
p
.2 0 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
.2 0 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.56063 .79176 L
s
P
p
.2 0 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
.2 0 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.90639 .39243 L
s
P
p
.2 0 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
.2 0 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.21783 .3634 L
s
P
p
.2 0 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
.2 0 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.86372 .60378 L
s
P
p
.2 0 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
.2 0 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.32372 .17558 L
s
P
p
.2 0 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
.2 0 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.70497 .74969 L
s
P
p
.2 0 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
.2 0 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0415981 0.952381 [
[ 0 0 0 0 ]
[ 1 .86918 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .86918 L
0 .86918 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.43366 .67544 m
.31797 .79114 L
s
P
p
.2 0 1 r
.02 w
.52082 .66164 m
.6666 .73592 L
s
P
p
0 .4 1 r
.018 w
.47223 .63688 m
.43366 .67544 L
s
P
p
0 .4 1 r
.018 w
.47223 .63688 m
.52082 .66164 L
s
P
p
.2 0 1 r
.02 w
.52082 .18118 m
.6666 .1069 L
s
P
p
.2 0 1 r
.02 w
.43366 .16738 m
.31797 .05168 L
s
P
p
0 .4 1 r
.018 w
.47223 .20594 m
.52082 .18118 L
s
P
p
0 .4 1 r
.018 w
.47223 .20594 m
.43366 .16738 L
s
P
p
.2 0 1 r
.02 w
.28519 .62432 m
.12359 .64992 L
s
P
p
.2 0 1 r
.02 w
.36382 .66438 m
.4381 .81017 L
s
P
p
0 .4 1 r
.018 w
.33906 .61579 m
.28519 .62432 L
s
P
p
0 .4 1 r
.018 w
.33906 .61579 m
.36382 .66438 L
s
P
p
.2 0 1 r
.02 w
.64623 .27568 m
.80783 .30128 L
s
P
p
.2 0 1 r
.02 w
.58383 .21328 m
.55823 .05168 L
s
P
p
0 .4 1 r
.018 w
.59236 .26715 m
.64623 .27568 L
s
P
p
0 .4 1 r
.018 w
.59236 .26715 m
.58383 .21328 L
s
P
p
.2 0 1 r
.02 w
.19513 .49569 m
.04934 .42141 L
s
P
p
.2 0 1 r
.02 w
.23519 .57432 m
.20959 .73592 L
s
P
p
0 .4 1 r
.018 w
.24372 .52045 m
.19513 .49569 L
s
P
p
0 .4 1 r
.018 w
.24372 .52045 m
.23519 .57432 L
s
P
p
.2 0 1 r
.016 w
.4381 .42141 m
.47223 .63688 L
s
P
p
.2 0 1 r
.016 w
.4381 .42141 m
.47223 .20594 L
s
P
p
.2 0 1 r
.016 w
.4381 .42141 m
.33906 .61579 L
s
P
p
.2 0 1 r
.016 w
.4381 .42141 m
.59236 .26715 L
s
P
p
.2 0 1 r
.016 w
.4381 .42141 m
.24372 .52045 L
s
P
p
.2 0 1 r
.02 w
.55295 .67756 m
.47867 .82335 L
s
P
p
.2 0 1 r
.02 w
.63158 .6375 m
.79318 .6631 L
s
P
p
0 .4 1 r
.018 w
.57771 .62897 m
.55295 .67756 L
s
P
p
0 .4 1 r
.018 w
.57771 .62897 m
.63158 .6375 L
s
P
p
.2 0 1 r
.02 w
.48311 .18056 m
.5988 .06486 L
s
P
p
.2 0 1 r
.02 w
.39595 .19436 m
.25017 .12008 L
s
P
p
0 .4 1 r
.018 w
.44454 .21912 m
.48311 .18056 L
s
P
p
0 .4 1 r
.018 w
.44454 .21912 m
.39595 .19436 L
s
P
p
.2 0 1 r
.02 w
.39595 .67482 m
.25017 .7491 L
s
P
p
.2 0 1 r
.02 w
.48311 .68863 m
.5988 .80432 L
s
P
p
0 .4 1 r
.018 w
.44454 .65006 m
.39595 .67482 L
s
P
p
0 .4 1 r
.018 w
.44454 .65006 m
.48311 .68863 L
s
P
p
.2 0 1 r
.02 w
.63158 .23168 m
.79318 .20609 L
s
P
p
.2 0 1 r
.02 w
.55295 .19162 m
.47867 .04584 L
s
P
p
0 .4 1 r
.018 w
.57771 .24021 m
.63158 .23168 L
s
P
p
0 .4 1 r
.018 w
.57771 .24021 m
.55295 .19162 L
s
P
p
.2 0 1 r
.02 w
.27054 .58032 m
.10894 .55472 L
s
P
p
.2 0 1 r
.02 w
.33294 .64272 m
.35854 .80432 L
s
P
p
0 .4 1 r
.018 w
.32441 .58885 m
.27054 .58032 L
s
P
p
0 .4 1 r
.018 w
.32441 .58885 m
.33294 .64272 L
s
P
p
.2 0 1 r
.016 w
.47867 .43459 m
.57771 .62897 L
s
P
p
.2 0 1 r
.016 w
.47867 .43459 m
.44454 .21912 L
s
P
p
.2 0 1 r
.016 w
.47867 .43459 m
.44454 .65006 L
s
P
p
.2 0 1 r
.016 w
.47867 .43459 m
.57771 .24021 L
s
P
p
.2 0 1 r
.016 w
.47867 .43459 m
.32441 .58885 L
s
P
p
.2 0 1 r
.02 w
.66706 .64272 m
.64146 .80432 L
s
P
p
.2 0 1 r
.02 w
.72946 .58032 m
.89106 .55472 L
s
P
p
0 .4 1 r
.018 w
.67559 .58885 m
.66706 .64272 L
s
P
p
0 .4 1 r
.018 w
.67559 .58885 m
.72946 .58032 L
s
P
p
.2 0 1 r
.02 w
.44705 .19162 m
.52133 .04584 L
s
P
p
.2 0 1 r
.02 w
.36842 .23168 m
.20682 .20609 L
s
P
p
0 .4 1 r
.018 w
.42229 .24021 m
.44705 .19162 L
s
P
p
0 .4 1 r
.018 w
.42229 .24021 m
.36842 .23168 L
s
P
p
.2 0 1 r
.02 w
.51689 .68863 m
.4012 .80432 L
s
P
p
.2 0 1 r
.02 w
.60405 .67482 m
.74983 .7491 L
s
P
p
0 .4 1 r
.018 w
.55546 .65006 m
.51689 .68863 L
s
P
p
0 .4 1 r
.018 w
.55546 .65006 m
.60405 .67482 L
s
P
p
.2 0 1 r
.02 w
.60405 .19436 m
.74983 .12008 L
s
P
p
.2 0 1 r
.02 w
.51689 .18056 m
.4012 .06486 L
s
P
p
0 .4 1 r
.018 w
.55546 .21912 m
.60405 .19436 L
s
P
p
0 .4 1 r
.018 w
.55546 .21912 m
.51689 .18056 L
s
P
p
.2 0 1 r
.02 w
.36842 .6375 m
.20682 .6631 L
s
P
p
.2 0 1 r
.02 w
.44705 .67756 m
.52133 .82335 L
s
P
p
0 .4 1 r
.018 w
.42229 .62897 m
.36842 .6375 L
s
P
p
0 .4 1 r
.018 w
.42229 .62897 m
.44705 .67756 L
s
P
p
.2 0 1 r
.016 w
.52133 .43459 m
.67559 .58885 L
s
P
p
.2 0 1 r
.016 w
.52133 .43459 m
.42229 .24021 L
s
P
p
.2 0 1 r
.016 w
.52133 .43459 m
.55546 .65006 L
s
P
p
.2 0 1 r
.016 w
.52133 .43459 m
.55546 .21912 L
s
P
p
.2 0 1 r
.016 w
.52133 .43459 m
.42229 .62897 L
s
P
p
.2 0 1 r
.02 w
.76481 .57432 m
.79041 .73592 L
s
P
p
.2 0 1 r
.02 w
.80487 .49569 m
.95066 .42141 L
s
P
p
0 .4 1 r
.018 w
.75628 .52045 m
.76481 .57432 L
s
P
p
0 .4 1 r
.018 w
.75628 .52045 m
.80487 .49569 L
s
P
p
.2 0 1 r
.02 w
.41617 .21328 m
.44177 .05168 L
s
P
p
.2 0 1 r
.02 w
.35377 .27568 m
.19217 .30128 L
s
P
p
0 .4 1 r
.018 w
.40764 .26715 m
.41617 .21328 L
s
P
p
0 .4 1 r
.018 w
.40764 .26715 m
.35377 .27568 L
s
P
p
.2 0 1 r
.02 w
.63618 .66438 m
.5619 .81017 L
s
P
p
.2 0 1 r
.02 w
.71481 .62432 m
.87641 .64992 L
s
P
p
0 .4 1 r
.018 w
.66094 .61579 m
.63618 .66438 L
s
P
p
0 .4 1 r
.018 w
.66094 .61579 m
.71481 .62432 L
s
P
p
.2 0 1 r
.02 w
.56634 .16738 m
.68203 .05168 L
s
P
p
.2 0 1 r
.02 w
.47918 .18118 m
.3334 .1069 L
s
P
p
0 .4 1 r
.018 w
.52777 .20594 m
.56634 .16738 L
s
P
p
0 .4 1 r
.018 w
.52777 .20594 m
.47918 .18118 L
s
P
p
.2 0 1 r
.02 w
.47918 .66164 m
.3334 .73592 L
s
P
p
.2 0 1 r
.02 w
.56634 .67544 m
.68203 .79114 L
s
P
p
0 .4 1 r
.018 w
.52777 .63688 m
.47918 .66164 L
s
P
p
0 .4 1 r
.018 w
.52777 .63688 m
.56634 .67544 L
s
P
p
.2 0 1 r
.016 w
.5619 .42141 m
.75628 .52045 L
s
P
p
.2 0 1 r
.016 w
.5619 .42141 m
.40764 .26715 L
s
P
p
.2 0 1 r
.016 w
.5619 .42141 m
.66094 .61579 L
s
P
p
.2 0 1 r
.016 w
.5619 .42141 m
.52777 .20594 L
s
P
p
.2 0 1 r
.016 w
.5619 .42141 m
.52777 .63688 L
s
P
p
1 .6 0 r
.016 w
.5 .29992 m
.4381 .42141 L
s
P
p
1 .6 0 r
.016 w
.5 .29992 m
.47867 .43459 L
s
P
p
1 .6 0 r
.016 w
.5 .29992 m
.52133 .43459 L
s
P
p
1 .6 0 r
.016 w
.5 .29992 m
.5619 .42141 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0293046 0.952381 [
[ 0 0 0 0 ]
[ 1 .89377 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .89377 L
0 .89377 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.43617 .68497 m
.28645 .73362 L
s
P
p
.2 0 1 r
.02 w
.43617 .68497 m
.38752 .83469 L
s
P
p
.2 0 1 r
.02 w
.52003 .67169 m
.61257 .79905 L
s
P
p
.2 0 1 r
.02 w
.52003 .67169 m
.67746 .67169 L
s
P
p
0 .4 1 r
.018 w
.47328 .64786 m
.43617 .68497 L
s
P
p
0 .4 1 r
.018 w
.47328 .64786 m
.52003 .67169 L
s
P
p
.2 0 1 r
.02 w
.52003 .2094 m
.67746 .2094 L
s
P
p
.2 0 1 r
.02 w
.52003 .2094 m
.61257 .08204 L
s
P
p
.2 0 1 r
.02 w
.43617 .19612 m
.38752 .0464 L
s
P
p
.2 0 1 r
.02 w
.43617 .19612 m
.28645 .14747 L
s
P
p
0 .4 1 r
.018 w
.47328 .23323 m
.52003 .2094 L
s
P
p
0 .4 1 r
.018 w
.47328 .23323 m
.43617 .19612 L
s
P
p
.2 0 1 r
.02 w
.29332 .63578 m
.1436 .58713 L
s
P
p
.2 0 1 r
.02 w
.29332 .63578 m
.16596 .72831 L
s
P
p
.2 0 1 r
.02 w
.36897 .67432 m
.36897 .83175 L
s
P
p
.2 0 1 r
.02 w
.36897 .67432 m
.49633 .76686 L
s
P
p
0 .4 1 r
.018 w
.34515 .62757 m
.29332 .63578 L
s
P
p
0 .4 1 r
.018 w
.34515 .62757 m
.36897 .67432 L
s
P
p
.2 0 1 r
.02 w
.64069 .30033 m
.76805 .39286 L
s
P
p
.2 0 1 r
.02 w
.64069 .30033 m
.79042 .25168 L
s
P
p
.2 0 1 r
.02 w
.58066 .24029 m
.6293 .09057 L
s
P
p
.2 0 1 r
.02 w
.58066 .24029 m
.48812 .11293 L
s
P
p
0 .4 1 r
.018 w
.58886 .29212 m
.64069 .30033 L
s
P
p
0 .4 1 r
.018 w
.58886 .29212 m
.58066 .24029 L
s
P
p
.2 0 1 r
.02 w
.20666 .51201 m
.11413 .38465 L
s
P
p
.2 0 1 r
.02 w
.20666 .51201 m
.04924 .51201 L
s
P
p
.2 0 1 r
.02 w
.24521 .58767 m
.15268 .71503 L
s
P
p
.2 0 1 r
.02 w
.24521 .58767 m
.29386 .73739 L
s
P
p
0 .4 1 r
.018 w
.25342 .53584 m
.20666 .51201 L
s
P
p
0 .4 1 r
.018 w
.25342 .53584 m
.24521 .58767 L
s
P
p
.2 0 1 r
.016 w
.44044 .44054 m
.47328 .64786 L
s
P
p
.2 0 1 r
.016 w
.44044 .44054 m
.47328 .23323 L
s
P
p
.2 0 1 r
.016 w
.44044 .44054 m
.34515 .62757 L
s
P
p
.2 0 1 r
.016 w
.44044 .44054 m
.58886 .29212 L
s
P
p
.2 0 1 r
.016 w
.44044 .44054 m
.25342 .53584 L
s
P
p
.2 0 1 r
.02 w
.55095 .68701 m
.42359 .77954 L
s
P
p
.2 0 1 r
.02 w
.55095 .68701 m
.55095 .84443 L
s
P
p
.2 0 1 r
.02 w
.6266 .64846 m
.75396 .74099 L
s
P
p
.2 0 1 r
.02 w
.6266 .64846 m
.77632 .59981 L
s
P
p
0 .4 1 r
.018 w
.57477 .64025 m
.55095 .68701 L
s
P
p
0 .4 1 r
.018 w
.57477 .64025 m
.6266 .64846 L
s
P
p
.2 0 1 r
.02 w
.48375 .2088 m
.63347 .16016 L
s
P
p
.2 0 1 r
.02 w
.48375 .2088 m
.53239 .05908 L
s
P
p
.2 0 1 r
.02 w
.39989 .22209 m
.30735 .09473 L
s
P
p
.2 0 1 r
.02 w
.39989 .22209 m
.24246 .22209 L
s
P
p
0 .4 1 r
.018 w
.44664 .24591 m
.48375 .2088 L
s
P
p
0 .4 1 r
.018 w
.44664 .24591 m
.39989 .22209 L
s
P
p
.2 0 1 r
.02 w
.39989 .68437 m
.24246 .68437 L
s
P
p
.2 0 1 r
.02 w
.39989 .68437 m
.30735 .81173 L
s
P
p
.2 0 1 r
.02 w
.48375 .69765 m
.53239 .84737 L
s
P
p
.2 0 1 r
.02 w
.48375 .69765 m
.63347 .7463 L
s
P
p
0 .4 1 r
.018 w
.44664 .66055 m
.39989 .68437 L
s
P
p
0 .4 1 r
.018 w
.44664 .66055 m
.48375 .69765 L
s
P
p
.2 0 1 r
.02 w
.6266 .25799 m
.77632 .30664 L
s
P
p
.2 0 1 r
.02 w
.6266 .25799 m
.75396 .16546 L
s
P
p
.2 0 1 r
.02 w
.55095 .21945 m
.55095 .06202 L
s
P
p
.2 0 1 r
.02 w
.55095 .21945 m
.42359 .12691 L
s
P
p
0 .4 1 r
.018 w
.57477 .2662 m
.6266 .25799 L
s
P
p
0 .4 1 r
.018 w
.57477 .2662 m
.55095 .21945 L
s
P
p
.2 0 1 r
.02 w
.27923 .59344 m
.15186 .50091 L
s
P
p
.2 0 1 r
.02 w
.27923 .59344 m
.1295 .64209 L
s
P
p
.2 0 1 r
.02 w
.33926 .65348 m
.29062 .8032 L
s
P
p
.2 0 1 r
.02 w
.33926 .65348 m
.4318 .78084 L
s
P
p
0 .4 1 r
.018 w
.33105 .60165 m
.27923 .59344 L
s
P
p
0 .4 1 r
.018 w
.33105 .60165 m
.33926 .65348 L
s
P
p
.2 0 1 r
.016 w
.47948 .45323 m
.57477 .64025 L
s
P
p
.2 0 1 r
.016 w
.47948 .45323 m
.44664 .24591 L
s
P
p
.2 0 1 r
.016 w
.47948 .45323 m
.44664 .66055 L
s
P
p
.2 0 1 r
.016 w
.47948 .45323 m
.57477 .2662 L
s
P
p
.2 0 1 r
.016 w
.47948 .45323 m
.33105 .60165 L
s
P
p
.2 0 1 r
.02 w
.66074 .65348 m
.5682 .78084 L
s
P
p
.2 0 1 r
.02 w
.66074 .65348 m
.70938 .8032 L
s
P
p
.2 0 1 r
.02 w
.72077 .59344 m
.8705 .64209 L
s
P
p
.2 0 1 r
.02 w
.72077 .59344 m
.84814 .50091 L
s
P
p
0 .4 1 r
.018 w
.66895 .60165 m
.66074 .65348 L
s
P
p
0 .4 1 r
.018 w
.66895 .60165 m
.72077 .59344 L
s
P
p
.2 0 1 r
.02 w
.44905 .21945 m
.57641 .12691 L
s
P
p
.2 0 1 r
.02 w
.44905 .21945 m
.44905 .06202 L
s
P
p
.2 0 1 r
.02 w
.3734 .25799 m
.24604 .16546 L
s
P
p
.2 0 1 r
.02 w
.3734 .25799 m
.22368 .30664 L
s
P
p
0 .4 1 r
.018 w
.42523 .2662 m
.44905 .21945 L
s
P
p
0 .4 1 r
.018 w
.42523 .2662 m
.3734 .25799 L
s
P
p
.2 0 1 r
.02 w
.51625 .69765 m
.36653 .7463 L
s
P
p
.2 0 1 r
.02 w
.51625 .69765 m
.46761 .84737 L
s
P
p
.2 0 1 r
.02 w
.60011 .68437 m
.69265 .81173 L
s
P
p
.2 0 1 r
.02 w
.60011 .68437 m
.75754 .68437 L
s
P
p
0 .4 1 r
.018 w
.55336 .66055 m
.51625 .69765 L
s
P
p
0 .4 1 r
.018 w
.55336 .66055 m
.60011 .68437 L
s
P
p
.2 0 1 r
.02 w
.60011 .22209 m
.75754 .22209 L
s
P
p
.2 0 1 r
.02 w
.60011 .22209 m
.69265 .09473 L
s
P
p
.2 0 1 r
.02 w
.51625 .2088 m
.46761 .05908 L
s
P
p
.2 0 1 r
.02 w
.51625 .2088 m
.36653 .16016 L
s
P
p
0 .4 1 r
.018 w
.55336 .24591 m
.60011 .22209 L
s
P
p
0 .4 1 r
.018 w
.55336 .24591 m
.51625 .2088 L
s
P
p
.2 0 1 r
.02 w
.3734 .64846 m
.22368 .59981 L
s
P
p
.2 0 1 r
.02 w
.3734 .64846 m
.24604 .74099 L
s
P
p
.2 0 1 r
.02 w
.44905 .68701 m
.44905 .84443 L
s
P
p
.2 0 1 r
.02 w
.44905 .68701 m
.57641 .77954 L
s
P
p
0 .4 1 r
.018 w
.42523 .64025 m
.3734 .64846 L
s
P
p
0 .4 1 r
.018 w
.42523 .64025 m
.44905 .68701 L
s
P
p
.2 0 1 r
.016 w
.52052 .45323 m
.66895 .60165 L
s
P
p
.2 0 1 r
.016 w
.52052 .45323 m
.42523 .2662 L
s
P
p
.2 0 1 r
.016 w
.52052 .45323 m
.55336 .66055 L
s
P
p
.2 0 1 r
.016 w
.52052 .45323 m
.55336 .24591 L
s
P
p
.2 0 1 r
.016 w
.52052 .45323 m
.42523 .64025 L
s
P
p
.2 0 1 r
.02 w
.75479 .58767 m
.70614 .73739 L
s
P
p
.2 0 1 r
.02 w
.75479 .58767 m
.84732 .71503 L
s
P
p
.2 0 1 r
.02 w
.79334 .51201 m
.95076 .51201 L
s
P
p
.2 0 1 r
.02 w
.79334 .51201 m
.88587 .38465 L
s
P
p
0 .4 1 r
.018 w
.74658 .53584 m
.75479 .58767 L
s
P
p
0 .4 1 r
.018 w
.74658 .53584 m
.79334 .51201 L
s
P
p
.2 0 1 r
.02 w
.41934 .24029 m
.51188 .11293 L
s
P
p
.2 0 1 r
.02 w
.41934 .24029 m
.3707 .09057 L
s
P
p
.2 0 1 r
.02 w
.35931 .30033 m
.20958 .25168 L
s
P
p
.2 0 1 r
.02 w
.35931 .30033 m
.23195 .39286 L
s
P
p
0 .4 1 r
.018 w
.41114 .29212 m
.41934 .24029 L
s
P
p
0 .4 1 r
.018 w
.41114 .29212 m
.35931 .30033 L
s
P
p
.2 0 1 r
.02 w
.63103 .67432 m
.50367 .76686 L
s
P
p
.2 0 1 r
.02 w
.63103 .67432 m
.63103 .83175 L
s
P
p
.2 0 1 r
.02 w
.70668 .63578 m
.83404 .72831 L
s
P
p
.2 0 1 r
.02 w
.70668 .63578 m
.8564 .58713 L
s
P
p
0 .4 1 r
.018 w
.65485 .62757 m
.63103 .67432 L
s
P
p
0 .4 1 r
.018 w
.65485 .62757 m
.70668 .63578 L
s
P
p
.2 0 1 r
.02 w
.56383 .19612 m
.71355 .14747 L
s
P
p
.2 0 1 r
.02 w
.56383 .19612 m
.61248 .0464 L
s
P
p
.2 0 1 r
.02 w
.47997 .2094 m
.38743 .08204 L
s
P
p
.2 0 1 r
.02 w
.47997 .2094 m
.32254 .2094 L
s
P
p
0 .4 1 r
.018 w
.52672 .23323 m
.56383 .19612 L
s
P
p
0 .4 1 r
.018 w
.52672 .23323 m
.47997 .2094 L
s
P
p
.2 0 1 r
.02 w
.47997 .67169 m
.32254 .67169 L
s
P
p
.2 0 1 r
.02 w
.47997 .67169 m
.38743 .79905 L
s
P
p
.2 0 1 r
.02 w
.56383 .68497 m
.61248 .83469 L
s
P
p
.2 0 1 r
.02 w
.56383 .68497 m
.71355 .73362 L
s
P
p
0 .4 1 r
.018 w
.52672 .64786 m
.47997 .67169 L
s
P
p
0 .4 1 r
.018 w
.52672 .64786 m
.56383 .68497 L
s
P
p
.2 0 1 r
.016 w
.55956 .44054 m
.74658 .53584 L
s
P
p
.2 0 1 r
.016 w
.55956 .44054 m
.41114 .29212 L
s
P
p
.2 0 1 r
.016 w
.55956 .44054 m
.65485 .62757 L
s
P
p
.2 0 1 r
.016 w
.55956 .44054 m
.52672 .23323 L
s
P
p
.2 0 1 r
.016 w
.55956 .44054 m
.52672 .64786 L
s
P
p
1 .6 0 r
.016 w
.5 .32365 m
.44044 .44054 L
s
P
p
1 .6 0 r
.016 w
.5 .32365 m
.47948 .45323 L
s
P
p
1 .6 0 r
.016 w
.5 .32365 m
.52052 .45323 L
s
P
p
1 .6 0 r
.016 w
.5 .32365 m
.55956 .44054 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0372599 0.952381 [
[ 0 0 0 0 ]
[ 1 .87786 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .87786 L
0 .87786 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.432 .6915 m
.30746 .75496 L
s
P
p
.2 0 1 r
.02 w
.432 .6915 m
.36854 .81604 L
s
P
p
.2 0 1 r
.02 w
.52134 .67735 m
.62018 .77619 L
s
P
p
.2 0 1 r
.02 w
.52134 .67735 m
.6594 .69922 L
s
P
p
0 .4 1 r
.018 w
.47153 .65197 m
.432 .6915 L
s
P
p
0 .4 1 r
.018 w
.47153 .65197 m
.52134 .67735 L
s
P
p
.2 0 1 r
.02 w
.52134 .18482 m
.6594 .16296 L
s
P
p
.2 0 1 r
.02 w
.52134 .18482 m
.62018 .08599 L
s
P
p
.2 0 1 r
.02 w
.432 .17067 m
.36854 .04613 L
s
P
p
.2 0 1 r
.02 w
.432 .17067 m
.30746 .10722 L
s
P
p
0 .4 1 r
.018 w
.47153 .2102 m
.52134 .18482 L
s
P
p
0 .4 1 r
.018 w
.47153 .2102 m
.432 .17067 L
s
P
p
.2 0 1 r
.02 w
.2798 .63909 m
.14174 .61723 L
s
P
p
.2 0 1 r
.02 w
.2798 .63909 m
.15526 .70255 L
s
P
p
.2 0 1 r
.02 w
.3604 .68016 m
.38226 .81822 L
s
P
p
.2 0 1 r
.02 w
.3604 .68016 m
.45923 .779 L
s
P
p
0 .4 1 r
.018 w
.33502 .63035 m
.2798 .63909 L
s
P
p
0 .4 1 r
.018 w
.33502 .63035 m
.3604 .68016 L
s
P
p
.2 0 1 r
.02 w
.6499 .2817 m
.77444 .34515 L
s
P
p
.2 0 1 r
.02 w
.6499 .2817 m
.78795 .25983 L
s
P
p
.2 0 1 r
.02 w
.58593 .21773 m
.6078 .07968 L
s
P
p
.2 0 1 r
.02 w
.58593 .21773 m
.52248 .09319 L
s
P
p
0 .4 1 r
.018 w
.59468 .27295 m
.6499 .2817 L
s
P
p
0 .4 1 r
.018 w
.59468 .27295 m
.58593 .21773 L
s
P
p
.2 0 1 r
.02 w
.18747 .50723 m
.08863 .4084 L
s
P
p
.2 0 1 r
.02 w
.18747 .50723 m
.04942 .48537 L
s
P
p
.2 0 1 r
.02 w
.22854 .58784 m
.16508 .71237 L
s
P
p
.2 0 1 r
.02 w
.22854 .58784 m
.2504 .72589 L
s
P
p
0 .4 1 r
.018 w
.23728 .53262 m
.18747 .50723 L
s
P
p
0 .4 1 r
.018 w
.23728 .53262 m
.22854 .58784 L
s
P
p
.2 0 1 r
.016 w
.43654 .43109 m
.47153 .65197 L
s
P
p
.2 0 1 r
.016 w
.43654 .43109 m
.47153 .2102 L
s
P
p
.2 0 1 r
.016 w
.43654 .43109 m
.33502 .63035 L
s
P
p
.2 0 1 r
.016 w
.43654 .43109 m
.59468 .27295 L
s
P
p
.2 0 1 r
.016 w
.43654 .43109 m
.23728 .53262 L
s
P
p
.2 0 1 r
.02 w
.55428 .69368 m
.45545 .79251 L
s
P
p
.2 0 1 r
.02 w
.55428 .69368 m
.53242 .83173 L
s
P
p
.2 0 1 r
.02 w
.63488 .65261 m
.75942 .71606 L
s
P
p
.2 0 1 r
.02 w
.63488 .65261 m
.77294 .63074 L
s
P
p
0 .4 1 r
.018 w
.57966 .64386 m
.55428 .69368 L
s
P
p
0 .4 1 r
.018 w
.57966 .64386 m
.63488 .65261 L
s
P
p
.2 0 1 r
.02 w
.48268 .18418 m
.60722 .12073 L
s
P
p
.2 0 1 r
.02 w
.48268 .18418 m
.54614 .05965 L
s
P
p
.2 0 1 r
.02 w
.39334 .19834 m
.2945 .0995 L
s
P
p
.2 0 1 r
.02 w
.39334 .19834 m
.25528 .17647 L
s
P
p
0 .4 1 r
.018 w
.44315 .22372 m
.48268 .18418 L
s
P
p
0 .4 1 r
.018 w
.44315 .22372 m
.39334 .19834 L
s
P
p
.2 0 1 r
.02 w
.39334 .69087 m
.25528 .71273 L
s
P
p
.2 0 1 r
.02 w
.39334 .69087 m
.2945 .7897 L
s
P
p
.2 0 1 r
.02 w
.48268 .70502 m
.54614 .82956 L
s
P
p
.2 0 1 r
.02 w
.48268 .70502 m
.60722 .76847 L
s
P
p
0 .4 1 r
.018 w
.44315 .66548 m
.39334 .69087 L
s
P
p
0 .4 1 r
.018 w
.44315 .66548 m
.48268 .70502 L
s
P
p
.2 0 1 r
.02 w
.63488 .23659 m
.77294 .25846 L
s
P
p
.2 0 1 r
.02 w
.63488 .23659 m
.75942 .17314 L
s
P
p
.2 0 1 r
.02 w
.55428 .19552 m
.53242 .05747 L
s
P
p
.2 0 1 r
.02 w
.55428 .19552 m
.45545 .09669 L
s
P
p
0 .4 1 r
.018 w
.57966 .24534 m
.63488 .23659 L
s
P
p
0 .4 1 r
.018 w
.57966 .24534 m
.55428 .19552 L
s
P
p
.2 0 1 r
.02 w
.26478 .59399 m
.14024 .53053 L
s
P
p
.2 0 1 r
.02 w
.26478 .59399 m
.12673 .61585 L
s
P
p
.2 0 1 r
.02 w
.32875 .65796 m
.30688 .79601 L
s
P
p
.2 0 1 r
.02 w
.32875 .65796 m
.3922 .78249 L
s
P
p
0 .4 1 r
.018 w
.32 .60274 m
.26478 .59399 L
s
P
p
0 .4 1 r
.018 w
.32 .60274 m
.32875 .65796 L
s
P
p
.2 0 1 r
.016 w
.47813 .4446 m
.57966 .64386 L
s
P
p
.2 0 1 r
.016 w
.47813 .4446 m
.44315 .22372 L
s
P
p
.2 0 1 r
.016 w
.47813 .4446 m
.44315 .66548 L
s
P
p
.2 0 1 r
.016 w
.47813 .4446 m
.57966 .24534 L
s
P
p
.2 0 1 r
.016 w
.47813 .4446 m
.32 .60274 L
s
P
p
.2 0 1 r
.02 w
.67125 .65796 m
.6078 .78249 L
s
P
p
.2 0 1 r
.02 w
.67125 .65796 m
.69312 .79601 L
s
P
p
.2 0 1 r
.02 w
.73522 .59399 m
.87327 .61585 L
s
P
p
.2 0 1 r
.02 w
.73522 .59399 m
.85976 .53053 L
s
P
p
0 .4 1 r
.018 w
.68 .60274 m
.67125 .65796 L
s
P
p
0 .4 1 r
.018 w
.68 .60274 m
.73522 .59399 L
s
P
p
.2 0 1 r
.02 w
.44572 .19552 m
.54455 .09669 L
s
P
p
.2 0 1 r
.02 w
.44572 .19552 m
.46758 .05747 L
s
P
p
.2 0 1 r
.02 w
.36512 .23659 m
.24058 .17314 L
s
P
p
.2 0 1 r
.02 w
.36512 .23659 m
.22706 .25846 L
s
P
p
0 .4 1 r
.018 w
.42034 .24534 m
.44572 .19552 L
s
P
p
0 .4 1 r
.018 w
.42034 .24534 m
.36512 .23659 L
s
P
p
.2 0 1 r
.02 w
.51732 .70502 m
.39278 .76847 L
s
P
p
.2 0 1 r
.02 w
.51732 .70502 m
.45386 .82956 L
s
P
p
.2 0 1 r
.02 w
.60666 .69087 m
.7055 .7897 L
s
P
p
.2 0 1 r
.02 w
.60666 .69087 m
.74472 .71273 L
s
P
p
0 .4 1 r
.018 w
.55685 .66548 m
.51732 .70502 L
s
P
p
0 .4 1 r
.018 w
.55685 .66548 m
.60666 .69087 L
s
P
p
.2 0 1 r
.02 w
.60666 .19834 m
.74472 .17647 L
s
P
p
.2 0 1 r
.02 w
.60666 .19834 m
.7055 .0995 L
s
P
p
.2 0 1 r
.02 w
.51732 .18418 m
.45386 .05965 L
s
P
p
.2 0 1 r
.02 w
.51732 .18418 m
.39278 .12073 L
s
P
p
0 .4 1 r
.018 w
.55685 .22372 m
.60666 .19834 L
s
P
p
0 .4 1 r
.018 w
.55685 .22372 m
.51732 .18418 L
s
P
p
.2 0 1 r
.02 w
.36512 .65261 m
.22706 .63074 L
s
P
p
.2 0 1 r
.02 w
.36512 .65261 m
.24058 .71606 L
s
P
p
.2 0 1 r
.02 w
.44572 .69368 m
.46758 .83173 L
s
P
p
.2 0 1 r
.02 w
.44572 .69368 m
.54455 .79251 L
s
P
p
0 .4 1 r
.018 w
.42034 .64386 m
.36512 .65261 L
s
P
p
0 .4 1 r
.018 w
.42034 .64386 m
.44572 .69368 L
s
P
p
.2 0 1 r
.016 w
.52187 .4446 m
.68 .60274 L
s
P
p
.2 0 1 r
.016 w
.52187 .4446 m
.42034 .24534 L
s
P
p
.2 0 1 r
.016 w
.52187 .4446 m
.55685 .66548 L
s
P
p
.2 0 1 r
.016 w
.52187 .4446 m
.55685 .22372 L
s
P
p
.2 0 1 r
.016 w
.52187 .4446 m
.42034 .64386 L
s
P
p
.2 0 1 r
.02 w
.77146 .58784 m
.7496 .72589 L
s
P
p
.2 0 1 r
.02 w
.77146 .58784 m
.83492 .71237 L
s
P
p
.2 0 1 r
.02 w
.81253 .50723 m
.95058 .48537 L
s
P
p
.2 0 1 r
.02 w
.81253 .50723 m
.91137 .4084 L
s
P
p
0 .4 1 r
.018 w
.76272 .53262 m
.77146 .58784 L
s
P
p
0 .4 1 r
.018 w
.76272 .53262 m
.81253 .50723 L
s
P
p
.2 0 1 r
.02 w
.41407 .21773 m
.47752 .09319 L
s
P
p
.2 0 1 r
.02 w
.41407 .21773 m
.3922 .07968 L
s
P
p
.2 0 1 r
.02 w
.3501 .2817 m
.21205 .25983 L
s
P
p
.2 0 1 r
.02 w
.3501 .2817 m
.22556 .34515 L
s
P
p
0 .4 1 r
.018 w
.40532 .27295 m
.41407 .21773 L
s
P
p
0 .4 1 r
.018 w
.40532 .27295 m
.3501 .2817 L
s
P
p
.2 0 1 r
.02 w
.6396 .68016 m
.54077 .779 L
s
P
p
.2 0 1 r
.02 w
.6396 .68016 m
.61774 .81822 L
s
P
p
.2 0 1 r
.02 w
.7202 .63909 m
.84474 .70255 L
s
P
p
.2 0 1 r
.02 w
.7202 .63909 m
.85826 .61723 L
s
P
p
0 .4 1 r
.018 w
.66498 .63035 m
.6396 .68016 L
s
P
p
0 .4 1 r
.018 w
.66498 .63035 m
.7202 .63909 L
s
P
p
.2 0 1 r
.02 w
.568 .17067 m
.69254 .10722 L
s
P
p
.2 0 1 r
.02 w
.568 .17067 m
.63146 .04613 L
s
P
p
.2 0 1 r
.02 w
.47866 .18482 m
.37982 .08599 L
s
P
p
.2 0 1 r
.02 w
.47866 .18482 m
.3406 .16296 L
s
P
p
0 .4 1 r
.018 w
.52847 .2102 m
.568 .17067 L
s
P
p
0 .4 1 r
.018 w
.52847 .2102 m
.47866 .18482 L
s
P
p
.2 0 1 r
.02 w
.47866 .67735 m
.3406 .69922 L
s
P
p
.2 0 1 r
.02 w
.47866 .67735 m
.37982 .77619 L
s
P
p
.2 0 1 r
.02 w
.568 .6915 m
.63146 .81604 L
s
P
p
.2 0 1 r
.02 w
.568 .6915 m
.69254 .75496 L
s
P
p
0 .4 1 r
.018 w
.52847 .65197 m
.47866 .67735 L
s
P
p
0 .4 1 r
.018 w
.52847 .65197 m
.568 .6915 L
s
P
p
.2 0 1 r
.016 w
.56346 .43109 m
.76272 .53262 L
s
P
p
.2 0 1 r
.016 w
.56346 .43109 m
.40532 .27295 L
s
P
p
.2 0 1 r
.016 w
.56346 .43109 m
.66498 .63035 L
s
P
p
.2 0 1 r
.016 w
.56346 .43109 m
.52847 .2102 L
s
P
p
.2 0 1 r
.016 w
.56346 .43109 m
.52847 .65197 L
s
P
p
1 .6 0 r
.016 w
.5 .30655 m
.43654 .43109 L
s
P
p
1 .6 0 r
.016 w
.5 .30655 m
.47813 .4446 L
s
P
p
1 .6 0 r
.016 w
.5 .30655 m
.52187 .4446 L
s
P
p
1 .6 0 r
.016 w
.5 .30655 m
.56346 .43109 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.02 w
.4359 .67792 m
.29503 .74969 L
s
P
p
0 .4 1 r
.02 w
.4359 .67792 m
.36412 .81879 L
s
P
p
0 .4 1 r
.02 w
.52012 .66458 m
.63191 .77637 L
s
P
p
0 .4 1 r
.02 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
0 .4 1 r
.02 w
.52012 .20031 m
.67628 .17558 L
s
P
p
0 .4 1 r
.02 w
.52012 .20031 m
.63191 .08852 L
s
P
p
0 .4 1 r
.02 w
.4359 .18697 m
.36412 .0461 L
s
P
p
0 .4 1 r
.02 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
0 .4 1 r
.02 w
.29243 .62851 m
.13628 .60378 L
s
P
p
0 .4 1 r
.02 w
.29243 .62851 m
.15156 .70029 L
s
P
p
0 .4 1 r
.02 w
.36841 .66723 m
.39314 .82338 L
s
P
p
0 .4 1 r
.02 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
0 .4 1 r
.02 w
.6413 .29163 m
.78217 .3634 L
s
P
p
0 .4 1 r
.02 w
.6413 .29163 m
.79745 .2669 L
s
P
p
0 .4 1 r
.02 w
.581 .23133 m
.60573 .07518 L
s
P
p
0 .4 1 r
.02 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
0 .4 1 r
.02 w
.2054 .50422 m
.09361 .39243 L
s
P
p
0 .4 1 r
.02 w
.2054 .50422 m
.04925 .47949 L
s
P
p
0 .4 1 r
.02 w
.24412 .5802 m
.17234 .72107 L
s
P
p
0 .4 1 r
.02 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
0 .4 1 r
.02 w
.55117 .67997 m
.43937 .79176 L
s
P
p
0 .4 1 r
.02 w
.55117 .67997 m
.52643 .83612 L
s
P
p
0 .4 1 r
.02 w
.62714 .64125 m
.76801 .71303 L
s
P
p
0 .4 1 r
.02 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
0 .4 1 r
.02 w
.48368 .19971 m
.62455 .12793 L
s
P
p
0 .4 1 r
.02 w
.48368 .19971 m
.55545 .05884 L
s
P
p
0 .4 1 r
.02 w
.39946 .21305 m
.28766 .10125 L
s
P
p
0 .4 1 r
.02 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
0 .4 1 r
.02 w
.39946 .67731 m
.2433 .70205 L
s
P
p
0 .4 1 r
.02 w
.39946 .67731 m
.28766 .78911 L
s
P
p
0 .4 1 r
.02 w
.48368 .69065 m
.55545 .83152 L
s
P
p
0 .4 1 r
.02 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
0 .4 1 r
.02 w
.62714 .24911 m
.7833 .27384 L
s
P
p
0 .4 1 r
.02 w
.62714 .24911 m
.76801 .17733 L
s
P
p
0 .4 1 r
.02 w
.55117 .2104 m
.52643 .05424 L
s
P
p
0 .4 1 r
.02 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
0 .4 1 r
.02 w
.27828 .586 m
.13741 .51422 L
s
P
p
0 .4 1 r
.02 w
.27828 .586 m
.12212 .61073 L
s
P
p
0 .4 1 r
.02 w
.33857 .64629 m
.31384 .80245 L
s
P
p
0 .4 1 r
.02 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
0 .4 1 r
.02 w
.66143 .64629 m
.58965 .78716 L
s
P
p
0 .4 1 r
.02 w
.66143 .64629 m
.68616 .80245 L
s
P
p
0 .4 1 r
.02 w
.72172 .586 m
.87788 .61073 L
s
P
p
0 .4 1 r
.02 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
0 .4 1 r
.02 w
.44883 .2104 m
.56063 .0986 L
s
P
p
0 .4 1 r
.02 w
.44883 .2104 m
.47357 .05424 L
s
P
p
0 .4 1 r
.02 w
.37286 .24911 m
.23199 .17733 L
s
P
p
0 .4 1 r
.02 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
0 .4 1 r
.02 w
.51632 .69065 m
.37545 .76243 L
s
P
p
0 .4 1 r
.02 w
.51632 .69065 m
.44455 .83152 L
s
P
p
0 .4 1 r
.02 w
.60054 .67731 m
.71234 .78911 L
s
P
p
0 .4 1 r
.02 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
0 .4 1 r
.02 w
.60054 .21305 m
.7567 .18832 L
s
P
p
0 .4 1 r
.02 w
.60054 .21305 m
.71234 .10125 L
s
P
p
0 .4 1 r
.02 w
.51632 .19971 m
.44455 .05884 L
s
P
p
0 .4 1 r
.02 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
0 .4 1 r
.02 w
.37286 .64125 m
.2167 .61652 L
s
P
p
0 .4 1 r
.02 w
.37286 .64125 m
.23199 .71303 L
s
P
p
0 .4 1 r
.02 w
.44883 .67997 m
.47357 .83612 L
s
P
p
0 .4 1 r
.02 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
0 .4 1 r
.02 w
.75588 .5802 m
.73115 .73635 L
s
P
p
0 .4 1 r
.02 w
.75588 .5802 m
.82766 .72107 L
s
P
p
0 .4 1 r
.02 w
.7946 .50422 m
.95075 .47949 L
s
P
p
0 .4 1 r
.02 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
0 .4 1 r
.02 w
.419 .23133 m
.49078 .09046 L
s
P
p
0 .4 1 r
.02 w
.419 .23133 m
.39427 .07518 L
s
P
p
0 .4 1 r
.02 w
.3587 .29163 m
.20255 .2669 L
s
P
p
0 .4 1 r
.02 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
0 .4 1 r
.02 w
.63159 .66723 m
.5198 .77902 L
s
P
p
0 .4 1 r
.02 w
.63159 .66723 m
.60686 .82338 L
s
P
p
0 .4 1 r
.02 w
.70757 .62851 m
.84844 .70029 L
s
P
p
0 .4 1 r
.02 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
0 .4 1 r
.02 w
.5641 .18697 m
.70497 .11519 L
s
P
p
0 .4 1 r
.02 w
.5641 .18697 m
.63588 .0461 L
s
P
p
0 .4 1 r
.02 w
.47988 .20031 m
.36809 .08852 L
s
P
p
0 .4 1 r
.02 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
0 .4 1 r
.02 w
.47988 .66458 m
.32372 .68931 L
s
P
p
0 .4 1 r
.02 w
.47988 .66458 m
.36809 .77637 L
s
P
p
0 .4 1 r
.02 w
.5641 .67792 m
.63588 .81879 L
s
P
p
0 .4 1 r
.02 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0150404 1.03008 0.025752 1.03008 [
[ 0 0 0 0 ]
[ 1 1.08158 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.08158 L
0 1.08158 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.24404 .77756 m
.05147 .74706 L
s
P
p
.2 0 1 r
.02 w
.24404 .77756 m
.07032 .86607 L
s
P
p
.2 0 1 r
.02 w
.33773 .8253 m
.36823 1.01786 L
s
P
p
.2 0 1 r
.02 w
.33773 .8253 m
.47559 .96316 L
s
P
p
0 .4 1 r
.018 w
.30822 .76739 m
.24404 .77756 L
s
P
p
0 .4 1 r
.018 w
.30822 .76739 m
.33773 .8253 L
s
P
p
.2 0 1 r
.02 w
.60844 .29399 m
.80101 .32449 L
s
P
p
.2 0 1 r
.02 w
.60844 .29399 m
.78216 .20548 L
s
P
p
.2 0 1 r
.02 w
.51475 .24625 m
.48425 .05369 L
s
P
p
.2 0 1 r
.02 w
.51475 .24625 m
.37689 .10839 L
s
P
p
0 .4 1 r
.018 w
.54426 .30415 m
.60844 .29399 L
s
P
p
0 .4 1 r
.018 w
.54426 .30415 m
.51475 .24625 L
s
P
p
.2 0 1 r
.016 w
.42624 .53577 m
.30822 .76739 L
s
P
p
.2 0 1 r
.016 w
.42624 .53577 m
.54426 .30415 L
s
P
p
.2 0 1 r
.02 w
.37601 .83774 m
.18345 .86823 L
s
P
p
.2 0 1 r
.02 w
.37601 .83774 m
.23815 .9756 L
s
P
p
.2 0 1 r
.02 w
.47987 .85418 m
.56838 1.0279 L
s
P
p
.2 0 1 r
.02 w
.47987 .85418 m
.65359 .9427 L
s
P
p
0 .4 1 r
.018 w
.43392 .80823 m
.37601 .83774 L
s
P
p
0 .4 1 r
.018 w
.43392 .80823 m
.47987 .85418 L
s
P
p
.2 0 1 r
.02 w
.57315 .26523 m
.76572 .23473 L
s
P
p
.2 0 1 r
.02 w
.57315 .26523 m
.71101 .12737 L
s
P
p
.2 0 1 r
.02 w
.4693 .24878 m
.38078 .07506 L
s
P
p
.2 0 1 r
.02 w
.4693 .24878 m
.29558 .16026 L
s
P
p
0 .4 1 r
.018 w
.51525 .29473 m
.57315 .26523 L
s
P
p
0 .4 1 r
.018 w
.51525 .29473 m
.4693 .24878 L
s
P
p
.2 0 1 r
.016 w
.47458 .55148 m
.43392 .80823 L
s
P
p
.2 0 1 r
.016 w
.47458 .55148 m
.51525 .29473 L
s
P
p
.2 0 1 r
.02 w
.52013 .85418 m
.34641 .9427 L
s
P
p
.2 0 1 r
.02 w
.52013 .85418 m
.43162 1.0279 L
s
P
p
.2 0 1 r
.02 w
.62399 .83774 m
.76185 .9756 L
s
P
p
.2 0 1 r
.02 w
.62399 .83774 m
.81655 .86823 L
s
P
p
0 .4 1 r
.018 w
.56608 .80823 m
.52013 .85418 L
s
P
p
0 .4 1 r
.018 w
.56608 .80823 m
.62399 .83774 L
s
P
p
.2 0 1 r
.02 w
.5307 .24878 m
.70442 .16026 L
s
P
p
.2 0 1 r
.02 w
.5307 .24878 m
.61922 .07506 L
s
P
p
.2 0 1 r
.02 w
.42685 .26523 m
.28899 .12737 L
s
P
p
.2 0 1 r
.02 w
.42685 .26523 m
.23428 .23473 L
s
P
p
0 .4 1 r
.018 w
.48475 .29473 m
.5307 .24878 L
s
P
p
0 .4 1 r
.018 w
.48475 .29473 m
.42685 .26523 L
s
P
p
.2 0 1 r
.016 w
.52542 .55148 m
.56608 .80823 L
s
P
p
.2 0 1 r
.016 w
.52542 .55148 m
.48475 .29473 L
s
P
p
.2 0 1 r
.02 w
.66227 .8253 m
.52441 .96316 L
s
P
p
.2 0 1 r
.02 w
.66227 .8253 m
.63177 1.01786 L
s
P
p
.2 0 1 r
.02 w
.75596 .77756 m
.92968 .86607 L
s
P
p
.2 0 1 r
.02 w
.75596 .77756 m
.94853 .74706 L
s
P
p
0 .4 1 r
.018 w
.69178 .76739 m
.66227 .8253 L
s
P
p
0 .4 1 r
.018 w
.69178 .76739 m
.75596 .77756 L
s
P
p
.2 0 1 r
.02 w
.48525 .24625 m
.62311 .10839 L
s
P
p
.2 0 1 r
.02 w
.48525 .24625 m
.51575 .05369 L
s
P
p
.2 0 1 r
.02 w
.39156 .29399 m
.21784 .20548 L
s
P
p
.2 0 1 r
.02 w
.39156 .29399 m
.19899 .32449 L
s
P
p
0 .4 1 r
.018 w
.45574 .30415 m
.48525 .24625 L
s
P
p
0 .4 1 r
.018 w
.45574 .30415 m
.39156 .29399 L
s
P
p
.2 0 1 r
.016 w
.57376 .53577 m
.69178 .76739 L
s
P
p
.2 0 1 r
.016 w
.57376 .53577 m
.45574 .30415 L
s
P
p
1 .6 0 r
.016 w
.5 .39101 m
.42624 .53577 L
s
P
p
1 .6 0 r
.016 w
.5 .39101 m
.47458 .55148 L
s
P
p
1 .6 0 r
.016 w
.5 .39101 m
.52542 .55148 L
s
P
p
1 .6 0 r
.016 w
.5 .39101 m
.57376 .53577 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.030885 0.952381 [
[ 0 0 0 0 ]
[ 1 .89061 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .89061 L
0 .89061 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.44297 .69641 m
.30904 .76466 L
s
P
p
.2 0 1 r
.02 w
.44297 .69641 m
.37473 .83035 L
s
P
p
.2 0 1 r
.02 w
.52305 .68373 m
.62934 .79002 L
s
P
p
.2 0 1 r
.02 w
.52305 .68373 m
.67152 .70724 L
s
P
p
0 .4 1 r
.018 w
.4784 .66098 m
.44297 .69641 L
s
P
p
0 .4 1 r
.018 w
.4784 .66098 m
.52305 .68373 L
s
P
p
.2 0 1 r
.02 w
.52305 .19282 m
.67152 .16931 L
s
P
p
.2 0 1 r
.02 w
.52305 .19282 m
.62934 .08653 L
s
P
p
.2 0 1 r
.02 w
.44297 .18014 m
.37473 .0462 L
s
P
p
.2 0 1 r
.02 w
.44297 .18014 m
.30904 .1119 L
s
P
p
0 .4 1 r
.018 w
.4784 .21557 m
.52305 .19282 L
s
P
p
0 .4 1 r
.018 w
.4784 .21557 m
.44297 .18014 L
s
P
p
.2 0 1 r
.02 w
.29127 .64702 m
.1428 .6235 L
s
P
p
.2 0 1 r
.02 w
.29127 .64702 m
.15734 .71526 L
s
P
p
.2 0 1 r
.02 w
.36351 .68383 m
.38703 .8323 L
s
P
p
.2 0 1 r
.02 w
.36351 .68383 m
.4698 .79012 L
s
P
p
0 .4 1 r
.018 w
.34076 .63918 m
.29127 .64702 L
s
P
p
0 .4 1 r
.018 w
.34076 .63918 m
.36351 .68383 L
s
P
p
.2 0 1 r
.02 w
.65206 .28668 m
.786 .35492 L
s
P
p
.2 0 1 r
.02 w
.65206 .28668 m
.80053 .26316 L
s
P
p
.2 0 1 r
.02 w
.59473 .22935 m
.61825 .08088 L
s
P
p
.2 0 1 r
.02 w
.59473 .22935 m
.52649 .09541 L
s
P
p
0 .4 1 r
.018 w
.60257 .27884 m
.65206 .28668 L
s
P
p
0 .4 1 r
.018 w
.60257 .27884 m
.59473 .22935 L
s
P
p
.2 0 1 r
.02 w
.19758 .51789 m
.09129 .4116 L
s
P
p
.2 0 1 r
.02 w
.19758 .51789 m
.04911 .49438 L
s
P
p
.2 0 1 r
.02 w
.23439 .59013 m
.16614 .72407 L
s
P
p
.2 0 1 r
.02 w
.23439 .59013 m
.2579 .7386 L
s
P
p
0 .4 1 r
.018 w
.24223 .54064 m
.19758 .51789 L
s
P
p
0 .4 1 r
.018 w
.24223 .54064 m
.23439 .59013 L
s
P
p
.2 0 1 r
.016 w
.44313 .43828 m
.4784 .66098 L
s
P
p
.2 0 1 r
.016 w
.44313 .43828 m
.4784 .21557 L
s
P
p
.2 0 1 r
.016 w
.44313 .43828 m
.34076 .63918 L
s
P
p
.2 0 1 r
.016 w
.44313 .43828 m
.60257 .27884 L
s
P
p
.2 0 1 r
.016 w
.44313 .43828 m
.24223 .54064 L
s
P
p
.2 0 1 r
.02 w
.56002 .69594 m
.45373 .80223 L
s
P
p
.2 0 1 r
.02 w
.56002 .69594 m
.53651 .84441 L
s
P
p
.2 0 1 r
.02 w
.63226 .65913 m
.7662 .72737 L
s
P
p
.2 0 1 r
.02 w
.63226 .65913 m
.78073 .63561 L
s
P
p
0 .4 1 r
.018 w
.58277 .65129 m
.56002 .69594 L
s
P
p
0 .4 1 r
.018 w
.58277 .65129 m
.63226 .65913 L
s
P
p
.2 0 1 r
.02 w
.48056 .19225 m
.6145 .12401 L
s
P
p
.2 0 1 r
.02 w
.48056 .19225 m
.54881 .05832 L
s
P
p
.2 0 1 r
.02 w
.40049 .20493 m
.29419 .09864 L
s
P
p
.2 0 1 r
.02 w
.40049 .20493 m
.25202 .18142 L
s
P
p
0 .4 1 r
.018 w
.44513 .22768 m
.48056 .19225 L
s
P
p
0 .4 1 r
.018 w
.44513 .22768 m
.40049 .20493 L
s
P
p
.2 0 1 r
.02 w
.40049 .69584 m
.25202 .71935 L
s
P
p
.2 0 1 r
.02 w
.40049 .69584 m
.29419 .80213 L
s
P
p
.2 0 1 r
.02 w
.48056 .70852 m
.54881 .84246 L
s
P
p
.2 0 1 r
.02 w
.48056 .70852 m
.6145 .77677 L
s
P
p
0 .4 1 r
.018 w
.44513 .67309 m
.40049 .69584 L
s
P
p
0 .4 1 r
.018 w
.44513 .67309 m
.48056 .70852 L
s
P
p
.2 0 1 r
.02 w
.63226 .24164 m
.78073 .26516 L
s
P
p
.2 0 1 r
.02 w
.63226 .24164 m
.7662 .1734 L
s
P
p
.2 0 1 r
.02 w
.56002 .20484 m
.53651 .05637 L
s
P
p
.2 0 1 r
.02 w
.56002 .20484 m
.45373 .09854 L
s
P
p
0 .4 1 r
.018 w
.58277 .24948 m
.63226 .24164 L
s
P
p
0 .4 1 r
.018 w
.58277 .24948 m
.56002 .20484 L
s
P
p
.2 0 1 r
.02 w
.27148 .60199 m
.13754 .53374 L
s
P
p
.2 0 1 r
.02 w
.27148 .60199 m
.12301 .6255 L
s
P
p
.2 0 1 r
.02 w
.3288 .65932 m
.30529 .80779 L
s
P
p
.2 0 1 r
.02 w
.3288 .65932 m
.39705 .79325 L
s
P
p
0 .4 1 r
.018 w
.32097 .60983 m
.27148 .60199 L
s
P
p
0 .4 1 r
.018 w
.32097 .60983 m
.3288 .65932 L
s
P
p
.2 0 1 r
.016 w
.4804 .45039 m
.58277 .65129 L
s
P
p
.2 0 1 r
.016 w
.4804 .45039 m
.44513 .22768 L
s
P
p
.2 0 1 r
.016 w
.4804 .45039 m
.44513 .67309 L
s
P
p
.2 0 1 r
.016 w
.4804 .45039 m
.58277 .24948 L
s
P
p
.2 0 1 r
.016 w
.4804 .45039 m
.32097 .60983 L
s
P
p
.2 0 1 r
.02 w
.6712 .65932 m
.60295 .79325 L
s
P
p
.2 0 1 r
.02 w
.6712 .65932 m
.69471 .80779 L
s
P
p
.2 0 1 r
.02 w
.72852 .60199 m
.87699 .6255 L
s
P
p
.2 0 1 r
.02 w
.72852 .60199 m
.86246 .53374 L
s
P
p
0 .4 1 r
.018 w
.67903 .60983 m
.6712 .65932 L
s
P
p
0 .4 1 r
.018 w
.67903 .60983 m
.72852 .60199 L
s
P
p
.2 0 1 r
.02 w
.43998 .20484 m
.54627 .09854 L
s
P
p
.2 0 1 r
.02 w
.43998 .20484 m
.46349 .05637 L
s
P
p
.2 0 1 r
.02 w
.36774 .24164 m
.2338 .1734 L
s
P
p
.2 0 1 r
.02 w
.36774 .24164 m
.21927 .26516 L
s
P
p
0 .4 1 r
.018 w
.41723 .24948 m
.43998 .20484 L
s
P
p
0 .4 1 r
.018 w
.41723 .24948 m
.36774 .24164 L
s
P
p
.2 0 1 r
.02 w
.51944 .70852 m
.3855 .77677 L
s
P
p
.2 0 1 r
.02 w
.51944 .70852 m
.45119 .84246 L
s
P
p
.2 0 1 r
.02 w
.59951 .69584 m
.70581 .80213 L
s
P
p
.2 0 1 r
.02 w
.59951 .69584 m
.74798 .71935 L
s
P
p
0 .4 1 r
.018 w
.55487 .67309 m
.51944 .70852 L
s
P
p
0 .4 1 r
.018 w
.55487 .67309 m
.59951 .69584 L
s
P
p
.2 0 1 r
.02 w
.59951 .20493 m
.74798 .18142 L
s
P
p
.2 0 1 r
.02 w
.59951 .20493 m
.70581 .09864 L
s
P
p
.2 0 1 r
.02 w
.51944 .19225 m
.45119 .05832 L
s
P
p
.2 0 1 r
.02 w
.51944 .19225 m
.3855 .12401 L
s
P
p
0 .4 1 r
.018 w
.55487 .22768 m
.59951 .20493 L
s
P
p
0 .4 1 r
.018 w
.55487 .22768 m
.51944 .19225 L
s
P
p
.2 0 1 r
.02 w
.36774 .65913 m
.21927 .63561 L
s
P
p
.2 0 1 r
.02 w
.36774 .65913 m
.2338 .72737 L
s
P
p
.2 0 1 r
.02 w
.43998 .69594 m
.46349 .84441 L
s
P
p
.2 0 1 r
.02 w
.43998 .69594 m
.54627 .80223 L
s
P
p
0 .4 1 r
.018 w
.41723 .65129 m
.36774 .65913 L
s
P
p
0 .4 1 r
.018 w
.41723 .65129 m
.43998 .69594 L
s
P
p
.2 0 1 r
.016 w
.5196 .45039 m
.67903 .60983 L
s
P
p
.2 0 1 r
.016 w
.5196 .45039 m
.41723 .24948 L
s
P
p
.2 0 1 r
.016 w
.5196 .45039 m
.55487 .67309 L
s
P
p
.2 0 1 r
.016 w
.5196 .45039 m
.55487 .22768 L
s
P
p
.2 0 1 r
.016 w
.5196 .45039 m
.41723 .65129 L
s
P
p
.2 0 1 r
.02 w
.76561 .59013 m
.7421 .7386 L
s
P
p
.2 0 1 r
.02 w
.76561 .59013 m
.83386 .72407 L
s
P
p
.2 0 1 r
.02 w
.80242 .51789 m
.95089 .49438 L
s
P
p
.2 0 1 r
.02 w
.80242 .51789 m
.90871 .4116 L
s
P
p
0 .4 1 r
.018 w
.75777 .54064 m
.76561 .59013 L
s
P
p
0 .4 1 r
.018 w
.75777 .54064 m
.80242 .51789 L
s
P
p
.2 0 1 r
.02 w
.40527 .22935 m
.47351 .09541 L
s
P
p
.2 0 1 r
.02 w
.40527 .22935 m
.38175 .08088 L
s
P
p
.2 0 1 r
.02 w
.34794 .28668 m
.19947 .26316 L
s
P
p
.2 0 1 r
.02 w
.34794 .28668 m
.214 .35492 L
s
P
p
0 .4 1 r
.018 w
.39743 .27884 m
.40527 .22935 L
s
P
p
0 .4 1 r
.018 w
.39743 .27884 m
.34794 .28668 L
s
P
p
.2 0 1 r
.02 w
.63649 .68383 m
.5302 .79012 L
s
P
p
.2 0 1 r
.02 w
.63649 .68383 m
.61297 .8323 L
s
P
p
.2 0 1 r
.02 w
.70873 .64702 m
.84266 .71526 L
s
P
p
.2 0 1 r
.02 w
.70873 .64702 m
.8572 .6235 L
s
P
p
0 .4 1 r
.018 w
.65924 .63918 m
.63649 .68383 L
s
P
p
0 .4 1 r
.018 w
.65924 .63918 m
.70873 .64702 L
s
P
p
.2 0 1 r
.02 w
.55703 .18014 m
.69096 .1119 L
s
P
p
.2 0 1 r
.02 w
.55703 .18014 m
.62527 .0462 L
s
P
p
.2 0 1 r
.02 w
.47695 .19282 m
.37066 .08653 L
s
P
p
.2 0 1 r
.02 w
.47695 .19282 m
.32848 .16931 L
s
P
p
0 .4 1 r
.018 w
.5216 .21557 m
.55703 .18014 L
s
P
p
0 .4 1 r
.018 w
.5216 .21557 m
.47695 .19282 L
s
P
p
.2 0 1 r
.02 w
.47695 .68373 m
.32848 .70724 L
s
P
p
.2 0 1 r
.02 w
.47695 .68373 m
.37066 .79002 L
s
P
p
.2 0 1 r
.02 w
.55703 .69641 m
.62527 .83035 L
s
P
p
.2 0 1 r
.02 w
.55703 .69641 m
.69096 .76466 L
s
P
p
0 .4 1 r
.018 w
.5216 .66098 m
.47695 .68373 L
s
P
p
0 .4 1 r
.018 w
.5216 .66098 m
.55703 .69641 L
s
P
p
.2 0 1 r
.016 w
.55687 .43828 m
.75777 .54064 L
s
P
p
.2 0 1 r
.016 w
.55687 .43828 m
.39743 .27884 L
s
P
p
.2 0 1 r
.016 w
.55687 .43828 m
.65924 .63918 L
s
P
p
.2 0 1 r
.016 w
.55687 .43828 m
.5216 .21557 L
s
P
p
.2 0 1 r
.016 w
.55687 .43828 m
.5216 .66098 L
s
P
p
1 .6 0 r
.016 w
.5 .32666 m
.44313 .43828 L
s
P
p
1 .6 0 r
.016 w
.5 .32666 m
.4804 .45039 L
s
P
p
1 .6 0 r
.016 w
.5 .32666 m
.5196 .45039 L
s
P
p
1 .6 0 r
.016 w
.5 .32666 m
.55687 .43828 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.014 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.014 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.014 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.014 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.014 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.014 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.014 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.014 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.014 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.014 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.014 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.014 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.014 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.014 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.014 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.014 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.014 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.014 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.014 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.014 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
0 .4 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
0 .4 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
0 .4 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
0 .4 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
0 .4 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
0 .4 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
0 .4 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
0 .4 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
0 .4 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
0 .4 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
0 .4 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
0 .4 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
0 .4 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
0 .4 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
0 .4 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
0 .4 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
0 .4 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
0 .4 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
0 .4 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
0 .4 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00573791 0.952381 [
[ 0 0 0 0 ]
[ 1 .94091 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .94091 L
0 .94091 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.48141 .72434 m
.45667 .8805 L
s
P
p
.2 0 1 r
.02 w
.48141 .72434 m
.55318 .86521 L
s
P
p
0 .4 1 r
.018 w
.47316 .67229 m
.48141 .72434 L
s
P
p
.2 0 1 r
.02 w
.48141 .20382 m
.55318 .06295 L
s
P
p
.2 0 1 r
.02 w
.48141 .20382 m
.45667 .04767 L
s
P
p
0 .4 1 r
.018 w
.47316 .25588 m
.48141 .20382 L
s
P
p
.2 0 1 r
.02 w
.32056 .69887 m
.20876 .81066 L
s
P
p
.2 0 1 r
.02 w
.32056 .69887 m
.29583 .85502 L
s
P
p
0 .4 1 r
.018 w
.34448 .65191 m
.32056 .69887 L
s
P
p
.2 0 1 r
.02 w
.62651 .27776 m
.76738 .20598 L
s
P
p
.2 0 1 r
.02 w
.62651 .27776 m
.69829 .13689 L
s
P
p
0 .4 1 r
.018 w
.58925 .31502 m
.62651 .27776 L
s
P
p
.2 0 1 r
.02 w
.2054 .58371 m
.04925 .60844 L
s
P
p
.2 0 1 r
.02 w
.2054 .58371 m
.09361 .69551 L
s
P
p
0 .4 1 r
.018 w
.25236 .55979 m
.2054 .58371 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.47316 .67229 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.47316 .25588 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.34448 .65191 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.58925 .31502 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.25236 .55979 L
s
P
p
.2 0 1 r
.02 w
.59902 .7116 m
.62375 .86776 L
s
P
p
.2 0 1 r
.02 w
.59902 .7116 m
.71081 .8234 L
s
P
p
0 .4 1 r
.018 w
.57509 .66465 m
.59902 .7116 L
s
P
p
.2 0 1 r
.02 w
.43817 .21656 m
.4629 .06041 L
s
P
p
.2 0 1 r
.02 w
.43817 .21656 m
.36639 .07569 L
s
P
p
0 .4 1 r
.018 w
.44641 .26861 m
.43817 .21656 L
s
P
p
.2 0 1 r
.02 w
.43817 .73708 m
.36639 .87795 L
s
P
p
.2 0 1 r
.02 w
.43817 .73708 m
.4629 .89324 L
s
P
p
0 .4 1 r
.018 w
.44641 .68503 m
.43817 .73708 L
s
P
p
.2 0 1 r
.02 w
.59902 .24204 m
.71081 .13024 L
s
P
p
.2 0 1 r
.02 w
.59902 .24204 m
.62375 .08588 L
s
P
p
0 .4 1 r
.018 w
.57509 .28899 m
.59902 .24204 L
s
P
p
.2 0 1 r
.02 w
.29306 .66315 m
.15219 .73492 L
s
P
p
.2 0 1 r
.02 w
.29306 .66315 m
.22129 .80402 L
s
P
p
0 .4 1 r
.018 w
.33033 .62588 m
.29306 .66315 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.57509 .66465 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.44641 .26861 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.44641 .68503 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.57509 .28899 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.33033 .62588 L
s
P
p
.2 0 1 r
.02 w
.70694 .66315 m
.77871 .80402 L
s
P
p
.2 0 1 r
.02 w
.70694 .66315 m
.84781 .73492 L
s
P
p
0 .4 1 r
.018 w
.66967 .62588 m
.70694 .66315 L
s
P
p
.2 0 1 r
.02 w
.40098 .24204 m
.37625 .08588 L
s
P
p
.2 0 1 r
.02 w
.40098 .24204 m
.28919 .13024 L
s
P
p
0 .4 1 r
.018 w
.42491 .28899 m
.40098 .24204 L
s
P
p
.2 0 1 r
.02 w
.56183 .73708 m
.5371 .89324 L
s
P
p
.2 0 1 r
.02 w
.56183 .73708 m
.63361 .87795 L
s
P
p
0 .4 1 r
.018 w
.55359 .68503 m
.56183 .73708 L
s
P
p
.2 0 1 r
.02 w
.56183 .21656 m
.63361 .07569 L
s
P
p
.2 0 1 r
.02 w
.56183 .21656 m
.5371 .06041 L
s
P
p
0 .4 1 r
.018 w
.55359 .26861 m
.56183 .21656 L
s
P
p
.2 0 1 r
.02 w
.40098 .7116 m
.28919 .8234 L
s
P
p
.2 0 1 r
.02 w
.40098 .7116 m
.37625 .86776 L
s
P
p
0 .4 1 r
.018 w
.42491 .66465 m
.40098 .7116 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.66967 .62588 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.42491 .28899 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.55359 .68503 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.55359 .26861 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.42491 .66465 L
s
P
p
.2 0 1 r
.02 w
.7946 .58371 m
.90639 .69551 L
s
P
p
.2 0 1 r
.02 w
.7946 .58371 m
.95075 .60844 L
s
P
p
0 .4 1 r
.018 w
.74764 .55979 m
.7946 .58371 L
s
P
p
.2 0 1 r
.02 w
.37349 .27776 m
.30171 .13689 L
s
P
p
.2 0 1 r
.02 w
.37349 .27776 m
.23262 .20598 L
s
P
p
0 .4 1 r
.018 w
.41075 .31502 m
.37349 .27776 L
s
P
p
.2 0 1 r
.02 w
.67944 .69887 m
.70417 .85502 L
s
P
p
.2 0 1 r
.02 w
.67944 .69887 m
.79124 .81066 L
s
P
p
0 .4 1 r
.018 w
.65552 .65191 m
.67944 .69887 L
s
P
p
.2 0 1 r
.02 w
.51859 .20382 m
.54333 .04767 L
s
P
p
.2 0 1 r
.02 w
.51859 .20382 m
.44682 .06295 L
s
P
p
0 .4 1 r
.018 w
.52684 .25588 m
.51859 .20382 L
s
P
p
.2 0 1 r
.02 w
.51859 .72434 m
.44682 .86521 L
s
P
p
.2 0 1 r
.02 w
.51859 .72434 m
.54333 .8805 L
s
P
p
0 .4 1 r
.018 w
.52684 .67229 m
.51859 .72434 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.74764 .55979 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.41075 .31502 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.65552 .65191 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.52684 .25588 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.52684 .67229 L
s
P
p
1 .6 0 r
.016 w
.5 .34669 m
.44019 .46408 L
s
P
p
1 .6 0 r
.016 w
.5 .34669 m
.47939 .47682 L
s
P
p
1 .6 0 r
.016 w
.5 .34669 m
.52061 .47682 L
s
P
p
1 .6 0 r
.016 w
.5 .34669 m
.55981 .46408 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0408302 0.952381 [
[ 0 0 0 0 ]
[ 1 .87072 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .87072 L
0 .87072 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.42894 .66697 m
.27515 .71694 L
s
P
p
.2 0 1 r
.02 w
.42894 .66697 m
.33389 .7978 L
s
P
p
.2 0 1 r
.02 w
.52382 .65194 m
.65464 .74699 L
s
P
p
.2 0 1 r
.02 w
.52382 .65194 m
.68552 .65194 L
s
P
p
0 .4 1 r
.018 w
.47255 .63529 m
.42894 .66697 L
s
P
p
0 .4 1 r
.018 w
.47255 .63529 m
.52382 .65194 L
s
P
p
.2 0 1 r
.02 w
.52382 .19272 m
.68552 .19272 L
s
P
p
.2 0 1 r
.02 w
.52382 .19272 m
.65464 .09767 L
s
P
p
.2 0 1 r
.02 w
.42894 .17769 m
.33389 .04687 L
s
P
p
.2 0 1 r
.02 w
.42894 .17769 m
.27515 .12772 L
s
P
p
0 .4 1 r
.018 w
.47255 .20938 m
.52382 .19272 L
s
P
p
0 .4 1 r
.018 w
.47255 .20938 m
.42894 .17769 L
s
P
p
.2 0 1 r
.02 w
.28703 .61444 m
.13324 .56447 L
s
P
p
.2 0 1 r
.02 w
.28703 .61444 m
.13324 .66441 L
s
P
p
.2 0 1 r
.02 w
.37262 .65805 m
.42259 .81184 L
s
P
p
.2 0 1 r
.02 w
.37262 .65805 m
.50344 .7531 L
s
P
p
0 .4 1 r
.018 w
.34094 .61444 m
.28703 .61444 L
s
P
p
0 .4 1 r
.018 w
.34094 .61444 m
.37262 .65805 L
s
P
p
.2 0 1 r
.02 w
.64255 .28653 m
.77337 .38158 L
s
P
p
.2 0 1 r
.02 w
.64255 .28653 m
.80425 .28653 L
s
P
p
.2 0 1 r
.02 w
.57462 .21861 m
.57462 .0569 L
s
P
p
.2 0 1 r
.02 w
.57462 .21861 m
.47958 .08778 L
s
P
p
0 .4 1 r
.018 w
.59128 .26987 m
.64255 .28653 L
s
P
p
0 .4 1 r
.018 w
.59128 .26987 m
.57462 .21861 L
s
P
p
.2 0 1 r
.02 w
.2031 .48853 m
.10805 .35771 L
s
P
p
.2 0 1 r
.02 w
.2031 .48853 m
.04931 .43856 L
s
P
p
.2 0 1 r
.02 w
.24671 .57412 m
.19674 .72791 L
s
P
p
.2 0 1 r
.02 w
.24671 .57412 m
.29668 .72791 L
s
P
p
0 .4 1 r
.018 w
.24671 .52022 m
.2031 .48853 L
s
P
p
0 .4 1 r
.018 w
.24671 .52022 m
.24671 .57412 L
s
P
p
.2 0 1 r
.016 w
.43882 .42233 m
.47255 .63529 L
s
P
p
.2 0 1 r
.016 w
.43882 .42233 m
.47255 .20938 L
s
P
p
.2 0 1 r
.016 w
.43882 .42233 m
.34094 .61444 L
s
P
p
.2 0 1 r
.016 w
.43882 .42233 m
.59128 .26987 L
s
P
p
.2 0 1 r
.016 w
.43882 .42233 m
.24671 .52022 L
s
P
p
.2 0 1 r
.02 w
.54512 .67108 m
.4143 .76613 L
s
P
p
.2 0 1 r
.02 w
.54512 .67108 m
.49515 .82487 L
s
P
p
.2 0 1 r
.02 w
.63071 .62747 m
.7845 .67744 L
s
P
p
.2 0 1 r
.02 w
.63071 .62747 m
.7845 .5775 L
s
P
p
0 .4 1 r
.018 w
.5768 .62747 m
.54512 .67108 L
s
P
p
0 .4 1 r
.018 w
.5768 .62747 m
.63071 .62747 L
s
P
p
.2 0 1 r
.02 w
.4888 .19072 m
.64259 .14075 L
s
P
p
.2 0 1 r
.02 w
.4888 .19072 m
.58385 .0599 L
s
P
p
.2 0 1 r
.02 w
.39393 .20575 m
.2631 .1107 L
s
P
p
.2 0 1 r
.02 w
.39393 .20575 m
.23222 .20575 L
s
P
p
0 .4 1 r
.018 w
.44519 .2224 m
.4888 .19072 L
s
P
p
0 .4 1 r
.018 w
.44519 .2224 m
.39393 .20575 L
s
P
p
.2 0 1 r
.02 w
.39393 .66497 m
.23222 .66497 L
s
P
p
.2 0 1 r
.02 w
.39393 .66497 m
.2631 .76002 L
s
P
p
.2 0 1 r
.02 w
.4888 .68 m
.58385 .81082 L
s
P
p
.2 0 1 r
.02 w
.4888 .68 m
.64259 .72997 L
s
P
p
0 .4 1 r
.018 w
.44519 .64832 m
.39393 .66497 L
s
P
p
0 .4 1 r
.018 w
.44519 .64832 m
.4888 .68 L
s
P
p
.2 0 1 r
.02 w
.63071 .24325 m
.7845 .29322 L
s
P
p
.2 0 1 r
.02 w
.63071 .24325 m
.7845 .19328 L
s
P
p
.2 0 1 r
.02 w
.54512 .19964 m
.49515 .04585 L
s
P
p
.2 0 1 r
.02 w
.54512 .19964 m
.4143 .10459 L
s
P
p
0 .4 1 r
.018 w
.5768 .24325 m
.63071 .24325 L
s
P
p
0 .4 1 r
.018 w
.5768 .24325 m
.54512 .19964 L
s
P
p
.2 0 1 r
.02 w
.2752 .57116 m
.14437 .47611 L
s
P
p
.2 0 1 r
.02 w
.2752 .57116 m
.11349 .57116 L
s
P
p
.2 0 1 r
.02 w
.34312 .63908 m
.34312 .80079 L
s
P
p
.2 0 1 r
.02 w
.34312 .63908 m
.43817 .76991 L
s
P
p
0 .4 1 r
.018 w
.32646 .58782 m
.2752 .57116 L
s
P
p
0 .4 1 r
.018 w
.32646 .58782 m
.34312 .63908 L
s
P
p
.2 0 1 r
.016 w
.47892 .43536 m
.5768 .62747 L
s
P
p
.2 0 1 r
.016 w
.47892 .43536 m
.44519 .2224 L
s
P
p
.2 0 1 r
.016 w
.47892 .43536 m
.44519 .64832 L
s
P
p
.2 0 1 r
.016 w
.47892 .43536 m
.5768 .24325 L
s
P
p
.2 0 1 r
.016 w
.47892 .43536 m
.32646 .58782 L
s
P
p
.2 0 1 r
.02 w
.65688 .63908 m
.56183 .76991 L
s
P
p
.2 0 1 r
.02 w
.65688 .63908 m
.65688 .80079 L
s
P
p
.2 0 1 r
.02 w
.7248 .57116 m
.88651 .57116 L
s
P
p
.2 0 1 r
.02 w
.7248 .57116 m
.85563 .47611 L
s
P
p
0 .4 1 r
.018 w
.67354 .58782 m
.65688 .63908 L
s
P
p
0 .4 1 r
.018 w
.67354 .58782 m
.7248 .57116 L
s
P
p
.2 0 1 r
.02 w
.45488 .19964 m
.5857 .10459 L
s
P
p
.2 0 1 r
.02 w
.45488 .19964 m
.50485 .04585 L
s
P
p
.2 0 1 r
.02 w
.36929 .24325 m
.2155 .19328 L
s
P
p
.2 0 1 r
.02 w
.36929 .24325 m
.2155 .29322 L
s
P
p
0 .4 1 r
.018 w
.4232 .24325 m
.45488 .19964 L
s
P
p
0 .4 1 r
.018 w
.4232 .24325 m
.36929 .24325 L
s
P
p
.2 0 1 r
.02 w
.5112 .68 m
.35741 .72997 L
s
P
p
.2 0 1 r
.02 w
.5112 .68 m
.41615 .81082 L
s
P
p
.2 0 1 r
.02 w
.60607 .66497 m
.7369 .76002 L
s
P
p
.2 0 1 r
.02 w
.60607 .66497 m
.76778 .66497 L
s
P
p
0 .4 1 r
.018 w
.55481 .64832 m
.5112 .68 L
s
P
p
0 .4 1 r
.018 w
.55481 .64832 m
.60607 .66497 L
s
P
p
.2 0 1 r
.02 w
.60607 .20575 m
.76778 .20575 L
s
P
p
.2 0 1 r
.02 w
.60607 .20575 m
.7369 .1107 L
s
P
p
.2 0 1 r
.02 w
.5112 .19072 m
.41615 .0599 L
s
P
p
.2 0 1 r
.02 w
.5112 .19072 m
.35741 .14075 L
s
P
p
0 .4 1 r
.018 w
.55481 .2224 m
.60607 .20575 L
s
P
p
0 .4 1 r
.018 w
.55481 .2224 m
.5112 .19072 L
s
P
p
.2 0 1 r
.02 w
.36929 .62747 m
.2155 .5775 L
s
P
p
.2 0 1 r
.02 w
.36929 .62747 m
.2155 .67744 L
s
P
p
.2 0 1 r
.02 w
.45488 .67108 m
.50485 .82487 L
s
P
p
.2 0 1 r
.02 w
.45488 .67108 m
.5857 .76613 L
s
P
p
0 .4 1 r
.018 w
.4232 .62747 m
.36929 .62747 L
s
P
p
0 .4 1 r
.018 w
.4232 .62747 m
.45488 .67108 L
s
P
p
.2 0 1 r
.016 w
.52108 .43536 m
.67354 .58782 L
s
P
p
.2 0 1 r
.016 w
.52108 .43536 m
.4232 .24325 L
s
P
p
.2 0 1 r
.016 w
.52108 .43536 m
.55481 .64832 L
s
P
p
.2 0 1 r
.016 w
.52108 .43536 m
.55481 .2224 L
s
P
p
.2 0 1 r
.016 w
.52108 .43536 m
.4232 .62747 L
s
P
p
.2 0 1 r
.02 w
.75329 .57412 m
.70332 .72791 L
s
P
p
.2 0 1 r
.02 w
.75329 .57412 m
.80326 .72791 L
s
P
p
.2 0 1 r
.02 w
.7969 .48853 m
.95069 .43856 L
s
P
p
.2 0 1 r
.02 w
.7969 .48853 m
.89195 .35771 L
s
P
p
0 .4 1 r
.018 w
.75329 .52022 m
.75329 .57412 L
s
P
p
0 .4 1 r
.018 w
.75329 .52022 m
.7969 .48853 L
s
P
p
.2 0 1 r
.02 w
.42538 .21861 m
.52042 .08778 L
s
P
p
.2 0 1 r
.02 w
.42538 .21861 m
.42538 .0569 L
s
P
p
.2 0 1 r
.02 w
.35745 .28653 m
.19575 .28653 L
s
P
p
.2 0 1 r
.02 w
.35745 .28653 m
.22663 .38158 L
s
P
p
0 .4 1 r
.018 w
.40872 .26987 m
.42538 .21861 L
s
P
p
0 .4 1 r
.018 w
.40872 .26987 m
.35745 .28653 L
s
P
p
.2 0 1 r
.02 w
.62738 .65805 m
.49656 .7531 L
s
P
p
.2 0 1 r
.02 w
.62738 .65805 m
.57741 .81184 L
s
P
p
.2 0 1 r
.02 w
.71297 .61444 m
.86676 .66441 L
s
P
p
.2 0 1 r
.02 w
.71297 .61444 m
.86676 .56447 L
s
P
p
0 .4 1 r
.018 w
.65906 .61444 m
.62738 .65805 L
s
P
p
0 .4 1 r
.018 w
.65906 .61444 m
.71297 .61444 L
s
P
p
.2 0 1 r
.02 w
.57106 .17769 m
.72485 .12772 L
s
P
p
.2 0 1 r
.02 w
.57106 .17769 m
.66611 .04687 L
s
P
p
.2 0 1 r
.02 w
.47618 .19272 m
.34536 .09767 L
s
P
p
.2 0 1 r
.02 w
.47618 .19272 m
.31448 .19272 L
s
P
p
0 .4 1 r
.018 w
.52745 .20938 m
.57106 .17769 L
s
P
p
0 .4 1 r
.018 w
.52745 .20938 m
.47618 .19272 L
s
P
p
.2 0 1 r
.02 w
.47618 .65194 m
.31448 .65194 L
s
P
p
.2 0 1 r
.02 w
.47618 .65194 m
.34536 .74699 L
s
P
p
.2 0 1 r
.02 w
.57106 .66697 m
.66611 .7978 L
s
P
p
.2 0 1 r
.02 w
.57106 .66697 m
.72485 .71694 L
s
P
p
0 .4 1 r
.018 w
.52745 .63529 m
.47618 .65194 L
s
P
p
0 .4 1 r
.018 w
.52745 .63529 m
.57106 .66697 L
s
P
p
.2 0 1 r
.016 w
.56118 .42233 m
.75329 .52022 L
s
P
p
.2 0 1 r
.016 w
.56118 .42233 m
.40872 .26987 L
s
P
p
.2 0 1 r
.016 w
.56118 .42233 m
.65906 .61444 L
s
P
p
.2 0 1 r
.016 w
.56118 .42233 m
.52745 .20938 L
s
P
p
.2 0 1 r
.016 w
.56118 .42233 m
.52745 .63529 L
s
P
p
1 .6 0 r
.016 w
.5 .30226 m
.43882 .42233 L
s
P
p
1 .6 0 r
.016 w
.5 .30226 m
.47892 .43536 L
s
P
p
1 .6 0 r
.016 w
.5 .30226 m
.52108 .43536 L
s
P
p
1 .6 0 r
.016 w
.5 .30226 m
.56118 .42233 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.034597 0.952381 [
[ 0 0 0 0 ]
[ 1 .88319 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88319 L
0 .88319 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.42134 .68216 m
.2874 .7504 L
s
P
p
.2 0 1 r
.02 w
.42134 .68216 m
.35309 .81609 L
s
P
p
.2 0 1 r
.02 w
.54145 .66313 m
.64774 .76942 L
s
P
p
.2 0 1 r
.02 w
.54145 .66313 m
.68992 .68665 L
s
P
p
0 .4 1 r
.018 w
.47448 .62901 m
.42134 .68216 L
s
P
p
0 .4 1 r
.018 w
.47448 .62901 m
.54145 .66313 L
s
P
p
.2 0 1 r
.02 w
.54145 .19897 m
.68992 .17545 L
s
P
p
.2 0 1 r
.02 w
.54145 .19897 m
.64774 .09268 L
s
P
p
.2 0 1 r
.02 w
.42134 .17994 m
.35309 .04601 L
s
P
p
.2 0 1 r
.02 w
.42134 .17994 m
.2874 .1117 L
s
P
p
0 .4 1 r
.018 w
.47448 .23309 m
.54145 .19897 L
s
P
p
0 .4 1 r
.018 w
.47448 .23309 m
.42134 .17994 L
s
P
p
.2 0 1 r
.02 w
.2779 .62139 m
.12943 .59787 L
s
P
p
.2 0 1 r
.02 w
.2779 .62139 m
.14397 .68963 L
s
P
p
.2 0 1 r
.02 w
.38626 .6766 m
.40978 .82507 L
s
P
p
.2 0 1 r
.02 w
.38626 .6766 m
.49255 .78289 L
s
P
p
0 .4 1 r
.018 w
.35214 .60963 m
.2779 .62139 L
s
P
p
0 .4 1 r
.018 w
.35214 .60963 m
.38626 .6766 L
s
P
p
.2 0 1 r
.02 w
.65909 .30108 m
.79302 .36933 L
s
P
p
.2 0 1 r
.02 w
.65909 .30108 m
.80756 .27757 L
s
P
p
.2 0 1 r
.02 w
.5731 .21509 m
.59661 .06662 L
s
P
p
.2 0 1 r
.02 w
.5731 .21509 m
.50485 .08115 L
s
P
p
0 .4 1 r
.018 w
.58485 .28933 m
.65909 .30108 L
s
P
p
0 .4 1 r
.018 w
.58485 .28933 m
.5731 .21509 L
s
P
p
.2 0 1 r
.02 w
.19758 .48792 m
.09129 .38163 L
s
P
p
.2 0 1 r
.02 w
.19758 .48792 m
.04911 .4644 L
s
P
p
.2 0 1 r
.02 w
.25279 .59628 m
.18455 .73021 L
s
P
p
.2 0 1 r
.02 w
.25279 .59628 m
.27631 .74475 L
s
P
p
0 .4 1 r
.018 w
.26455 .52204 m
.19758 .48792 L
s
P
p
0 .4 1 r
.018 w
.26455 .52204 m
.25279 .59628 L
s
P
p
.2 0 1 r
.016 w
.44313 .43105 m
.47448 .62901 L
s
P
p
.2 0 1 r
.016 w
.44313 .43105 m
.47448 .23309 L
s
P
p
.2 0 1 r
.016 w
.44313 .43105 m
.35214 .60963 L
s
P
p
.2 0 1 r
.016 w
.44313 .43105 m
.58485 .28933 L
s
P
p
.2 0 1 r
.016 w
.44313 .43105 m
.26455 .52204 L
s
P
p
.2 0 1 r
.02 w
.53727 .68871 m
.43098 .795 L
s
P
p
.2 0 1 r
.02 w
.53727 .68871 m
.51376 .83718 L
s
P
p
.2 0 1 r
.02 w
.64563 .6335 m
.77957 .70174 L
s
P
p
.2 0 1 r
.02 w
.64563 .6335 m
.7941 .60998 L
s
P
p
0 .4 1 r
.018 w
.5714 .62174 m
.53727 .68871 L
s
P
p
0 .4 1 r
.018 w
.5714 .62174 m
.64563 .6335 L
s
P
p
.2 0 1 r
.02 w
.5022 .19205 m
.63613 .12381 L
s
P
p
.2 0 1 r
.02 w
.5022 .19205 m
.57044 .05812 L
s
P
p
.2 0 1 r
.02 w
.38208 .21108 m
.27579 .10479 L
s
P
p
.2 0 1 r
.02 w
.38208 .21108 m
.23361 .18756 L
s
P
p
0 .4 1 r
.018 w
.44905 .2452 m
.5022 .19205 L
s
P
p
0 .4 1 r
.018 w
.44905 .2452 m
.38208 .21108 L
s
P
p
.2 0 1 r
.02 w
.38208 .67524 m
.23361 .69876 L
s
P
p
.2 0 1 r
.02 w
.38208 .67524 m
.27579 .78153 L
s
P
p
.2 0 1 r
.02 w
.5022 .69427 m
.57044 .8282 L
s
P
p
.2 0 1 r
.02 w
.5022 .69427 m
.63613 .76251 L
s
P
p
0 .4 1 r
.018 w
.44905 .64112 m
.38208 .67524 L
s
P
p
0 .4 1 r
.018 w
.44905 .64112 m
.5022 .69427 L
s
P
p
.2 0 1 r
.02 w
.64563 .25282 m
.7941 .27634 L
s
P
p
.2 0 1 r
.02 w
.64563 .25282 m
.77957 .18458 L
s
P
p
.2 0 1 r
.02 w
.53727 .19761 m
.51376 .04914 L
s
P
p
.2 0 1 r
.02 w
.53727 .19761 m
.43098 .09132 L
s
P
p
0 .4 1 r
.018 w
.5714 .26458 m
.64563 .25282 L
s
P
p
0 .4 1 r
.018 w
.5714 .26458 m
.53727 .19761 L
s
P
p
.2 0 1 r
.02 w
.26445 .57313 m
.13051 .50488 L
s
P
p
.2 0 1 r
.02 w
.26445 .57313 m
.11598 .59664 L
s
P
p
.2 0 1 r
.02 w
.35044 .65912 m
.32692 .80759 L
s
P
p
.2 0 1 r
.02 w
.35044 .65912 m
.41868 .79305 L
s
P
p
0 .4 1 r
.018 w
.33868 .58488 m
.26445 .57313 L
s
P
p
0 .4 1 r
.018 w
.33868 .58488 m
.35044 .65912 L
s
P
p
.2 0 1 r
.016 w
.4804 .44316 m
.5714 .62174 L
s
P
p
.2 0 1 r
.016 w
.4804 .44316 m
.44905 .2452 L
s
P
p
.2 0 1 r
.016 w
.4804 .44316 m
.44905 .64112 L
s
P
p
.2 0 1 r
.016 w
.4804 .44316 m
.5714 .26458 L
s
P
p
.2 0 1 r
.016 w
.4804 .44316 m
.33868 .58488 L
s
P
p
.2 0 1 r
.02 w
.64956 .65912 m
.58132 .79305 L
s
P
p
.2 0 1 r
.02 w
.64956 .65912 m
.67308 .80759 L
s
P
p
.2 0 1 r
.02 w
.73555 .57313 m
.88402 .59664 L
s
P
p
.2 0 1 r
.02 w
.73555 .57313 m
.86949 .50488 L
s
P
p
0 .4 1 r
.018 w
.66132 .58488 m
.64956 .65912 L
s
P
p
0 .4 1 r
.018 w
.66132 .58488 m
.73555 .57313 L
s
P
p
.2 0 1 r
.02 w
.46273 .19761 m
.56902 .09132 L
s
P
p
.2 0 1 r
.02 w
.46273 .19761 m
.48624 .04914 L
s
P
p
.2 0 1 r
.02 w
.35437 .25282 m
.22043 .18458 L
s
P
p
.2 0 1 r
.02 w
.35437 .25282 m
.2059 .27634 L
s
P
p
0 .4 1 r
.018 w
.4286 .26458 m
.46273 .19761 L
s
P
p
0 .4 1 r
.018 w
.4286 .26458 m
.35437 .25282 L
s
P
p
.2 0 1 r
.02 w
.4978 .69427 m
.36387 .76251 L
s
P
p
.2 0 1 r
.02 w
.4978 .69427 m
.42956 .8282 L
s
P
p
.2 0 1 r
.02 w
.61792 .67524 m
.72421 .78153 L
s
P
p
.2 0 1 r
.02 w
.61792 .67524 m
.76639 .69876 L
s
P
p
0 .4 1 r
.018 w
.55095 .64112 m
.4978 .69427 L
s
P
p
0 .4 1 r
.018 w
.55095 .64112 m
.61792 .67524 L
s
P
p
.2 0 1 r
.02 w
.61792 .21108 m
.76639 .18756 L
s
P
p
.2 0 1 r
.02 w
.61792 .21108 m
.72421 .10479 L
s
P
p
.2 0 1 r
.02 w
.4978 .19205 m
.42956 .05812 L
s
P
p
.2 0 1 r
.02 w
.4978 .19205 m
.36387 .12381 L
s
P
p
0 .4 1 r
.018 w
.55095 .2452 m
.61792 .21108 L
s
P
p
0 .4 1 r
.018 w
.55095 .2452 m
.4978 .19205 L
s
P
p
.2 0 1 r
.02 w
.35437 .6335 m
.2059 .60998 L
s
P
p
.2 0 1 r
.02 w
.35437 .6335 m
.22043 .70174 L
s
P
p
.2 0 1 r
.02 w
.46273 .68871 m
.48624 .83718 L
s
P
p
.2 0 1 r
.02 w
.46273 .68871 m
.56902 .795 L
s
P
p
0 .4 1 r
.018 w
.4286 .62174 m
.35437 .6335 L
s
P
p
0 .4 1 r
.018 w
.4286 .62174 m
.46273 .68871 L
s
P
p
.2 0 1 r
.016 w
.5196 .44316 m
.66132 .58488 L
s
P
p
.2 0 1 r
.016 w
.5196 .44316 m
.4286 .26458 L
s
P
p
.2 0 1 r
.016 w
.5196 .44316 m
.55095 .64112 L
s
P
p
.2 0 1 r
.016 w
.5196 .44316 m
.55095 .2452 L
s
P
p
.2 0 1 r
.016 w
.5196 .44316 m
.4286 .62174 L
s
P
p
.2 0 1 r
.02 w
.74721 .59628 m
.72369 .74475 L
s
P
p
.2 0 1 r
.02 w
.74721 .59628 m
.81545 .73021 L
s
P
p
.2 0 1 r
.02 w
.80242 .48792 m
.95089 .4644 L
s
P
p
.2 0 1 r
.02 w
.80242 .48792 m
.90871 .38163 L
s
P
p
0 .4 1 r
.018 w
.73545 .52204 m
.74721 .59628 L
s
P
p
0 .4 1 r
.018 w
.73545 .52204 m
.80242 .48792 L
s
P
p
.2 0 1 r
.02 w
.4269 .21509 m
.49515 .08115 L
s
P
p
.2 0 1 r
.02 w
.4269 .21509 m
.40339 .06662 L
s
P
p
.2 0 1 r
.02 w
.34091 .30108 m
.19244 .27757 L
s
P
p
.2 0 1 r
.02 w
.34091 .30108 m
.20698 .36933 L
s
P
p
0 .4 1 r
.018 w
.41515 .28933 m
.4269 .21509 L
s
P
p
0 .4 1 r
.018 w
.41515 .28933 m
.34091 .30108 L
s
P
p
.2 0 1 r
.02 w
.61374 .6766 m
.50745 .78289 L
s
P
p
.2 0 1 r
.02 w
.61374 .6766 m
.59022 .82507 L
s
P
p
.2 0 1 r
.02 w
.7221 .62139 m
.85603 .68963 L
s
P
p
.2 0 1 r
.02 w
.7221 .62139 m
.87057 .59787 L
s
P
p
0 .4 1 r
.018 w
.64786 .60963 m
.61374 .6766 L
s
P
p
0 .4 1 r
.018 w
.64786 .60963 m
.7221 .62139 L
s
P
p
.2 0 1 r
.02 w
.57866 .17994 m
.7126 .1117 L
s
P
p
.2 0 1 r
.02 w
.57866 .17994 m
.64691 .04601 L
s
P
p
.2 0 1 r
.02 w
.45855 .19897 m
.35226 .09268 L
s
P
p
.2 0 1 r
.02 w
.45855 .19897 m
.31008 .17545 L
s
P
p
0 .4 1 r
.018 w
.52552 .23309 m
.57866 .17994 L
s
P
p
0 .4 1 r
.018 w
.52552 .23309 m
.45855 .19897 L
s
P
p
.2 0 1 r
.02 w
.45855 .66313 m
.31008 .68665 L
s
P
p
.2 0 1 r
.02 w
.45855 .66313 m
.35226 .76942 L
s
P
p
.2 0 1 r
.02 w
.57866 .68216 m
.64691 .81609 L
s
P
p
.2 0 1 r
.02 w
.57866 .68216 m
.7126 .7504 L
s
P
p
0 .4 1 r
.018 w
.52552 .62901 m
.45855 .66313 L
s
P
p
0 .4 1 r
.018 w
.52552 .62901 m
.57866 .68216 L
s
P
p
.2 0 1 r
.016 w
.55687 .43105 m
.73545 .52204 L
s
P
p
.2 0 1 r
.016 w
.55687 .43105 m
.41515 .28933 L
s
P
p
.2 0 1 r
.016 w
.55687 .43105 m
.64786 .60963 L
s
P
p
.2 0 1 r
.016 w
.55687 .43105 m
.52552 .23309 L
s
P
p
.2 0 1 r
.016 w
.55687 .43105 m
.52552 .62901 L
s
P
p
1 .6 0 r
.016 w
.5 .31944 m
.44313 .43105 L
s
P
p
1 .6 0 r
.016 w
.5 .31944 m
.4804 .44316 L
s
P
p
1 .6 0 r
.016 w
.5 .31944 m
.5196 .44316 L
s
P
p
1 .6 0 r
.016 w
.5 .31944 m
.55687 .43105 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0158367 1.03167 0.0257918 1.03167 [
[ 0 0 0 0 ]
[ 1 1.08326 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.08326 L
0 1.08326 L
closepath
clip
newpath
p
P
p
1 .6 0 r
.016 w
.5 .07108 m
.06743 .92006 L
s
P
p
1 .6 0 r
.016 w
.5 .07108 m
.35094 1.01218 L
s
P
p
1 .6 0 r
.016 w
.5 .07108 m
.64906 1.01218 L
s
P
p
1 .6 0 r
.016 w
.5 .07108 m
.93257 .92006 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0450362 0.952381 [
[ 0 0 0 0 ]
[ 1 .86231 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .86231 L
0 .86231 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.38504 .65368 m
.24108 .70045 L
s
P
p
.2 0 1 r
.02 w
.38504 .65368 m
.29606 .77614 L
s
P
p
.2 0 1 r
.02 w
.46668 .65368 m
.55565 .77614 L
s
P
p
.2 0 1 r
.02 w
.46668 .65368 m
.61064 .70045 L
s
P
p
0 .4 1 r
.018 w
.42586 .62402 m
.38504 .65368 L
s
P
p
0 .4 1 r
.018 w
.42586 .62402 m
.46668 .65368 L
s
P
p
.2 0 1 r
.02 w
.53621 .21466 m
.68758 .21466 L
s
P
p
.2 0 1 r
.02 w
.53621 .21466 m
.65867 .12568 L
s
P
p
.2 0 1 r
.02 w
.45857 .18943 m
.41179 .04547 L
s
P
p
.2 0 1 r
.02 w
.45857 .18943 m
.33611 .10046 L
s
P
p
0 .4 1 r
.018 w
.48822 .23025 m
.53621 .21466 L
s
P
p
0 .4 1 r
.018 w
.48822 .23025 m
.45857 .18943 L
s
P
p
.2 0 1 r
.02 w
.25677 .58548 m
.11281 .5387 L
s
P
p
.2 0 1 r
.02 w
.25677 .58548 m
.11281 .63225 L
s
P
p
.2 0 1 r
.02 w
.32282 .63346 m
.32282 .78483 L
s
P
p
.2 0 1 r
.02 w
.32282 .63346 m
.41179 .75592 L
s
P
p
0 .4 1 r
.018 w
.30723 .58548 m
.25677 .58548 L
s
P
p
0 .4 1 r
.018 w
.30723 .58548 m
.32282 .63346 L
s
P
p
.2 0 1 r
.02 w
.63712 .31916 m
.75958 .40813 L
s
P
p
.2 0 1 r
.02 w
.63712 .31916 m
.78849 .31916 L
s
P
p
.2 0 1 r
.02 w
.58914 .25311 m
.63591 .10915 L
s
P
p
.2 0 1 r
.02 w
.58914 .25311 m
.54236 .10915 L
s
P
p
0 .4 1 r
.018 w
.58914 .30357 m
.63712 .31916 L
s
P
p
0 .4 1 r
.018 w
.58914 .30357 m
.58914 .25311 L
s
P
p
.2 0 1 r
.02 w
.19309 .45491 m
.10412 .33245 L
s
P
p
.2 0 1 r
.02 w
.19309 .45491 m
.04913 .40813 L
s
P
p
.2 0 1 r
.02 w
.21832 .53255 m
.12934 .65501 L
s
P
p
.2 0 1 r
.02 w
.21832 .53255 m
.21832 .68392 L
s
P
p
0 .4 1 r
.018 w
.23391 .48456 m
.19309 .45491 L
s
P
p
0 .4 1 r
.018 w
.23391 .48456 m
.21832 .53255 L
s
P
p
.2 0 1 r
.016 w
.42586 .4222 m
.42586 .62402 L
s
P
p
.2 0 1 r
.016 w
.42586 .4222 m
.48822 .23025 L
s
P
p
.2 0 1 r
.016 w
.42586 .4222 m
.30723 .58548 L
s
P
p
.2 0 1 r
.016 w
.42586 .4222 m
.58914 .30357 L
s
P
p
.2 0 1 r
.016 w
.42586 .4222 m
.23391 .48456 L
s
P
p
.2 0 1 r
.02 w
.49373 .67288 m
.37127 .76185 L
s
P
p
.2 0 1 r
.02 w
.49373 .67288 m
.44695 .81684 L
s
P
p
.2 0 1 r
.02 w
.57137 .64765 m
.69383 .73662 L
s
P
p
.2 0 1 r
.02 w
.57137 .64765 m
.72274 .64765 L
s
P
p
0 .4 1 r
.018 w
.52339 .63206 m
.49373 .67288 L
s
P
p
0 .4 1 r
.018 w
.52339 .63206 m
.57137 .64765 L
s
P
p
.2 0 1 r
.02 w
.50184 .20863 m
.6458 .16185 L
s
P
p
.2 0 1 r
.02 w
.50184 .20863 m
.59081 .08617 L
s
P
p
.2 0 1 r
.02 w
.4202 .20863 m
.33123 .08617 L
s
P
p
.2 0 1 r
.02 w
.4202 .20863 m
.27624 .16185 L
s
P
p
0 .4 1 r
.018 w
.46102 .23829 m
.50184 .20863 L
s
P
p
0 .4 1 r
.018 w
.46102 .23829 m
.4202 .20863 L
s
P
p
.2 0 1 r
.02 w
.35067 .64765 m
.1993 .64765 L
s
P
p
.2 0 1 r
.02 w
.35067 .64765 m
.22821 .73662 L
s
P
p
.2 0 1 r
.02 w
.42831 .67288 m
.47509 .81684 L
s
P
p
.2 0 1 r
.02 w
.42831 .67288 m
.55077 .76185 L
s
P
p
0 .4 1 r
.018 w
.39865 .63206 m
.35067 .64765 L
s
P
p
0 .4 1 r
.018 w
.39865 .63206 m
.42831 .67288 L
s
P
p
.2 0 1 r
.02 w
.63011 .27683 m
.77407 .32361 L
s
P
p
.2 0 1 r
.02 w
.63011 .27683 m
.77407 .23006 L
s
P
p
.2 0 1 r
.02 w
.56406 .22885 m
.56406 .07748 L
s
P
p
.2 0 1 r
.02 w
.56406 .22885 m
.47509 .10639 L
s
P
p
0 .4 1 r
.018 w
.57965 .27683 m
.63011 .27683 L
s
P
p
0 .4 1 r
.018 w
.57965 .27683 m
.56406 .22885 L
s
P
p
.2 0 1 r
.02 w
.24975 .54315 m
.12729 .45418 L
s
P
p
.2 0 1 r
.02 w
.24975 .54315 m
.09838 .54315 L
s
P
p
.2 0 1 r
.02 w
.29774 .6092 m
.25096 .75316 L
s
P
p
.2 0 1 r
.02 w
.29774 .6092 m
.34452 .75316 L
s
P
p
0 .4 1 r
.018 w
.29774 .55874 m
.24975 .54315 L
s
P
p
0 .4 1 r
.018 w
.29774 .55874 m
.29774 .6092 L
s
P
p
.2 0 1 r
.016 w
.46102 .44011 m
.52339 .63206 L
s
P
p
.2 0 1 r
.016 w
.46102 .44011 m
.46102 .23829 L
s
P
p
.2 0 1 r
.016 w
.46102 .44011 m
.39865 .63206 L
s
P
p
.2 0 1 r
.016 w
.46102 .44011 m
.57965 .27683 L
s
P
p
.2 0 1 r
.016 w
.46102 .44011 m
.29774 .55874 L
s
P
p
.2 0 1 r
.02 w
.60304 .65755 m
.51407 .78001 L
s
P
p
.2 0 1 r
.02 w
.60304 .65755 m
.60304 .80892 L
s
P
p
.2 0 1 r
.02 w
.66909 .60957 m
.81305 .65634 L
s
P
p
.2 0 1 r
.02 w
.66909 .60957 m
.81305 .56279 L
s
P
p
0 .4 1 r
.018 w
.61863 .60957 m
.60304 .65755 L
s
P
p
0 .4 1 r
.018 w
.61863 .60957 m
.66909 .60957 L
s
P
p
.2 0 1 r
.02 w
.46729 .21352 m
.58975 .12455 L
s
P
p
.2 0 1 r
.02 w
.46729 .21352 m
.51407 .06956 L
s
P
p
.2 0 1 r
.02 w
.38965 .23875 m
.26719 .14977 L
s
P
p
.2 0 1 r
.02 w
.38965 .23875 m
.23828 .23875 L
s
P
p
0 .4 1 r
.018 w
.43763 .25434 m
.46729 .21352 L
s
P
p
0 .4 1 r
.018 w
.43763 .25434 m
.38965 .23875 L
s
P
p
.2 0 1 r
.02 w
.45918 .67777 m
.31522 .72454 L
s
P
p
.2 0 1 r
.02 w
.45918 .67777 m
.37021 .80023 L
s
P
p
.2 0 1 r
.02 w
.54082 .67777 m
.62979 .80023 L
s
P
p
.2 0 1 r
.02 w
.54082 .67777 m
.68478 .72454 L
s
P
p
0 .4 1 r
.018 w
.5 .64811 m
.45918 .67777 L
s
P
p
0 .4 1 r
.018 w
.5 .64811 m
.54082 .67777 L
s
P
p
.2 0 1 r
.02 w
.61035 .23875 m
.76172 .23875 L
s
P
p
.2 0 1 r
.02 w
.61035 .23875 m
.73281 .14977 L
s
P
p
.2 0 1 r
.02 w
.53271 .21352 m
.48593 .06956 L
s
P
p
.2 0 1 r
.02 w
.53271 .21352 m
.41025 .12455 L
s
P
p
0 .4 1 r
.018 w
.56237 .25434 m
.61035 .23875 L
s
P
p
0 .4 1 r
.018 w
.56237 .25434 m
.53271 .21352 L
s
P
p
.2 0 1 r
.02 w
.33091 .60957 m
.18695 .56279 L
s
P
p
.2 0 1 r
.02 w
.33091 .60957 m
.18695 .65634 L
s
P
p
.2 0 1 r
.02 w
.39696 .65755 m
.39696 .80892 L
s
P
p
.2 0 1 r
.02 w
.39696 .65755 m
.48593 .78001 L
s
P
p
0 .4 1 r
.018 w
.38137 .60957 m
.33091 .60957 L
s
P
p
0 .4 1 r
.018 w
.38137 .60957 m
.39696 .65755 L
s
P
p
.2 0 1 r
.016 w
.5 .44629 m
.61863 .60957 L
s
P
p
.2 0 1 r
.016 w
.5 .44629 m
.43763 .25434 L
s
P
p
.2 0 1 r
.016 w
.5 .44629 m
.5 .64811 L
s
P
p
.2 0 1 r
.016 w
.5 .44629 m
.56237 .25434 L
s
P
p
.2 0 1 r
.016 w
.5 .44629 m
.38137 .60957 L
s
P
p
.2 0 1 r
.02 w
.70226 .6092 m
.65548 .75316 L
s
P
p
.2 0 1 r
.02 w
.70226 .6092 m
.74904 .75316 L
s
P
p
.2 0 1 r
.02 w
.75025 .54315 m
.90162 .54315 L
s
P
p
.2 0 1 r
.02 w
.75025 .54315 m
.87271 .45418 L
s
P
p
0 .4 1 r
.018 w
.70226 .55874 m
.70226 .6092 L
s
P
p
0 .4 1 r
.018 w
.70226 .55874 m
.75025 .54315 L
s
P
p
.2 0 1 r
.02 w
.43594 .22885 m
.52491 .10639 L
s
P
p
.2 0 1 r
.02 w
.43594 .22885 m
.43594 .07748 L
s
P
p
.2 0 1 r
.02 w
.36989 .27683 m
.22593 .23006 L
s
P
p
.2 0 1 r
.02 w
.36989 .27683 m
.22593 .32361 L
s
P
p
0 .4 1 r
.018 w
.42035 .27683 m
.43594 .22885 L
s
P
p
0 .4 1 r
.018 w
.42035 .27683 m
.36989 .27683 L
s
P
p
.2 0 1 r
.02 w
.57169 .67288 m
.44923 .76185 L
s
P
p
.2 0 1 r
.02 w
.57169 .67288 m
.52491 .81684 L
s
P
p
.2 0 1 r
.02 w
.64933 .64765 m
.77179 .73662 L
s
P
p
.2 0 1 r
.02 w
.64933 .64765 m
.8007 .64765 L
s
P
p
0 .4 1 r
.018 w
.60135 .63206 m
.57169 .67288 L
s
P
p
0 .4 1 r
.018 w
.60135 .63206 m
.64933 .64765 L
s
P
p
.2 0 1 r
.02 w
.5798 .20863 m
.72376 .16185 L
s
P
p
.2 0 1 r
.02 w
.5798 .20863 m
.66877 .08617 L
s
P
p
.2 0 1 r
.02 w
.49816 .20863 m
.40919 .08617 L
s
P
p
.2 0 1 r
.02 w
.49816 .20863 m
.3542 .16185 L
s
P
p
0 .4 1 r
.018 w
.53898 .23829 m
.5798 .20863 L
s
P
p
0 .4 1 r
.018 w
.53898 .23829 m
.49816 .20863 L
s
P
p
.2 0 1 r
.02 w
.42863 .64765 m
.27726 .64765 L
s
P
p
.2 0 1 r
.02 w
.42863 .64765 m
.30617 .73662 L
s
P
p
.2 0 1 r
.02 w
.50627 .67288 m
.55305 .81684 L
s
P
p
.2 0 1 r
.02 w
.50627 .67288 m
.62873 .76185 L
s
P
p
0 .4 1 r
.018 w
.47661 .63206 m
.42863 .64765 L
s
P
p
0 .4 1 r
.018 w
.47661 .63206 m
.50627 .67288 L
s
P
p
.2 0 1 r
.016 w
.53898 .44011 m
.70226 .55874 L
s
P
p
.2 0 1 r
.016 w
.53898 .44011 m
.42035 .27683 L
s
P
p
.2 0 1 r
.016 w
.53898 .44011 m
.60135 .63206 L
s
P
p
.2 0 1 r
.016 w
.53898 .44011 m
.53898 .23829 L
s
P
p
.2 0 1 r
.016 w
.53898 .44011 m
.47661 .63206 L
s
P
p
.2 0 1 r
.02 w
.78168 .53255 m
.78168 .68392 L
s
P
p
.2 0 1 r
.02 w
.78168 .53255 m
.87066 .65501 L
s
P
p
.2 0 1 r
.02 w
.80691 .45491 m
.95087 .40813 L
s
P
p
.2 0 1 r
.02 w
.80691 .45491 m
.89588 .33245 L
s
P
p
0 .4 1 r
.018 w
.76609 .48456 m
.78168 .53255 L
s
P
p
0 .4 1 r
.018 w
.76609 .48456 m
.80691 .45491 L
s
P
p
.2 0 1 r
.02 w
.41086 .25311 m
.45764 .10915 L
s
P
p
.2 0 1 r
.02 w
.41086 .25311 m
.36409 .10915 L
s
P
p
.2 0 1 r
.02 w
.36288 .31916 m
.21151 .31916 L
s
P
p
.2 0 1 r
.02 w
.36288 .31916 m
.24042 .40813 L
s
P
p
0 .4 1 r
.018 w
.41086 .30357 m
.41086 .25311 L
s
P
p
0 .4 1 r
.018 w
.41086 .30357 m
.36288 .31916 L
s
P
p
.2 0 1 r
.02 w
.67718 .63346 m
.58821 .75592 L
s
P
p
.2 0 1 r
.02 w
.67718 .63346 m
.67718 .78483 L
s
P
p
.2 0 1 r
.02 w
.74323 .58548 m
.88719 .63225 L
s
P
p
.2 0 1 r
.02 w
.74323 .58548 m
.88719 .5387 L
s
P
p
0 .4 1 r
.018 w
.69277 .58548 m
.67718 .63346 L
s
P
p
0 .4 1 r
.018 w
.69277 .58548 m
.74323 .58548 L
s
P
p
.2 0 1 r
.02 w
.54143 .18943 m
.66389 .10046 L
s
P
p
.2 0 1 r
.02 w
.54143 .18943 m
.58821 .04547 L
s
P
p
.2 0 1 r
.02 w
.46379 .21466 m
.34133 .12568 L
s
P
p
.2 0 1 r
.02 w
.46379 .21466 m
.31242 .21466 L
s
P
p
0 .4 1 r
.018 w
.51178 .23025 m
.54143 .18943 L
s
P
p
0 .4 1 r
.018 w
.51178 .23025 m
.46379 .21466 L
s
P
p
.2 0 1 r
.02 w
.53332 .65368 m
.38936 .70045 L
s
P
p
.2 0 1 r
.02 w
.53332 .65368 m
.44435 .77614 L
s
P
p
.2 0 1 r
.02 w
.61496 .65368 m
.70394 .77614 L
s
P
p
.2 0 1 r
.02 w
.61496 .65368 m
.75892 .70045 L
s
P
p
0 .4 1 r
.018 w
.57414 .62402 m
.53332 .65368 L
s
P
p
0 .4 1 r
.018 w
.57414 .62402 m
.61496 .65368 L
s
P
p
.2 0 1 r
.016 w
.57414 .4222 m
.76609 .48456 L
s
P
p
.2 0 1 r
.016 w
.57414 .4222 m
.41086 .30357 L
s
P
p
.2 0 1 r
.016 w
.57414 .4222 m
.69277 .58548 L
s
P
p
.2 0 1 r
.016 w
.57414 .4222 m
.51178 .23025 L
s
P
p
.2 0 1 r
.016 w
.57414 .4222 m
.57414 .62402 L
s
P
p
1 .6 0 r
.016 w
.5 .32015 m
.42586 .4222 L
s
P
p
1 .6 0 r
.016 w
.5 .32015 m
.46102 .44011 L
s
P
p
1 .6 0 r
.016 w
.5 .32015 m
.5 .44629 L
s
P
p
1 .6 0 r
.016 w
.5 .32015 m
.53898 .44011 L
s
P
p
1 .6 0 r
.016 w
.5 .32015 m
.57414 .4222 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.29387 .59845 m
.14698 .59845 L
s
P
p
.2 0 1 r
.02 w
.29387 .59845 m
.17503 .6848 L
s
P
p
.2 0 1 r
.02 w
.36922 .62294 m
.41462 .76264 L
s
P
p
.2 0 1 r
.02 w
.36922 .62294 m
.48806 .70928 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.29387 .59845 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.36922 .62294 L
s
P
p
.2 0 1 r
.02 w
.56505 .2386 m
.70476 .28399 L
s
P
p
.2 0 1 r
.02 w
.56505 .2386 m
.70476 .1932 L
s
P
p
.2 0 1 r
.02 w
.50096 .19203 m
.50096 .04513 L
s
P
p
.2 0 1 r
.02 w
.50096 .19203 m
.41462 .07319 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.56505 .2386 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.50096 .19203 L
s
P
p
.2 0 1 r
.02 w
.19594 .49704 m
.0771 .4107 L
s
P
p
.2 0 1 r
.02 w
.19594 .49704 m
.04905 .49704 L
s
P
p
.2 0 1 r
.02 w
.24251 .56114 m
.19712 .70084 L
s
P
p
.2 0 1 r
.02 w
.24251 .56114 m
.28791 .70084 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.19594 .49704 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.24251 .56114 L
s
P
p
.2 0 1 r
.02 w
.62685 .36531 m
.7132 .48415 L
s
P
p
.2 0 1 r
.02 w
.62685 .36531 m
.76656 .4107 L
s
P
p
.2 0 1 r
.02 w
.60237 .28996 m
.68871 .17112 L
s
P
p
.2 0 1 r
.02 w
.60237 .28996 m
.60237 .14306 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.62685 .36531 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.60237 .28996 L
s
P
p
.2 0 1 r
.02 w
.17633 .35744 m
.13093 .21773 L
s
P
p
.2 0 1 r
.02 w
.17633 .35744 m
.05749 .27109 L
s
P
p
.2 0 1 r
.02 w
.17633 .43666 m
.05749 .52301 L
s
P
p
.2 0 1 r
.02 w
.17633 .43666 m
.13093 .57637 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .35744 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .43666 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.34044 .58332 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.51609 .2386 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.24251 .51217 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.58724 .33653 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.20511 .39705 L
s
P
p
.2 0 1 r
.02 w
.49392 .66741 m
.37508 .75375 L
s
P
p
.2 0 1 r
.02 w
.49392 .66741 m
.44852 .80711 L
s
P
p
.2 0 1 r
.02 w
.56926 .64292 m
.6881 .72927 L
s
P
p
.2 0 1 r
.02 w
.56926 .64292 m
.71616 .64292 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.49392 .66741 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.56926 .64292 L
s
P
p
.2 0 1 r
.02 w
.50179 .21688 m
.64149 .17149 L
s
P
p
.2 0 1 r
.02 w
.50179 .21688 m
.58813 .09804 L
s
P
p
.2 0 1 r
.02 w
.42256 .21688 m
.33622 .09804 L
s
P
p
.2 0 1 r
.02 w
.42256 .21688 m
.28285 .17149 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.50179 .21688 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.42256 .21688 L
s
P
p
.2 0 1 r
.02 w
.35508 .64292 m
.20819 .64292 L
s
P
p
.2 0 1 r
.02 w
.35508 .64292 m
.23624 .72927 L
s
P
p
.2 0 1 r
.02 w
.43043 .66741 m
.47582 .80711 L
s
P
p
.2 0 1 r
.02 w
.43043 .66741 m
.54927 .75375 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.35508 .64292 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.43043 .66741 L
s
P
p
.2 0 1 r
.02 w
.62626 .28307 m
.76597 .32846 L
s
P
p
.2 0 1 r
.02 w
.62626 .28307 m
.76597 .23767 L
s
P
p
.2 0 1 r
.02 w
.56216 .2365 m
.56216 .0896 L
s
P
p
.2 0 1 r
.02 w
.56216 .2365 m
.47582 .11766 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.62626 .28307 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.56216 .2365 L
s
P
p
.2 0 1 r
.02 w
.25715 .54151 m
.13831 .45517 L
s
P
p
.2 0 1 r
.02 w
.25715 .54151 m
.11026 .54151 L
s
P
p
.2 0 1 r
.02 w
.30372 .60561 m
.25833 .74531 L
s
P
p
.2 0 1 r
.02 w
.30372 .60561 m
.34911 .74531 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.25715 .54151 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.30372 .60561 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5227 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.46217 .24566 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.40165 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5773 .28307 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.30372 .55664 L
s
P
p
.2 0 1 r
.02 w
.69628 .60561 m
.65089 .74531 L
s
P
p
.2 0 1 r
.02 w
.69628 .60561 m
.74167 .74531 L
s
P
p
.2 0 1 r
.02 w
.74285 .54151 m
.88974 .54151 L
s
P
p
.2 0 1 r
.02 w
.74285 .54151 m
.86169 .45517 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.69628 .60561 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.74285 .54151 L
s
P
p
.2 0 1 r
.02 w
.43784 .2365 m
.52418 .11766 L
s
P
p
.2 0 1 r
.02 w
.43784 .2365 m
.43784 .0896 L
s
P
p
.2 0 1 r
.02 w
.37374 .28307 m
.23403 .23767 L
s
P
p
.2 0 1 r
.02 w
.37374 .28307 m
.23403 .32846 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.43784 .2365 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.37374 .28307 L
s
P
p
.2 0 1 r
.02 w
.56957 .66741 m
.45073 .75375 L
s
P
p
.2 0 1 r
.02 w
.56957 .66741 m
.52418 .80711 L
s
P
p
.2 0 1 r
.02 w
.64492 .64292 m
.76376 .72927 L
s
P
p
.2 0 1 r
.02 w
.64492 .64292 m
.79181 .64292 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.56957 .66741 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.64492 .64292 L
s
P
p
.2 0 1 r
.02 w
.57744 .21688 m
.71715 .17149 L
s
P
p
.2 0 1 r
.02 w
.57744 .21688 m
.66378 .09804 L
s
P
p
.2 0 1 r
.02 w
.49821 .21688 m
.41187 .09804 L
s
P
p
.2 0 1 r
.02 w
.49821 .21688 m
.35851 .17149 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.57744 .21688 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.49821 .21688 L
s
P
p
.2 0 1 r
.02 w
.43074 .64292 m
.28384 .64292 L
s
P
p
.2 0 1 r
.02 w
.43074 .64292 m
.3119 .72927 L
s
P
p
.2 0 1 r
.02 w
.50608 .66741 m
.55148 .80711 L
s
P
p
.2 0 1 r
.02 w
.50608 .66741 m
.62492 .75375 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.43074 .64292 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.50608 .66741 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.69628 .55664 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4227 .28307 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.59835 .62779 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.53783 .24566 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4773 .62779 L
s
P
p
.2 0 1 r
.02 w
.82367 .43666 m
.86907 .57637 L
s
P
p
.2 0 1 r
.02 w
.82367 .43666 m
.94251 .52301 L
s
P
p
.2 0 1 r
.02 w
.82367 .35744 m
.94251 .27109 L
s
P
p
.2 0 1 r
.02 w
.82367 .35744 m
.86907 .21773 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .43666 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .35744 L
s
P
p
.2 0 1 r
.02 w
.39763 .28996 m
.39763 .14306 L
s
P
p
.2 0 1 r
.02 w
.39763 .28996 m
.31129 .17112 L
s
P
p
.2 0 1 r
.02 w
.37315 .36531 m
.23344 .4107 L
s
P
p
.2 0 1 r
.02 w
.37315 .36531 m
.2868 .48415 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.39763 .28996 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.37315 .36531 L
s
P
p
.2 0 1 r
.02 w
.75749 .56114 m
.71209 .70084 L
s
P
p
.2 0 1 r
.02 w
.75749 .56114 m
.80288 .70084 L
s
P
p
.2 0 1 r
.02 w
.80406 .49704 m
.95095 .49704 L
s
P
p
.2 0 1 r
.02 w
.80406 .49704 m
.9229 .4107 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.75749 .56114 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.80406 .49704 L
s
P
p
.2 0 1 r
.02 w
.49904 .19203 m
.58538 .07319 L
s
P
p
.2 0 1 r
.02 w
.49904 .19203 m
.49904 .04513 L
s
P
p
.2 0 1 r
.02 w
.43495 .2386 m
.29524 .1932 L
s
P
p
.2 0 1 r
.02 w
.43495 .2386 m
.29524 .28399 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.49904 .19203 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.43495 .2386 L
s
P
p
.2 0 1 r
.02 w
.63078 .62294 m
.51194 .70928 L
s
P
p
.2 0 1 r
.02 w
.63078 .62294 m
.58538 .76264 L
s
P
p
.2 0 1 r
.02 w
.70613 .59845 m
.82497 .6848 L
s
P
p
.2 0 1 r
.02 w
.70613 .59845 m
.85302 .59845 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.63078 .62294 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.70613 .59845 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.79489 .39705 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.41276 .33653 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.75749 .51217 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.48391 .2386 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.65956 .58332 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.40097 .39705 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.46217 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.53783 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0445573 0.952381 [
[ 0 0 0 0 ]
[ 1 .86327 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .86327 L
0 .86327 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.42589 .66111 m
.28864 .73104 L
s
P
p
.2 0 1 r
.02 w
.42589 .66111 m
.35596 .79836 L
s
P
p
.2 0 1 r
.02 w
.50795 .64812 m
.61687 .75704 L
s
P
p
.2 0 1 r
.02 w
.50795 .64812 m
.66009 .67221 L
s
P
p
0 .4 1 r
.018 w
.4622 .6248 m
.42589 .66111 L
s
P
p
0 .4 1 r
.018 w
.4622 .6248 m
.50795 .64812 L
s
P
p
.2 0 1 r
.02 w
.50795 .19578 m
.66009 .17168 L
s
P
p
.2 0 1 r
.02 w
.50795 .19578 m
.61687 .08686 L
s
P
p
.2 0 1 r
.02 w
.42589 .18278 m
.35596 .04553 L
s
P
p
.2 0 1 r
.02 w
.42589 .18278 m
.28864 .11285 L
s
P
p
0 .4 1 r
.018 w
.4622 .21909 m
.50795 .19578 L
s
P
p
0 .4 1 r
.018 w
.4622 .21909 m
.42589 .18278 L
s
P
p
.2 0 1 r
.02 w
.28611 .61298 m
.13397 .58888 L
s
P
p
.2 0 1 r
.02 w
.28611 .61298 m
.14886 .68291 L
s
P
p
.2 0 1 r
.02 w
.36014 .6507 m
.38423 .80284 L
s
P
p
.2 0 1 r
.02 w
.36014 .6507 m
.46906 .75962 L
s
P
p
0 .4 1 r
.018 w
.33682 .60495 m
.28611 .61298 L
s
P
p
0 .4 1 r
.018 w
.33682 .60495 m
.36014 .6507 L
s
P
p
.2 0 1 r
.02 w
.62601 .28475 m
.76326 .35468 L
s
P
p
.2 0 1 r
.02 w
.62601 .28475 m
.77815 .26065 L
s
P
p
.2 0 1 r
.02 w
.56726 .226 m
.59136 .07386 L
s
P
p
.2 0 1 r
.02 w
.56726 .226 m
.49733 .08875 L
s
P
p
0 .4 1 r
.018 w
.5753 .27672 m
.62601 .28475 L
s
P
p
0 .4 1 r
.018 w
.5753 .27672 m
.56726 .226 L
s
P
p
.2 0 1 r
.02 w
.20132 .49188 m
.0924 .38296 L
s
P
p
.2 0 1 r
.02 w
.20132 .49188 m
.04918 .46778 L
s
P
p
.2 0 1 r
.02 w
.23904 .5659 m
.1691 .70315 L
s
P
p
.2 0 1 r
.02 w
.23904 .5659 m
.26313 .71805 L
s
P
p
0 .4 1 r
.018 w
.24707 .51519 m
.20132 .49188 L
s
P
p
0 .4 1 r
.018 w
.24707 .51519 m
.23904 .5659 L
s
P
p
.2 0 1 r
.016 w
.43007 .42195 m
.4622 .6248 L
s
P
p
.2 0 1 r
.016 w
.43007 .42195 m
.4622 .21909 L
s
P
p
.2 0 1 r
.016 w
.43007 .42195 m
.33682 .60495 L
s
P
p
.2 0 1 r
.016 w
.43007 .42195 m
.5753 .27672 L
s
P
p
.2 0 1 r
.016 w
.43007 .42195 m
.24707 .51519 L
s
P
p
.2 0 1 r
.02 w
.54584 .66559 m
.43691 .77451 L
s
P
p
.2 0 1 r
.02 w
.54584 .66559 m
.52174 .81773 L
s
P
p
.2 0 1 r
.02 w
.61986 .62787 m
.75711 .6978 L
s
P
p
.2 0 1 r
.02 w
.61986 .62787 m
.772 .60378 L
s
P
p
0 .4 1 r
.018 w
.56915 .61984 m
.54584 .66559 L
s
P
p
0 .4 1 r
.018 w
.56915 .61984 m
.61986 .62787 L
s
P
p
.2 0 1 r
.02 w
.48008 .19768 m
.61733 .12774 L
s
P
p
.2 0 1 r
.02 w
.48008 .19768 m
.55001 .06043 L
s
P
p
.2 0 1 r
.02 w
.39802 .21067 m
.2891 .10175 L
s
P
p
.2 0 1 r
.02 w
.39802 .21067 m
.24588 .18658 L
s
P
p
0 .4 1 r
.018 w
.44377 .23398 m
.48008 .19768 L
s
P
p
0 .4 1 r
.018 w
.44377 .23398 m
.39802 .21067 L
s
P
p
.2 0 1 r
.02 w
.39802 .66301 m
.24588 .6871 L
s
P
p
.2 0 1 r
.02 w
.39802 .66301 m
.2891 .77193 L
s
P
p
.2 0 1 r
.02 w
.48008 .676 m
.55001 .81325 L
s
P
p
.2 0 1 r
.02 w
.48008 .676 m
.61733 .74594 L
s
P
p
0 .4 1 r
.018 w
.44377 .6397 m
.39802 .66301 L
s
P
p
0 .4 1 r
.018 w
.44377 .6397 m
.48008 .676 L
s
P
p
.2 0 1 r
.02 w
.61986 .24581 m
.772 .26991 L
s
P
p
.2 0 1 r
.02 w
.61986 .24581 m
.75711 .17588 L
s
P
p
.2 0 1 r
.02 w
.54584 .20809 m
.52174 .05595 L
s
P
p
.2 0 1 r
.02 w
.54584 .20809 m
.43691 .09917 L
s
P
p
0 .4 1 r
.018 w
.56915 .25384 m
.61986 .24581 L
s
P
p
0 .4 1 r
.018 w
.56915 .25384 m
.54584 .20809 L
s
P
p
.2 0 1 r
.02 w
.27996 .57404 m
.14271 .50411 L
s
P
p
.2 0 1 r
.02 w
.27996 .57404 m
.12782 .59813 L
s
P
p
.2 0 1 r
.02 w
.33871 .63278 m
.31461 .78493 L
s
P
p
.2 0 1 r
.02 w
.33871 .63278 m
.40864 .77003 L
s
P
p
0 .4 1 r
.018 w
.33067 .58207 m
.27996 .57404 L
s
P
p
0 .4 1 r
.018 w
.33067 .58207 m
.33871 .63278 L
s
P
p
.2 0 1 r
.016 w
.4759 .43684 m
.56915 .61984 L
s
P
p
.2 0 1 r
.016 w
.4759 .43684 m
.44377 .23398 L
s
P
p
.2 0 1 r
.016 w
.4759 .43684 m
.44377 .6397 L
s
P
p
.2 0 1 r
.016 w
.4759 .43684 m
.56915 .25384 L
s
P
p
.2 0 1 r
.016 w
.4759 .43684 m
.33067 .58207 L
s
P
p
.2 0 1 r
.02 w
.66129 .63278 m
.59136 .77003 L
s
P
p
.2 0 1 r
.02 w
.66129 .63278 m
.68539 .78493 L
s
P
p
.2 0 1 r
.02 w
.72004 .57404 m
.87218 .59813 L
s
P
p
.2 0 1 r
.02 w
.72004 .57404 m
.85729 .50411 L
s
P
p
0 .4 1 r
.018 w
.66933 .58207 m
.66129 .63278 L
s
P
p
0 .4 1 r
.018 w
.66933 .58207 m
.72004 .57404 L
s
P
p
.2 0 1 r
.02 w
.45416 .20809 m
.56309 .09917 L
s
P
p
.2 0 1 r
.02 w
.45416 .20809 m
.47826 .05595 L
s
P
p
.2 0 1 r
.02 w
.38014 .24581 m
.24289 .17588 L
s
P
p
.2 0 1 r
.02 w
.38014 .24581 m
.228 .26991 L
s
P
p
0 .4 1 r
.018 w
.43085 .25384 m
.45416 .20809 L
s
P
p
0 .4 1 r
.018 w
.43085 .25384 m
.38014 .24581 L
s
P
p
.2 0 1 r
.02 w
.51992 .676 m
.38267 .74594 L
s
P
p
.2 0 1 r
.02 w
.51992 .676 m
.44999 .81325 L
s
P
p
.2 0 1 r
.02 w
.60198 .66301 m
.7109 .77193 L
s
P
p
.2 0 1 r
.02 w
.60198 .66301 m
.75412 .6871 L
s
P
p
0 .4 1 r
.018 w
.55623 .6397 m
.51992 .676 L
s
P
p
0 .4 1 r
.018 w
.55623 .6397 m
.60198 .66301 L
s
P
p
.2 0 1 r
.02 w
.60198 .21067 m
.75412 .18658 L
s
P
p
.2 0 1 r
.02 w
.60198 .21067 m
.7109 .10175 L
s
P
p
.2 0 1 r
.02 w
.51992 .19768 m
.44999 .06043 L
s
P
p
.2 0 1 r
.02 w
.51992 .19768 m
.38267 .12774 L
s
P
p
0 .4 1 r
.018 w
.55623 .23398 m
.60198 .21067 L
s
P
p
0 .4 1 r
.018 w
.55623 .23398 m
.51992 .19768 L
s
P
p
.2 0 1 r
.02 w
.38014 .62787 m
.228 .60378 L
s
P
p
.2 0 1 r
.02 w
.38014 .62787 m
.24289 .6978 L
s
P
p
.2 0 1 r
.02 w
.45416 .66559 m
.47826 .81773 L
s
P
p
.2 0 1 r
.02 w
.45416 .66559 m
.56309 .77451 L
s
P
p
0 .4 1 r
.018 w
.43085 .61984 m
.38014 .62787 L
s
P
p
0 .4 1 r
.018 w
.43085 .61984 m
.45416 .66559 L
s
P
p
.2 0 1 r
.016 w
.5241 .43684 m
.66933 .58207 L
s
P
p
.2 0 1 r
.016 w
.5241 .43684 m
.43085 .25384 L
s
P
p
.2 0 1 r
.016 w
.5241 .43684 m
.55623 .6397 L
s
P
p
.2 0 1 r
.016 w
.5241 .43684 m
.55623 .23398 L
s
P
p
.2 0 1 r
.016 w
.5241 .43684 m
.43085 .61984 L
s
P
p
.2 0 1 r
.02 w
.76096 .5659 m
.73687 .71805 L
s
P
p
.2 0 1 r
.02 w
.76096 .5659 m
.8309 .70315 L
s
P
p
.2 0 1 r
.02 w
.79868 .49188 m
.95082 .46778 L
s
P
p
.2 0 1 r
.02 w
.79868 .49188 m
.9076 .38296 L
s
P
p
0 .4 1 r
.018 w
.75293 .51519 m
.76096 .5659 L
s
P
p
0 .4 1 r
.018 w
.75293 .51519 m
.79868 .49188 L
s
P
p
.2 0 1 r
.02 w
.43274 .226 m
.50267 .08875 L
s
P
p
.2 0 1 r
.02 w
.43274 .226 m
.40864 .07386 L
s
P
p
.2 0 1 r
.02 w
.37399 .28475 m
.22185 .26065 L
s
P
p
.2 0 1 r
.02 w
.37399 .28475 m
.23674 .35468 L
s
P
p
0 .4 1 r
.018 w
.4247 .27672 m
.43274 .226 L
s
P
p
0 .4 1 r
.018 w
.4247 .27672 m
.37399 .28475 L
s
P
p
.2 0 1 r
.02 w
.63986 .6507 m
.53094 .75962 L
s
P
p
.2 0 1 r
.02 w
.63986 .6507 m
.61577 .80284 L
s
P
p
.2 0 1 r
.02 w
.71389 .61298 m
.85114 .68291 L
s
P
p
.2 0 1 r
.02 w
.71389 .61298 m
.86603 .58888 L
s
P
p
0 .4 1 r
.018 w
.66318 .60495 m
.63986 .6507 L
s
P
p
0 .4 1 r
.018 w
.66318 .60495 m
.71389 .61298 L
s
P
p
.2 0 1 r
.02 w
.57411 .18278 m
.71136 .11285 L
s
P
p
.2 0 1 r
.02 w
.57411 .18278 m
.64404 .04553 L
s
P
p
.2 0 1 r
.02 w
.49205 .19578 m
.38313 .08686 L
s
P
p
.2 0 1 r
.02 w
.49205 .19578 m
.33991 .17168 L
s
P
p
0 .4 1 r
.018 w
.5378 .21909 m
.57411 .18278 L
s
P
p
0 .4 1 r
.018 w
.5378 .21909 m
.49205 .19578 L
s
P
p
.2 0 1 r
.02 w
.49205 .64812 m
.33991 .67221 L
s
P
p
.2 0 1 r
.02 w
.49205 .64812 m
.38313 .75704 L
s
P
p
.2 0 1 r
.02 w
.57411 .66111 m
.64404 .79836 L
s
P
p
.2 0 1 r
.02 w
.57411 .66111 m
.71136 .73104 L
s
P
p
0 .4 1 r
.018 w
.5378 .6248 m
.49205 .64812 L
s
P
p
0 .4 1 r
.018 w
.5378 .6248 m
.57411 .66111 L
s
P
p
.2 0 1 r
.016 w
.56993 .42195 m
.75293 .51519 L
s
P
p
.2 0 1 r
.016 w
.56993 .42195 m
.4247 .27672 L
s
P
p
.2 0 1 r
.016 w
.56993 .42195 m
.66318 .60495 L
s
P
p
.2 0 1 r
.016 w
.56993 .42195 m
.5378 .21909 L
s
P
p
.2 0 1 r
.016 w
.56993 .42195 m
.5378 .6248 L
s
P
p
1 .6 0 r
.016 w
.5 .2847 m
.43007 .42195 L
s
P
p
1 .6 0 r
.016 w
.5 .2847 m
.4759 .43684 L
s
P
p
1 .6 0 r
.016 w
.5 .2847 m
.5241 .43684 L
s
P
p
1 .6 0 r
.016 w
.5 .2847 m
.56993 .42195 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.018 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.018 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.018 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.018 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.02 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.02 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.02 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.02 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.02 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.02 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.02 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.02 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.02 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.02 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.02 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.02 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.02 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.02 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.02 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.02 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.02 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.02 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.02 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.02 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.02 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.02 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.02 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.02 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.02 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.02 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.02 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.02 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.02 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.02 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.02 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.02 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.02 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.02 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.02 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.02 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.02 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.02 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.02 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.02 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
.8 1 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
.8 1 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
.8 1 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
.8 1 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.114296 0.952381 [
[ 0 0 0 0 ]
[ 1 .72379 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .72379 L
0 .72379 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.02 w
.24314 .43023 m
.04991 .39963 L
s
P
p
.2 0 1 r
.02 w
.24314 .43023 m
.06882 .51906 L
s
P
p
.2 0 1 r
.02 w
.33716 .47814 m
.36777 .67138 L
s
P
p
.2 0 1 r
.02 w
.33716 .47814 m
.4755 .61648 L
s
P
p
0 .4 1 r
.018 w
.30756 .42003 m
.24314 .43023 L
s
P
p
0 .4 1 r
.018 w
.30756 .42003 m
.33716 .47814 L
s
P
p
.2 0 1 r
.016 w
.42598 .18761 m
.30756 .42003 L
s
P
p
.2 0 1 r
.02 w
.37558 .49062 m
.18235 .52123 L
s
P
p
.2 0 1 r
.02 w
.37558 .49062 m
.23724 .62896 L
s
P
p
.2 0 1 r
.02 w
.4798 .50713 m
.56862 .68145 L
s
P
p
.2 0 1 r
.02 w
.4798 .50713 m
.65412 .59595 L
s
P
p
0 .4 1 r
.018 w
.43369 .46102 m
.37558 .49062 L
s
P
p
0 .4 1 r
.018 w
.43369 .46102 m
.4798 .50713 L
s
P
p
.2 0 1 r
.016 w
.4745 .20337 m
.43369 .46102 L
s
P
p
.2 0 1 r
.02 w
.5202 .50713 m
.34588 .59595 L
s
P
p
.2 0 1 r
.02 w
.5202 .50713 m
.43138 .68145 L
s
P
p
.2 0 1 r
.02 w
.62442 .49062 m
.76276 .62896 L
s
P
p
.2 0 1 r
.02 w
.62442 .49062 m
.81765 .52123 L
s
P
p
0 .4 1 r
.018 w
.56631 .46102 m
.5202 .50713 L
s
P
p
0 .4 1 r
.018 w
.56631 .46102 m
.62442 .49062 L
s
P
p
.2 0 1 r
.016 w
.5255 .20337 m
.56631 .46102 L
s
P
p
.2 0 1 r
.02 w
.66284 .47814 m
.5245 .61648 L
s
P
p
.2 0 1 r
.02 w
.66284 .47814 m
.63223 .67138 L
s
P
p
.2 0 1 r
.02 w
.75686 .43023 m
.93118 .51906 L
s
P
p
.2 0 1 r
.02 w
.75686 .43023 m
.95009 .39963 L
s
P
p
0 .4 1 r
.018 w
.69244 .42003 m
.66284 .47814 L
s
P
p
0 .4 1 r
.018 w
.69244 .42003 m
.75686 .43023 L
s
P
p
.2 0 1 r
.016 w
.57402 .18761 m
.69244 .42003 L
s
P
p
1 .6 0 r
.016 w
.5 .04234 m
.42598 .18761 L
s
P
p
1 .6 0 r
.016 w
.5 .04234 m
.4745 .20337 L
s
P
p
1 .6 0 r
.016 w
.5 .04234 m
.5255 .20337 L
s
P
p
1 .6 0 r
.016 w
.5 .04234 m
.57402 .18761 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`0001<000=<00001@000d`0000H0003C00000D000=<0000>`000d`000050003C00001P0
00=<00001@000d`0000H0003C00000D000=<000060000lH000050003aP000180000C00A=00<0CDd0
0TdJ00A=00<0CDd00TdH009=00D0CDe=0003C@0304e=01P000E=04e=0002C@0304d001T000I=001=
04d20003C@0001P014d00`1=C@02CAX01<H00`36aP02aQ@0000@0003C00000U<0P000d`0000B0003
C00000U<0P000d`0000E00A<00D0C4`0C00H0003C01<00Q<00<0C0005005C00504`0C0001D`D0003
C00000U<0P000d`0000B0003aP0000W60P000lH0000?00004002C@0404e=00==00<0CDd00TdE009=
00@0CDd00dd00`1=C@02CA@00Td00`1=C@02C@0304e=00A=00<0CDd04`02C@0304e=00M=00<0CDd0
5P0;CAL014d01@1=CDd0009=00<0CDd05@04aP050<K6aP000/H00`36aP0A00004P0;C1P02d`G00Q<
00?6C4`00T`D009<00<0C4`02D`00`1<C00E00M<00C6C4a<600;C1P02lHC00003P08C@C61TdA019=
5`000dg6aP04aQT01Dd2aP03CLI=00==5007C@G61DdB00M=1<H7CA404/H?00004004C0;600E<04a<
aP03C1D01d`00`1<C004C1<014`200;600E<04a<aP0300=<4@05C0?600@0C<K61D`D009<00D0a/I<
0002C004aP1<C1H00d`3aP0404c6aPA<5@05aP04C01<C0G64@0000d01Td2aP9=00<0CDd00/H5C@l0
2Td00`1=C@07CA@000==a/H00Td00`1=C@02aP9=4`03C@0404g6aP9=00<0CDd00/H00dd0C@02CA00
1Dd2aP9=00D0CDe=aP05CA001Dd2aP9=00<0CDd00/H5CA001lH2C@0304e=00S63P0000h014`2aP=<
00D0C4a<aP02C00304a<01002D`00`1<C004C00304a<01800T`2aP=<00@0C4a<0/H3C1800d`2aP=<
00D0C4a<aP04C1@000=<a/H00d`0101<C4`2aP03C00001400d`00`1<aP03C00404a<C0;600A<04a<
4003aP030<K600=<00@0C4a<1/H?000040000dd00002009=00<ACDd00`02CA@000==00000P02C@03
4De=00<00TdA00==1@02C@034De=00H00Td?0003C@1=00@00Td00a5=C@030004C@00CA400Td4009=
00<ACDd01002CA<00Td3009=00<ACDd010000dd0000B00;60`02C@034De=00@000?600003`0000l0
00=<00000`02C0034Da<00D000=<000040000d`00003009<00<AC4`01@000d`0000F009<00<AC4`0
60000d`00003009<00<AC4`010000d`0000@0003C00000@00T`00a5<C0060003C00000l000=<0000
0`02C0034Da<00D000=<000040000lH00003009<00<AC4`01@000lH0000>00002P001Dd0001=00H0
00E=4A4AC@060005C@0004d020001Dd0001=00H000E=4A4AC@060005C@0004d04`001DdA4A5=01@0
00A=001=1P001DdA4A5=00D000E=0000C@0D0005CA4A4Dd04`001Dd0001=00H000E=4A4AC@060005
C@0004d020001LH0003600H000E=4A4AC@060005aP000<H02`0000X000=<000020001D`AC15<00T0
00=<000020000d`000070005C15<4D`02@000d`0000B0005C15<4D`050000d`000070005C15<4D`0
2@000d`000070003C00000P000E<4D`AC00:0003C00000L000=<00001`001D`AC15<00T000=<0000
20000lH000070005C15<4D`02@000lH0000:00002`000dd000060004CA4A008A00==00001@000dd0
000:0003C@0000D000A=4A400Q400dd000050003C@0000L00Td90004CA4A008A00==00001`02C@T0
00==00001@0014dA4@024@03C@0000D000==00002@000dd000060004CA4A008A00==00001P000dd0
00090003C@0000D000A=4A400Q400dd000050003C@0000X000?600001@0014dA4@024@03C@0000D0
00?600002`0000T014`5009<00@0C4`00T`00`1<C0040003C01<009<1P05C0@00T`0101<C002C003
04a<00@000=<04`00T`8009<1@02C00404a<009<00<0C4`01@02C0`000=<00000P02C00404a<009<
00<0C4`010000d`0000800A<1@02C00404a<009<00<0C4`01@04C0H01D`4009<00@0C4`00T`00`1<
C0040003C01<009<1P05aP@00T`0101<C002C00304a<00@000?60<H00/H:00002`02C@;600<0CDd0
0P07C@800Td01036CDd;00A=00<0CDd00P07C@800Td0101=CDd=00;600<0CDd00P07C@800Td00`36
aP0:00E=00C604e=0P07C@800Td00`36C@04C@T000A=a/H00Td200M=0P02C@040<K6C@/00dd01<H0
CDd200M=0P02C@030<I=009=2`03aP0304e=00801dd2009=00<0a/H00/H<00003@03C0<024`4009<
3`03C0@01d`4009<4@0014`00009C0<000=<00003`02C0@01d`4009<3P02C00304`000802D`30004
C01<C0d00d`400M<1003C0l000?6C0000`07C0@000=<a/H03P0000l000==00000Td0101=C@02C@03
04d0008000?6000040001Td0001=009=00D0CDd0C@030003C@0000/014d01<H00002C@0404e=009=
00<0CDd00P000lH0C@02C@/00Td00`1=00020005C@1=C@000Td00`1=00020004aP1=C@h00Td2009=
00@0CDd00Td00`1=C@020003aTd0010000I=0000C@02C@0504e=04d00`000lH0000@0006aP0004d0
0Td01@1=C@1=00<000?600003P0000/01D`01LI<04`0009<00@0C4`00T`2aPE<2P09C00404a<009<
00<0C4`01d`=009<00G6C01<0002C00804a<04`0C<H2C1001T`0101<C002C00304a<00;60d`?009<
00G6C01<0002C00;04a<04`0C<I<aT`03005C0;60T`0101<C002C00304a<00;61D`:00O60T`0101<
C002C00304a<00O6300000h01Dd01LI=CDg6009=0/H00dg6C@02CA004dd@009=00C6CDg60dd00lI=
C@02aP03CLK600==3005C@;600==a/H00Td00lI=C@02aP03CLK6009=00<0CDd02P08C@800Td00`1=
C@020003CLK600E=3@05C@;60Td00lI=C@02aP03CLK6009=4007aP9=00?6CDd00/H00dg6aP02aPl0
000=009<00<0C4`00/H2C003aP36009<0/H5C0h00T`00`1<C005C00304a<00E<00<0C4`03006C00:
0<K6aTc60<I<00;60P02C00304a<00`00T`00`1<C004C003aP36009<0/H2C00304a<00h00T`30003
C<I<009<00C6C4a<0/H00d`00002C0h00T`00`1<C002aP9<00?60<H00T`2aP9<00<0C4`03P02aP03
0<K600G600<0aT`01LH00`36aP0>00003002C@0304e=00==0/H014g6CLH7C@0304d000/00Td00`1=
C@0@C@0304d000d000A=00000dd3aP030<I=009=0`000dd0000=0003C@1=00A=0/H014g6CLH6C@03
04d000`00Td00`1=C@05C@06aTg6aTg614d00`1=C@0<0003C@1=00E=0/H2C@;61dd00`1=000;0003
aP36017600<0a/H03@0000`000A<04`03D`01@1<C01<00d000A<04`03D`01@1<C01<00l000=<04`0
1D`00`1<0006C00304`000d000=<00003D`0101<C4`20003C00000X000=<000024`00`1<C003C003
04a<008000=<00002`001D`0C4`000e<00<0C4`03P001LH0a/H000g600@0aP363@0001000Td00`1=
C@07C@0304d001@00Td00`1=C@07C@0304d001800Td20008C@1=04d0C@03C@800TdC0003C@1=00Q=
00<0C@005@000dd0C@02C@0304d000==00<0C@005@000dd0C@08C@0304e=01D000?60<H02<H00`36
aP0A00004002C00304a<009<00<0C4`00T`00`1<C00D009<00<0C4`00T`00`1<C002C00304a<01D0
0T`01P1<C01<00=<00<0C00050000d`0C005C00304a<009<00<0C0004`02C00404a<00=<00@0C4`0
0T`D009<00<0C4`00T`00`1<C002C00304a<01@00/H00`36aP02aP030<K600;600<0a/H04@000140
00A=04d00Td00`1=C@02C@0304d001L014d00`1=C@02CAT000==04d00Td00`1=C@02CAP000A=04d0
0dd01P1=04d0CAP000I=001=04d20003C@0001P014d00`1=C@02CAP000?60<H00lH00`36aP02aP03
0<H00140000F0003C01<020000=<04`0@P02C00304a<01l000=<04`080000d`0C00P0003aP3601L0
003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0000C0003C000009<0P000d`0
003U00004`000dd00002C@8000==00006@000dd000050003C@0001P000==00001@000dd0000H0003
C@0000D000==000060001Dd0CDd0009=00<0C@00>`000dd000070003C@000140000A0005C000C000
0T`00`1<00020003C00001H000I<04a<04`20003C00001P014`00`1<C002C1X014`00`1<C002C1X0
00E<04a<0002C00304`001P000M<04a<04`0009<00<0C0005`001D`0C4`000A<00<0C0004P000140
0Td200E=0P02CAD01dd00`1=0004CAD000==00002Dd20003C@00018000==00002Dd20003C@000180
0Td0201=C@1=04d00Td00`1=C@0F00]=5P000dd0C@03C@0304e=00A=00<0C@00400000l00T`200E<
00@0C4a<0P02C1D00d`01@1<C4`000=<5P02C00404a<00=<00<0C4`00T`E009<00@0C4`00d`00`1<
C002C1H000=<04`024`00`1<000C00=<00<0C4`01d`0101<C4`C009<00@0C4`00d`0101<C002C140
000?00A=00<0C@000lH00`1=0004CA400Td00`1=C@0:C@0304e=01D02ddH00]=60000dd0C@06C@03
04d001H03DdF00U=00@0CDe=4P0001<00T`5aP9<5P07C0G61D`A00Q<0/H00dc6C005C14024`2aP03
C<I<00E<4@02C0800d`2aP030<K600=<0P02C1000T`00`1<C003C0C614`00`1<C00@00Q<1LH6C0l0
000A00==0/H3C@;60ddG0006C@36aTd00Td00lH0C@0F00A=0lH0101=a/H3CAD014d3aP040<K6aP==
5@03C@060<K6C@1=0/H0101=CDdC00E=0lH0101=CLH6CA800dd4aP0304g600;60ddA00003P03C0D0
0d`500=<3`06C0;60T`01@1<C4c600E<3`06C0;60T`00`1<C002aPE<4005C0C600<0a/H00/H5C1D0
00G604a<0002C0030<H001P000I<a/K6C002C0;600=<00005002C0C600A<04a<0lH2C140000F009=
70000dg6aP03C@0404e=C@;600==00004@04C@;60dd01@1=CDg6009=00<0CDd04004C@G600<0a/H0
0/H2C@0304e=01H00dd0101=CDdE00E=0/H3C@0404e=C@;61Dd>00A=0P001LI=CDd000==00C60000
0dd>00005`000a40000H009<1002C0034Da<00@00T`C0003C00000800T`00a5<C003009<50000d`0
000200;600<Aa/H00`02C1T00T`00a5<C00G0003C01<00@00T`00a5<C0040003C01<01<000A<aP00
0T`00a5<C0020003aTa<0140000F0003CA5=01P000==00001002C@034De=00H000==00003`000dd0
0003009=00<ACDd01@000dd0000@0003C@0000<00/H00a76aP050003C@0001H00Td00a5=C@0H0003
C@0000<00Td00a5=C@050003C@0001000Td4009=00<ACDd01002CA00000F00<A7`001D`A4A5<01<0
00E<0000C0060005C14A4D`01P001D`0001<00P000E<0000C0060005aQ4A4LH01P001D`0001<01<0
00E<4A4AC00D0004C000C0H000E<4A4AC0060005C00004`020001D`0001<00H000E<4A4AC0060005
C00004`02`0001H000<A014050000dd000080005CA5=4Dd02P000dd000070003C@0000L000E=4DdA
C@090003C@0000P000==00001`001LHAaQ7600T000==00004P001DdACA5=01@000==00001`001DdA
CA5=00T000==00001`000dd000080005CA5=4Dd02P000dd0000900005@024@03014A01@000=<0000
1P0014`A4@024@03C00000H000=<00002@000d`000050004C14A008A00=<00001@000d`0000:0003
C00000D000C64A400Q400lH000050003C000018000A<4A400Q400d`0000?009<00<0C0001P0014`A
4@024@03C00000D000A<04a<20000d`000060004C14A008A00=<00001P000d`0000:00005@02C@03
04e=01D000==00000`02C@0404e=009=00<0CDd01@000dd0000700E=1002C@0404e=009=00<0CDd0
10000dd0C@02C@H01Dd400;600@0a/H00/H00`36aP040003C@1=009=3`02C@0404e=009=00<0CDd0
4@03C@@00Td0101=C@02C@0304e=00@00dd800A=1@02C@0404e=009=00<0CDd01@04C@X0000D0007
C01<04`0C00A00A<0/H00`1<C00200M<0P02C0030<K600A<2003C004aP1<C0801d`2009<00@0aTa<
2`03C004aP36aP801lH200;600<0aT`00T`?009<0P07C0800T`B0004C01<C0801d`2009<00<0aP00
3002C0?600@0C0001d`2009<00<0a/H00T`<000050001dd0C@1=04d04`02C@8000A=00002Dd30004
C@1=C@d00dd400M=1002C@l00Td00lH0000200O610000lI=C@0@0003C@0000801dd40003C@000100
00==00000P08C@<000==00003P04C@802Dd300==3P0001<000I<001<04`20003C00001800d`2009<
00@0C4`00T`00`1<C0020003aT`0010000I<0000C002C00504a<04`00`000lH0000@0006C0000<H0
0/H01@36aP3600<000?600002P05C003aP00008000E<04a<0002C00304`000<000?6C4`00d`800E<
0/H00`1<0002C00404a<009<00<0a/H014`=009<0/H00`1<0002C00504a<04`00P02aP9<3P000180
00A=001=0`0014d004dD009=00G6C@1=0002C@0704e=04d0C@02aP9=3005C@;60Td0101=C@02C@03
04e=00;61Dd:00E=1<H01036aP02aP030<K600;61Dd;0003C@00008000C6CDd00Td0101=C@02C@03
aP00008000==00002`07C@0404e=009=00<0C@001Dd<00I=00C6C@000Td00`1=C@020004CLI=aPA=
300000X014`40004C000C0<000A<001<1004C0T024`2009<00<0C4`00P000dc6aP05C0d01D`2aP9<
00?6C4`00/H00dc6aP02C1001D`<aP9<3@0024`0001<aP1<0P02C00304a<008000A<0<I<0`000d`0
000;00=<00C6C<K60T`00lI<C002aP03C<K600=<40000dc6C003aP9<00?6C4`00lH014c6C4`?0000
3P0014g6aTd30005C@0004d00`0014g6CDd?009=0P000lI=aP03C@04aTe=C@;600A=04e=3`02C@03
04e=00;60Td00lH0aP02C@;60Td00`1=C@0>009=00<0CDd00/H2C@05aP36aTd00/H2C@0304e=00/0
00==00000Td00`1=aP0300;600<0aTd00`000lI=0002C@8000==00001`0;C@06aP36aTg61Dd00`1=
C@0<00E=0/H2C@06aP36aTg61Td>00003002C0@000C60<I<0P001LI<aP3600<00T`>0003C01<00I<
00K6C<K6C<H4C00304`000`00T`00`1<C003C0;600A<aTc61d`00`1<000;0003C01<00E<0/H014c6
C<H7C00304`000/000Q<001<04`0C0?600T0a/K6C01<04`00P000d`0000<0003C01<00E<00?6C4`0
1T`00`1<000=0003C01<00I<0lH00d`0aP06C00304`000`0000;0003C@0000<00Td01LH004g600<0
14d3009=2`000dd0C@0>C@0304e=008000==00002P0014d0C@0=C@0504e=04d03P02C@0304e=00]=
00D0CDd0C@0@00A=00T0CLI=04g6C@0014d@0003C@0000E=00D0CDe=0003C@0504d004d03P000dd0
000?C@8000==0000300000X000A<00000d`00`1<0007C00404`0009<0`000d`0000=0003C01<00A<
00<0C4`00d`E009<00<0C4`01d`00`1<000D009<00<0C4`01d`00`1<000C00=<0P07C0800d`B0003
C00000]<0P000d`0000A00E<00@0C01<0P04C140000A00==00D0CDe=0002C@0304e=01D00Td00`1=
C@04C@0504e=04d05@02C@0304e=009=00<0CDd00Td00`1=C@0D009=00<0CDd00Td00`1=C@02C@03
04e=018000==04d00P04C@0304e=009=0P000dd0C@0D00A=00<0C@0014dF0003C@1=00U=00<0CDd0
4@00010000A<04a<0P000d`0C0020004C000C1D000=<04`00P03C08000=<04`05P000d`0C003C003
04a<009<00<0C0005@000d`0C003C00304a<009<00<0C00050000d`00002C00504`0C0000T`20003
C00001@000M<04a<04`0009<00<0C0005`001D`0C4`000A<00<0C4`04P0000l000E=0000C@020003
C@1=008000E=0000C@0H009=00<0C@007`000dd0C@0P0003C@1=01d000E=04e=0002C@0304d00400
0TdG00004`000d`0C0030003C01<08H000=<04`0G@000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`0001L000<A0000j00001L000<A0000Q@000d`000050003C00001P000=<00001@000d`0
000e00005P034Ah000==00000`000dd0000M0003C@0001/000==00000Td00`1=C@020003C@0001L0
14d00`1=C@02CAX014d00`1=C@02CCL0000F00<A70000d`0C003C00504a<04`06P02C00304`0009<
6P0;C1H000=<00002D`20003C000018000=<00002D`20003C0000380000E008A00<04A406`0;CAP0
00==04d01Td00`1=000E009=00<0CDd01dd00`1=C@0D009=00@0CDd00dd0101=C@02CAD014d01@1=
CDd0009=00<0CDd06`000a40000F00005@024@03014A01T03d`F0003C01<00M<6@0;C1P02d`H00]<
7@000a40000F000050001a404@0A01406@07C@03aTe=009=5P0?CA<02Td00lI=C@04CA4024d4aPM=
4@07C@C61ddH00<A5`0001@000LA01404@0A01T01D`4aPA<40000d`0000200M<00?6C<H014`50003
C00000h00d`01<I<C<H2C004aTa<C1D014`3aP0404c6aPA<5@03C0?600@0C<K614`J00034@0A01L0
000C00064@004@0A0P000a40000C00E=0lH4C@03aTe=00A=3@000dd00002C@8000A=04g60dd01LI=
04d0009=0`000dd0000>009=0lH014d0CDd2aP==5@02C@;60Td00`1=C@02aP==5@02C@;60Td00`1=
C@02aP==6P000a404@0G00004`000a404@0200044@004AT000=<a/H01D`2aP9<3P02C00304`00080
1D`01LI<C4c600A<100014`0C4`;00E<0/H2C0034Da<00;61D`@00A<0/H3C00404a<C0;614`@00E<
00G6C4a<0003C0;614`G008A00<04A405P00018000@A000A0P001A40000A01@01Dd01LI=CDd000==
00?6CDd00dd=009=0`03C@;600<0CDd00Td2aP9=1002CA0000A=00000Td00a5=C@030003C@0001<0
00==00000P02C@034De=00@000==00004P02C@<00Td00mi=C@040003C@0001L00Td00`1=C@0F0000
4P001140014300044@004A0000E<0000C0020004C000009<00<AC0000`0014`004`30003C00000P0
00=<04`00T`3009<0a42C0<00T`20003C00000h000=<00000P001D`A4A5<00@000=<00004@000d`0
0003009<00<AC4`01@000d`0000@0003C00000<00T`00mm<C0050003C00001D000M<04`0C01<01D0
000A00054@0001400`001A40000A00l000==00000`000dd000030003CA5=00D000==00000`000dd0
00090003aP00008000]=aP0ACA5=4@36C@040003aP0000h000==00000`001DdACA5=00D000==0000
3`000dd000040005CA4A4Dd01P000dd0000>0003C@0000@000E=g]kNC@060003C@0001@000M=04d0
C@1=01D0000@00034@00008000DA00004@0400034@0000/00d`30003C00000<000E<4A4AC0050004
C00000=<2`06C0074Da<4D`04@06C0`000=<000020001D`AC15<00T00T`8009<2@001D`AC15<00T0
0T`8009<2@001DcOC=m<00T00T`A0006C000C01<0P000d`0000B000040000a40000200054@000140
10000a40000=009=1P02C@DA0Td6009=2002C@0404g6C@<000]=04d04DdA04d0C@020003C@3600==
2@000dd000060004CA4A008A00==00001@000dd0000:0003C@0000D000A=4A400Q400dd000050003
C@0000X000==00001@0014gNgP02gP03C@0000D000==0000400014d004d30004C@00CA<0000?0003
4@00008000<A00000P000a40000300034@0000`00T`00lH00003C00504a<C1400d`01@1<C4`000;6
0T`:00=<0`003D`0C01<4@0AC01<04`00`03C0P014`5009<00@0C4`00T`00`1<C0040003C01<009<
1P05C0@00T`0101<C002C00304a<00@000=<04`00T`600E<1002C00404a<009<00<0C4`010000d`0
C002C0H014`50004C000C0<000A<001<1@04C0X0000?00034@00008000<A00000P000a4000030003
4@0000h00dd200A=00<0C@000dd30003C@1=00X01Dd00lH0C@02009=00D0C@1=0002C@8000A=0<K6
14d9009=00C604e=0P07C@800Td01036CDd;00==00C604e=0P07C@800Td00`36C@02C@X00dd01<H0
CDd200M=0P02C@030<I=009=3002C@;600E=0000C@030005C@0004d00/H2C@h0000>00034@0000<0
00<A00000P000a40000400034@0000/00T`0201<001<04`01D`00`1<C0030004aP1<C0P000E<001<
0002C0800T`01`1<04`0C0000T`2009<00D0C000C00;009<1007C0@00T`?00=<1007C0@00d`>00=<
1007C0@00d`=009<0`001LH00<I<00<000E<aP00aP03009<3@0000h000<A00000`000a4000030003
4@0000<000<A00002P05C@04aTd0C@8000E=04d0C@02009=0/H5C@T014d2aP9=0P001Dd0C@1=0080
0Td2aPA=3P001Td0001=009=00D0CDd0C@030003aP00010000I=0000C@02C@0504e=04d00`000lH0
000@0006C@0004d00Td01@1=C@1=00<000?600002`02C@@00dd00lH0aP030004aP36aP9=1002C@/0
000=00034@0000@000<A00000`000a40000400034@0000`01D`200M<0P000dc6aP02C0`000Q<0000
C036C08000E<04`0C0020004C<H0C0<000=<00002005C0;60T`0101<C002C00304a<00;61D`:00E<
0/H2C00404a<009<00<0C4`00/H5C0X01D`2aP9<00@0C4`00T`00`1<C002aPE<200014`00003C080
0T`20003aTc600800T`200=<0`000d`0000800003@000a40000400034@0000<000<A000010000a40
000:009=00<0C@000Td00lI=C@05C@C60dd00`1=C@0;00A=0/H02`36C@1=04d0CLH000;614d>00E=
0/H2C@0304e=00;600==a/H00Td@00E=0/H2C@03aTe=00;600==a/H00Td@00E=0/H2C@03aTe=00;6
00==a/H00TdD0003C@1=009=00H0CDe=04dC000030000a40000400034@0000@000<A00001@000a40
00090003C01<00M<0/H00dc6aP02aPI<00<0C0003007C0;600H0aTc6C<H4C0l00d`01@1<C4c6009<
00G6C<I<aP02C00404a<C0h00T`00`1<C002aP9<00?60<H00T`2aP9<00<0C4`03P02C00304a<00;6
0T`00lH0aP02C0;60T`00`1<C00B00E<00<0C0001D`B000030000a40000400034@0000@000<A0000
1@000a40000<0003C@1=00I=00?6CLH01Dd00`1=000>009=00h0CDd0C@36CLI=aP1=009=00<0CDd0
3@02C@0304e=00E=00?6CLH014d01P1=CDd0C@`000==04d01Dd2aP9=0/H7C@0304d000/000==04d0
1Dd2aP9=0/H7C@0304d000l000A=04e=0P000dd0C@02009=00<0C@00400000/000<A00001@000a40
000400034@0000H000<A000030000d`0C00>C10000M<001<04`0009<00<0C0000T`0101<04`20003
C00000/000E<001<000=C00404`0C0h00T`00`1<C00=C00304a<00h000E<04a<000=C00304a<0100
00E<0000C0020003C01<008000E<0000C00@00002`000a40000500034@0000@000<A00001P000a40
000;009=00@0CDd00dd01@1=CDd0009=00<0CDd04@001Dd0CDd000==00D0CDe=0002C@0304d00180
0Td0101=0003C@8000A=04e=5002C@0304e=00M=00<0CDd05@000dd0C@08C@0304e=01L000==04d0
0`000dd0C@0D00002P000a40000600034@0000D000<A00001P000a40000<009<00<0C4`01d`00`1<
000G00A<00<0C4`00T`G009<00<0C4`00T`00`1<C002C00304a<01@00T`00`1<C002C00304a<009<
00<0C4`05002C00304a<009<00<0C4`00T`00`1<C00d00004P000a40000600034@0001P014d00`1=
C@02CA`00Td00`1=C@0K009=00@0CDd00Td00`1=C@0G0009C@1=C@1=04d0009=00<0C@005@000dd0
C@03C@0304e=009=00<0C@00=000018000<A00001P000a400023009<00<0C4`07`000d`0C00j0000
4P000a40000600034@000>@0003o00<0003o00<0003o00<0003o00<00000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.109419,
   0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110616, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.10942, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438, 
  72.5625}} -> {-3.74027, -0.110616, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.109418, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277,
   -0.110616, 0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.1939, -0.109419, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.271517, -1.26686, 0.0330061, 0.0330061}, {{42.5, 74.3125},
   {69.375, 37.5625}} -> {-1.42777, -1.26686, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26687, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.88594, -1.2634, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277,
   -1.26686, 0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.1939, -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.270011, -2.4174, 0.0329417, 0.0329417}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.74027, -2.42311, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277,
   -2.42311, 0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1939, -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .88222 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{179, 157},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002c0000W@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000;<0002c0000/`000;<0002c0000/`000;<0
002c0000/`00040000=<0000;P000d`0000o0000@0000dd0000A0003C@0000H000==00004@000dd0
000o0000@@000d`0000;0003C000008000=<00001P000d`000020003C00000/000=<0000@0000440
00==00002`000dd000020003C@0000H000==00000P000dd0000;0003C@00040000120003C00000/0
00E<0000C0080005C00004`03@000d`000110000@P001Dd0001=00T000A=001=2P0014d004d90005
C@0004d0@`0004<000A<001<2P000d`0C00:0003C01<00X000A<001<A000044000==04d00P000dd0
00080003C@1=00<000A=001=0`000dd0C@0:0006C@00C@1=@P00048000E<04`0C00;009<0`0014`0
04`3009<2`001D`0C01<04<0000c0003C@0000d00Td20003C@0000@000A=00000Td20003C@000080
00==00000Td30003C@0000@000==00000Td?0003C@000380000d0003C00000d00T`00`1<00060003
C000009<0P000d`000020003C000009<0P000d`000050004C01<C0l000=<0000<`0003D000==0000
3@000dd0C@080006C@1=C@1=1P001Td0CDd0C@P000==04d03`000dd0000d0000=003C0l00T`9009<
00<0C4`01P02C00304a<00T00T`?00=<=@0003H00Td?0003C@0000P000==04d020000dd0C@0:0003
C@0000d00Tdg0000>002C0P00T`3009<2@04C0H014`9009<0`02C0P00T`i0000>@03C@P00Td0101=
CDd800A=1P04C@P00dd00`1=C@0800==>P0003X000A<04a<2003C00304`000D000E<04`0C0060005
C01<04`01P000d`0C002C0P00T`00`1<000j0000>`000dd00002C@P00Td00`1=0004009=0`000dd0
00020004C@00009=1@0014d0CDd8009=0P000dd0000j0000?00014`00002C0H01D`4009<0`02C080
0T`3009<1005C0H00T`30003C00003/0000m0003C@00008000==00000`0014d0C@02C@<000==0000
0`04C@D000A=00000Td0101=04d50003C@00008000==0000?00003h000=<00000P02C0<000=<04`0
0`04C0D014`500A<0`000d`0C003009<10000d`0000m0000?`000dd00003009=00D0C@00C@0300==
1@04C@D00dd30005C@00C@000Td50003C@0003h000100003C00000@00T`20004C00000A<0`001T`0
C4`0C0<014`30003C000009<1P000d`0000o0000:@02C@h01Dd30003C@0000D00Td0101=0003C@04
04e=C@800Td200==00@0CDe=0P0014d0CDd70003C@00008014d>009=:P0002/00T`A00M<10000d`0
C002aP06C<I<04`00d`0101<C003C00404`0C0C600=<04`01@07C1000T`/0000:`05CA<000==04d0
1Td2aP03CLI=008000A=000014d30003C@0000G600<0CDd01TdD00A=;00002l024`=0003C0000080
00=<00001d`00`36aP02aP9<1<H00`1<aP05aP03C01<00@000=<00003007C300000a009=1007C@L0
00E=0000C@030007CLI=aTg6C@0@aP05C@0004d00`000dd0000600M=0`02CC80000c009<2@07C005
0<K6aT`00P000d`0aP0EaP0404`000C60P07C0P00T`d0000=@02C@h000E=a/K6C@02aP03C@3601G6
00<0CLH01LH2C@d00Tdf0000=`000d`0000<00C60T`PaPh000=<0000=P0003P00Td>00c600A=a/K6
0P02aP9=3<H>009=>@0003X00T`=00[60T`00lH00004009<2lH=009<>`0003`00Td;00W600<0CDd0
1`02C@8000?6CDd01/H;009=?@0003h00T`900K600A<aP000T`7009<0`02C0K62@02C3l000100003
CLK600c600==00000dd700==0P02C@K600<0a/H01LH00dd0000o0000?`02C0g60T`2009<2@02C080
0T`00`36aP0;aP=<?`0003P01dd200g60dd00`1=C@09009=00H0CDe=0<H2C@[60`07CCP0000a00M<
3`06aP800T`00`1<C009009<00<0C4`00`02C0G63`07C340000T00E=00<0CDd01DdG00?60Td2009=
00<0CDd02@02C@0304e=00800dd3aQP01dd00`1=C@02CBD0000V00Y<6003aP9<0P02C00304a<00T0
0T`00`1<C002009<00@0a/K66@09C2L0000`00M=3@07aP==00<0CDd00dd900E=00D0CDe=0008aPd0
1dd`0000=`07C0030<K600O60T`01LH0C4`000A<2`04C00304a<00800T`:aP801d`g0000?P000dg6
aP07aP==00<0CDd01Dd;00M=00@0CDe=2/H2CCh0000m009<1lH300=<00@0C4`00d`;00=<00@0C4`0
0d`500K60T`n0000>`02C@d02Dd;00U=3P02CC`0000i009<4008C0/024`A009<>P0003L00TdC00M=
1@024@@01ddD009=>00003D00T`F00E<1P024@D01D`G009<=P0003<00TdI00E=10044@<01DdJ009=
=000038000=<00006P04C0@0114300A<7@000d`0000a0000<002CAh00dd300HA0P03CAl00Tda0000
;P02C20014`200HA00<0C4`00T`Q009<;`0002`00TdR00E=2144CB<00Td]0000:P02C2<01T`84@E<
9002C2/0000X009=9@05C@XA14dV009=:@0002L000=<00009@05C08A00=<4A400Q400d`A4@04C2P0
00=<00009P0004l00Td00`1=4@074@05CA4A4@000TeA0000C`02C005014A4D`00Q400d`A4@02C08A
00<0C4`0D@0004l00Td01@0A4@1=008A00E=4A4A00024@0304e=0540001>00=<0a401P1<4A40C08A
00@04A4A0da@00004@000dd0000j009=00<04A400dd24@0404dA4@9=0Q400`1=C@0m0003C@000100
000A0003C00003X00T`34@9<0a42C08A0T`34@9<?@000d`0000@00004P000dd0000i009=0Q43C@8A
0dd24@==0Q42CC`000==00004@0001<000=<0000>00014`A4A43C08A0d`24@=<0a400d`0000i0003
C0000180000D0003C@0003L000==4A4014d24@==0Q44C@8A00==0000>0000dd0000C00005@000d`0
000e0006C14A4D`00T`24@=<0Q42C00304`A008A00=<0000=P000d`0000D00005P000dd0000d0004
CA4AC@800Td24@03C@1=00<A00A=001=0Q400dd0000e0003C@0001D0000G0003C000038000A<4A4A
0`001T`A4A5<009<0Q4014`000034@03C00003<000=<00005P0001P000==0000;`03C@8A1@024@05
C@0004d00Q45008A0ddb0003C@0001L0000I0003C00002`01d`5008A00E<0000C0024@D01d`_0003
C00001P0000J0003C@0002T01Dd0101=CDd5008A1@024@03C@0000800dd00`1=C@03CB`000==0000
6@0001/000=<00009P05C0801D`300A<0`05C0801D`200E<:@000d`0000J000070000dd0000S00E=
1002C@0304e=00801Dd300I=00@0CDd00Td400E=9P000dd0000K00007@000d`0000P00E<1@03C004
04a<00M<00<0C4`024`0101<C4`500E<8`000d`0000L00007P000dd0000M00E=1`02C@801dd0101=
C@02C@0404e=00A=0P02C@L01DdP0003C@0001d0000900A<4P000d`0000J00E<2003C08014`0101<
C005C00304a<00800d`200=<2005C1d000=<00004004C0X0000=00E=3P000dd0000H00A=2P02C@<0
0dd2009=0P03C@800Td300==0P02C@X014dK0003C@0000`01Dd>00004P06C0T000=<00005@04C0/0
0d`200A<0P02C0800d`2009<0P05C00404a<C0/014`H0003C00000L01T`C00006005C@D000==0000
4P05C@`00Td200E=0P02C@800dd2009=0P02C@0504e=C@000Td<00E=5@000dd0000300E=6@0001d0
1D`00`36aP02aPh01D`=00=<00D0C4a<0002C00504a<C0001D`01@1<C4`0009<0P06C0d01D`?00C6
00<0C4`00d`N00008P000dg6aP04aPX01Dd?009=00@0CDe=0P02C@0304e=00800Td00`1=C@02009=
00<0CDd00`05C@l01Dd;00K600==00008@0001P00T`900W61@05C1001T`3009<00@0C4`00d`01@1<
C4`0009<00<0C4`01005C1001D`600W62@02C1T0000J009=2@09aP0304e=00==4P05C@@00Td0101=
C@02C@<00Td0101=C@02C@D014dB00E=0P09aPT00TdK00007002C0T01/H5C1<01D`500Q<0`08C0H0
14`C00E<1lH9009<7@0001h00Td:00;614dD00E=1`06C@D01Td800A=5004C@?62P02CAl0000P009<
2P02C003aP0001<014`800I<1@06C0T00d`F009<00?600002002C240000R009=1`04aQ@014d900E=
1`05C@X00ddE00C61`02CB<0000T009<1@04aQ@00d`:00A<2@04C0/00d`D00C61@02C2D0000V0003
C@0000800lHD00==2`04C@T014d;00A=5003aP@000==00009@0002L00T`200?64`03C0`00d`;00=<
3004C1<00lH2009<:00002T00Td3aQ8014d<00==2`03C@`01DdB00?60TdZ0000:P001<I<C<HA00A<
3@03C0/00d`=00E<4@04aR/0000Z00?60Td?00E=3004C@/014d<00I=3`000dg6aP02aR/0000Z00?6
0P000dc6aP04aPL01D`=00A<2`04C0d00T`0101<C4`800G600=<00000lH[0000:P03aP0304e=00_6
00<0CDd014d<00E=2`05C@`00dd0101=CDd200[60Td01036a/H[00009`07C0802lH3C00304a<00d0
1D`;00E<3@02C0800d`;aP801d`X00008007C@<00Td800K60dd0101=CDd<00M=2@07C@`00dd200==
1lH7009=0`07CB40000H00Q<2@0014`004`<0005aTa<aP000T`=009<00<0C4`00T`900A<00<0C4`0
3@02C0<00T`2aP/000A<001<2@08C1T0000F00==0`05C@P000A=001=3@03aP==3008C@T024d<00==
00<0a/H00/H<0004C@00C@P01Dd300==5`0002401T`00`1<00020003C00000/00lH2C0d00T`0101<
C002C0T00T`0101<C002C0d00T`5aP`000I<0000C006C280000V00M=2009aP03C@0000X00dd0101=
C@02C@T00Td0101=C@03C@`00dd8aPP01ddW00009`0014`00007C0030<K600_62003aP9<0P02C003
04a<00T00T`00`1<C002009<1<H80003aTa<00[600<0C4`01T`20003C00002H0000W0003C@0000<0
00==00000P07C@O60`07aP==0P02C@0404e=C@L00dd00`1=C@0200==2<H300g60Td30003C@0000<0
00==00009P0002H000=<0000100014`00002C0C60P07C0[60T`2aP0504a<0<H00T`2aP@000?6C4`0
0/H2C08000?6C4`04LH2C0030<K600;60T`30003C00000@000=<00009@0002H000==0000100014d0
CDd:00G600==a/H02lH3C@;60Td7aP9=0lH2C@030<K601;62@02C@0304d000D000==00009@0002D0
00=<00001@02C0`01<H2C0C61P04aP04C<K6aP9<1lH2C0C600=<a/H00/H600[63002C0L000=<0000
900002D000==00000`03C@d00/H2C@?62@04aP03CLK600;600<0a/H01/H00`36aP07aPT01lH=00==
1@000dd0000T00009@0014`00002C08000=<00002`03C0030<K600;61P06aP05C<K6aP002/H00`36
aP08aPH01<H0101<C4`=0003C000009<0`000d`0000T000090000dd0C@02C@D000==00002002C@04
04e=00C6100;aP9=5lH400C600@0CDd00Td:0003C@0000<00dd00`1=000T00009002C0P000=<0000
1P02C08000E<001<0003aP<01LH7C0G6100AaP<00lH01@1<001<00800T`80003C00000H00T`U0000
8P02C@X000==00001002C@@000A=001=0P000dd0C@07C@030<K600G600==a/H01P0:aP030<K600?6
0dd01@1=001=008000==00000P02C@H000==00002002CB<0000P009<00<0C0002@000d`000030003
C00000@000=<04`01d`01@36a/H0009<1LH00`1<aP03aP@01LH00`36aP03aP9<00D0a/K6000:C0H0
00=<00000`000d`000080004C01<C240000N009=0P000dd000090004C@00009=1@07C@8000A=001=
0P02C@8000==0<H00/H00dd0aP04aP801LH00`1=aP02aP0404d0009=0P0014d004d200M=1@02C@<0
00==00002@000dd00002CAl0000L009<10000d`000090005C01<C0001T`20003C000008000I<04`0
C002C0@000=<00000d`200C60P04aP800d`20003C00000800T`01P1<04`0C0@000=<00001T`01@1<
C01<00/000=<00000P02C1d0000K0003C@0000<000==00002P05C@P000==00000P000dd0C@03C@03
04d0008000E=0000C@020003C@0000?60Td3aP8000A=001=0`001Td0001=00A=00<0C@000`000dd0
000600E=30000dd000030003C@0001X0000Q0003C00000L00d`00`1<000:0003C00000<00d`40004
C000C08000=<04`00P000d`00002C0800T`20006C000C01<0P0014`004`400=<1@000d`000090003
C01<009<2@000d`0000P000080000dd00007009=0`000dd000080003C@0000<00dd6009=0P0014d0
04d3009=00H0C@00C@02C@<000A=001=0P02C@H00dd50003C@0000P000A=00000Td90003C@0001l0
000P0003C00000H000=<00000`000d`000080003C00000800T`00`1<C0060003C01<00<000I<04a<
04`2009<0P001T`0C4`0C0<000=<04`01P02C00304a<00@000=<000020000d`000030003C00000H0
00=<00007`0001l000==00003@000dd000080003C@0000==0`000dd000030003C@1=00@00Td40006
C@1=C@1=1002C@@000==04d01@0014d00003C@8000==000020000dd0000=0003C@0001h0000`0003
C00000L00d`00`1<00030003C00000<00T`00`1<C003C0H014`600E<00<0C4`01@000d`000020003
C01<009<2@000d`0000_0000<0000dd00006009=0P000dd00003009=0`02C@0404e=C@<000==0000
1002C@H000A=00000dd00`1=C@03009=1@000dd00002C@P000==0000;`00030000=<00001002C004
04`0C0H00T`300=<0`0014`004`500A<1@0014`004`300=<0`02C0H000A<04`00T`60003C00002l0
000e009=0`02C@L000A=04d00Td60003C@1=00D000A=001=1@000dd0C@06009=00@0C@1=1`02C@<0
0Tdf0000=0000d`00002009<2@03C0T00T`40003C000008000=<00000P02C0T00d`9009<10000d`0
000c0000>@000dd0000700A=2P0014d00002C@@00Td30003C@0000P014d90003C@0003P0000h009<
20000d`0C002C0/000A<04a<1P02C00304`000X00d`00`1<0007009<>@0003L000==04d02@03C@03
04d000T00Td00`1=00050004C@1=C@X000==04d00Td90003C@1=03P0000f0004C000C0P000=<04`0
0P000d`000080004C01<C0H00T`00`1<00090006C000C01<200014`004`g0000=@001Dd0001=00L0
00A=001=0`000dd00006009=00<0CDd01P02C@0304e=00P000E=0000C@020003C@0000D000E=0000
C@0f0000=0000d`000020003C00000L000=<04`00P000d`000050005C01<04`020001D`0C01<00L0
00I<001<04`90003C000008000=<0000<`0003<000==00000P000dd000080003C@1=00<000==0000
0`000dd00002C@X00Td20003C@0000<000M=0000C@1=00X000==00000P000dd0000b0000>0000d`0
00070004C000C0P000=<00000P000d`000080003C000008000=<00001P0014`004`90003C00003L0
000h0003C@0000L000A=001=3002C@X00Td<0004C@00C@T000==0000=`00044000E<0000C00<009<
2P02C0`000E<0000C0120000@@000dd000020003C@0000P000==04d02P000dd0C@0:0003C@000080
00==0000@000040000=<00000`000d`000080003C01<00X000=<04`02P000d`000030003C00003l0
00160003C@0000L000E=0000C@080005C@0004d02@000dd000150000D0001D`0001<00P000E<0000
C01A0000C`000dd000020003C@0000H000==00000P000dd0001>0000/`000;<0002c0000/`000;<0
002c0000/`000;<00000\
\>"],
  ImageRangeCache->{{{0, 178}, {156, 0}} -> {-0.028489, 0.0368288, 0.00593808,
   0.00593808}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.02 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.02 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.02 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.02 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.02 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.02 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.02 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.02 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.02 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.02 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.02 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.02 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.02 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.02 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.02 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.02 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.02 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.02 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.02 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.02 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.02 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.02 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.02 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.02 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.02 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.02 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.02 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.02 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.02 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.02 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.02 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.02 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.02 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.02 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.02 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.02 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.02 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.02 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.02 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.02 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.67628 .68931 L
s
P
p
.2 0 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
.2 0 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.29503 .11519 L
s
P
p
.2 0 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
.2 0 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.4802 .77902 L
s
P
p
.2 0 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
.2 0 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.50922 .09046 L
s
P
p
.2 0 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
.2 0 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.26885 .73635 L
s
P
p
.2 0 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
.2 0 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.7833 .61652 L
s
P
p
.2 0 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
.2 0 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.2433 .18832 L
s
P
p
.2 0 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
.2 0 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.62455 .76243 L
s
P
p
.2 0 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
.2 0 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.43937 .0986 L
s
P
p
.2 0 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
.2 0 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.41035 .78716 L
s
P
p
.2 0 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
.2 0 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.86259 .51422 L
s
P
p
.2 0 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
.2 0 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.2167 .27384 L
s
P
p
.2 0 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
.2 0 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.7567 .70205 L
s
P
p
.2 0 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
.2 0 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.37545 .12793 L
s
P
p
.2 0 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
.2 0 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.56063 .79176 L
s
P
p
.2 0 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
.2 0 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.90639 .39243 L
s
P
p
.2 0 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
.2 0 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.21783 .3634 L
s
P
p
.2 0 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
.2 0 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.86372 .60378 L
s
P
p
.2 0 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
.2 0 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.32372 .17558 L
s
P
p
.2 0 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
.2 0 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.70497 .74969 L
s
P
p
.2 0 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
.2 0 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0213592 0.952381 [
[ 0 0 0 0 ]
[ 1 .90966 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .90966 L
0 .90966 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.4359 .69393 m
.27974 .71867 L
s
P
p
.2 0 1 r
.002 w
.4359 .69393 m
.3241 .80573 L
s
P
p
.2 0 1 r
.002 w
.4359 .69393 m
.41117 .85009 L
s
P
p
.2 0 1 r
.002 w
.52012 .6806 m
.5919 .82147 L
s
P
p
.2 0 1 r
.002 w
.52012 .6806 m
.66099 .75237 L
s
P
p
.2 0 1 r
.002 w
.52012 .6806 m
.67628 .65586 L
s
P
p
0 .4 1 r
.018 w
.47316 .65667 m
.4359 .69393 L
s
P
p
0 .4 1 r
.018 w
.47316 .65667 m
.52012 .6806 L
s
P
p
.2 0 1 r
.002 w
.52012 .21633 m
.67628 .24106 L
s
P
p
.2 0 1 r
.002 w
.52012 .21633 m
.66099 .14455 L
s
P
p
.2 0 1 r
.002 w
.52012 .21633 m
.5919 .07546 L
s
P
p
.2 0 1 r
.002 w
.4359 .20299 m
.41117 .04683 L
s
P
p
.2 0 1 r
.002 w
.4359 .20299 m
.3241 .09119 L
s
P
p
.2 0 1 r
.002 w
.4359 .20299 m
.27974 .17826 L
s
P
p
0 .4 1 r
.018 w
.47316 .24025 m
.52012 .21633 L
s
P
p
0 .4 1 r
.018 w
.47316 .24025 m
.4359 .20299 L
s
P
p
.2 0 1 r
.002 w
.29243 .64453 m
.15156 .57276 L
s
P
p
.2 0 1 r
.002 w
.29243 .64453 m
.13628 .66927 L
s
P
p
.2 0 1 r
.002 w
.29243 .64453 m
.18064 .75633 L
s
P
p
.2 0 1 r
.002 w
.36841 .68325 m
.34368 .8394 L
s
P
p
.2 0 1 r
.002 w
.36841 .68325 m
.44019 .82412 L
s
P
p
.2 0 1 r
.002 w
.36841 .68325 m
.50928 .75502 L
s
P
p
0 .4 1 r
.018 w
.34448 .63629 m
.29243 .64453 L
s
P
p
0 .4 1 r
.018 w
.34448 .63629 m
.36841 .68325 L
s
P
p
.2 0 1 r
.002 w
.6413 .30765 m
.75309 .41944 L
s
P
p
.2 0 1 r
.002 w
.6413 .30765 m
.79745 .33238 L
s
P
p
.2 0 1 r
.002 w
.6413 .30765 m
.78217 .23587 L
s
P
p
.2 0 1 r
.002 w
.581 .24735 m
.65278 .10648 L
s
P
p
.2 0 1 r
.002 w
.581 .24735 m
.55627 .09119 L
s
P
p
.2 0 1 r
.002 w
.581 .24735 m
.46921 .13556 L
s
P
p
0 .4 1 r
.018 w
.58925 .2994 m
.6413 .30765 L
s
P
p
0 .4 1 r
.018 w
.58925 .2994 m
.581 .24735 L
s
P
p
.2 0 1 r
.002 w
.2054 .52024 m
.13363 .37937 L
s
P
p
.2 0 1 r
.002 w
.2054 .52024 m
.06453 .44846 L
s
P
p
.2 0 1 r
.002 w
.2054 .52024 m
.04925 .54497 L
s
P
p
.2 0 1 r
.002 w
.24412 .59622 m
.13232 .70801 L
s
P
p
.2 0 1 r
.002 w
.24412 .59622 m
.21938 .75237 L
s
P
p
.2 0 1 r
.002 w
.24412 .59622 m
.31589 .73709 L
s
P
p
0 .4 1 r
.018 w
.25236 .54416 m
.2054 .52024 L
s
P
p
0 .4 1 r
.018 w
.25236 .54416 m
.24412 .59622 L
s
P
p
.2 0 1 r
.016 w
.44019 .44846 m
.47316 .65667 L
s
P
p
.2 0 1 r
.016 w
.44019 .44846 m
.47316 .24025 L
s
P
p
.2 0 1 r
.016 w
.44019 .44846 m
.34448 .63629 L
s
P
p
.2 0 1 r
.016 w
.44019 .44846 m
.58925 .2994 L
s
P
p
.2 0 1 r
.016 w
.44019 .44846 m
.25236 .54416 L
s
P
p
.2 0 1 r
.002 w
.55117 .69598 m
.4103 .76776 L
s
P
p
.2 0 1 r
.002 w
.55117 .69598 m
.47939 .83685 L
s
P
p
.2 0 1 r
.002 w
.55117 .69598 m
.5759 .85214 L
s
P
p
.2 0 1 r
.002 w
.62714 .65727 m
.73894 .76907 L
s
P
p
.2 0 1 r
.002 w
.62714 .65727 m
.7833 .682 L
s
P
p
.2 0 1 r
.002 w
.62714 .65727 m
.76801 .58549 L
s
P
p
0 .4 1 r
.018 w
.57509 .64903 m
.55117 .69598 L
s
P
p
0 .4 1 r
.018 w
.57509 .64903 m
.62714 .65727 L
s
P
p
.2 0 1 r
.002 w
.48368 .21573 m
.63983 .191 L
s
P
p
.2 0 1 r
.002 w
.48368 .21573 m
.59547 .10393 L
s
P
p
.2 0 1 r
.002 w
.48368 .21573 m
.50841 .05957 L
s
P
p
.2 0 1 r
.002 w
.39946 .22907 m
.32768 .0882 L
s
P
p
.2 0 1 r
.002 w
.39946 .22907 m
.25859 .15729 L
s
P
p
.2 0 1 r
.002 w
.39946 .22907 m
.2433 .2538 L
s
P
p
0 .4 1 r
.018 w
.44641 .25299 m
.48368 .21573 L
s
P
p
0 .4 1 r
.018 w
.44641 .25299 m
.39946 .22907 L
s
P
p
.2 0 1 r
.002 w
.39946 .69333 m
.2433 .6686 L
s
P
p
.2 0 1 r
.002 w
.39946 .69333 m
.25859 .76511 L
s
P
p
.2 0 1 r
.002 w
.39946 .69333 m
.32768 .8342 L
s
P
p
.2 0 1 r
.002 w
.48368 .70667 m
.50841 .86283 L
s
P
p
.2 0 1 r
.002 w
.48368 .70667 m
.59547 .81847 L
s
P
p
.2 0 1 r
.002 w
.48368 .70667 m
.63983 .73141 L
s
P
p
0 .4 1 r
.018 w
.44641 .66941 m
.39946 .69333 L
s
P
p
0 .4 1 r
.018 w
.44641 .66941 m
.48368 .70667 L
s
P
p
.2 0 1 r
.002 w
.62714 .26513 m
.76801 .33691 L
s
P
p
.2 0 1 r
.002 w
.62714 .26513 m
.7833 .2404 L
s
P
p
.2 0 1 r
.002 w
.62714 .26513 m
.73894 .15333 L
s
P
p
.2 0 1 r
.002 w
.55117 .22642 m
.5759 .07026 L
s
P
p
.2 0 1 r
.002 w
.55117 .22642 m
.47939 .08555 L
s
P
p
.2 0 1 r
.002 w
.55117 .22642 m
.4103 .15464 L
s
P
p
0 .4 1 r
.018 w
.57509 .27337 m
.62714 .26513 L
s
P
p
0 .4 1 r
.018 w
.57509 .27337 m
.55117 .22642 L
s
P
p
.2 0 1 r
.002 w
.27828 .60202 m
.16648 .49022 L
s
P
p
.2 0 1 r
.002 w
.27828 .60202 m
.12212 .57728 L
s
P
p
.2 0 1 r
.002 w
.27828 .60202 m
.13741 .67379 L
s
P
p
.2 0 1 r
.002 w
.33857 .66231 m
.2668 .80318 L
s
P
p
.2 0 1 r
.002 w
.33857 .66231 m
.36331 .81847 L
s
P
p
.2 0 1 r
.002 w
.33857 .66231 m
.45037 .77411 L
s
P
p
0 .4 1 r
.018 w
.33033 .61026 m
.27828 .60202 L
s
P
p
0 .4 1 r
.018 w
.33033 .61026 m
.33857 .66231 L
s
P
p
.2 0 1 r
.016 w
.47939 .4612 m
.57509 .64903 L
s
P
p
.2 0 1 r
.016 w
.47939 .4612 m
.44641 .25299 L
s
P
p
.2 0 1 r
.016 w
.47939 .4612 m
.44641 .66941 L
s
P
p
.2 0 1 r
.016 w
.47939 .4612 m
.57509 .27337 L
s
P
p
.2 0 1 r
.016 w
.47939 .4612 m
.33033 .61026 L
s
P
p
.2 0 1 r
.002 w
.66143 .66231 m
.54963 .77411 L
s
P
p
.2 0 1 r
.002 w
.66143 .66231 m
.63669 .81847 L
s
P
p
.2 0 1 r
.002 w
.66143 .66231 m
.7332 .80318 L
s
P
p
.2 0 1 r
.002 w
.72172 .60202 m
.86259 .67379 L
s
P
p
.2 0 1 r
.002 w
.72172 .60202 m
.87788 .57728 L
s
P
p
.2 0 1 r
.002 w
.72172 .60202 m
.83352 .49022 L
s
P
p
0 .4 1 r
.018 w
.66967 .61026 m
.66143 .66231 L
s
P
p
0 .4 1 r
.018 w
.66967 .61026 m
.72172 .60202 L
s
P
p
.2 0 1 r
.002 w
.44883 .22642 m
.5897 .15464 L
s
P
p
.2 0 1 r
.002 w
.44883 .22642 m
.52061 .08555 L
s
P
p
.2 0 1 r
.002 w
.44883 .22642 m
.4241 .07026 L
s
P
p
.2 0 1 r
.002 w
.37286 .26513 m
.26106 .15333 L
s
P
p
.2 0 1 r
.002 w
.37286 .26513 m
.2167 .2404 L
s
P
p
.2 0 1 r
.002 w
.37286 .26513 m
.23199 .33691 L
s
P
p
0 .4 1 r
.018 w
.42491 .27337 m
.44883 .22642 L
s
P
p
0 .4 1 r
.018 w
.42491 .27337 m
.37286 .26513 L
s
P
p
.2 0 1 r
.002 w
.51632 .70667 m
.36017 .73141 L
s
P
p
.2 0 1 r
.002 w
.51632 .70667 m
.40453 .81847 L
s
P
p
.2 0 1 r
.002 w
.51632 .70667 m
.49159 .86283 L
s
P
p
.2 0 1 r
.002 w
.60054 .69333 m
.67232 .8342 L
s
P
p
.2 0 1 r
.002 w
.60054 .69333 m
.74141 .76511 L
s
P
p
.2 0 1 r
.002 w
.60054 .69333 m
.7567 .6686 L
s
P
p
0 .4 1 r
.018 w
.55359 .66941 m
.51632 .70667 L
s
P
p
0 .4 1 r
.018 w
.55359 .66941 m
.60054 .69333 L
s
P
p
.2 0 1 r
.002 w
.60054 .22907 m
.7567 .2538 L
s
P
p
.2 0 1 r
.002 w
.60054 .22907 m
.74141 .15729 L
s
P
p
.2 0 1 r
.002 w
.60054 .22907 m
.67232 .0882 L
s
P
p
.2 0 1 r
.002 w
.51632 .21573 m
.49159 .05957 L
s
P
p
.2 0 1 r
.002 w
.51632 .21573 m
.40453 .10393 L
s
P
p
.2 0 1 r
.002 w
.51632 .21573 m
.36017 .191 L
s
P
p
0 .4 1 r
.018 w
.55359 .25299 m
.60054 .22907 L
s
P
p
0 .4 1 r
.018 w
.55359 .25299 m
.51632 .21573 L
s
P
p
.2 0 1 r
.002 w
.37286 .65727 m
.23199 .58549 L
s
P
p
.2 0 1 r
.002 w
.37286 .65727 m
.2167 .682 L
s
P
p
.2 0 1 r
.002 w
.37286 .65727 m
.26106 .76907 L
s
P
p
.2 0 1 r
.002 w
.44883 .69598 m
.4241 .85214 L
s
P
p
.2 0 1 r
.002 w
.44883 .69598 m
.52061 .83685 L
s
P
p
.2 0 1 r
.002 w
.44883 .69598 m
.5897 .76776 L
s
P
p
0 .4 1 r
.018 w
.42491 .64903 m
.37286 .65727 L
s
P
p
0 .4 1 r
.018 w
.42491 .64903 m
.44883 .69598 L
s
P
p
.2 0 1 r
.016 w
.52061 .4612 m
.66967 .61026 L
s
P
p
.2 0 1 r
.016 w
.52061 .4612 m
.42491 .27337 L
s
P
p
.2 0 1 r
.016 w
.52061 .4612 m
.55359 .66941 L
s
P
p
.2 0 1 r
.016 w
.52061 .4612 m
.55359 .25299 L
s
P
p
.2 0 1 r
.016 w
.52061 .4612 m
.42491 .64903 L
s
P
p
.2 0 1 r
.002 w
.75588 .59622 m
.68411 .73709 L
s
P
p
.2 0 1 r
.002 w
.75588 .59622 m
.78062 .75237 L
s
P
p
.2 0 1 r
.002 w
.75588 .59622 m
.86768 .70801 L
s
P
p
.2 0 1 r
.002 w
.7946 .52024 m
.95075 .54497 L
s
P
p
.2 0 1 r
.002 w
.7946 .52024 m
.93547 .44846 L
s
P
p
.2 0 1 r
.002 w
.7946 .52024 m
.86637 .37937 L
s
P
p
0 .4 1 r
.018 w
.74764 .54416 m
.75588 .59622 L
s
P
p
0 .4 1 r
.018 w
.74764 .54416 m
.7946 .52024 L
s
P
p
.2 0 1 r
.002 w
.419 .24735 m
.53079 .13556 L
s
P
p
.2 0 1 r
.002 w
.419 .24735 m
.44373 .09119 L
s
P
p
.2 0 1 r
.002 w
.419 .24735 m
.34722 .10648 L
s
P
p
.2 0 1 r
.002 w
.3587 .30765 m
.21783 .23587 L
s
P
p
.2 0 1 r
.002 w
.3587 .30765 m
.20255 .33238 L
s
P
p
.2 0 1 r
.002 w
.3587 .30765 m
.24691 .41944 L
s
P
p
0 .4 1 r
.018 w
.41075 .2994 m
.419 .24735 L
s
P
p
0 .4 1 r
.018 w
.41075 .2994 m
.3587 .30765 L
s
P
p
.2 0 1 r
.002 w
.63159 .68325 m
.49072 .75502 L
s
P
p
.2 0 1 r
.002 w
.63159 .68325 m
.55981 .82412 L
s
P
p
.2 0 1 r
.002 w
.63159 .68325 m
.65632 .8394 L
s
P
p
.2 0 1 r
.002 w
.70757 .64453 m
.81936 .75633 L
s
P
p
.2 0 1 r
.002 w
.70757 .64453 m
.86372 .66927 L
s
P
p
.2 0 1 r
.002 w
.70757 .64453 m
.84844 .57276 L
s
P
p
0 .4 1 r
.018 w
.65552 .63629 m
.63159 .68325 L
s
P
p
0 .4 1 r
.018 w
.65552 .63629 m
.70757 .64453 L
s
P
p
.2 0 1 r
.002 w
.5641 .20299 m
.72026 .17826 L
s
P
p
.2 0 1 r
.002 w
.5641 .20299 m
.6759 .09119 L
s
P
p
.2 0 1 r
.002 w
.5641 .20299 m
.58883 .04683 L
s
P
p
.2 0 1 r
.002 w
.47988 .21633 m
.4081 .07546 L
s
P
p
.2 0 1 r
.002 w
.47988 .21633 m
.33901 .14455 L
s
P
p
.2 0 1 r
.002 w
.47988 .21633 m
.32372 .24106 L
s
P
p
0 .4 1 r
.018 w
.52684 .24025 m
.5641 .20299 L
s
P
p
0 .4 1 r
.018 w
.52684 .24025 m
.47988 .21633 L
s
P
p
.2 0 1 r
.002 w
.47988 .6806 m
.32372 .65586 L
s
P
p
.2 0 1 r
.002 w
.47988 .6806 m
.33901 .75237 L
s
P
p
.2 0 1 r
.002 w
.47988 .6806 m
.4081 .82147 L
s
P
p
.2 0 1 r
.002 w
.5641 .69393 m
.58883 .85009 L
s
P
p
.2 0 1 r
.002 w
.5641 .69393 m
.6759 .80573 L
s
P
p
.2 0 1 r
.002 w
.5641 .69393 m
.72026 .71867 L
s
P
p
0 .4 1 r
.018 w
.52684 .65667 m
.47988 .6806 L
s
P
p
0 .4 1 r
.018 w
.52684 .65667 m
.5641 .69393 L
s
P
p
.2 0 1 r
.016 w
.55981 .44846 m
.74764 .54416 L
s
P
p
.2 0 1 r
.016 w
.55981 .44846 m
.41075 .2994 L
s
P
p
.2 0 1 r
.016 w
.55981 .44846 m
.65552 .63629 L
s
P
p
.2 0 1 r
.016 w
.55981 .44846 m
.52684 .24025 L
s
P
p
.2 0 1 r
.016 w
.55981 .44846 m
.52684 .65667 L
s
P
p
1 .6 0 r
.016 w
.5 .33107 m
.44019 .44846 L
s
P
p
1 .6 0 r
.016 w
.5 .33107 m
.47939 .4612 L
s
P
p
1 .6 0 r
.016 w
.5 .33107 m
.52061 .4612 L
s
P
p
1 .6 0 r
.016 w
.5 .33107 m
.55981 .44846 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0396832 0.952381 [
[ 0 0 0 0 ]
[ 1 .87301 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .87301 L
0 .87301 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.43507 .67274 m
.30551 .76688 L
s
P
p
.2 0 1 r
.002 w
.43507 .67274 m
.34094 .80231 L
s
P
p
.2 0 1 r
.002 w
.52038 .65923 m
.64994 .75336 L
s
P
p
.2 0 1 r
.002 w
.52038 .65923 m
.67269 .70872 L
s
P
p
0 .4 1 r
.018 w
.47282 .635 m
.43507 .67274 L
s
P
p
0 .4 1 r
.018 w
.47282 .635 m
.52038 .65923 L
s
P
p
.2 0 1 r
.002 w
.52038 .18896 m
.67269 .13947 L
s
P
p
.2 0 1 r
.002 w
.52038 .18896 m
.64994 .09483 L
s
P
p
.2 0 1 r
.002 w
.43507 .17545 m
.34094 .04589 L
s
P
p
.2 0 1 r
.002 w
.43507 .17545 m
.30551 .08132 L
s
P
p
0 .4 1 r
.018 w
.47282 .2132 m
.52038 .18896 L
s
P
p
0 .4 1 r
.018 w
.47282 .2132 m
.43507 .17545 L
s
P
p
.2 0 1 r
.002 w
.28975 .6227 m
.1296 .6227 L
s
P
p
.2 0 1 r
.002 w
.28975 .6227 m
.13744 .67219 L
s
P
p
.2 0 1 r
.002 w
.36671 .66192 m
.4162 .81423 L
s
P
p
.2 0 1 r
.002 w
.36671 .66192 m
.46084 .79148 L
s
P
p
0 .4 1 r
.018 w
.34247 .61435 m
.28975 .6227 L
s
P
p
0 .4 1 r
.018 w
.34247 .61435 m
.36671 .66192 L
s
P
p
.2 0 1 r
.002 w
.64313 .28146 m
.79543 .33095 L
s
P
p
.2 0 1 r
.002 w
.64313 .28146 m
.80327 .28146 L
s
P
p
.2 0 1 r
.002 w
.58205 .22038 m
.58205 .06024 L
s
P
p
.2 0 1 r
.002 w
.58205 .22038 m
.53256 .06807 L
s
P
p
0 .4 1 r
.018 w
.5904 .27311 m
.64313 .28146 L
s
P
p
0 .4 1 r
.018 w
.5904 .27311 m
.58205 .22038 L
s
P
p
.2 0 1 r
.002 w
.20159 .4968 m
.07203 .40267 L
s
P
p
.2 0 1 r
.002 w
.20159 .4968 m
.04928 .44731 L
s
P
p
.2 0 1 r
.002 w
.24081 .57376 m
.19132 .72607 L
s
P
p
.2 0 1 r
.002 w
.24081 .57376 m
.24081 .73391 L
s
P
p
0 .4 1 r
.018 w
.24916 .52104 m
.20159 .4968 L
s
P
p
0 .4 1 r
.018 w
.24916 .52104 m
.24081 .57376 L
s
P
p
.2 0 1 r
.016 w
.43941 .4241 m
.47282 .635 L
s
P
p
.2 0 1 r
.016 w
.43941 .4241 m
.47282 .2132 L
s
P
p
.2 0 1 r
.016 w
.43941 .4241 m
.34247 .61435 L
s
P
p
.2 0 1 r
.016 w
.43941 .4241 m
.5904 .27311 L
s
P
p
.2 0 1 r
.016 w
.43941 .4241 m
.24916 .52104 L
s
P
p
.2 0 1 r
.002 w
.55183 .67482 m
.4577 .80438 L
s
P
p
.2 0 1 r
.002 w
.55183 .67482 m
.50234 .82713 L
s
P
p
.2 0 1 r
.002 w
.62879 .63561 m
.7811 .68509 L
s
P
p
.2 0 1 r
.002 w
.62879 .63561 m
.78894 .63561 L
s
P
p
0 .4 1 r
.018 w
.57606 .62725 m
.55183 .67482 L
s
P
p
0 .4 1 r
.018 w
.57606 .62725 m
.62879 .63561 L
s
P
p
.2 0 1 r
.002 w
.48347 .18835 m
.61303 .09422 L
s
P
p
.2 0 1 r
.002 w
.48347 .18835 m
.5776 .05879 L
s
P
p
.2 0 1 r
.002 w
.39816 .20186 m
.26859 .10773 L
s
P
p
.2 0 1 r
.002 w
.39816 .20186 m
.24585 .15237 L
s
P
p
0 .4 1 r
.018 w
.44572 .2261 m
.48347 .18835 L
s
P
p
0 .4 1 r
.018 w
.44572 .2261 m
.39816 .20186 L
s
P
p
.2 0 1 r
.002 w
.39816 .67213 m
.24585 .72162 L
s
P
p
.2 0 1 r
.002 w
.39816 .67213 m
.26859 .76627 L
s
P
p
.2 0 1 r
.002 w
.48347 .68565 m
.5776 .81521 L
s
P
p
.2 0 1 r
.002 w
.48347 .68565 m
.61303 .77978 L
s
P
p
0 .4 1 r
.018 w
.44572 .6479 m
.39816 .67213 L
s
P
p
0 .4 1 r
.018 w
.44572 .6479 m
.48347 .68565 L
s
P
p
.2 0 1 r
.002 w
.62879 .23839 m
.78894 .23839 L
s
P
p
.2 0 1 r
.002 w
.62879 .23839 m
.7811 .1889 L
s
P
p
.2 0 1 r
.002 w
.55183 .19918 m
.50234 .04687 L
s
P
p
.2 0 1 r
.002 w
.55183 .19918 m
.4577 .06962 L
s
P
p
0 .4 1 r
.018 w
.57606 .24674 m
.62879 .23839 L
s
P
p
0 .4 1 r
.018 w
.57606 .24674 m
.55183 .19918 L
s
P
p
.2 0 1 r
.002 w
.27541 .57964 m
.1231 .53015 L
s
P
p
.2 0 1 r
.002 w
.27541 .57964 m
.11526 .57964 L
s
P
p
.2 0 1 r
.002 w
.33649 .64071 m
.33649 .80086 L
s
P
p
.2 0 1 r
.002 w
.33649 .64071 m
.38597 .79302 L
s
P
p
0 .4 1 r
.018 w
.32813 .58799 m
.27541 .57964 L
s
P
p
0 .4 1 r
.018 w
.32813 .58799 m
.33649 .64071 L
s
P
p
.2 0 1 r
.016 w
.47912 .437 m
.57606 .62725 L
s
P
p
.2 0 1 r
.016 w
.47912 .437 m
.44572 .2261 L
s
P
p
.2 0 1 r
.016 w
.47912 .437 m
.44572 .6479 L
s
P
p
.2 0 1 r
.016 w
.47912 .437 m
.57606 .24674 L
s
P
p
.2 0 1 r
.016 w
.47912 .437 m
.32813 .58799 L
s
P
p
.2 0 1 r
.002 w
.66351 .64071 m
.61403 .79302 L
s
P
p
.2 0 1 r
.002 w
.66351 .64071 m
.66351 .80086 L
s
P
p
.2 0 1 r
.002 w
.72459 .57964 m
.88474 .57964 L
s
P
p
.2 0 1 r
.002 w
.72459 .57964 m
.8769 .53015 L
s
P
p
0 .4 1 r
.018 w
.67187 .58799 m
.66351 .64071 L
s
P
p
0 .4 1 r
.018 w
.67187 .58799 m
.72459 .57964 L
s
P
p
.2 0 1 r
.002 w
.44817 .19918 m
.5423 .06962 L
s
P
p
.2 0 1 r
.002 w
.44817 .19918 m
.49766 .04687 L
s
P
p
.2 0 1 r
.002 w
.37121 .23839 m
.2189 .1889 L
s
P
p
.2 0 1 r
.002 w
.37121 .23839 m
.21106 .23839 L
s
P
p
0 .4 1 r
.018 w
.42394 .24674 m
.44817 .19918 L
s
P
p
0 .4 1 r
.018 w
.42394 .24674 m
.37121 .23839 L
s
P
p
.2 0 1 r
.002 w
.51653 .68565 m
.38697 .77978 L
s
P
p
.2 0 1 r
.002 w
.51653 .68565 m
.4224 .81521 L
s
P
p
.2 0 1 r
.002 w
.60184 .67213 m
.73141 .76627 L
s
P
p
.2 0 1 r
.002 w
.60184 .67213 m
.75415 .72162 L
s
P
p
0 .4 1 r
.018 w
.55428 .6479 m
.51653 .68565 L
s
P
p
0 .4 1 r
.018 w
.55428 .6479 m
.60184 .67213 L
s
P
p
.2 0 1 r
.002 w
.60184 .20186 m
.75415 .15237 L
s
P
p
.2 0 1 r
.002 w
.60184 .20186 m
.73141 .10773 L
s
P
p
.2 0 1 r
.002 w
.51653 .18835 m
.4224 .05879 L
s
P
p
.2 0 1 r
.002 w
.51653 .18835 m
.38697 .09422 L
s
P
p
0 .4 1 r
.018 w
.55428 .2261 m
.60184 .20186 L
s
P
p
0 .4 1 r
.018 w
.55428 .2261 m
.51653 .18835 L
s
P
p
.2 0 1 r
.002 w
.37121 .63561 m
.21106 .63561 L
s
P
p
.2 0 1 r
.002 w
.37121 .63561 m
.2189 .68509 L
s
P
p
.2 0 1 r
.002 w
.44817 .67482 m
.49766 .82713 L
s
P
p
.2 0 1 r
.002 w
.44817 .67482 m
.5423 .80438 L
s
P
p
0 .4 1 r
.018 w
.42394 .62725 m
.37121 .63561 L
s
P
p
0 .4 1 r
.018 w
.42394 .62725 m
.44817 .67482 L
s
P
p
.2 0 1 r
.016 w
.52088 .437 m
.67187 .58799 L
s
P
p
.2 0 1 r
.016 w
.52088 .437 m
.42394 .24674 L
s
P
p
.2 0 1 r
.016 w
.52088 .437 m
.55428 .6479 L
s
P
p
.2 0 1 r
.016 w
.52088 .437 m
.55428 .2261 L
s
P
p
.2 0 1 r
.016 w
.52088 .437 m
.42394 .62725 L
s
P
p
.2 0 1 r
.002 w
.75919 .57376 m
.75919 .73391 L
s
P
p
.2 0 1 r
.002 w
.75919 .57376 m
.80868 .72607 L
s
P
p
.2 0 1 r
.002 w
.79841 .4968 m
.95072 .44731 L
s
P
p
.2 0 1 r
.002 w
.79841 .4968 m
.92797 .40267 L
s
P
p
0 .4 1 r
.018 w
.75084 .52104 m
.75919 .57376 L
s
P
p
0 .4 1 r
.018 w
.75084 .52104 m
.79841 .4968 L
s
P
p
.2 0 1 r
.002 w
.41795 .22038 m
.46744 .06807 L
s
P
p
.2 0 1 r
.002 w
.41795 .22038 m
.41795 .06024 L
s
P
p
.2 0 1 r
.002 w
.35687 .28146 m
.19673 .28146 L
s
P
p
.2 0 1 r
.002 w
.35687 .28146 m
.20457 .33095 L
s
P
p
0 .4 1 r
.018 w
.4096 .27311 m
.41795 .22038 L
s
P
p
0 .4 1 r
.018 w
.4096 .27311 m
.35687 .28146 L
s
P
p
.2 0 1 r
.002 w
.63329 .66192 m
.53916 .79148 L
s
P
p
.2 0 1 r
.002 w
.63329 .66192 m
.5838 .81423 L
s
P
p
.2 0 1 r
.002 w
.71025 .6227 m
.86256 .67219 L
s
P
p
.2 0 1 r
.002 w
.71025 .6227 m
.8704 .6227 L
s
P
p
0 .4 1 r
.018 w
.65753 .61435 m
.63329 .66192 L
s
P
p
0 .4 1 r
.018 w
.65753 .61435 m
.71025 .6227 L
s
P
p
.2 0 1 r
.002 w
.56493 .17545 m
.69449 .08132 L
s
P
p
.2 0 1 r
.002 w
.56493 .17545 m
.65906 .04589 L
s
P
p
.2 0 1 r
.002 w
.47962 .18896 m
.35006 .09483 L
s
P
p
.2 0 1 r
.002 w
.47962 .18896 m
.32731 .13947 L
s
P
p
0 .4 1 r
.018 w
.52718 .2132 m
.56493 .17545 L
s
P
p
0 .4 1 r
.018 w
.52718 .2132 m
.47962 .18896 L
s
P
p
.2 0 1 r
.002 w
.47962 .65923 m
.32731 .70872 L
s
P
p
.2 0 1 r
.002 w
.47962 .65923 m
.35006 .75336 L
s
P
p
.2 0 1 r
.002 w
.56493 .67274 m
.65906 .80231 L
s
P
p
.2 0 1 r
.002 w
.56493 .67274 m
.69449 .76688 L
s
P
p
0 .4 1 r
.018 w
.52718 .635 m
.47962 .65923 L
s
P
p
0 .4 1 r
.018 w
.52718 .635 m
.56493 .67274 L
s
P
p
.2 0 1 r
.016 w
.56059 .4241 m
.75084 .52104 L
s
P
p
.2 0 1 r
.016 w
.56059 .4241 m
.4096 .27311 L
s
P
p
.2 0 1 r
.016 w
.56059 .4241 m
.65753 .61435 L
s
P
p
.2 0 1 r
.016 w
.56059 .4241 m
.52718 .2132 L
s
P
p
.2 0 1 r
.016 w
.56059 .4241 m
.52718 .635 L
s
P
p
1 .6 0 r
.016 w
.5 .30519 m
.43941 .4241 L
s
P
p
1 .6 0 r
.016 w
.5 .30519 m
.47912 .437 L
s
P
p
1 .6 0 r
.016 w
.5 .30519 m
.52088 .437 L
s
P
p
1 .6 0 r
.016 w
.5 .30519 m
.56059 .4241 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0331372 0.952381 [
[ 0 0 0 0 ]
[ 1 .88611 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88611 L
0 .88611 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.43938 .6658 m
.28395 .745 L
s
P
p
.2 0 1 r
.002 w
.43938 .6658 m
.36018 .82123 L
s
P
p
.2 0 1 r
.002 w
.51903 .65319 m
.64238 .77654 L
s
P
p
.2 0 1 r
.002 w
.51903 .65319 m
.69132 .68048 L
s
P
p
0 .4 1 r
.018 w
.47462 .63056 m
.43938 .6658 L
s
P
p
0 .4 1 r
.018 w
.47462 .63056 m
.51903 .65319 L
s
P
p
.2 0 1 r
.002 w
.51903 .21412 m
.69132 .18683 L
s
P
p
.2 0 1 r
.002 w
.51903 .21412 m
.64238 .09077 L
s
P
p
.2 0 1 r
.002 w
.43938 .2015 m
.36018 .04607 L
s
P
p
.2 0 1 r
.002 w
.43938 .2015 m
.28395 .12231 L
s
P
p
0 .4 1 r
.018 w
.47462 .23674 m
.51903 .21412 L
s
P
p
0 .4 1 r
.018 w
.47462 .23674 m
.43938 .2015 L
s
P
p
.2 0 1 r
.002 w
.3037 .61908 m
.1314 .59179 L
s
P
p
.2 0 1 r
.002 w
.3037 .61908 m
.14827 .69828 L
s
P
p
.2 0 1 r
.002 w
.37555 .65569 m
.40284 .82799 L
s
P
p
.2 0 1 r
.002 w
.37555 .65569 m
.4989 .77904 L
s
P
p
0 .4 1 r
.018 w
.35292 .61128 m
.3037 .61908 L
s
P
p
0 .4 1 r
.018 w
.35292 .61128 m
.37555 .65569 L
s
P
p
.2 0 1 r
.002 w
.63363 .30048 m
.78906 .37967 L
s
P
p
.2 0 1 r
.002 w
.63363 .30048 m
.80592 .27319 L
s
P
p
.2 0 1 r
.002 w
.57661 .24345 m
.60389 .07116 L
s
P
p
.2 0 1 r
.002 w
.57661 .24345 m
.49741 .08803 L
s
P
p
0 .4 1 r
.018 w
.5844 .29268 m
.63363 .30048 L
s
P
p
0 .4 1 r
.018 w
.5844 .29268 m
.57661 .24345 L
s
P
p
.2 0 1 r
.002 w
.22139 .50153 m
.09804 .37818 L
s
P
p
.2 0 1 r
.002 w
.22139 .50153 m
.0491 .47424 L
s
P
p
.2 0 1 r
.002 w
.258 .57339 m
.17881 .72882 L
s
P
p
.2 0 1 r
.002 w
.258 .57339 m
.28529 .74568 L
s
P
p
0 .4 1 r
.018 w
.2658 .52416 m
.22139 .50153 L
s
P
p
0 .4 1 r
.018 w
.2658 .52416 m
.258 .57339 L
s
P
p
.2 0 1 r
.016 w
.44343 .43365 m
.47462 .63056 L
s
P
p
.2 0 1 r
.016 w
.44343 .43365 m
.47462 .23674 L
s
P
p
.2 0 1 r
.016 w
.44343 .43365 m
.35292 .61128 L
s
P
p
.2 0 1 r
.016 w
.44343 .43365 m
.5844 .29268 L
s
P
p
.2 0 1 r
.016 w
.44343 .43365 m
.2658 .52416 L
s
P
p
.2 0 1 r
.002 w
.54839 .66774 m
.42504 .79109 L
s
P
p
.2 0 1 r
.002 w
.54839 .66774 m
.5211 .84003 L
s
P
p
.2 0 1 r
.002 w
.62024 .63113 m
.77567 .71032 L
s
P
p
.2 0 1 r
.002 w
.62024 .63113 m
.79254 .60384 L
s
P
p
0 .4 1 r
.018 w
.57102 .62333 m
.54839 .66774 L
s
P
p
0 .4 1 r
.018 w
.57102 .62333 m
.62024 .63113 L
s
P
p
.2 0 1 r
.002 w
.48456 .21355 m
.63999 .13435 L
s
P
p
.2 0 1 r
.002 w
.48456 .21355 m
.56376 .05812 L
s
P
p
.2 0 1 r
.002 w
.40491 .22616 m
.28156 .10281 L
s
P
p
.2 0 1 r
.002 w
.40491 .22616 m
.23262 .19887 L
s
P
p
0 .4 1 r
.018 w
.44932 .24879 m
.48456 .21355 L
s
P
p
0 .4 1 r
.018 w
.44932 .24879 m
.40491 .22616 L
s
P
p
.2 0 1 r
.002 w
.40491 .66523 m
.23262 .69252 L
s
P
p
.2 0 1 r
.002 w
.40491 .66523 m
.28156 .78858 L
s
P
p
.2 0 1 r
.002 w
.48456 .67785 m
.56376 .83328 L
s
P
p
.2 0 1 r
.002 w
.48456 .67785 m
.63999 .75704 L
s
P
p
0 .4 1 r
.018 w
.44932 .64261 m
.40491 .66523 L
s
P
p
0 .4 1 r
.018 w
.44932 .64261 m
.48456 .67785 L
s
P
p
.2 0 1 r
.002 w
.62024 .26027 m
.79254 .28756 L
s
P
p
.2 0 1 r
.002 w
.62024 .26027 m
.77567 .18107 L
s
P
p
.2 0 1 r
.002 w
.54839 .22366 m
.5211 .05136 L
s
P
p
.2 0 1 r
.002 w
.54839 .22366 m
.42504 .10031 L
s
P
p
0 .4 1 r
.018 w
.57102 .26807 m
.62024 .26027 L
s
P
p
0 .4 1 r
.018 w
.57102 .26807 m
.54839 .22366 L
s
P
p
.2 0 1 r
.002 w
.29031 .57887 m
.13488 .49968 L
s
P
p
.2 0 1 r
.002 w
.29031 .57887 m
.11802 .60616 L
s
P
p
.2 0 1 r
.002 w
.34733 .6359 m
.32005 .80819 L
s
P
p
.2 0 1 r
.002 w
.34733 .6359 m
.42653 .79133 L
s
P
p
0 .4 1 r
.018 w
.33954 .58667 m
.29031 .57887 L
s
P
p
0 .4 1 r
.018 w
.33954 .58667 m
.34733 .6359 L
s
P
p
.2 0 1 r
.016 w
.48051 .4457 m
.57102 .62333 L
s
P
p
.2 0 1 r
.016 w
.48051 .4457 m
.44932 .24879 L
s
P
p
.2 0 1 r
.016 w
.48051 .4457 m
.44932 .64261 L
s
P
p
.2 0 1 r
.016 w
.48051 .4457 m
.57102 .26807 L
s
P
p
.2 0 1 r
.016 w
.48051 .4457 m
.33954 .58667 L
s
P
p
.2 0 1 r
.002 w
.65267 .6359 m
.57347 .79133 L
s
P
p
.2 0 1 r
.002 w
.65267 .6359 m
.67995 .80819 L
s
P
p
.2 0 1 r
.002 w
.70969 .57887 m
.88198 .60616 L
s
P
p
.2 0 1 r
.002 w
.70969 .57887 m
.86512 .49968 L
s
P
p
0 .4 1 r
.018 w
.66046 .58667 m
.65267 .6359 L
s
P
p
0 .4 1 r
.018 w
.66046 .58667 m
.70969 .57887 L
s
P
p
.2 0 1 r
.002 w
.45161 .22366 m
.57496 .10031 L
s
P
p
.2 0 1 r
.002 w
.45161 .22366 m
.4789 .05136 L
s
P
p
.2 0 1 r
.002 w
.37976 .26027 m
.22433 .18107 L
s
P
p
.2 0 1 r
.002 w
.37976 .26027 m
.20746 .28756 L
s
P
p
0 .4 1 r
.018 w
.42898 .26807 m
.45161 .22366 L
s
P
p
0 .4 1 r
.018 w
.42898 .26807 m
.37976 .26027 L
s
P
p
.2 0 1 r
.002 w
.51544 .67785 m
.36001 .75704 L
s
P
p
.2 0 1 r
.002 w
.51544 .67785 m
.43624 .83328 L
s
P
p
.2 0 1 r
.002 w
.59509 .66523 m
.71844 .78858 L
s
P
p
.2 0 1 r
.002 w
.59509 .66523 m
.76738 .69252 L
s
P
p
0 .4 1 r
.018 w
.55068 .64261 m
.51544 .67785 L
s
P
p
0 .4 1 r
.018 w
.55068 .64261 m
.59509 .66523 L
s
P
p
.2 0 1 r
.002 w
.59509 .22616 m
.76738 .19887 L
s
P
p
.2 0 1 r
.002 w
.59509 .22616 m
.71844 .10281 L
s
P
p
.2 0 1 r
.002 w
.51544 .21355 m
.43624 .05812 L
s
P
p
.2 0 1 r
.002 w
.51544 .21355 m
.36001 .13435 L
s
P
p
0 .4 1 r
.018 w
.55068 .24879 m
.59509 .22616 L
s
P
p
0 .4 1 r
.018 w
.55068 .24879 m
.51544 .21355 L
s
P
p
.2 0 1 r
.002 w
.37976 .63113 m
.20746 .60384 L
s
P
p
.2 0 1 r
.002 w
.37976 .63113 m
.22433 .71032 L
s
P
p
.2 0 1 r
.002 w
.45161 .66774 m
.4789 .84003 L
s
P
p
.2 0 1 r
.002 w
.45161 .66774 m
.57496 .79109 L
s
P
p
0 .4 1 r
.018 w
.42898 .62333 m
.37976 .63113 L
s
P
p
0 .4 1 r
.018 w
.42898 .62333 m
.45161 .66774 L
s
P
p
.2 0 1 r
.016 w
.51949 .4457 m
.66046 .58667 L
s
P
p
.2 0 1 r
.016 w
.51949 .4457 m
.42898 .26807 L
s
P
p
.2 0 1 r
.016 w
.51949 .4457 m
.55068 .64261 L
s
P
p
.2 0 1 r
.016 w
.51949 .4457 m
.55068 .24879 L
s
P
p
.2 0 1 r
.016 w
.51949 .4457 m
.42898 .62333 L
s
P
p
.2 0 1 r
.002 w
.742 .57339 m
.71471 .74568 L
s
P
p
.2 0 1 r
.002 w
.742 .57339 m
.82119 .72882 L
s
P
p
.2 0 1 r
.002 w
.77861 .50153 m
.9509 .47424 L
s
P
p
.2 0 1 r
.002 w
.77861 .50153 m
.90196 .37818 L
s
P
p
0 .4 1 r
.018 w
.7342 .52416 m
.742 .57339 L
s
P
p
0 .4 1 r
.018 w
.7342 .52416 m
.77861 .50153 L
s
P
p
.2 0 1 r
.002 w
.42339 .24345 m
.50259 .08803 L
s
P
p
.2 0 1 r
.002 w
.42339 .24345 m
.39611 .07116 L
s
P
p
.2 0 1 r
.002 w
.36637 .30048 m
.19408 .27319 L
s
P
p
.2 0 1 r
.002 w
.36637 .30048 m
.21094 .37967 L
s
P
p
0 .4 1 r
.018 w
.4156 .29268 m
.42339 .24345 L
s
P
p
0 .4 1 r
.018 w
.4156 .29268 m
.36637 .30048 L
s
P
p
.2 0 1 r
.002 w
.62445 .65569 m
.5011 .77904 L
s
P
p
.2 0 1 r
.002 w
.62445 .65569 m
.59716 .82799 L
s
P
p
.2 0 1 r
.002 w
.6963 .61908 m
.85173 .69828 L
s
P
p
.2 0 1 r
.002 w
.6963 .61908 m
.8686 .59179 L
s
P
p
0 .4 1 r
.018 w
.64708 .61128 m
.62445 .65569 L
s
P
p
0 .4 1 r
.018 w
.64708 .61128 m
.6963 .61908 L
s
P
p
.2 0 1 r
.002 w
.56062 .2015 m
.71605 .12231 L
s
P
p
.2 0 1 r
.002 w
.56062 .2015 m
.63982 .04607 L
s
P
p
.2 0 1 r
.002 w
.48097 .21412 m
.35762 .09077 L
s
P
p
.2 0 1 r
.002 w
.48097 .21412 m
.30868 .18683 L
s
P
p
0 .4 1 r
.018 w
.52538 .23674 m
.56062 .2015 L
s
P
p
0 .4 1 r
.018 w
.52538 .23674 m
.48097 .21412 L
s
P
p
.2 0 1 r
.002 w
.48097 .65319 m
.30868 .68048 L
s
P
p
.2 0 1 r
.002 w
.48097 .65319 m
.35762 .77654 L
s
P
p
.2 0 1 r
.002 w
.56062 .6658 m
.63982 .82123 L
s
P
p
.2 0 1 r
.002 w
.56062 .6658 m
.71605 .745 L
s
P
p
0 .4 1 r
.018 w
.52538 .63056 m
.48097 .65319 L
s
P
p
0 .4 1 r
.018 w
.52538 .63056 m
.56062 .6658 L
s
P
p
.2 0 1 r
.016 w
.55657 .43365 m
.7342 .52416 L
s
P
p
.2 0 1 r
.016 w
.55657 .43365 m
.4156 .29268 L
s
P
p
.2 0 1 r
.016 w
.55657 .43365 m
.64708 .61128 L
s
P
p
.2 0 1 r
.016 w
.55657 .43365 m
.52538 .23674 L
s
P
p
.2 0 1 r
.016 w
.55657 .43365 m
.52538 .63056 L
s
P
p
1 .6 0 r
.016 w
.5 .32263 m
.44343 .43365 L
s
P
p
1 .6 0 r
.016 w
.5 .32263 m
.48051 .4457 L
s
P
p
1 .6 0 r
.016 w
.5 .32263 m
.51949 .4457 L
s
P
p
1 .6 0 r
.016 w
.5 .32263 m
.55657 .43365 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.004 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.004 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.004 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.004 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.004 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.004 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.004 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.004 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.004 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.004 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.004 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.004 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.004 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.004 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.004 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.004 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.004 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.004 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.004 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.004 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.004 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.004 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.004 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.004 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.004 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.004 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.004 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.004 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.004 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.004 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.004 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.004 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.004 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.004 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.004 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.004 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.004 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.004 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.004 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.004 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.004 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.004 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.004 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.004 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.004 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.004 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.004 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.004 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.004 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.004 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.004 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.004 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.004 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.004 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.004 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.004 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.004 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.004 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.004 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.004 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.004 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.004 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.004 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.004 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.004 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.004 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.004 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.004 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.004 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.004 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.004 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.004 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.004 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.004 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.004 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.004 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.004 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.004 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.004 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.004 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.002 w
.4359 .67792 m
.29503 .74969 L
s
P
p
0 .4 1 r
.002 w
.4359 .67792 m
.36412 .81879 L
s
P
p
0 .4 1 r
.002 w
.52012 .66458 m
.63191 .77637 L
s
P
p
0 .4 1 r
.002 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
0 .4 1 r
.002 w
.52012 .20031 m
.67628 .17558 L
s
P
p
0 .4 1 r
.002 w
.52012 .20031 m
.63191 .08852 L
s
P
p
0 .4 1 r
.002 w
.4359 .18697 m
.36412 .0461 L
s
P
p
0 .4 1 r
.002 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
0 .4 1 r
.002 w
.29243 .62851 m
.13628 .60378 L
s
P
p
0 .4 1 r
.002 w
.29243 .62851 m
.15156 .70029 L
s
P
p
0 .4 1 r
.002 w
.36841 .66723 m
.39314 .82338 L
s
P
p
0 .4 1 r
.002 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
0 .4 1 r
.002 w
.6413 .29163 m
.78217 .3634 L
s
P
p
0 .4 1 r
.002 w
.6413 .29163 m
.79745 .2669 L
s
P
p
0 .4 1 r
.002 w
.581 .23133 m
.60573 .07518 L
s
P
p
0 .4 1 r
.002 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
0 .4 1 r
.002 w
.2054 .50422 m
.09361 .39243 L
s
P
p
0 .4 1 r
.002 w
.2054 .50422 m
.04925 .47949 L
s
P
p
0 .4 1 r
.002 w
.24412 .5802 m
.17234 .72107 L
s
P
p
0 .4 1 r
.002 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
0 .4 1 r
.002 w
.55117 .67997 m
.43937 .79176 L
s
P
p
0 .4 1 r
.002 w
.55117 .67997 m
.52643 .83612 L
s
P
p
0 .4 1 r
.002 w
.62714 .64125 m
.76801 .71303 L
s
P
p
0 .4 1 r
.002 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
0 .4 1 r
.002 w
.48368 .19971 m
.62455 .12793 L
s
P
p
0 .4 1 r
.002 w
.48368 .19971 m
.55545 .05884 L
s
P
p
0 .4 1 r
.002 w
.39946 .21305 m
.28766 .10125 L
s
P
p
0 .4 1 r
.002 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
0 .4 1 r
.002 w
.39946 .67731 m
.2433 .70205 L
s
P
p
0 .4 1 r
.002 w
.39946 .67731 m
.28766 .78911 L
s
P
p
0 .4 1 r
.002 w
.48368 .69065 m
.55545 .83152 L
s
P
p
0 .4 1 r
.002 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
0 .4 1 r
.002 w
.62714 .24911 m
.7833 .27384 L
s
P
p
0 .4 1 r
.002 w
.62714 .24911 m
.76801 .17733 L
s
P
p
0 .4 1 r
.002 w
.55117 .2104 m
.52643 .05424 L
s
P
p
0 .4 1 r
.002 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
0 .4 1 r
.002 w
.27828 .586 m
.13741 .51422 L
s
P
p
0 .4 1 r
.002 w
.27828 .586 m
.12212 .61073 L
s
P
p
0 .4 1 r
.002 w
.33857 .64629 m
.31384 .80245 L
s
P
p
0 .4 1 r
.002 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
0 .4 1 r
.002 w
.66143 .64629 m
.58965 .78716 L
s
P
p
0 .4 1 r
.002 w
.66143 .64629 m
.68616 .80245 L
s
P
p
0 .4 1 r
.002 w
.72172 .586 m
.87788 .61073 L
s
P
p
0 .4 1 r
.002 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
0 .4 1 r
.002 w
.44883 .2104 m
.56063 .0986 L
s
P
p
0 .4 1 r
.002 w
.44883 .2104 m
.47357 .05424 L
s
P
p
0 .4 1 r
.002 w
.37286 .24911 m
.23199 .17733 L
s
P
p
0 .4 1 r
.002 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
0 .4 1 r
.002 w
.51632 .69065 m
.37545 .76243 L
s
P
p
0 .4 1 r
.002 w
.51632 .69065 m
.44455 .83152 L
s
P
p
0 .4 1 r
.002 w
.60054 .67731 m
.71234 .78911 L
s
P
p
0 .4 1 r
.002 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
0 .4 1 r
.002 w
.60054 .21305 m
.7567 .18832 L
s
P
p
0 .4 1 r
.002 w
.60054 .21305 m
.71234 .10125 L
s
P
p
0 .4 1 r
.002 w
.51632 .19971 m
.44455 .05884 L
s
P
p
0 .4 1 r
.002 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
0 .4 1 r
.002 w
.37286 .64125 m
.2167 .61652 L
s
P
p
0 .4 1 r
.002 w
.37286 .64125 m
.23199 .71303 L
s
P
p
0 .4 1 r
.002 w
.44883 .67997 m
.47357 .83612 L
s
P
p
0 .4 1 r
.002 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
0 .4 1 r
.002 w
.75588 .5802 m
.73115 .73635 L
s
P
p
0 .4 1 r
.002 w
.75588 .5802 m
.82766 .72107 L
s
P
p
0 .4 1 r
.002 w
.7946 .50422 m
.95075 .47949 L
s
P
p
0 .4 1 r
.002 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
0 .4 1 r
.002 w
.419 .23133 m
.49078 .09046 L
s
P
p
0 .4 1 r
.002 w
.419 .23133 m
.39427 .07518 L
s
P
p
0 .4 1 r
.002 w
.3587 .29163 m
.20255 .2669 L
s
P
p
0 .4 1 r
.002 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
0 .4 1 r
.002 w
.63159 .66723 m
.5198 .77902 L
s
P
p
0 .4 1 r
.002 w
.63159 .66723 m
.60686 .82338 L
s
P
p
0 .4 1 r
.002 w
.70757 .62851 m
.84844 .70029 L
s
P
p
0 .4 1 r
.002 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
0 .4 1 r
.002 w
.5641 .18697 m
.70497 .11519 L
s
P
p
0 .4 1 r
.002 w
.5641 .18697 m
.63588 .0461 L
s
P
p
0 .4 1 r
.002 w
.47988 .20031 m
.36809 .08852 L
s
P
p
0 .4 1 r
.002 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
0 .4 1 r
.002 w
.47988 .66458 m
.32372 .68931 L
s
P
p
0 .4 1 r
.002 w
.47988 .66458 m
.36809 .77637 L
s
P
p
0 .4 1 r
.002 w
.5641 .67792 m
.63588 .81879 L
s
P
p
0 .4 1 r
.002 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0150404 1.03008 0.025752 1.03008 [
[ 0 0 0 0 ]
[ 1 1.08158 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.08158 L
0 1.08158 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.24404 .77756 m
.05147 .74706 L
s
P
p
.2 0 1 r
.002 w
.24404 .77756 m
.07032 .86607 L
s
P
p
.2 0 1 r
.002 w
.33773 .8253 m
.36823 1.01786 L
s
P
p
.2 0 1 r
.002 w
.33773 .8253 m
.47559 .96316 L
s
P
p
0 .4 1 r
.018 w
.30822 .76739 m
.24404 .77756 L
s
P
p
0 .4 1 r
.018 w
.30822 .76739 m
.33773 .8253 L
s
P
p
.2 0 1 r
.002 w
.60844 .29399 m
.80101 .32449 L
s
P
p
.2 0 1 r
.002 w
.60844 .29399 m
.78216 .20548 L
s
P
p
.2 0 1 r
.002 w
.51475 .24625 m
.48425 .05369 L
s
P
p
.2 0 1 r
.002 w
.51475 .24625 m
.37689 .10839 L
s
P
p
0 .4 1 r
.018 w
.54426 .30415 m
.60844 .29399 L
s
P
p
0 .4 1 r
.018 w
.54426 .30415 m
.51475 .24625 L
s
P
p
.2 0 1 r
.016 w
.42624 .53577 m
.30822 .76739 L
s
P
p
.2 0 1 r
.016 w
.42624 .53577 m
.54426 .30415 L
s
P
p
.2 0 1 r
.002 w
.37601 .83774 m
.18345 .86823 L
s
P
p
.2 0 1 r
.002 w
.37601 .83774 m
.23815 .9756 L
s
P
p
.2 0 1 r
.002 w
.47987 .85418 m
.56838 1.0279 L
s
P
p
.2 0 1 r
.002 w
.47987 .85418 m
.65359 .9427 L
s
P
p
0 .4 1 r
.018 w
.43392 .80823 m
.37601 .83774 L
s
P
p
0 .4 1 r
.018 w
.43392 .80823 m
.47987 .85418 L
s
P
p
.2 0 1 r
.002 w
.57315 .26523 m
.76572 .23473 L
s
P
p
.2 0 1 r
.002 w
.57315 .26523 m
.71101 .12737 L
s
P
p
.2 0 1 r
.002 w
.4693 .24878 m
.38078 .07506 L
s
P
p
.2 0 1 r
.002 w
.4693 .24878 m
.29558 .16026 L
s
P
p
0 .4 1 r
.018 w
.51525 .29473 m
.57315 .26523 L
s
P
p
0 .4 1 r
.018 w
.51525 .29473 m
.4693 .24878 L
s
P
p
.2 0 1 r
.016 w
.47458 .55148 m
.43392 .80823 L
s
P
p
.2 0 1 r
.016 w
.47458 .55148 m
.51525 .29473 L
s
P
p
.2 0 1 r
.002 w
.52013 .85418 m
.34641 .9427 L
s
P
p
.2 0 1 r
.002 w
.52013 .85418 m
.43162 1.0279 L
s
P
p
.2 0 1 r
.002 w
.62399 .83774 m
.76185 .9756 L
s
P
p
.2 0 1 r
.002 w
.62399 .83774 m
.81655 .86823 L
s
P
p
0 .4 1 r
.018 w
.56608 .80823 m
.52013 .85418 L
s
P
p
0 .4 1 r
.018 w
.56608 .80823 m
.62399 .83774 L
s
P
p
.2 0 1 r
.002 w
.5307 .24878 m
.70442 .16026 L
s
P
p
.2 0 1 r
.002 w
.5307 .24878 m
.61922 .07506 L
s
P
p
.2 0 1 r
.002 w
.42685 .26523 m
.28899 .12737 L
s
P
p
.2 0 1 r
.002 w
.42685 .26523 m
.23428 .23473 L
s
P
p
0 .4 1 r
.018 w
.48475 .29473 m
.5307 .24878 L
s
P
p
0 .4 1 r
.018 w
.48475 .29473 m
.42685 .26523 L
s
P
p
.2 0 1 r
.016 w
.52542 .55148 m
.56608 .80823 L
s
P
p
.2 0 1 r
.016 w
.52542 .55148 m
.48475 .29473 L
s
P
p
.2 0 1 r
.002 w
.66227 .8253 m
.52441 .96316 L
s
P
p
.2 0 1 r
.002 w
.66227 .8253 m
.63177 1.01786 L
s
P
p
.2 0 1 r
.002 w
.75596 .77756 m
.92968 .86607 L
s
P
p
.2 0 1 r
.002 w
.75596 .77756 m
.94853 .74706 L
s
P
p
0 .4 1 r
.018 w
.69178 .76739 m
.66227 .8253 L
s
P
p
0 .4 1 r
.018 w
.69178 .76739 m
.75596 .77756 L
s
P
p
.2 0 1 r
.002 w
.48525 .24625 m
.62311 .10839 L
s
P
p
.2 0 1 r
.002 w
.48525 .24625 m
.51575 .05369 L
s
P
p
.2 0 1 r
.002 w
.39156 .29399 m
.21784 .20548 L
s
P
p
.2 0 1 r
.002 w
.39156 .29399 m
.19899 .32449 L
s
P
p
0 .4 1 r
.018 w
.45574 .30415 m
.48525 .24625 L
s
P
p
0 .4 1 r
.018 w
.45574 .30415 m
.39156 .29399 L
s
P
p
.2 0 1 r
.016 w
.57376 .53577 m
.69178 .76739 L
s
P
p
.2 0 1 r
.016 w
.57376 .53577 m
.45574 .30415 L
s
P
p
1 .6 0 r
.016 w
.5 .39101 m
.42624 .53577 L
s
P
p
1 .6 0 r
.016 w
.5 .39101 m
.47458 .55148 L
s
P
p
1 .6 0 r
.016 w
.5 .39101 m
.52542 .55148 L
s
P
p
1 .6 0 r
.016 w
.5 .39101 m
.57376 .53577 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.030885 0.952381 [
[ 0 0 0 0 ]
[ 1 .89061 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .89061 L
0 .89061 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.44297 .69641 m
.30904 .76466 L
s
P
p
.2 0 1 r
.002 w
.44297 .69641 m
.37473 .83035 L
s
P
p
.2 0 1 r
.002 w
.52305 .68373 m
.62934 .79002 L
s
P
p
.2 0 1 r
.002 w
.52305 .68373 m
.67152 .70724 L
s
P
p
0 .4 1 r
.018 w
.4784 .66098 m
.44297 .69641 L
s
P
p
0 .4 1 r
.018 w
.4784 .66098 m
.52305 .68373 L
s
P
p
.2 0 1 r
.002 w
.52305 .19282 m
.67152 .16931 L
s
P
p
.2 0 1 r
.002 w
.52305 .19282 m
.62934 .08653 L
s
P
p
.2 0 1 r
.002 w
.44297 .18014 m
.37473 .0462 L
s
P
p
.2 0 1 r
.002 w
.44297 .18014 m
.30904 .1119 L
s
P
p
0 .4 1 r
.018 w
.4784 .21557 m
.52305 .19282 L
s
P
p
0 .4 1 r
.018 w
.4784 .21557 m
.44297 .18014 L
s
P
p
.2 0 1 r
.002 w
.29127 .64702 m
.1428 .6235 L
s
P
p
.2 0 1 r
.002 w
.29127 .64702 m
.15734 .71526 L
s
P
p
.2 0 1 r
.002 w
.36351 .68383 m
.38703 .8323 L
s
P
p
.2 0 1 r
.002 w
.36351 .68383 m
.4698 .79012 L
s
P
p
0 .4 1 r
.018 w
.34076 .63918 m
.29127 .64702 L
s
P
p
0 .4 1 r
.018 w
.34076 .63918 m
.36351 .68383 L
s
P
p
.2 0 1 r
.002 w
.65206 .28668 m
.786 .35492 L
s
P
p
.2 0 1 r
.002 w
.65206 .28668 m
.80053 .26316 L
s
P
p
.2 0 1 r
.002 w
.59473 .22935 m
.61825 .08088 L
s
P
p
.2 0 1 r
.002 w
.59473 .22935 m
.52649 .09541 L
s
P
p
0 .4 1 r
.018 w
.60257 .27884 m
.65206 .28668 L
s
P
p
0 .4 1 r
.018 w
.60257 .27884 m
.59473 .22935 L
s
P
p
.2 0 1 r
.002 w
.19758 .51789 m
.09129 .4116 L
s
P
p
.2 0 1 r
.002 w
.19758 .51789 m
.04911 .49438 L
s
P
p
.2 0 1 r
.002 w
.23439 .59013 m
.16614 .72407 L
s
P
p
.2 0 1 r
.002 w
.23439 .59013 m
.2579 .7386 L
s
P
p
0 .4 1 r
.018 w
.24223 .54064 m
.19758 .51789 L
s
P
p
0 .4 1 r
.018 w
.24223 .54064 m
.23439 .59013 L
s
P
p
.2 0 1 r
.016 w
.44313 .43828 m
.4784 .66098 L
s
P
p
.2 0 1 r
.016 w
.44313 .43828 m
.4784 .21557 L
s
P
p
.2 0 1 r
.016 w
.44313 .43828 m
.34076 .63918 L
s
P
p
.2 0 1 r
.016 w
.44313 .43828 m
.60257 .27884 L
s
P
p
.2 0 1 r
.016 w
.44313 .43828 m
.24223 .54064 L
s
P
p
.2 0 1 r
.002 w
.56002 .69594 m
.45373 .80223 L
s
P
p
.2 0 1 r
.002 w
.56002 .69594 m
.53651 .84441 L
s
P
p
.2 0 1 r
.002 w
.63226 .65913 m
.7662 .72737 L
s
P
p
.2 0 1 r
.002 w
.63226 .65913 m
.78073 .63561 L
s
P
p
0 .4 1 r
.018 w
.58277 .65129 m
.56002 .69594 L
s
P
p
0 .4 1 r
.018 w
.58277 .65129 m
.63226 .65913 L
s
P
p
.2 0 1 r
.002 w
.48056 .19225 m
.6145 .12401 L
s
P
p
.2 0 1 r
.002 w
.48056 .19225 m
.54881 .05832 L
s
P
p
.2 0 1 r
.002 w
.40049 .20493 m
.29419 .09864 L
s
P
p
.2 0 1 r
.002 w
.40049 .20493 m
.25202 .18142 L
s
P
p
0 .4 1 r
.018 w
.44513 .22768 m
.48056 .19225 L
s
P
p
0 .4 1 r
.018 w
.44513 .22768 m
.40049 .20493 L
s
P
p
.2 0 1 r
.002 w
.40049 .69584 m
.25202 .71935 L
s
P
p
.2 0 1 r
.002 w
.40049 .69584 m
.29419 .80213 L
s
P
p
.2 0 1 r
.002 w
.48056 .70852 m
.54881 .84246 L
s
P
p
.2 0 1 r
.002 w
.48056 .70852 m
.6145 .77677 L
s
P
p
0 .4 1 r
.018 w
.44513 .67309 m
.40049 .69584 L
s
P
p
0 .4 1 r
.018 w
.44513 .67309 m
.48056 .70852 L
s
P
p
.2 0 1 r
.002 w
.63226 .24164 m
.78073 .26516 L
s
P
p
.2 0 1 r
.002 w
.63226 .24164 m
.7662 .1734 L
s
P
p
.2 0 1 r
.002 w
.56002 .20484 m
.53651 .05637 L
s
P
p
.2 0 1 r
.002 w
.56002 .20484 m
.45373 .09854 L
s
P
p
0 .4 1 r
.018 w
.58277 .24948 m
.63226 .24164 L
s
P
p
0 .4 1 r
.018 w
.58277 .24948 m
.56002 .20484 L
s
P
p
.2 0 1 r
.002 w
.27148 .60199 m
.13754 .53374 L
s
P
p
.2 0 1 r
.002 w
.27148 .60199 m
.12301 .6255 L
s
P
p
.2 0 1 r
.002 w
.3288 .65932 m
.30529 .80779 L
s
P
p
.2 0 1 r
.002 w
.3288 .65932 m
.39705 .79325 L
s
P
p
0 .4 1 r
.018 w
.32097 .60983 m
.27148 .60199 L
s
P
p
0 .4 1 r
.018 w
.32097 .60983 m
.3288 .65932 L
s
P
p
.2 0 1 r
.016 w
.4804 .45039 m
.58277 .65129 L
s
P
p
.2 0 1 r
.016 w
.4804 .45039 m
.44513 .22768 L
s
P
p
.2 0 1 r
.016 w
.4804 .45039 m
.44513 .67309 L
s
P
p
.2 0 1 r
.016 w
.4804 .45039 m
.58277 .24948 L
s
P
p
.2 0 1 r
.016 w
.4804 .45039 m
.32097 .60983 L
s
P
p
.2 0 1 r
.002 w
.6712 .65932 m
.60295 .79325 L
s
P
p
.2 0 1 r
.002 w
.6712 .65932 m
.69471 .80779 L
s
P
p
.2 0 1 r
.002 w
.72852 .60199 m
.87699 .6255 L
s
P
p
.2 0 1 r
.002 w
.72852 .60199 m
.86246 .53374 L
s
P
p
0 .4 1 r
.018 w
.67903 .60983 m
.6712 .65932 L
s
P
p
0 .4 1 r
.018 w
.67903 .60983 m
.72852 .60199 L
s
P
p
.2 0 1 r
.002 w
.43998 .20484 m
.54627 .09854 L
s
P
p
.2 0 1 r
.002 w
.43998 .20484 m
.46349 .05637 L
s
P
p
.2 0 1 r
.002 w
.36774 .24164 m
.2338 .1734 L
s
P
p
.2 0 1 r
.002 w
.36774 .24164 m
.21927 .26516 L
s
P
p
0 .4 1 r
.018 w
.41723 .24948 m
.43998 .20484 L
s
P
p
0 .4 1 r
.018 w
.41723 .24948 m
.36774 .24164 L
s
P
p
.2 0 1 r
.002 w
.51944 .70852 m
.3855 .77677 L
s
P
p
.2 0 1 r
.002 w
.51944 .70852 m
.45119 .84246 L
s
P
p
.2 0 1 r
.002 w
.59951 .69584 m
.70581 .80213 L
s
P
p
.2 0 1 r
.002 w
.59951 .69584 m
.74798 .71935 L
s
P
p
0 .4 1 r
.018 w
.55487 .67309 m
.51944 .70852 L
s
P
p
0 .4 1 r
.018 w
.55487 .67309 m
.59951 .69584 L
s
P
p
.2 0 1 r
.002 w
.59951 .20493 m
.74798 .18142 L
s
P
p
.2 0 1 r
.002 w
.59951 .20493 m
.70581 .09864 L
s
P
p
.2 0 1 r
.002 w
.51944 .19225 m
.45119 .05832 L
s
P
p
.2 0 1 r
.002 w
.51944 .19225 m
.3855 .12401 L
s
P
p
0 .4 1 r
.018 w
.55487 .22768 m
.59951 .20493 L
s
P
p
0 .4 1 r
.018 w
.55487 .22768 m
.51944 .19225 L
s
P
p
.2 0 1 r
.002 w
.36774 .65913 m
.21927 .63561 L
s
P
p
.2 0 1 r
.002 w
.36774 .65913 m
.2338 .72737 L
s
P
p
.2 0 1 r
.002 w
.43998 .69594 m
.46349 .84441 L
s
P
p
.2 0 1 r
.002 w
.43998 .69594 m
.54627 .80223 L
s
P
p
0 .4 1 r
.018 w
.41723 .65129 m
.36774 .65913 L
s
P
p
0 .4 1 r
.018 w
.41723 .65129 m
.43998 .69594 L
s
P
p
.2 0 1 r
.016 w
.5196 .45039 m
.67903 .60983 L
s
P
p
.2 0 1 r
.016 w
.5196 .45039 m
.41723 .24948 L
s
P
p
.2 0 1 r
.016 w
.5196 .45039 m
.55487 .67309 L
s
P
p
.2 0 1 r
.016 w
.5196 .45039 m
.55487 .22768 L
s
P
p
.2 0 1 r
.016 w
.5196 .45039 m
.41723 .65129 L
s
P
p
.2 0 1 r
.002 w
.76561 .59013 m
.7421 .7386 L
s
P
p
.2 0 1 r
.002 w
.76561 .59013 m
.83386 .72407 L
s
P
p
.2 0 1 r
.002 w
.80242 .51789 m
.95089 .49438 L
s
P
p
.2 0 1 r
.002 w
.80242 .51789 m
.90871 .4116 L
s
P
p
0 .4 1 r
.018 w
.75777 .54064 m
.76561 .59013 L
s
P
p
0 .4 1 r
.018 w
.75777 .54064 m
.80242 .51789 L
s
P
p
.2 0 1 r
.002 w
.40527 .22935 m
.47351 .09541 L
s
P
p
.2 0 1 r
.002 w
.40527 .22935 m
.38175 .08088 L
s
P
p
.2 0 1 r
.002 w
.34794 .28668 m
.19947 .26316 L
s
P
p
.2 0 1 r
.002 w
.34794 .28668 m
.214 .35492 L
s
P
p
0 .4 1 r
.018 w
.39743 .27884 m
.40527 .22935 L
s
P
p
0 .4 1 r
.018 w
.39743 .27884 m
.34794 .28668 L
s
P
p
.2 0 1 r
.002 w
.63649 .68383 m
.5302 .79012 L
s
P
p
.2 0 1 r
.002 w
.63649 .68383 m
.61297 .8323 L
s
P
p
.2 0 1 r
.002 w
.70873 .64702 m
.84266 .71526 L
s
P
p
.2 0 1 r
.002 w
.70873 .64702 m
.8572 .6235 L
s
P
p
0 .4 1 r
.018 w
.65924 .63918 m
.63649 .68383 L
s
P
p
0 .4 1 r
.018 w
.65924 .63918 m
.70873 .64702 L
s
P
p
.2 0 1 r
.002 w
.55703 .18014 m
.69096 .1119 L
s
P
p
.2 0 1 r
.002 w
.55703 .18014 m
.62527 .0462 L
s
P
p
.2 0 1 r
.002 w
.47695 .19282 m
.37066 .08653 L
s
P
p
.2 0 1 r
.002 w
.47695 .19282 m
.32848 .16931 L
s
P
p
0 .4 1 r
.018 w
.5216 .21557 m
.55703 .18014 L
s
P
p
0 .4 1 r
.018 w
.5216 .21557 m
.47695 .19282 L
s
P
p
.2 0 1 r
.002 w
.47695 .68373 m
.32848 .70724 L
s
P
p
.2 0 1 r
.002 w
.47695 .68373 m
.37066 .79002 L
s
P
p
.2 0 1 r
.002 w
.55703 .69641 m
.62527 .83035 L
s
P
p
.2 0 1 r
.002 w
.55703 .69641 m
.69096 .76466 L
s
P
p
0 .4 1 r
.018 w
.5216 .66098 m
.47695 .68373 L
s
P
p
0 .4 1 r
.018 w
.5216 .66098 m
.55703 .69641 L
s
P
p
.2 0 1 r
.016 w
.55687 .43828 m
.75777 .54064 L
s
P
p
.2 0 1 r
.016 w
.55687 .43828 m
.39743 .27884 L
s
P
p
.2 0 1 r
.016 w
.55687 .43828 m
.65924 .63918 L
s
P
p
.2 0 1 r
.016 w
.55687 .43828 m
.5216 .21557 L
s
P
p
.2 0 1 r
.016 w
.55687 .43828 m
.5216 .66098 L
s
P
p
1 .6 0 r
.016 w
.5 .32666 m
.44313 .43828 L
s
P
p
1 .6 0 r
.016 w
.5 .32666 m
.4804 .45039 L
s
P
p
1 .6 0 r
.016 w
.5 .32666 m
.5196 .45039 L
s
P
p
1 .6 0 r
.016 w
.5 .32666 m
.55687 .43828 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.014 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.014 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.014 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.014 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.014 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.014 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.014 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.014 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.014 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.014 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.014 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.014 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.014 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.014 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.014 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.014 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.014 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.014 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.014 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.014 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
0 .4 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
0 .4 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
0 .4 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
0 .4 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
0 .4 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
0 .4 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
0 .4 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
0 .4 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
0 .4 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
0 .4 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
0 .4 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
0 .4 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
0 .4 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
0 .4 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
0 .4 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
0 .4 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
0 .4 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
0 .4 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
0 .4 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
0 .4 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00573791 0.952381 [
[ 0 0 0 0 ]
[ 1 .94091 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .94091 L
0 .94091 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.48141 .72434 m
.45667 .8805 L
s
P
p
.2 0 1 r
.002 w
.48141 .72434 m
.55318 .86521 L
s
P
p
0 .4 1 r
.018 w
.47316 .67229 m
.48141 .72434 L
s
P
p
.2 0 1 r
.002 w
.48141 .20382 m
.55318 .06295 L
s
P
p
.2 0 1 r
.002 w
.48141 .20382 m
.45667 .04767 L
s
P
p
0 .4 1 r
.018 w
.47316 .25588 m
.48141 .20382 L
s
P
p
.2 0 1 r
.002 w
.32056 .69887 m
.20876 .81066 L
s
P
p
.2 0 1 r
.002 w
.32056 .69887 m
.29583 .85502 L
s
P
p
0 .4 1 r
.018 w
.34448 .65191 m
.32056 .69887 L
s
P
p
.2 0 1 r
.002 w
.62651 .27776 m
.76738 .20598 L
s
P
p
.2 0 1 r
.002 w
.62651 .27776 m
.69829 .13689 L
s
P
p
0 .4 1 r
.018 w
.58925 .31502 m
.62651 .27776 L
s
P
p
.2 0 1 r
.002 w
.2054 .58371 m
.04925 .60844 L
s
P
p
.2 0 1 r
.002 w
.2054 .58371 m
.09361 .69551 L
s
P
p
0 .4 1 r
.018 w
.25236 .55979 m
.2054 .58371 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.47316 .67229 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.47316 .25588 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.34448 .65191 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.58925 .31502 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.25236 .55979 L
s
P
p
.2 0 1 r
.002 w
.59902 .7116 m
.62375 .86776 L
s
P
p
.2 0 1 r
.002 w
.59902 .7116 m
.71081 .8234 L
s
P
p
0 .4 1 r
.018 w
.57509 .66465 m
.59902 .7116 L
s
P
p
.2 0 1 r
.002 w
.43817 .21656 m
.4629 .06041 L
s
P
p
.2 0 1 r
.002 w
.43817 .21656 m
.36639 .07569 L
s
P
p
0 .4 1 r
.018 w
.44641 .26861 m
.43817 .21656 L
s
P
p
.2 0 1 r
.002 w
.43817 .73708 m
.36639 .87795 L
s
P
p
.2 0 1 r
.002 w
.43817 .73708 m
.4629 .89324 L
s
P
p
0 .4 1 r
.018 w
.44641 .68503 m
.43817 .73708 L
s
P
p
.2 0 1 r
.002 w
.59902 .24204 m
.71081 .13024 L
s
P
p
.2 0 1 r
.002 w
.59902 .24204 m
.62375 .08588 L
s
P
p
0 .4 1 r
.018 w
.57509 .28899 m
.59902 .24204 L
s
P
p
.2 0 1 r
.002 w
.29306 .66315 m
.15219 .73492 L
s
P
p
.2 0 1 r
.002 w
.29306 .66315 m
.22129 .80402 L
s
P
p
0 .4 1 r
.018 w
.33033 .62588 m
.29306 .66315 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.57509 .66465 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.44641 .26861 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.44641 .68503 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.57509 .28899 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.33033 .62588 L
s
P
p
.2 0 1 r
.002 w
.70694 .66315 m
.77871 .80402 L
s
P
p
.2 0 1 r
.002 w
.70694 .66315 m
.84781 .73492 L
s
P
p
0 .4 1 r
.018 w
.66967 .62588 m
.70694 .66315 L
s
P
p
.2 0 1 r
.002 w
.40098 .24204 m
.37625 .08588 L
s
P
p
.2 0 1 r
.002 w
.40098 .24204 m
.28919 .13024 L
s
P
p
0 .4 1 r
.018 w
.42491 .28899 m
.40098 .24204 L
s
P
p
.2 0 1 r
.002 w
.56183 .73708 m
.5371 .89324 L
s
P
p
.2 0 1 r
.002 w
.56183 .73708 m
.63361 .87795 L
s
P
p
0 .4 1 r
.018 w
.55359 .68503 m
.56183 .73708 L
s
P
p
.2 0 1 r
.002 w
.56183 .21656 m
.63361 .07569 L
s
P
p
.2 0 1 r
.002 w
.56183 .21656 m
.5371 .06041 L
s
P
p
0 .4 1 r
.018 w
.55359 .26861 m
.56183 .21656 L
s
P
p
.2 0 1 r
.002 w
.40098 .7116 m
.28919 .8234 L
s
P
p
.2 0 1 r
.002 w
.40098 .7116 m
.37625 .86776 L
s
P
p
0 .4 1 r
.018 w
.42491 .66465 m
.40098 .7116 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.66967 .62588 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.42491 .28899 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.55359 .68503 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.55359 .26861 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.42491 .66465 L
s
P
p
.2 0 1 r
.002 w
.7946 .58371 m
.90639 .69551 L
s
P
p
.2 0 1 r
.002 w
.7946 .58371 m
.95075 .60844 L
s
P
p
0 .4 1 r
.018 w
.74764 .55979 m
.7946 .58371 L
s
P
p
.2 0 1 r
.002 w
.37349 .27776 m
.30171 .13689 L
s
P
p
.2 0 1 r
.002 w
.37349 .27776 m
.23262 .20598 L
s
P
p
0 .4 1 r
.018 w
.41075 .31502 m
.37349 .27776 L
s
P
p
.2 0 1 r
.002 w
.67944 .69887 m
.70417 .85502 L
s
P
p
.2 0 1 r
.002 w
.67944 .69887 m
.79124 .81066 L
s
P
p
0 .4 1 r
.018 w
.65552 .65191 m
.67944 .69887 L
s
P
p
.2 0 1 r
.002 w
.51859 .20382 m
.54333 .04767 L
s
P
p
.2 0 1 r
.002 w
.51859 .20382 m
.44682 .06295 L
s
P
p
0 .4 1 r
.018 w
.52684 .25588 m
.51859 .20382 L
s
P
p
.2 0 1 r
.002 w
.51859 .72434 m
.44682 .86521 L
s
P
p
.2 0 1 r
.002 w
.51859 .72434 m
.54333 .8805 L
s
P
p
0 .4 1 r
.018 w
.52684 .67229 m
.51859 .72434 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.74764 .55979 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.41075 .31502 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.65552 .65191 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.52684 .25588 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.52684 .67229 L
s
P
p
1 .6 0 r
.016 w
.5 .34669 m
.44019 .46408 L
s
P
p
1 .6 0 r
.016 w
.5 .34669 m
.47939 .47682 L
s
P
p
1 .6 0 r
.016 w
.5 .34669 m
.52061 .47682 L
s
P
p
1 .6 0 r
.016 w
.5 .34669 m
.55981 .46408 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0266315 0.952381 [
[ 0 0 0 0 ]
[ 1 .89912 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .89912 L
0 .89912 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.44283 .69131 m
.31635 .7832 L
s
P
p
.2 0 1 r
.002 w
.44283 .69131 m
.39452 .84 L
s
P
p
.2 0 1 r
.002 w
.51562 .67978 m
.60752 .80626 L
s
P
p
.2 0 1 r
.002 w
.51562 .67978 m
.66431 .72809 L
s
P
p
0 .4 1 r
.018 w
.47346 .64915 m
.44283 .69131 L
s
P
p
0 .4 1 r
.018 w
.47346 .64915 m
.51562 .67978 L
s
P
p
.2 0 1 r
.002 w
.51562 .20674 m
.66431 .15843 L
s
P
p
.2 0 1 r
.002 w
.51562 .20674 m
.60752 .08026 L
s
P
p
.2 0 1 r
.002 w
.44283 .19521 m
.39452 .04652 L
s
P
p
.2 0 1 r
.002 w
.44283 .19521 m
.31635 .10332 L
s
P
p
0 .4 1 r
.018 w
.47346 .23737 m
.51562 .20674 L
s
P
p
0 .4 1 r
.018 w
.47346 .23737 m
.44283 .19521 L
s
P
p
.2 0 1 r
.002 w
.29665 .6451 m
.14031 .6451 L
s
P
p
.2 0 1 r
.002 w
.29665 .6451 m
.17017 .73699 L
s
P
p
.2 0 1 r
.002 w
.36232 .67856 m
.36232 .8349 L
s
P
p
.2 0 1 r
.002 w
.36232 .67856 m
.45421 .80504 L
s
P
p
0 .4 1 r
.018 w
.34622 .62899 m
.29665 .6451 L
s
P
p
0 .4 1 r
.018 w
.34622 .62899 m
.36232 .67856 L
s
P
p
.2 0 1 r
.002 w
.64036 .29586 m
.78905 .34417 L
s
P
p
.2 0 1 r
.002 w
.64036 .29586 m
.78905 .24755 L
s
P
p
.2 0 1 r
.002 w
.58825 .24375 m
.63656 .09506 L
s
P
p
.2 0 1 r
.002 w
.58825 .24375 m
.53994 .09506 L
s
P
p
0 .4 1 r
.018 w
.58825 .29586 m
.64036 .29586 L
s
P
p
0 .4 1 r
.018 w
.58825 .29586 m
.58825 .24375 L
s
P
p
.2 0 1 r
.002 w
.20556 .52179 m
.07907 .4299 L
s
P
p
.2 0 1 r
.002 w
.20556 .52179 m
.04922 .52179 L
s
P
p
.2 0 1 r
.002 w
.23902 .58746 m
.14712 .71394 L
s
P
p
.2 0 1 r
.002 w
.23902 .58746 m
.23902 .7438 L
s
P
p
0 .4 1 r
.018 w
.25512 .5379 m
.20556 .52179 L
s
P
p
0 .4 1 r
.018 w
.25512 .5379 m
.23902 .58746 L
s
P
p
.2 0 1 r
.016 w
.44085 .44326 m
.47346 .64915 L
s
P
p
.2 0 1 r
.016 w
.44085 .44326 m
.47346 .23737 L
s
P
p
.2 0 1 r
.016 w
.44085 .44326 m
.34622 .62899 L
s
P
p
.2 0 1 r
.016 w
.44085 .44326 m
.58825 .29586 L
s
P
p
.2 0 1 r
.016 w
.44085 .44326 m
.25512 .5379 L
s
P
p
.2 0 1 r
.002 w
.55815 .69115 m
.46626 .81764 L
s
P
p
.2 0 1 r
.002 w
.55815 .69115 m
.55815 .84749 L
s
P
p
.2 0 1 r
.002 w
.62382 .65769 m
.7503 .74959 L
s
P
p
.2 0 1 r
.002 w
.62382 .65769 m
.78016 .65769 L
s
P
p
0 .4 1 r
.018 w
.57426 .64159 m
.55815 .69115 L
s
P
p
0 .4 1 r
.018 w
.57426 .64159 m
.62382 .65769 L
s
P
p
.2 0 1 r
.002 w
.47764 .20781 m
.60412 .11591 L
s
P
p
.2 0 1 r
.002 w
.47764 .20781 m
.52595 .05912 L
s
P
p
.2 0 1 r
.002 w
.40485 .21934 m
.31295 .09286 L
s
P
p
.2 0 1 r
.002 w
.40485 .21934 m
.25616 .17103 L
s
P
p
0 .4 1 r
.018 w
.44701 .24997 m
.47764 .20781 L
s
P
p
0 .4 1 r
.018 w
.44701 .24997 m
.40485 .21934 L
s
P
p
.2 0 1 r
.002 w
.40485 .69238 m
.25616 .74069 L
s
P
p
.2 0 1 r
.002 w
.40485 .69238 m
.31295 .81886 L
s
P
p
.2 0 1 r
.002 w
.47764 .7039 m
.52595 .85259 L
s
P
p
.2 0 1 r
.002 w
.47764 .7039 m
.60412 .7958 L
s
P
p
0 .4 1 r
.018 w
.44701 .66174 m
.40485 .69238 L
s
P
p
0 .4 1 r
.018 w
.44701 .66174 m
.47764 .7039 L
s
P
p
.2 0 1 r
.002 w
.62382 .25402 m
.78016 .25402 L
s
P
p
.2 0 1 r
.002 w
.62382 .25402 m
.7503 .16213 L
s
P
p
.2 0 1 r
.002 w
.55815 .22056 m
.55815 .06422 L
s
P
p
.2 0 1 r
.002 w
.55815 .22056 m
.46626 .09408 L
s
P
p
0 .4 1 r
.018 w
.57426 .27012 m
.62382 .25402 L
s
P
p
0 .4 1 r
.018 w
.57426 .27012 m
.55815 .22056 L
s
P
p
.2 0 1 r
.002 w
.28011 .60326 m
.13142 .55494 L
s
P
p
.2 0 1 r
.002 w
.28011 .60326 m
.13142 .65157 L
s
P
p
.2 0 1 r
.002 w
.33222 .65537 m
.28391 .80406 L
s
P
p
.2 0 1 r
.002 w
.33222 .65537 m
.38053 .80406 L
s
P
p
0 .4 1 r
.018 w
.33222 .60326 m
.28011 .60326 L
s
P
p
0 .4 1 r
.018 w
.33222 .60326 m
.33222 .65537 L
s
P
p
.2 0 1 r
.016 w
.47962 .45586 m
.57426 .64159 L
s
P
p
.2 0 1 r
.016 w
.47962 .45586 m
.44701 .24997 L
s
P
p
.2 0 1 r
.016 w
.47962 .45586 m
.44701 .66174 L
s
P
p
.2 0 1 r
.016 w
.47962 .45586 m
.57426 .27012 L
s
P
p
.2 0 1 r
.016 w
.47962 .45586 m
.33222 .60326 L
s
P
p
.2 0 1 r
.002 w
.66778 .65537 m
.61947 .80406 L
s
P
p
.2 0 1 r
.002 w
.66778 .65537 m
.71609 .80406 L
s
P
p
.2 0 1 r
.002 w
.71989 .60326 m
.86858 .65157 L
s
P
p
.2 0 1 r
.002 w
.71989 .60326 m
.86858 .55494 L
s
P
p
0 .4 1 r
.018 w
.66778 .60326 m
.66778 .65537 L
s
P
p
0 .4 1 r
.018 w
.66778 .60326 m
.71989 .60326 L
s
P
p
.2 0 1 r
.002 w
.44185 .22056 m
.53374 .09408 L
s
P
p
.2 0 1 r
.002 w
.44185 .22056 m
.44185 .06422 L
s
P
p
.2 0 1 r
.002 w
.37618 .25402 m
.2497 .16213 L
s
P
p
.2 0 1 r
.002 w
.37618 .25402 m
.21984 .25402 L
s
P
p
0 .4 1 r
.018 w
.42574 .27012 m
.44185 .22056 L
s
P
p
0 .4 1 r
.018 w
.42574 .27012 m
.37618 .25402 L
s
P
p
.2 0 1 r
.002 w
.52236 .7039 m
.39588 .7958 L
s
P
p
.2 0 1 r
.002 w
.52236 .7039 m
.47405 .85259 L
s
P
p
.2 0 1 r
.002 w
.59515 .69238 m
.68705 .81886 L
s
P
p
.2 0 1 r
.002 w
.59515 .69238 m
.74384 .74069 L
s
P
p
0 .4 1 r
.018 w
.55299 .66174 m
.52236 .7039 L
s
P
p
0 .4 1 r
.018 w
.55299 .66174 m
.59515 .69238 L
s
P
p
.2 0 1 r
.002 w
.59515 .21934 m
.74384 .17103 L
s
P
p
.2 0 1 r
.002 w
.59515 .21934 m
.68705 .09286 L
s
P
p
.2 0 1 r
.002 w
.52236 .20781 m
.47405 .05912 L
s
P
p
.2 0 1 r
.002 w
.52236 .20781 m
.39588 .11591 L
s
P
p
0 .4 1 r
.018 w
.55299 .24997 m
.59515 .21934 L
s
P
p
0 .4 1 r
.018 w
.55299 .24997 m
.52236 .20781 L
s
P
p
.2 0 1 r
.002 w
.37618 .65769 m
.21984 .65769 L
s
P
p
.2 0 1 r
.002 w
.37618 .65769 m
.2497 .74959 L
s
P
p
.2 0 1 r
.002 w
.44185 .69115 m
.44185 .84749 L
s
P
p
.2 0 1 r
.002 w
.44185 .69115 m
.53374 .81764 L
s
P
p
0 .4 1 r
.018 w
.42574 .64159 m
.37618 .65769 L
s
P
p
0 .4 1 r
.018 w
.42574 .64159 m
.44185 .69115 L
s
P
p
.2 0 1 r
.016 w
.52038 .45586 m
.66778 .60326 L
s
P
p
.2 0 1 r
.016 w
.52038 .45586 m
.42574 .27012 L
s
P
p
.2 0 1 r
.016 w
.52038 .45586 m
.55299 .66174 L
s
P
p
.2 0 1 r
.016 w
.52038 .45586 m
.55299 .24997 L
s
P
p
.2 0 1 r
.016 w
.52038 .45586 m
.42574 .64159 L
s
P
p
.2 0 1 r
.002 w
.76098 .58746 m
.76098 .7438 L
s
P
p
.2 0 1 r
.002 w
.76098 .58746 m
.85288 .71394 L
s
P
p
.2 0 1 r
.002 w
.79444 .52179 m
.95078 .52179 L
s
P
p
.2 0 1 r
.002 w
.79444 .52179 m
.92093 .4299 L
s
P
p
0 .4 1 r
.018 w
.74488 .5379 m
.76098 .58746 L
s
P
p
0 .4 1 r
.018 w
.74488 .5379 m
.79444 .52179 L
s
P
p
.2 0 1 r
.002 w
.41175 .24375 m
.46006 .09506 L
s
P
p
.2 0 1 r
.002 w
.41175 .24375 m
.36344 .09506 L
s
P
p
.2 0 1 r
.002 w
.35964 .29586 m
.21095 .24755 L
s
P
p
.2 0 1 r
.002 w
.35964 .29586 m
.21095 .34417 L
s
P
p
0 .4 1 r
.018 w
.41175 .29586 m
.41175 .24375 L
s
P
p
0 .4 1 r
.018 w
.41175 .29586 m
.35964 .29586 L
s
P
p
.2 0 1 r
.002 w
.63768 .67856 m
.54579 .80504 L
s
P
p
.2 0 1 r
.002 w
.63768 .67856 m
.63768 .8349 L
s
P
p
.2 0 1 r
.002 w
.70335 .6451 m
.82983 .73699 L
s
P
p
.2 0 1 r
.002 w
.70335 .6451 m
.85969 .6451 L
s
P
p
0 .4 1 r
.018 w
.65378 .62899 m
.63768 .67856 L
s
P
p
0 .4 1 r
.018 w
.65378 .62899 m
.70335 .6451 L
s
P
p
.2 0 1 r
.002 w
.55717 .19521 m
.68365 .10332 L
s
P
p
.2 0 1 r
.002 w
.55717 .19521 m
.60548 .04652 L
s
P
p
.2 0 1 r
.002 w
.48438 .20674 m
.39248 .08026 L
s
P
p
.2 0 1 r
.002 w
.48438 .20674 m
.33569 .15843 L
s
P
p
0 .4 1 r
.018 w
.52654 .23737 m
.55717 .19521 L
s
P
p
0 .4 1 r
.018 w
.52654 .23737 m
.48438 .20674 L
s
P
p
.2 0 1 r
.002 w
.48438 .67978 m
.33569 .72809 L
s
P
p
.2 0 1 r
.002 w
.48438 .67978 m
.39248 .80626 L
s
P
p
.2 0 1 r
.002 w
.55717 .69131 m
.60548 .84 L
s
P
p
.2 0 1 r
.002 w
.55717 .69131 m
.68365 .7832 L
s
P
p
0 .4 1 r
.018 w
.52654 .64915 m
.48438 .67978 L
s
P
p
0 .4 1 r
.018 w
.52654 .64915 m
.55717 .69131 L
s
P
p
.2 0 1 r
.016 w
.55915 .44326 m
.74488 .5379 L
s
P
p
.2 0 1 r
.016 w
.55915 .44326 m
.41175 .29586 L
s
P
p
.2 0 1 r
.016 w
.55915 .44326 m
.65378 .62899 L
s
P
p
.2 0 1 r
.016 w
.55915 .44326 m
.52654 .23737 L
s
P
p
.2 0 1 r
.016 w
.55915 .44326 m
.52654 .64915 L
s
P
p
1 .6 0 r
.016 w
.5 .32718 m
.44085 .44326 L
s
P
p
1 .6 0 r
.016 w
.5 .32718 m
.47962 .45586 L
s
P
p
1 .6 0 r
.016 w
.5 .32718 m
.52038 .45586 L
s
P
p
1 .6 0 r
.016 w
.5 .32718 m
.55915 .44326 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0354762 0.952381 [
[ 0 0 0 0 ]
[ 1 .88143 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88143 L
0 .88143 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.45205 .67322 m
.30349 .74892 L
s
P
p
.2 0 1 r
.002 w
.45205 .67322 m
.37635 .82178 L
s
P
p
.2 0 1 r
.002 w
.49646 .66619 m
.61436 .78409 L
s
P
p
.2 0 1 r
.002 w
.49646 .66619 m
.66114 .69227 L
s
P
p
0 .4 1 r
.018 w
.4717 .65357 m
.45205 .67322 L
s
P
p
0 .4 1 r
.018 w
.4717 .65357 m
.49646 .66619 L
s
P
p
.2 0 1 r
.002 w
.49646 .20181 m
.66114 .17572 L
s
P
p
.2 0 1 r
.002 w
.49646 .20181 m
.61436 .08391 L
s
P
p
.2 0 1 r
.002 w
.45205 .19477 m
.37635 .04621 L
s
P
p
.2 0 1 r
.002 w
.45205 .19477 m
.30349 .11908 L
s
P
p
0 .4 1 r
.018 w
.4717 .21442 m
.49646 .20181 L
s
P
p
0 .4 1 r
.018 w
.4717 .21442 m
.45205 .19477 L
s
P
p
.2 0 1 r
.002 w
.30855 .63643 m
.14387 .61034 L
s
P
p
.2 0 1 r
.002 w
.30855 .63643 m
.15999 .71212 L
s
P
p
.2 0 1 r
.002 w
.34861 .65684 m
.37469 .82152 L
s
P
p
.2 0 1 r
.002 w
.34861 .65684 m
.46651 .77474 L
s
P
p
0 .4 1 r
.018 w
.33599 .63208 m
.30855 .63643 L
s
P
p
0 .4 1 r
.018 w
.33599 .63208 m
.34861 .65684 L
s
P
p
.2 0 1 r
.002 w
.62157 .28115 m
.77013 .35684 L
s
P
p
.2 0 1 r
.002 w
.62157 .28115 m
.78625 .25506 L
s
P
p
.2 0 1 r
.002 w
.58977 .24935 m
.61585 .08467 L
s
P
p
.2 0 1 r
.002 w
.58977 .24935 m
.51408 .10079 L
s
P
p
0 .4 1 r
.018 w
.59412 .2768 m
.62157 .28115 L
s
P
p
0 .4 1 r
.018 w
.59412 .2768 m
.58977 .24935 L
s
P
p
.2 0 1 r
.002 w
.21408 .52231 m
.09618 .40441 L
s
P
p
.2 0 1 r
.002 w
.21408 .52231 m
.0494 .49623 L
s
P
p
.2 0 1 r
.002 w
.23449 .56237 m
.1588 .71093 L
s
P
p
.2 0 1 r
.002 w
.23449 .56237 m
.26058 .72705 L
s
P
p
0 .4 1 r
.018 w
.23884 .53492 m
.21408 .52231 L
s
P
p
0 .4 1 r
.018 w
.23884 .53492 m
.23449 .56237 L
s
P
p
.2 0 1 r
.016 w
.43692 .434 m
.4717 .65357 L
s
P
p
.2 0 1 r
.016 w
.43692 .434 m
.4717 .21442 L
s
P
p
.2 0 1 r
.016 w
.43692 .434 m
.33599 .63208 L
s
P
p
.2 0 1 r
.016 w
.43692 .434 m
.59412 .2768 L
s
P
p
.2 0 1 r
.016 w
.43692 .434 m
.23884 .53492 L
s
P
p
.2 0 1 r
.002 w
.56658 .67027 m
.44868 .78817 L
s
P
p
.2 0 1 r
.002 w
.56658 .67027 m
.54049 .83495 L
s
P
p
.2 0 1 r
.002 w
.60664 .64986 m
.7552 .72555 L
s
P
p
.2 0 1 r
.002 w
.60664 .64986 m
.77132 .62378 L
s
P
p
0 .4 1 r
.018 w
.57919 .64551 m
.56658 .67027 L
s
P
p
0 .4 1 r
.018 w
.57919 .64551 m
.60664 .64986 L
s
P
p
.2 0 1 r
.002 w
.46314 .20821 m
.6117 .13251 L
s
P
p
.2 0 1 r
.002 w
.46314 .20821 m
.53883 .05965 L
s
P
p
.2 0 1 r
.002 w
.41873 .21524 m
.30083 .09734 L
s
P
p
.2 0 1 r
.002 w
.41873 .21524 m
.25405 .18916 L
s
P
p
0 .4 1 r
.018 w
.44349 .22786 m
.46314 .20821 L
s
P
p
0 .4 1 r
.018 w
.44349 .22786 m
.41873 .21524 L
s
P
p
.2 0 1 r
.002 w
.41873 .67962 m
.25405 .7057 L
s
P
p
.2 0 1 r
.002 w
.41873 .67962 m
.30083 .79752 L
s
P
p
.2 0 1 r
.002 w
.46314 .68666 m
.53883 .83522 L
s
P
p
.2 0 1 r
.002 w
.46314 .68666 m
.6117 .76235 L
s
P
p
0 .4 1 r
.018 w
.44349 .66701 m
.41873 .67962 L
s
P
p
0 .4 1 r
.018 w
.44349 .66701 m
.46314 .68666 L
s
P
p
.2 0 1 r
.002 w
.60664 .245 m
.77132 .27109 L
s
P
p
.2 0 1 r
.002 w
.60664 .245 m
.7552 .16931 L
s
P
p
.2 0 1 r
.002 w
.56658 .22459 m
.54049 .05991 L
s
P
p
.2 0 1 r
.002 w
.56658 .22459 m
.44868 .10669 L
s
P
p
0 .4 1 r
.018 w
.57919 .24935 m
.60664 .245 L
s
P
p
0 .4 1 r
.018 w
.57919 .24935 m
.56658 .22459 L
s
P
p
.2 0 1 r
.002 w
.29362 .60028 m
.14506 .52459 L
s
P
p
.2 0 1 r
.002 w
.29362 .60028 m
.12894 .62636 L
s
P
p
.2 0 1 r
.002 w
.32541 .63208 m
.29933 .79676 L
s
P
p
.2 0 1 r
.002 w
.32541 .63208 m
.40111 .78064 L
s
P
p
0 .4 1 r
.018 w
.32107 .60463 m
.29362 .60028 L
s
P
p
0 .4 1 r
.018 w
.32107 .60463 m
.32541 .63208 L
s
P
p
.2 0 1 r
.016 w
.47826 .44743 m
.57919 .64551 L
s
P
p
.2 0 1 r
.016 w
.47826 .44743 m
.44349 .22786 L
s
P
p
.2 0 1 r
.016 w
.47826 .44743 m
.44349 .66701 L
s
P
p
.2 0 1 r
.016 w
.47826 .44743 m
.57919 .24935 L
s
P
p
.2 0 1 r
.016 w
.47826 .44743 m
.32107 .60463 L
s
P
p
.2 0 1 r
.002 w
.67459 .63208 m
.59889 .78064 L
s
P
p
.2 0 1 r
.002 w
.67459 .63208 m
.70067 .79676 L
s
P
p
.2 0 1 r
.002 w
.70638 .60028 m
.87106 .62636 L
s
P
p
.2 0 1 r
.002 w
.70638 .60028 m
.85494 .52459 L
s
P
p
0 .4 1 r
.018 w
.67893 .60463 m
.67459 .63208 L
s
P
p
0 .4 1 r
.018 w
.67893 .60463 m
.70638 .60028 L
s
P
p
.2 0 1 r
.002 w
.43342 .22459 m
.55132 .10669 L
s
P
p
.2 0 1 r
.002 w
.43342 .22459 m
.45951 .05991 L
s
P
p
.2 0 1 r
.002 w
.39336 .245 m
.2448 .16931 L
s
P
p
.2 0 1 r
.002 w
.39336 .245 m
.22868 .27109 L
s
P
p
0 .4 1 r
.018 w
.42081 .24935 m
.43342 .22459 L
s
P
p
0 .4 1 r
.018 w
.42081 .24935 m
.39336 .245 L
s
P
p
.2 0 1 r
.002 w
.53686 .68666 m
.3883 .76235 L
s
P
p
.2 0 1 r
.002 w
.53686 .68666 m
.46117 .83522 L
s
P
p
.2 0 1 r
.002 w
.58127 .67962 m
.69917 .79752 L
s
P
p
.2 0 1 r
.002 w
.58127 .67962 m
.74595 .7057 L
s
P
p
0 .4 1 r
.018 w
.55651 .66701 m
.53686 .68666 L
s
P
p
0 .4 1 r
.018 w
.55651 .66701 m
.58127 .67962 L
s
P
p
.2 0 1 r
.002 w
.58127 .21524 m
.74595 .18916 L
s
P
p
.2 0 1 r
.002 w
.58127 .21524 m
.69917 .09734 L
s
P
p
.2 0 1 r
.002 w
.53686 .20821 m
.46117 .05965 L
s
P
p
.2 0 1 r
.002 w
.53686 .20821 m
.3883 .13251 L
s
P
p
0 .4 1 r
.018 w
.55651 .22786 m
.58127 .21524 L
s
P
p
0 .4 1 r
.018 w
.55651 .22786 m
.53686 .20821 L
s
P
p
.2 0 1 r
.002 w
.39336 .64986 m
.22868 .62378 L
s
P
p
.2 0 1 r
.002 w
.39336 .64986 m
.2448 .72555 L
s
P
p
.2 0 1 r
.002 w
.43342 .67027 m
.45951 .83495 L
s
P
p
.2 0 1 r
.002 w
.43342 .67027 m
.55132 .78817 L
s
P
p
0 .4 1 r
.018 w
.42081 .64551 m
.39336 .64986 L
s
P
p
0 .4 1 r
.018 w
.42081 .64551 m
.43342 .67027 L
s
P
p
.2 0 1 r
.016 w
.52174 .44743 m
.67893 .60463 L
s
P
p
.2 0 1 r
.016 w
.52174 .44743 m
.42081 .24935 L
s
P
p
.2 0 1 r
.016 w
.52174 .44743 m
.55651 .66701 L
s
P
p
.2 0 1 r
.016 w
.52174 .44743 m
.55651 .22786 L
s
P
p
.2 0 1 r
.016 w
.52174 .44743 m
.42081 .64551 L
s
P
p
.2 0 1 r
.002 w
.76551 .56237 m
.73942 .72705 L
s
P
p
.2 0 1 r
.002 w
.76551 .56237 m
.8412 .71093 L
s
P
p
.2 0 1 r
.002 w
.78592 .52231 m
.9506 .49623 L
s
P
p
.2 0 1 r
.002 w
.78592 .52231 m
.90382 .40441 L
s
P
p
0 .4 1 r
.018 w
.76116 .53492 m
.76551 .56237 L
s
P
p
0 .4 1 r
.018 w
.76116 .53492 m
.78592 .52231 L
s
P
p
.2 0 1 r
.002 w
.41023 .24935 m
.48592 .10079 L
s
P
p
.2 0 1 r
.002 w
.41023 .24935 m
.38415 .08467 L
s
P
p
.2 0 1 r
.002 w
.37843 .28115 m
.21375 .25506 L
s
P
p
.2 0 1 r
.002 w
.37843 .28115 m
.22987 .35684 L
s
P
p
0 .4 1 r
.018 w
.40588 .2768 m
.41023 .24935 L
s
P
p
0 .4 1 r
.018 w
.40588 .2768 m
.37843 .28115 L
s
P
p
.2 0 1 r
.002 w
.65139 .65684 m
.53349 .77474 L
s
P
p
.2 0 1 r
.002 w
.65139 .65684 m
.62531 .82152 L
s
P
p
.2 0 1 r
.002 w
.69145 .63643 m
.84001 .71212 L
s
P
p
.2 0 1 r
.002 w
.69145 .63643 m
.85613 .61034 L
s
P
p
0 .4 1 r
.018 w
.66401 .63208 m
.65139 .65684 L
s
P
p
0 .4 1 r
.018 w
.66401 .63208 m
.69145 .63643 L
s
P
p
.2 0 1 r
.002 w
.54795 .19477 m
.69651 .11908 L
s
P
p
.2 0 1 r
.002 w
.54795 .19477 m
.62365 .04621 L
s
P
p
.2 0 1 r
.002 w
.50354 .20181 m
.38564 .08391 L
s
P
p
.2 0 1 r
.002 w
.50354 .20181 m
.33886 .17572 L
s
P
p
0 .4 1 r
.018 w
.5283 .21442 m
.54795 .19477 L
s
P
p
0 .4 1 r
.018 w
.5283 .21442 m
.50354 .20181 L
s
P
p
.2 0 1 r
.002 w
.50354 .66619 m
.33886 .69227 L
s
P
p
.2 0 1 r
.002 w
.50354 .66619 m
.38564 .78409 L
s
P
p
.2 0 1 r
.002 w
.54795 .67322 m
.62365 .82178 L
s
P
p
.2 0 1 r
.002 w
.54795 .67322 m
.69651 .74892 L
s
P
p
0 .4 1 r
.018 w
.5283 .65357 m
.50354 .66619 L
s
P
p
0 .4 1 r
.018 w
.5283 .65357 m
.54795 .67322 L
s
P
p
.2 0 1 r
.016 w
.56308 .434 m
.76116 .53492 L
s
P
p
.2 0 1 r
.016 w
.56308 .434 m
.40588 .2768 L
s
P
p
.2 0 1 r
.016 w
.56308 .434 m
.66401 .63208 L
s
P
p
.2 0 1 r
.016 w
.56308 .434 m
.5283 .21442 L
s
P
p
.2 0 1 r
.016 w
.56308 .434 m
.5283 .65357 L
s
P
p
1 .6 0 r
.016 w
.5 .3102 m
.43692 .434 L
s
P
p
1 .6 0 r
.016 w
.5 .3102 m
.47826 .44743 L
s
P
p
1 .6 0 r
.016 w
.5 .3102 m
.52174 .44743 L
s
P
p
1 .6 0 r
.016 w
.5 .3102 m
.56308 .434 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0158367 1.03167 0.0257918 1.03167 [
[ 0 0 0 0 ]
[ 1 1.08326 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 1.08326 L
0 1.08326 L
closepath
clip
newpath
p
P
p
1 .6 0 r
.016 w
.5 .07108 m
.06743 .92006 L
s
P
p
1 .6 0 r
.016 w
.5 .07108 m
.35094 1.01218 L
s
P
p
1 .6 0 r
.016 w
.5 .07108 m
.64906 1.01218 L
s
P
p
1 .6 0 r
.016 w
.5 .07108 m
.93257 .92006 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00935971 0.952381 [
[ 0 0 0 0 ]
[ 1 .93366 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .93366 L
0 .93366 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.49297 .72449 m
.35559 .82431 L
s
P
p
.2 0 1 r
.002 w
.49297 .72449 m
.44049 .88599 L
s
P
p
.2 0 1 r
.002 w
.58007 .69619 m
.71745 .79601 L
s
P
p
.2 0 1 r
.002 w
.58007 .69619 m
.74988 .69619 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.49297 .72449 L
s
P
p
0 .4 1 r
.018 w
.52624 .6787 m
.58007 .69619 L
s
P
p
.2 0 1 r
.002 w
.50206 .20368 m
.66356 .15121 L
s
P
p
.2 0 1 r
.002 w
.50206 .20368 m
.60188 .0663 L
s
P
p
.2 0 1 r
.002 w
.41048 .20368 m
.31067 .0663 L
s
P
p
.2 0 1 r
.002 w
.41048 .20368 m
.24898 .15121 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.50206 .20368 L
s
P
p
0 .4 1 r
.018 w
.45627 .23695 m
.41048 .20368 L
s
P
p
.2 0 1 r
.002 w
.33247 .69619 m
.16266 .69619 L
s
P
p
.2 0 1 r
.002 w
.33247 .69619 m
.19509 .79601 L
s
P
p
.2 0 1 r
.002 w
.41958 .72449 m
.47205 .88599 L
s
P
p
.2 0 1 r
.002 w
.41958 .72449 m
.55696 .82431 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.33247 .69619 L
s
P
p
0 .4 1 r
.018 w
.38631 .6787 m
.41958 .72449 L
s
P
p
.2 0 1 r
.002 w
.64596 .28019 m
.80746 .33267 L
s
P
p
.2 0 1 r
.002 w
.64596 .28019 m
.80746 .22772 L
s
P
p
.2 0 1 r
.002 w
.57186 .22636 m
.57186 .05655 L
s
P
p
.2 0 1 r
.002 w
.57186 .22636 m
.47205 .08898 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.64596 .28019 L
s
P
p
0 .4 1 r
.018 w
.58935 .28019 m
.57186 .22636 L
s
P
p
.2 0 1 r
.002 w
.21926 .57896 m
.08188 .47915 L
s
P
p
.2 0 1 r
.002 w
.21926 .57896 m
.04945 .57896 L
s
P
p
.2 0 1 r
.002 w
.2731 .65306 m
.22062 .81456 L
s
P
p
.2 0 1 r
.002 w
.2731 .65306 m
.32557 .81456 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.21926 .57896 L
s
P
p
0 .4 1 r
.018 w
.2731 .59645 m
.2731 .65306 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.52624 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.45627 .23695 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.38631 .6787 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.58935 .28019 L
s
P
p
.2 0 1 r
.016 w
.45627 .46337 m
.2731 .59645 L
s
P
p
.2 0 1 r
.002 w
.61559 .7073 m
.51578 .84468 L
s
P
p
.2 0 1 r
.002 w
.61559 .7073 m
.61559 .87711 L
s
P
p
.2 0 1 r
.002 w
.68969 .65347 m
.85119 .70594 L
s
P
p
.2 0 1 r
.002 w
.68969 .65347 m
.85119 .60099 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.61559 .7073 L
s
P
p
0 .4 1 r
.018 w
.63308 .65347 m
.68969 .65347 L
s
P
p
.2 0 1 r
.002 w
.4633 .20917 m
.60069 .10935 L
s
P
p
.2 0 1 r
.002 w
.4633 .20917 m
.51578 .04767 L
s
P
p
.2 0 1 r
.002 w
.3762 .23747 m
.23882 .13766 L
s
P
p
.2 0 1 r
.002 w
.3762 .23747 m
.20639 .23747 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.4633 .20917 L
s
P
p
0 .4 1 r
.018 w
.43003 .25496 m
.3762 .23747 L
s
P
p
.2 0 1 r
.002 w
.45421 .72998 m
.29271 .78245 L
s
P
p
.2 0 1 r
.002 w
.45421 .72998 m
.35439 .86736 L
s
P
p
.2 0 1 r
.002 w
.54579 .72998 m
.64561 .86736 L
s
P
p
.2 0 1 r
.002 w
.54579 .72998 m
.70729 .78245 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.45421 .72998 L
s
P
p
0 .4 1 r
.018 w
.5 .69671 m
.54579 .72998 L
s
P
p
.2 0 1 r
.002 w
.6238 .23747 m
.79361 .23747 L
s
P
p
.2 0 1 r
.002 w
.6238 .23747 m
.76118 .13766 L
s
P
p
.2 0 1 r
.002 w
.5367 .20917 m
.48422 .04767 L
s
P
p
.2 0 1 r
.002 w
.5367 .20917 m
.39931 .10935 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.6238 .23747 L
s
P
p
0 .4 1 r
.018 w
.56997 .25496 m
.5367 .20917 L
s
P
p
.2 0 1 r
.002 w
.31031 .65347 m
.14881 .60099 L
s
P
p
.2 0 1 r
.002 w
.31031 .65347 m
.14881 .70594 L
s
P
p
.2 0 1 r
.002 w
.38441 .7073 m
.38441 .87711 L
s
P
p
.2 0 1 r
.002 w
.38441 .7073 m
.48422 .84468 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.31031 .65347 L
s
P
p
0 .4 1 r
.018 w
.36692 .65347 m
.38441 .7073 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.63308 .65347 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.43003 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.5 .69671 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.56997 .25496 L
s
P
p
.2 0 1 r
.016 w
.5 .47029 m
.36692 .65347 L
s
P
p
.2 0 1 r
.002 w
.7269 .65306 m
.67443 .81456 L
s
P
p
.2 0 1 r
.002 w
.7269 .65306 m
.77938 .81456 L
s
P
p
.2 0 1 r
.002 w
.78074 .57896 m
.95055 .57896 L
s
P
p
.2 0 1 r
.002 w
.78074 .57896 m
.91812 .47915 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.7269 .65306 L
s
P
p
0 .4 1 r
.018 w
.7269 .59645 m
.78074 .57896 L
s
P
p
.2 0 1 r
.002 w
.42814 .22636 m
.52795 .08898 L
s
P
p
.2 0 1 r
.002 w
.42814 .22636 m
.42814 .05655 L
s
P
p
.2 0 1 r
.002 w
.35404 .28019 m
.19254 .22772 L
s
P
p
.2 0 1 r
.002 w
.35404 .28019 m
.19254 .33267 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.42814 .22636 L
s
P
p
0 .4 1 r
.018 w
.41065 .28019 m
.35404 .28019 L
s
P
p
.2 0 1 r
.002 w
.58042 .72449 m
.44304 .82431 L
s
P
p
.2 0 1 r
.002 w
.58042 .72449 m
.52795 .88599 L
s
P
p
.2 0 1 r
.002 w
.66753 .69619 m
.80491 .79601 L
s
P
p
.2 0 1 r
.002 w
.66753 .69619 m
.83734 .69619 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.58042 .72449 L
s
P
p
0 .4 1 r
.018 w
.61369 .6787 m
.66753 .69619 L
s
P
p
.2 0 1 r
.002 w
.58952 .20368 m
.75102 .15121 L
s
P
p
.2 0 1 r
.002 w
.58952 .20368 m
.68933 .0663 L
s
P
p
.2 0 1 r
.002 w
.49794 .20368 m
.39812 .0663 L
s
P
p
.2 0 1 r
.002 w
.49794 .20368 m
.33644 .15121 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.58952 .20368 L
s
P
p
0 .4 1 r
.018 w
.54373 .23695 m
.49794 .20368 L
s
P
p
.2 0 1 r
.002 w
.41993 .69619 m
.25012 .69619 L
s
P
p
.2 0 1 r
.002 w
.41993 .69619 m
.28255 .79601 L
s
P
p
.2 0 1 r
.002 w
.50703 .72449 m
.55951 .88599 L
s
P
p
.2 0 1 r
.002 w
.50703 .72449 m
.64441 .82431 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.41993 .69619 L
s
P
p
0 .4 1 r
.018 w
.47376 .6787 m
.50703 .72449 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.7269 .59645 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.41065 .28019 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.61369 .6787 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.54373 .23695 L
s
P
p
.2 0 1 r
.016 w
.54373 .46337 m
.47376 .6787 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.45627 .46337 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.5 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .32878 m
.54373 .46337 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.14698 .59845 L
s
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.17503 .6848 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.41462 .76264 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.48806 .70928 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.29387 .59845 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.36922 .62294 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .28399 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .1932 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.50096 .04513 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.41462 .07319 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.56505 .2386 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.50096 .19203 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.0771 .4107 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.04905 .49704 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.19712 .70084 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.28791 .70084 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.19594 .49704 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.24251 .56114 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.7132 .48415 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.76656 .4107 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.68871 .17112 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.60237 .14306 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.62685 .36531 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.60237 .28996 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.13093 .21773 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.05749 .27109 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.05749 .52301 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.13093 .57637 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .35744 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .43666 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.34044 .58332 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.51609 .2386 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.24251 .51217 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.58724 .33653 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.20511 .39705 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.37508 .75375 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.44852 .80711 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.6881 .72927 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.71616 .64292 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.49392 .66741 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.56926 .64292 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.64149 .17149 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.58813 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.33622 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.28285 .17149 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.50179 .21688 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.42256 .21688 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.20819 .64292 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.23624 .72927 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.47582 .80711 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.54927 .75375 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.35508 .64292 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.43043 .66741 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .32846 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .23767 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.56216 .0896 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.47582 .11766 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.62626 .28307 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.56216 .2365 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.13831 .45517 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.11026 .54151 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.25833 .74531 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.34911 .74531 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.25715 .54151 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.30372 .60561 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5227 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.46217 .24566 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.40165 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5773 .28307 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.30372 .55664 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.65089 .74531 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.74167 .74531 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.88974 .54151 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.86169 .45517 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.69628 .60561 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.74285 .54151 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.52418 .11766 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.43784 .0896 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .23767 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .32846 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.43784 .2365 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.37374 .28307 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.45073 .75375 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.52418 .80711 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.76376 .72927 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.79181 .64292 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.56957 .66741 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.64492 .64292 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.71715 .17149 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.66378 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.41187 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.35851 .17149 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.57744 .21688 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.49821 .21688 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.28384 .64292 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.3119 .72927 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.55148 .80711 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.62492 .75375 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.43074 .64292 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.50608 .66741 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.69628 .55664 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4227 .28307 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.59835 .62779 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.53783 .24566 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4773 .62779 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.86907 .57637 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.94251 .52301 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.94251 .27109 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.86907 .21773 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .43666 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .35744 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.39763 .14306 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.31129 .17112 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.23344 .4107 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.2868 .48415 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.39763 .28996 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.37315 .36531 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.71209 .70084 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.80288 .70084 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.95095 .49704 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.9229 .4107 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.75749 .56114 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.80406 .49704 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.58538 .07319 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.49904 .04513 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .1932 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .28399 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.49904 .19203 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.43495 .2386 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.51194 .70928 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.58538 .76264 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.82497 .6848 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.85302 .59845 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.63078 .62294 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.70613 .59845 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.79489 .39705 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.41276 .33653 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.75749 .51217 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.48391 .2386 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.65956 .58332 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.40097 .39705 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.46217 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.53783 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0250849 0.952381 [
[ 0 0 0 0 ]
[ 1 .90221 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .90221 L
0 .90221 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.44645 .69563 m
.30176 .76936 L
s
P
p
.2 0 1 r
.002 w
.44645 .69563 m
.37273 .84032 L
s
P
p
.2 0 1 r
.002 w
.53295 .68193 m
.64778 .79676 L
s
P
p
.2 0 1 r
.002 w
.53295 .68193 m
.69334 .70734 L
s
P
p
0 .4 1 r
.018 w
.48472 .65736 m
.44645 .69563 L
s
P
p
0 .4 1 r
.018 w
.48472 .65736 m
.53295 .68193 L
s
P
p
.2 0 1 r
.002 w
.53295 .20509 m
.69334 .17969 L
s
P
p
.2 0 1 r
.002 w
.53295 .20509 m
.64778 .09027 L
s
P
p
.2 0 1 r
.002 w
.44645 .19139 m
.37273 .0467 L
s
P
p
.2 0 1 r
.002 w
.44645 .19139 m
.30176 .11767 L
s
P
p
0 .4 1 r
.018 w
.48472 .22966 m
.53295 .20509 L
s
P
p
0 .4 1 r
.018 w
.48472 .22966 m
.44645 .19139 L
s
P
p
.2 0 1 r
.002 w
.2991 .64489 m
.13871 .61949 L
s
P
p
.2 0 1 r
.002 w
.2991 .64489 m
.15441 .71862 L
s
P
p
.2 0 1 r
.002 w
.37713 .68466 m
.40253 .84504 L
s
P
p
.2 0 1 r
.002 w
.37713 .68466 m
.49195 .79948 L
s
P
p
0 .4 1 r
.018 w
.35256 .63643 m
.2991 .64489 L
s
P
p
0 .4 1 r
.018 w
.35256 .63643 m
.37713 .68466 L
s
P
p
.2 0 1 r
.002 w
.65741 .29888 m
.8021 .3726 L
s
P
p
.2 0 1 r
.002 w
.65741 .29888 m
.8178 .27348 L
s
P
p
.2 0 1 r
.002 w
.59548 .23695 m
.62089 .07657 L
s
P
p
.2 0 1 r
.002 w
.59548 .23695 m
.52176 .09226 L
s
P
p
0 .4 1 r
.018 w
.60395 .29041 m
.65741 .29888 L
s
P
p
0 .4 1 r
.018 w
.60395 .29041 m
.59548 .23695 L
s
P
p
.2 0 1 r
.002 w
.20971 .51723 m
.09488 .40241 L
s
P
p
.2 0 1 r
.002 w
.20971 .51723 m
.04932 .49183 L
s
P
p
.2 0 1 r
.002 w
.24947 .59527 m
.17575 .73996 L
s
P
p
.2 0 1 r
.002 w
.24947 .59527 m
.27487 .75566 L
s
P
p
0 .4 1 r
.018 w
.25794 .54181 m
.20971 .51723 L
s
P
p
0 .4 1 r
.018 w
.25794 .54181 m
.24947 .59527 L
s
P
p
.2 0 1 r
.016 w
.45085 .44351 m
.48472 .65736 L
s
P
p
.2 0 1 r
.016 w
.45085 .44351 m
.48472 .22966 L
s
P
p
.2 0 1 r
.016 w
.45085 .44351 m
.35256 .63643 L
s
P
p
.2 0 1 r
.016 w
.45085 .44351 m
.60395 .29041 L
s
P
p
.2 0 1 r
.016 w
.45085 .44351 m
.25794 .54181 L
s
P
p
.2 0 1 r
.002 w
.55679 .69512 m
.44196 .80995 L
s
P
p
.2 0 1 r
.002 w
.55679 .69512 m
.53138 .85551 L
s
P
p
.2 0 1 r
.002 w
.63482 .65536 m
.77951 .72908 L
s
P
p
.2 0 1 r
.002 w
.63482 .65536 m
.79521 .62996 L
s
P
p
0 .4 1 r
.018 w
.58136 .64689 m
.55679 .69512 L
s
P
p
0 .4 1 r
.018 w
.58136 .64689 m
.63482 .65536 L
s
P
p
.2 0 1 r
.002 w
.48747 .20186 m
.63216 .12813 L
s
P
p
.2 0 1 r
.002 w
.48747 .20186 m
.56119 .05717 L
s
P
p
.2 0 1 r
.002 w
.40097 .21556 m
.28614 .10073 L
s
P
p
.2 0 1 r
.002 w
.40097 .21556 m
.24058 .19015 L
s
P
p
0 .4 1 r
.018 w
.44919 .24013 m
.48747 .20186 L
s
P
p
0 .4 1 r
.018 w
.44919 .24013 m
.40097 .21556 L
s
P
p
.2 0 1 r
.002 w
.40097 .6924 m
.24058 .7178 L
s
P
p
.2 0 1 r
.002 w
.40097 .6924 m
.28614 .80722 L
s
P
p
.2 0 1 r
.002 w
.48747 .7061 m
.56119 .85079 L
s
P
p
.2 0 1 r
.002 w
.48747 .7061 m
.63216 .77982 L
s
P
p
0 .4 1 r
.018 w
.44919 .66783 m
.40097 .6924 L
s
P
p
0 .4 1 r
.018 w
.44919 .66783 m
.48747 .7061 L
s
P
p
.2 0 1 r
.002 w
.63482 .2526 m
.79521 .278 L
s
P
p
.2 0 1 r
.002 w
.63482 .2526 m
.77951 .17887 L
s
P
p
.2 0 1 r
.002 w
.55679 .21283 m
.53138 .05245 L
s
P
p
.2 0 1 r
.002 w
.55679 .21283 m
.44196 .09801 L
s
P
p
0 .4 1 r
.018 w
.58136 .26106 m
.63482 .2526 L
s
P
p
0 .4 1 r
.018 w
.58136 .26106 m
.55679 .21283 L
s
P
p
.2 0 1 r
.002 w
.2765 .59861 m
.13182 .52489 L
s
P
p
.2 0 1 r
.002 w
.2765 .59861 m
.11612 .62401 L
s
P
p
.2 0 1 r
.002 w
.33843 .66054 m
.31303 .82092 L
s
P
p
.2 0 1 r
.002 w
.33843 .66054 m
.41216 .80523 L
s
P
p
0 .4 1 r
.018 w
.32997 .60708 m
.2765 .59861 L
s
P
p
0 .4 1 r
.018 w
.32997 .60708 m
.33843 .66054 L
s
P
p
.2 0 1 r
.016 w
.48306 .45398 m
.58136 .64689 L
s
P
p
.2 0 1 r
.016 w
.48306 .45398 m
.44919 .24013 L
s
P
p
.2 0 1 r
.016 w
.48306 .45398 m
.44919 .66783 L
s
P
p
.2 0 1 r
.016 w
.48306 .45398 m
.58136 .26106 L
s
P
p
.2 0 1 r
.016 w
.48306 .45398 m
.32997 .60708 L
s
P
p
.2 0 1 r
.002 w
.66157 .66054 m
.58784 .80523 L
s
P
p
.2 0 1 r
.002 w
.66157 .66054 m
.68697 .82092 L
s
P
p
.2 0 1 r
.002 w
.7235 .59861 m
.88388 .62401 L
s
P
p
.2 0 1 r
.002 w
.7235 .59861 m
.86818 .52489 L
s
P
p
0 .4 1 r
.018 w
.67003 .60708 m
.66157 .66054 L
s
P
p
0 .4 1 r
.018 w
.67003 .60708 m
.7235 .59861 L
s
P
p
.2 0 1 r
.002 w
.44321 .21283 m
.55804 .09801 L
s
P
p
.2 0 1 r
.002 w
.44321 .21283 m
.46862 .05245 L
s
P
p
.2 0 1 r
.002 w
.36518 .2526 m
.22049 .17887 L
s
P
p
.2 0 1 r
.002 w
.36518 .2526 m
.20479 .278 L
s
P
p
0 .4 1 r
.018 w
.41864 .26106 m
.44321 .21283 L
s
P
p
0 .4 1 r
.018 w
.41864 .26106 m
.36518 .2526 L
s
P
p
.2 0 1 r
.002 w
.51253 .7061 m
.36784 .77982 L
s
P
p
.2 0 1 r
.002 w
.51253 .7061 m
.43881 .85079 L
s
P
p
.2 0 1 r
.002 w
.59903 .6924 m
.71386 .80722 L
s
P
p
.2 0 1 r
.002 w
.59903 .6924 m
.75942 .7178 L
s
P
p
0 .4 1 r
.018 w
.55081 .66783 m
.51253 .7061 L
s
P
p
0 .4 1 r
.018 w
.55081 .66783 m
.59903 .6924 L
s
P
p
.2 0 1 r
.002 w
.59903 .21556 m
.75942 .19015 L
s
P
p
.2 0 1 r
.002 w
.59903 .21556 m
.71386 .10073 L
s
P
p
.2 0 1 r
.002 w
.51253 .20186 m
.43881 .05717 L
s
P
p
.2 0 1 r
.002 w
.51253 .20186 m
.36784 .12813 L
s
P
p
0 .4 1 r
.018 w
.55081 .24013 m
.59903 .21556 L
s
P
p
0 .4 1 r
.018 w
.55081 .24013 m
.51253 .20186 L
s
P
p
.2 0 1 r
.002 w
.36518 .65536 m
.20479 .62996 L
s
P
p
.2 0 1 r
.002 w
.36518 .65536 m
.22049 .72908 L
s
P
p
.2 0 1 r
.002 w
.44321 .69512 m
.46862 .85551 L
s
P
p
.2 0 1 r
.002 w
.44321 .69512 m
.55804 .80995 L
s
P
p
0 .4 1 r
.018 w
.41864 .64689 m
.36518 .65536 L
s
P
p
0 .4 1 r
.018 w
.41864 .64689 m
.44321 .69512 L
s
P
p
.2 0 1 r
.016 w
.51694 .45398 m
.67003 .60708 L
s
P
p
.2 0 1 r
.016 w
.51694 .45398 m
.41864 .26106 L
s
P
p
.2 0 1 r
.016 w
.51694 .45398 m
.55081 .66783 L
s
P
p
.2 0 1 r
.016 w
.51694 .45398 m
.55081 .24013 L
s
P
p
.2 0 1 r
.016 w
.51694 .45398 m
.41864 .64689 L
s
P
p
.2 0 1 r
.002 w
.75053 .59527 m
.72513 .75566 L
s
P
p
.2 0 1 r
.002 w
.75053 .59527 m
.82425 .73996 L
s
P
p
.2 0 1 r
.002 w
.79029 .51723 m
.95068 .49183 L
s
P
p
.2 0 1 r
.002 w
.79029 .51723 m
.90512 .40241 L
s
P
p
0 .4 1 r
.018 w
.74206 .54181 m
.75053 .59527 L
s
P
p
0 .4 1 r
.018 w
.74206 .54181 m
.79029 .51723 L
s
P
p
.2 0 1 r
.002 w
.40452 .23695 m
.47824 .09226 L
s
P
p
.2 0 1 r
.002 w
.40452 .23695 m
.37911 .07657 L
s
P
p
.2 0 1 r
.002 w
.34259 .29888 m
.1822 .27348 L
s
P
p
.2 0 1 r
.002 w
.34259 .29888 m
.1979 .3726 L
s
P
p
0 .4 1 r
.018 w
.39605 .29041 m
.40452 .23695 L
s
P
p
0 .4 1 r
.018 w
.39605 .29041 m
.34259 .29888 L
s
P
p
.2 0 1 r
.002 w
.62287 .68466 m
.50805 .79948 L
s
P
p
.2 0 1 r
.002 w
.62287 .68466 m
.59747 .84504 L
s
P
p
.2 0 1 r
.002 w
.7009 .64489 m
.84559 .71862 L
s
P
p
.2 0 1 r
.002 w
.7009 .64489 m
.86129 .61949 L
s
P
p
0 .4 1 r
.018 w
.64744 .63643 m
.62287 .68466 L
s
P
p
0 .4 1 r
.018 w
.64744 .63643 m
.7009 .64489 L
s
P
p
.2 0 1 r
.002 w
.55355 .19139 m
.69824 .11767 L
s
P
p
.2 0 1 r
.002 w
.55355 .19139 m
.62727 .0467 L
s
P
p
.2 0 1 r
.002 w
.46705 .20509 m
.35222 .09027 L
s
P
p
.2 0 1 r
.002 w
.46705 .20509 m
.30666 .17969 L
s
P
p
0 .4 1 r
.018 w
.51528 .22966 m
.55355 .19139 L
s
P
p
0 .4 1 r
.018 w
.51528 .22966 m
.46705 .20509 L
s
P
p
.2 0 1 r
.002 w
.46705 .68193 m
.30666 .70734 L
s
P
p
.2 0 1 r
.002 w
.46705 .68193 m
.35222 .79676 L
s
P
p
.2 0 1 r
.002 w
.55355 .69563 m
.62727 .84032 L
s
P
p
.2 0 1 r
.002 w
.55355 .69563 m
.69824 .76936 L
s
P
p
0 .4 1 r
.018 w
.51528 .65736 m
.46705 .68193 L
s
P
p
0 .4 1 r
.018 w
.51528 .65736 m
.55355 .69563 L
s
P
p
.2 0 1 r
.016 w
.54915 .44351 m
.74206 .54181 L
s
P
p
.2 0 1 r
.016 w
.54915 .44351 m
.39605 .29041 L
s
P
p
.2 0 1 r
.016 w
.54915 .44351 m
.64744 .63643 L
s
P
p
.2 0 1 r
.016 w
.54915 .44351 m
.51528 .22966 L
s
P
p
.2 0 1 r
.016 w
.54915 .44351 m
.51528 .65736 L
s
P
p
1 .6 0 r
.016 w
.5 .34705 m
.45085 .44351 L
s
P
p
1 .6 0 r
.016 w
.5 .34705 m
.48306 .45398 L
s
P
p
1 .6 0 r
.016 w
.5 .34705 m
.51694 .45398 L
s
P
p
1 .6 0 r
.016 w
.5 .34705 m
.54915 .44351 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.014 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.014 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.014 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.014 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.114296 0.952381 [
[ 0 0 0 0 ]
[ 1 .72379 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .72379 L
0 .72379 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.24314 .43023 m
.04991 .39963 L
s
P
p
.2 0 1 r
.002 w
.24314 .43023 m
.06882 .51906 L
s
P
p
.2 0 1 r
.002 w
.33716 .47814 m
.36777 .67138 L
s
P
p
.2 0 1 r
.002 w
.33716 .47814 m
.4755 .61648 L
s
P
p
0 .4 1 r
.018 w
.30756 .42003 m
.24314 .43023 L
s
P
p
0 .4 1 r
.018 w
.30756 .42003 m
.33716 .47814 L
s
P
p
.2 0 1 r
.016 w
.42598 .18761 m
.30756 .42003 L
s
P
p
.2 0 1 r
.002 w
.37558 .49062 m
.18235 .52123 L
s
P
p
.2 0 1 r
.002 w
.37558 .49062 m
.23724 .62896 L
s
P
p
.2 0 1 r
.002 w
.4798 .50713 m
.56862 .68145 L
s
P
p
.2 0 1 r
.002 w
.4798 .50713 m
.65412 .59595 L
s
P
p
0 .4 1 r
.018 w
.43369 .46102 m
.37558 .49062 L
s
P
p
0 .4 1 r
.018 w
.43369 .46102 m
.4798 .50713 L
s
P
p
.2 0 1 r
.016 w
.4745 .20337 m
.43369 .46102 L
s
P
p
.2 0 1 r
.002 w
.5202 .50713 m
.34588 .59595 L
s
P
p
.2 0 1 r
.002 w
.5202 .50713 m
.43138 .68145 L
s
P
p
.2 0 1 r
.002 w
.62442 .49062 m
.76276 .62896 L
s
P
p
.2 0 1 r
.002 w
.62442 .49062 m
.81765 .52123 L
s
P
p
0 .4 1 r
.018 w
.56631 .46102 m
.5202 .50713 L
s
P
p
0 .4 1 r
.018 w
.56631 .46102 m
.62442 .49062 L
s
P
p
.2 0 1 r
.016 w
.5255 .20337 m
.56631 .46102 L
s
P
p
.2 0 1 r
.002 w
.66284 .47814 m
.5245 .61648 L
s
P
p
.2 0 1 r
.002 w
.66284 .47814 m
.63223 .67138 L
s
P
p
.2 0 1 r
.002 w
.75686 .43023 m
.93118 .51906 L
s
P
p
.2 0 1 r
.002 w
.75686 .43023 m
.95009 .39963 L
s
P
p
0 .4 1 r
.018 w
.69244 .42003 m
.66284 .47814 L
s
P
p
0 .4 1 r
.018 w
.69244 .42003 m
.75686 .43023 L
s
P
p
.2 0 1 r
.016 w
.57402 .18761 m
.69244 .42003 L
s
P
p
1 .6 0 r
.016 w
.5 .04234 m
.42598 .18761 L
s
P
p
1 .6 0 r
.016 w
.5 .04234 m
.4745 .20337 L
s
P
p
1 .6 0 r
.016 w
.5 .04234 m
.5255 .20337 L
s
P
p
1 .6 0 r
.016 w
.5 .04234 m
.57402 .18761 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`0001<000=<00001@000d`0000H0003C00000D000=<00006@0014`004`20003C00003`0
00=<00001@000d`0000H0003C00000D000=<000060000lH000050003aP000180000C00A=00<0CDd0
0TdJ00A=00<0CDd00TdH0003C@0000M=00<0CDd05`000dd0C@06C@0304d001P014d00`1=C@02CAX0
14d00`1=C@02CAX01<H00`36aP02aQ@0000@0003C00000U<0P000d`0000B0003C00000U<0P000d`0
000C009<00<0C4`01D`00`1<000F00e<5@0014`0C007C00404`0C1@000=<00002D`20003C0000180
00?600002LH20003aP0000l0000@009=00@0CDd00dd00`1=C@02CAD00Td0101=C@03C@0304e=009=
50000dd0000;C@8000==00004@02C@0304e=00M=00<0CDd05002C@0404e=00==00@0CDd00TdE00A=
00D0CDe=0002C@0304e=01D01<H01@36a/H000;600<0a/H04@0001802d`H00]<5@0AC1803T`00`1<
C00E00]<600;C1P02lHC00003P08C@C61TdA019=5005C@;600==aTd00ddC009=00<0CDd00dd4aPA=
00<0CDd04009C@0404g600I=4@07C@C61ddA01;63`00010014`2aP05C01<C<H00d`E00M<00<0C4`0
14`C00I<0lH0101<a/H6C1800d`01@36aT`0009<00?604`00T`D00A<00G6C<K6C002aPA<5@03C0?6
00@0C<K614`E00G600A<04a<1LHA00003@06C@;60Td00`1=C@02aPE=3`0:C@0304e=00M=4@04C@;6
0Td00`1=C@02aPA=4@05C@;60Td00`1=C@02aPE=4`02C@?600A=04e=0/H3CA801Dd2aP9=00<0CDd0
0/H5CA001lH2C@0304e=00S63P0000h014`2aP=<00D0C4a<aP02C00304a<01002D`00`1<C004C003
04a<01400d`2aP=<00D0C4a<aP03C1401D`2aP=<00@0C4a<0/H5C0h01T`01LI<C4`000=<00?6C4`0
14`?00=<00<0C<H00d`0101<C4`2aP04C01<C1000lH00`36aP03C00404a<C0K63`00010000==0000
0P02C@034De=00<00TdD0003C@0000800Td00a5=C@03009=4@03C@8000==00000Td00a5=C@020003
C@00009=4@02C@@00Td00a5=C@04009=4`02C@<00Td00a5=C@03009=5002C@<00Td00a5=C@040003
C@0001800/H3009=00<ACDd010000lH0000?00003`000d`00003009<00<AC4`01@000d`0000@0003
C00000<00T`00a5<C0050003C000018000A<00000T`00a5<C0030003C000014000=<00001002C003
4Da<00H000=<00003`000d`00003009<00<AC4`01@000d`0000@0003C00000<00T`00a5<C0050003
C000010000?600000`02C0034Da<00D000?600003P0000X000E=0000C@060005CA4A4Dd01P001Dd0
001=00P000E=0000C@060005CA4A4Dd01P001Dd0001=00T000==00000P000dd000020005CA4A4Dd0
10000dd000020003C@00018000E=4A4AC@0C0005C@0004d01P001DdA4A5=00H000E=0000C@080005
C@0004d01P001DdA4A5=00H000E=0000C@080005aP000<H01P001DdA4A5=00H000G60000aP0;0000
2P000d`000080005C15<4D`02@000d`000080003C00000L000E<4D`AC0090003C00000P000E<0000
C0050005C15<4D`01@001D`0001<00P00T`:0005C15<4D`02P02C0P000=<00001`001D`AC15<00T0
00=<000020000d`000070005C15<4D`02@000d`000080003aP0000L000E<4D`AC0090003aP0000X0
000;0003C@0000H000A=4A400Q400dd000050003C@0000X000==00001@0014dA4@024@03C@0000D0
00==00001`02C@0304d000H000A=4A400Q400dd000050004C@1=C@H00dd80004CA4A008A00==0000
1@04C@T000==00001@0014dA4@024@03C@0000D000==00002P000dd000050004CA4A008A00==0000
1@000dd0000:0003aP0000D000A=4A400Q400dd000050003aP0000/0000900A<1@02C00404a<009<
00<0C4`010000d`0C002C0H01D`4009<00@0C4`00T`00`1<C0040003C01<009<2003C0@00T`0101<
C002C00304a<00@00d`:009<1@02C00404a<009<00<0C4`01003C0P01D`4009<00@0C4`00T`00`1<
C0040003C01<009<1P05C0@00T`0101<C002C00304a<00@000=<04`00T`600G61002C00404a<009<
00<0C4`010000lH0aP02aPX0000;009=0/H00`1=C@0200M=0P02C@040<I=C@/014d00`1=C@0200M=
0P02C@0404e=C@`00Td01<H0CDd200M=0P02C@030<I=009=3002aP0304e=00801dd2009=00<0aP00
3003C@;600@0C@001dd20004C@36aP==2P03C@04aP1=C@801dd2009=00<0aTd00Td;00?600<0CDd0
0P07C@800Td00`36aP02aP`0000=00=<0`08C0@00T`?00=<1007C0@00T`;00=<0P02C0@01d`4009<
0`02C0P00T`20003C00000801d`40003C000009<3004C0802D`200A<3P03C0@01d`400=<3`000lI<
000300M<10000dc6aP0>00003`000dd00002C@0404e=009=00<0C@000P000lH0000@0006C@0004d0
0Td01@1=C@1=00<000==00003005C@<000E=04e=0002C@0704d004g60003C@`00dd30005C@1=C@00
0Td00`1=00020003aTe=00l00Td2aP0304d0009=00H0CDd0C@03aP9=40001Td0001=009=00D0CDd0
C@030003aP00010000K60000C@02C@0504e=04d00`000lH0000>00002`05C005aT`0C0000T`0101<
C002C0;61D`:00U<00@0C4`00T`00`1<C007C0d01T`0101<C002C00304a<00;60T`=00E<0/H2C004
04a<009<00<0C4`00/H5C0X024`2009<00<0C4`00P000d`0C005C0X01D`2aP9<00@0C4`00T`00`1<
C002aPE<2P07aP9<00@0C4`00T`00`1<C007aP`0000>00E=00G6CDe=aP02C@;600==aTd00Td@01==
3P04C@03aTe=00A=00?6CDd00/H00dg6aP03C@`024d2aP9=00?6CDd00/H00dg6aP05C@d00dd01LI=
a/I=00;60Td4aP==4005C@;60Td00lI=C@02aP03CLK6009=4007aP9=00?6CDd00/H00dg6aP02aPl0
000=009<00<0C4`00/H2C003aP36009<0/H5C0h00T`00`1<C005C00304a<00E<00<0C4`03008C006
aTa<aP360T`2aPA<00<0C4`02P09C006aTc60<I<0/H5C00304a<00`02D`2aP04C<I<aPI<3P02C003
04a<00;60T`00lH0aP02C0;60T`00`1<C00>00;600<0a/H01LH00`36C005aP030<K600h0000<009=
00<0CDd00dd2aP04CLI=aPM=00<0C@002`02C@0304e=011=00<0C@002P000dd00007C@05aTg6CLH0
1dd20003C@0000/01dd01LI=aP3600M=3P000dd0C@0BC@0304d000/000==04d01Dd2aP9=0/H7C@03
04d000/000?60<H04LH00`36aP0=0000300014`0C00=C00504a<04`03@0014`0C00=C00504a<04`0
3`000d`0C00>C00304`000h000A<04`03D`0101<04`>009<00<0C4`03D`00`1<C00>0005C01<C000
3D`00`1<C00>0005aP36aP003LH010360<H=00004002C@0304e=00M=00<0C@005002C@0304e=00M=
00<0C@004@0014d0C@0=C@0404d0CA4000==04d02Td00`1=000C009=00<0CDd00Td00`1=C@02C@03
04e=01D000==04d024d00`1=C@0E0003aP3600S600<0a/H04@0001000T`00`1<C002C00304a<009<
00<0C4`05002C00304a<009<00<0C4`00T`00`1<C00D00I<00<0C0001T`E00A<00D0C4a<0004C1D0
0d`00`1<C005C00404a<C1@00T`00`1<C002C00304a<009<00<0C4`05002aP030<K600;600<0a/H0
0/H00`36aP0A00004@0014d0C@02C@0304e=009=00<0C@005`04C@0304e=009=600<CAP000==04d0
1Td00`1=000F0003C@1=00==00<0CDd00Td00`1=000G00A=00<0CDd00TdH0003aP3600?600<0a/H0
0/H00`36000A00005P000d`0C00P0003C01<01h00T`00`1<0002C44000=<04`080000d`0C00P0003
aP3601L0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0000C0003C000009<
0P000d`0003U00004`000dd00002C@8000==00006@000dd000050003C@0001P000==00001@000dd0
000H0003C@0000D000==000060001Dd0CDd0009=00<0C@006P000dd000030003C@0001T000==0000
1@000dd0000B00004@001D`004`0009<00<0C0000P000d`0000F0006C01<C01<0P000d`0000H00A<
00<0C4`00T`J00A<00<0C4`00T`J0005C01<C0000T`00`1<000J00=<00@0C4a<6`001T`004`0C080
00=<00004P0001400Td200E=0P02CAD01dd00`1=0004CAD000==00002Dd20003C@00018000==0000
2Dd20003C@0001800Td0201=C@1=04d00Td00`1=C@0E00I=00<0CDd014dF0003C@1=00Q=00<0C@00
4@0000l00T`200E<00@0C4a<0P02C1D00d`01@1<C4`000=<5P02C00404a<00=<00<0C4`00T`E009<
00@0C4`00d`00`1<C002C1H000=<04`024`00`1<000E0004C01<00E<00@0C01<5P0=C180000?00A=
00<0C@000lH00`1=0004CA400Td00`1=C@0:C@0304e=01D02ddH00]=60000dd0C@06C@0304d001@0
0Td00`1=C@04C@0304e=009=00<0CDd04P02C@0304e=00U=00<0CDd0400001<00T`5aP9<5P07C0G6
1D`A00Q<0/H00dc6C005C14024`2aP03C<I<00E<4@02C0800d`2aP030<K600=<0P02C1<01T`3aPA<
5008C003aTc600I<400001400dd2aP==0/H3CAL000I=0<K6C@02C@03aP1=01H014d3aP0404g6aP==
5@04C@?600@0a/K60ddE00==00H0a/I=04d2aP0404e=CAH000==0<H00/H01P1=a/H0CAT00dd01LH0
CDg6009=4`0000h00d`500=<1@03C0l01T`2aP9<00D0C4a<aP05C0l01T`2aP9<00<0C4`00/H5C100
1D`4aP030<K600;61D`E0005aP1<C0000T`00`36000D00E<0/H2C00304a<00;61D`@00I<00C6C4`0
2D`?00005P02CA`000==a/H00dd0101=CDd2aP03C@00014014d2aP==00D0CDe=aP02C@0304e=0100
14d5aP030<K600;60Td00`1=C@0F00==00@0CDe=6P000dg6C@02C@0504e=CLH00TdC00==00<0CLH0
0dd01@1=CDg600E=3`0001L000<A00006002C0@00T`00a5<C004009<4`000d`00002009<00<AC4`0
0`02C1@000=<00000P02aP034LK600<00T`I009<00<AC4`06003C0<00T`00a5<C00300=<4P03C0<0
0T`00a5<C00300=<400001H000==4Dd060000dd00004009=00<ACDd01P000dd0000?0003C@0000<0
0Td00a5=C@050003C@00010000==00000`02aP034LK600D000==00005P02C@034De=01L000==0000
1002C@034De=00H000==00003P000dd00004009=00<ACDd01P000dd0000=00005P034Al000E<4A4A
C00C0005C00004`01P001D`A4A5<00H000E<0000C0080005C00004`01P001LHA4A7600H000E<0000
C00C0005C14A4D`07P001D`A4A5<01h000E<4A4AC00F00005P000a404@0D0003C@0000P000E=4DdA
C@0:0003C@0000L000==00001`001DdACA5=00T000==000020000dd000070005aQ764LH02@000dd0
000B0005CA5=4Dd04`02C@T000E=4DdAC@09009=20000dd000080005CA5=4Dd02P000dd000090000
5@024@03014A01@000=<00001P0014`A4@024@03C00000H000=<00002@000d`000050004C14A008A
00=<00001@000d`0000:0003C00000D000C64A400Q400lH000050003C000018000A<4A400Q400d`0
000B0003C00000D000A<4A400Q400d`000050003C00000T000=<00001P0014`A4@024@03C00000H0
00=<00002P0001D00Td00`1=C@0E0003C@0000<00Td0101=C@02C@0304e=00D000==00001`05C@@0
0Td0101=C@02C@0304e=00@000==04d00Td600E=1002aP040<K600;600<0a/H010000dd0C@02C@l0
0Td0101=C@02C@0304e=01<000==00000P02C@0404e=009=00<0CDd010000dd0000;0003C@0000<0
0Td0101=C@02C@0304e=00D000==00002`0001@000M<04`0C01<014014`2aP0304a<00801d`2009<
00<0a/H014`800=<00C604a<0P07C0800T`01036C4`;00=<00C60<K60P07aP800/H00`36C002C0l0
0T`200M<0P02C0d01D`01<H0C4`200M<0P02C0030<I<00A<1P05C0800T`200M<0P02C08000=<04`0
0T`:000050001dd0C@1=04d04`02C@8000A=00002Dd30004C@1=C@d00dd400M=1002C@l00Td00lH0
000200O610000lI=C@0@0003C@0000801dd40003C@0000`00Td20003C@0000801dd40003C@00009=
2`02C@03aTd000802Dd30004CLI=C@d0000C0006C000C01<0P000d`0000B00=<0P02C00404a<009<
00<0C4`00P000lI<000@0006C00004`00T`01@1<C01<00<000?6000040001T`0003600;600D0a/H0
aP030003aP0000X01D`00lH000020005C01<C0000T`00`1<00030003aTa<00=<2P03C0<000E<04a<
0002C00304`0008000?6C4`03`02C0800T`0101<C002C00304a<008000=<aP003P00018000A=001=
0`0014d004dD009=00G6C@1=0002C@0704e=04d0C@02aP9=3005C@;60Td0101=C@02C@0304e=00;6
1Dd:00E=1<H01036aP02aP030<K600;61Dd;0003C@00008000C6CDd00Td0101=C@02C@03aP000080
00==00003002C@;60Td0101=C@02C@0304e=00;60dd=00A=00G6C@1=0002C@0804e=04d0CLH4C@d0
000:00A<100014`004`30004C000C0@014`900Q<0P02C00304a<008000=<a/H01D`=00E<0/H2C003
aTa<00;600=<a/H00T`@00E<3<H2C0d000Q<0000C<H0C0800T`00`1<C0020004C036C0<000=<0000
2006C0;600D0aTa<aP02C003aP1<00;61D`:00Q<0P02C00304a<008000=<aT`01D`<00003P0014g6
aTd30005C@0004d00`0014g6CDd?009=0P000lI=aP03C@04aTe=C@;600A=04e=3`02C@0304e=00;6
0Td00lH0aP02C@;60Td00`1=C@0>009=00<0CDd00/H2C@05aP36aTd00/H2C@0304e=00/000==0000
0Td00`1=aP0300;600<0aTd00`000lI=0002C@8000==00002@06C@04aP36C@;600A=0<K61Dd>00==
00D0CDe=aP02C@03aTg6009=00?6C@000dd>00003002C0@000C60<I<0P001LI<aP3600<00T`>0003
C01<00I<00K6C<K6C<H4C00304`000`00T`00`1<C003C0;600A<aTc61d`00`1<000;0003C01<00E<
0/H014c6C<H7C00304`000/000Q<001<04`0C0?600T0a/K6C01<04`00P000d`0000:0005C01<C000
1D`01<I<a/H4C00304`0009<3@000d`0C008C003aTc600E<00<0C0003@0000/000==00000`02C@05
aP00CLH00`04C@<00Td;0003C@1=00i=00<0CDd00P000dd0000:0004C@1=00e=00D0CDd0C@0>009=
00<0CDd02dd01@1=C@1=010014d02@1=aTd0CLI=0004CA0000==04d01dd00`1=C@06C@8000==0000
2P001Dd004d000e=00D0C@00C@0=00002P0014`00003C00304`000M<00@0C0000T`30003C00000d0
00=<04`014`00`1<C003C1D00T`00`1<C007C00304`001@00T`00`1<C007C00304`001<00d`200M<
0P03C18000=<04`00T`00`1<C003C00604a<C01<500=C180000A00==00D0CDe=0002C@0304e=01D0
0Td00`1=C@04C@0504e=04d05@02C@0304e=009=00<0CDd00Td00`1=C@0D009=00<0CDd00Td00`1=
C@02C@0304e=018000==04d00P04C@0304e=009=0P000dd0C@0B00m=5@000dd0C@08C@0304d00140
000@0004C01<C08000=<04`00P0014`004`E0003C01<00800d`20003C01<01H000=<04`00d`00`1<
C002C00304`001D000=<04`00d`00`1<C002C00304`001@000=<00000T`01@1<04`0009<0P000d`0
000C0003C01<00Q<00<0C0005`000d`00003C08000=<00004P0000l000E=0000C@020003C@1=0080
00E=0000C@0H009=00<0C@007`000dd0C@0P0003C@1=01d000E=04e=0002C@0304d001/00Td00`1=
C@0O0003C@1=01L0000C0003C01<00<000=<04`0QP000d`0C01M0000o`030000o`030000o`030000
o`030000o`030000o`0300005`000a40003X00005`000a40000J0003C00000A<00<0C4`00P000d`0
000i0006C000C01<0P000d`0000H0003C00000D000=<000060000d`000050003C00003D0000F00<A
6`000dd00007C@8000==00006P000dd0000L0005C@1=C@000Td00`1=000I00A=00<0CDd00TdJ00A=
00<0CDd00Tdg00005P034A`000=<04`01T`00`1<000I009<00<0C0000T`H00M<00<0C4`01D`D0003
C00000U<0P000d`0000B0003C00000U<0P000d`0000b00005@024@03014A01P00Td0101=C@05C@04
04e=009=5@000dd0C@06C@0304d001H000==04d024d00`1=000D009=00@0CDd00dd0101=C@02CAD0
14d01@1=CDd0009=00<0CDd06`000a40000F00005@024@03014A01X03D`G0003C01<00M<5@02C003
04a<00A<00<0C4`014`00`1<C00D00]<600;C1d000<A00005P0001@000LA01404@0A01D00Td30003
C@3600K600<0C@000P02CA403ddC00M=1<H2C@0404e=CA4024d4aPM=4@07C@C61ddH00<A5`0001@0
00LA01404@0A01H01D`3aP04C01<C0;61D`=0003C00000801d`00lI<aP04C0D000=<00003`02C0;6
0T`00`1<aP02C1H014`3aP0404c6aPA<5@03C0?600@0C<K614`J00034@0A01L0000C00064@004@0A
0P000a40000F0003CLK600==00@0CDe=0/H00dd0000>0003C@00009=0P0014d0CLH3C@05aTd0C@00
0Td30003C@0000X01Td2aP==00@0CDg61TdB009=0/H2C@0304e=00;60ddE009=0/H2C@0304e=00;6
0ddJ00034@0A01L0000C00034@0A008000@A000A5@03C0<00d`0101<C4`300=<2`02C00304`00080
1D`01LI<C4c600A<100014`0C4`;00A<0/H4C00304a<00;614`@00A<0/H3C00404a<C0;614`@00E<
00G6C4a<0003C0;614`G008A00<04A405P00018000@A000A0P001A40000A01<000==00001@02C@03
4De=00L000==00002P02C@<00dd2aP0304e=009=0/H2C@@00Td>009=1002C@0304e=00@00TdC0003
C@0000800Td00a5=C@040003C@0001800Td3009=00<ACDd010000dd0000G009=00<0CDd05P000180
00@A000A0`001140014L0003C15<01H000=<04`00T`3009<0a42C0<00T`20003C00000`000=<0000
1002C0034D`000H000=<00003`000d`00003009<00<AC4`01@000d`0000@0003C00000<00T`00a5<
C0050003C00001D000M<04`0C01<01D0000A00054@0001400`001A40000A01/000==4Dd05`000lH0
0002000;CLH04DdACA40aTd010000lH0000<0003C@0000D00Td00a5=00070003C@0000d000==0000
10001DdA4A5=00H000==00003P000dd000040005CA4A4Dd01P000dd0000D0007C@1=04d0C@0E0000
40000a40000200054@00014010000a40000H00<A6006C0074Da<4D`04@06C0`00T`90005C15<4D`0
2@02C0P00T`90005C15<4D`02@02C0P00T`90005C15<4D`02@02C14000I<001<04`20003C0000180
000@00034@00008000DA00004@0400034@0000`000==000020001DdA4A5=00X000==00001@02C@04
04g6C@<000]=04d04DdA04d0C@020003C@3600==2P000dd000050004CA4A008A00==00001@000dd0
000:0003C@0000D000A=4A400Q400dd000050003C@0000X000==00001@0014dA4@024@03C@0000D0
00==0000400014d004d30004C@00CA<0000?00034@00008000<A00000P000a40000300034@0000`0
00=<00001P000d`0C002C00304`000L000=<00002003C0<000e<04`0C1404D`0C01<00<00d`800E<
1002C00404a<009<00<0C4`010000d`0C002C0H01D`4009<00@0C4`00T`00`1<C0040003C01<009<
1P05C0@00T`0101<C002C00304a<00@000=<04`00T`600A<1@0014`004`30004C000C0D014`:0000
3`000a40000200034@00008000<A00000`000a40000=0003C@0000<00Td00`1=C@03C@0304e=00D0
00==00001`05C@03aP1=00800Td01@1=04d0009=0P0014d0a/H4C@P00dd01<H0CDd200M=0P02C@03
0<I=009=2P03C@04aP1=C@801dd2009=00<0aTd00Td:00==00C604e=0P07C@800Td00`36C@02C@`0
0Td2aP05C@0004d00`001Dd0001=00;60Td>00003P000a40000300034@00008000<A000010000a40
000=0005C00004`00`001D`0C01<00<000E<0000C00:0005C000C0000T`2009<00L0C01<04`0009<
0P02C00504`004`02P03C0@00d`0101<04`400=<3P03C0@01d`400=<3P03C0@01d`400=<3@02C0<0
00G60036C0030005C<H00<H00`02C0d0000>00034@0000<000<A00000`000a40000300034@0000T0
1Dd2aP04C@00009=00<0C@000Td30003CLK600E=2004C@;60Td20005C@1=04d00P02C@;614d>0006
C@0004d00Td01@1=C@1=00<000?6000040001Td0001=009=00D0CDd0C@030003aP00010000I=0000
C@02C@0504e=04d00`000lH0000;009=1003C@03aP3600<000C60<K60Td4009=2`0000d000<A0000
10000a40000300034@0000@000<A00003@03C0<000A<001<0P001D`00036009<3@0024`0001<0<I<
0P001D`0C01<008000A<aP1<0`000d`0000800E<0/H2C00404a<009<00<0C4`00lH3C0/01D`2aP9<
00@0C4`00T`00`1<C002aPE<2P05C0;60T`0101<C002C00304a<00;61D`80004C00000=<0P02C080
00?6C<H00P02C0800d`30003C00000P0000=00034@0000@000<A00000`000a40000400034@0000l0
00==a/H00Td01@1=CDd0009=0lH@00A=0/H02`36C@1=04d0CLH000;614d;00M=00?604d00dd01P1=
C@1=aP==00<0CDd03@05C@;60Td00lI=C@02aP03CLK6009=4005C@;60Td00lI=C@02aP03CLK6009=
50000dd0C@02C@0604e=C@1=4`0000`000<A000010000a40000400034@0000D000<A00002P08C0;6
0d`2aP03C<I<00E<3P07C0;600H0aTc6C<H4C1000T`20008C<I<C<I<aT`3aP04C01<C0l00T`00`1<
C002aP9<00?60<H00T`2aP9<00<0C4`03P02C00304a<00;60T`00lH0aP02C0;60T`00`1<C00B00E<
00<0C0001D`B000030000a40000400034@0000@000<A00001@000a40000:0003C@00009=0P02C@08
aTg6CLI=aP03C@8000==00002`02C@0>04e=04d0aTg6CLH0C@02C@0304e=00h01dd01/I=CLI=aPQ=
3@000dd0C@05C@;60Td2aPM=00<0C@002`000dd0C@05C@;60Td2aPM=00<0C@003`0014d0CDd20003
C@1=00800Td00`1=000@00002`000a40000500034@0000@000<A00001P000a40000<0003C01<00a<
00<0C0003`001d`004`0C0000T`00`1<0002C00404`0C08000=<00002`0:C00304`000A<00<0C4`0
0d`=009<00<0C4`03D`00`1<C00>0005C01<C0003D`00`1<C00@0005C00004`00P000d`0C0020005
C00004`0400000/000<A00001@000a40000400034@0000H000<A00002`04C@0304e=009=00H0CDd0
C@04CA4000E=04e=0003C@0504e=C@000Td00`1=000B009=00<0CDd00Td00`1=C@02C@0304e=01@0
0Td00`1=C@07C@0304e=01D000==04d024d00`1=C@0G0003C@1=00<000==04d0500000X000<A0000
1P000a40000500034@0000H000<A00002@02C00304a<009<00@0C4`01D`00`1<0002C1@014`00`1<
C002C1L03d`D009<00<0C4`00T`00`1<C002C00304a<01@00T`00`1<C002C00304a<009<00<0C4`0
=000018000<A00001P000a40000H0003C@1=00==0P000dd0000J009=00<0CDd06P002Dd0CDd0C@1=
0002C@0304d001D000U=04e=04d0C@000Td00`1=000E0003C@1=00==00<0CDd00Td00`1=000d0000
4P000a40000600034@0001L00T`0101<C002C00304a<03d00d`0101<C4`M009<00<0C4`07`000d`0
C00j00004P000a40000600034@000>@0003o00<0003o00<0003o00<0003o00<00000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.109419,
   0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110616, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.109419, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.74027, -0.110618, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.109416, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277,
   -0.110616, 0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.1939, -0.109419, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.271517, -1.26686, 0.0330061, 0.0330061}, {{42.5, 74.3125},
   {69.375, 37.5625}} -> {-1.42777, -1.26686, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26687, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.88594, -1.2634, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277,
   -1.26686, 0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.1939, -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.270011, -2.4174, 0.0329417, 0.0329417}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.74027, -2.42311, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277,
   -2.42311, 0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1939, -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .85225 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.14698 .59845 L
s
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.17503 .6848 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.41462 .76264 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.48806 .70928 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.29387 .59845 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.36922 .62294 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .28399 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .1932 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.50096 .04513 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.41462 .07319 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.56505 .2386 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.50096 .19203 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.0771 .4107 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.04905 .49704 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.19712 .70084 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.28791 .70084 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.19594 .49704 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.24251 .56114 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.7132 .48415 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.76656 .4107 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.68871 .17112 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.60237 .14306 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.62685 .36531 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.60237 .28996 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.13093 .21773 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.05749 .27109 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.05749 .52301 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.13093 .57637 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .35744 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .43666 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.34044 .58332 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.51609 .2386 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.24251 .51217 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.58724 .33653 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.20511 .39705 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.37508 .75375 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.44852 .80711 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.6881 .72927 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.71616 .64292 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.49392 .66741 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.56926 .64292 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.64149 .17149 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.58813 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.33622 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.28285 .17149 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.50179 .21688 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.42256 .21688 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.20819 .64292 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.23624 .72927 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.47582 .80711 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.54927 .75375 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.35508 .64292 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.43043 .66741 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .32846 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .23767 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.56216 .0896 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.47582 .11766 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.62626 .28307 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.56216 .2365 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.13831 .45517 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.11026 .54151 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.25833 .74531 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.34911 .74531 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.25715 .54151 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.30372 .60561 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5227 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.46217 .24566 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.40165 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5773 .28307 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.30372 .55664 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.65089 .74531 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.74167 .74531 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.88974 .54151 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.86169 .45517 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.69628 .60561 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.74285 .54151 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.52418 .11766 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.43784 .0896 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .23767 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .32846 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.43784 .2365 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.37374 .28307 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.45073 .75375 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.52418 .80711 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.76376 .72927 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.79181 .64292 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.56957 .66741 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.64492 .64292 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.71715 .17149 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.66378 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.41187 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.35851 .17149 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.57744 .21688 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.49821 .21688 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.28384 .64292 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.3119 .72927 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.55148 .80711 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.62492 .75375 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.43074 .64292 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.50608 .66741 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.69628 .55664 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4227 .28307 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.59835 .62779 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.53783 .24566 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4773 .62779 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.86907 .57637 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.94251 .52301 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.94251 .27109 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.86907 .21773 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .43666 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .35744 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.39763 .14306 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.31129 .17112 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.23344 .4107 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.2868 .48415 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.39763 .28996 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.37315 .36531 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.71209 .70084 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.80288 .70084 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.95095 .49704 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.9229 .4107 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.75749 .56114 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.80406 .49704 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.58538 .07319 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.49904 .04513 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .1932 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .28399 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.49904 .19203 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.43495 .2386 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.51194 .70928 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.58538 .76264 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.82497 .6848 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.85302 .59845 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.63078 .62294 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.70613 .59845 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.79489 .39705 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.41276 .33653 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.75749 .51217 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.48391 .2386 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.65956 .58332 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.40097 .39705 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.46217 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.53783 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{182, 155},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002f0000V`P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000;H0002f0000]P000;H0002f0000]P000;H0
002f0000]P0005X000=<0000F@0005X000==0000F@0005X000=<0000F@0005X000==0000F@0005X0
00=<0000F@0004/000==000030000dd0000<0003C@0004X0001;0003C00000`000=<000030000d`0
001:0000C0000dd0000;0003C@0000/000==0000B`0004d000=<04`02P000d`000080003C01<04h0
000l0003C@0000/000A=00000Td:0003C@0000P00Td30003C@0000/000==0000>`0003`000=<0000
2`0014`00002C0X000=<00002002C0<000=<00002`000d`0000k0000?@000dd0000;0005C@0004d0
2P000dd000080005C@0004d03@000dd0000l0000?P000d`0000;0003C000009<2@000d`00007009<
0P000d`0000;0003C00003d0000o0003C@0000/000A=04e=1@001Dd0001=00<000==00000`02C@03
04d000`000==0000?P0003l000=<00002`001D`0C01<00@000E<0000C0030003C000008000E<04`0
C00=0003C00003h000100003C@0000/00Td20003C@00008000A=001=0P000dd000020003C@00009=
3@000dd0000o0000@@000d`0000;0005C00004`010001D`0C01<00@000E<0000C00=0003C0000400
00110003C@0000@000==000010001Dd0001=00D00dd50005C@0004d01P000dd000040003C@000400
00120003C00000<000=<00001002C0<000=<00000P03C0@000A<00000T`60003C00000<000=<0000
@@0004<000==00000P000dd000040003C@1=00<000==00000P000dd000020007C@0004d0C@060003
C@00008000==0000@P0004@000E<0000C0060004C000C08000A<00000d`30004C000C08000=<0000
10001D`0001<04D000140005C@0004d01P0014d004d30003C@0000==0P001Dd0001=008000==0000
10001Dd0001=04D0000c009<0`000d`00005009<0`0014`004`60005C00004`00`02C00304`0009<
0`001D`0001<00H000A<001<0`02C0L000A<00000T`d0000=@04C@T00dd0101=04d60003C@000080
00==00000Td00`1=0002C@8000==00000P000dd000040004C@1=00==2@04CCH0000h00=<2P04C0H0
00=<00000`02C00704`0C01<0002C0D000=<00001004C0X00d`i0000>P04C@T014d40003C@0000<0
0Td200?60P02C@D000==00000P04C@T014dk0000=@02C0@000=<00000d`70003C00000=<00<0C000
1002C0800lH2009<1@000d`0C002C08000=<00001@03C08000=<00000P02C3H0000g00==00<0C@00
1002C@D00Td400==0`0014d004d5aP04C@00C@<00dd4009=1@02C@D000==04d00Tdh0000>P03C0H0
0d`2009<1@000d`0C003C08000=<a/H00lH00d`00004C00304`000@00T`200=<1P03C3/0000m00==
1P03C@0304d000<000A=000014d00`36aP02aP03C@1=00==0`000dd000020003C@1=009=1P03CCh0
000m0003C00000=<1@03C0C600A<001<1006aP03C000008000A<001<1<H3C0D00d`20003C00003`0
000G0003C@0002@000==00000P02C@<000==00001<H00dd0C@0500O61@000dd0aP04aP8000A=0000
0Td40003C@0002@000==00005P0001L000=<00009@000d`0000300A<0P04aP03C<I<00<02lH300O6
0P04C0D000=<00009@000d`0000F000060000dd0000U0003C@0000D00dd200K600<0a/H01<H00`36
aP04aP030<K600C60P03C@L000==00009@000dd0000G000060000d`0000?009<50000d`000050003
C000009<3LH00`36aP0;aP9<0P000d`000050003C00001800T`A0003C00001L0000H0003C@000140
0ddB0003C@0000@000E=0000C@09aP9=00C600000Td:aP05C@0004d01P000dd0000@00==4`000dd0
000G00006@000d`0000C00=<40000d`0000300A<00<0a/H01lH2C004aP00009<0/H2C0K600<0C4`0
0T`50003C00000h00d`E0003C00001P0000I0003C@0001H00dd>0003C@0000==1003aP800Td00lH0
C@02C@800dd2009=00?600000lH400==0P000dd0000<00==60000dd0000H00006@000d`0000I00=<
2`03C08000A<00001<H2009<0`06C0<00T`300C60`000d`00003C0/00d`K0003C00001P0000J0003
C@0001/00Td600==00<0C@000P0014d00004aP800Td400A=1002C@<01<H30006C@0004d00dd6009=
7@000dd0000I00002P02C0h000=<00007@06C0D000A<001<0`03aP<00T`5009<1@02C0@00lH30004
C000C0D01T`O0003C00000`00T`;000030000dd0000;0003C@0001d01Td50004C@00C@801<H3009=
1004C@@00Td400C60P0014d004d500I=7`000dd0000;0003C@0000/0000=0003C00000/000=<0000
6@03C0H00T`4aP03C<I<00K60`02C0<01T`3009<100=aP9<1P03C1/000=<00002`000d`0000<0000
3P02C@/000==00005`02C@X000==a/H01lH2C@03aP0000800Td200==0P03C@800Td5009=2/H00dd0
0008009=6@000dd00009009=3`00010000=<00002@000d`0000O00=<00<0a/H01lH2C003aP000080
0T`2009<1002C0800T`5009<2/H0101<C4`Q0003C00000T000=<00003`0001400Td90003C@0001`0
0dd900?600@0CDe=1002C@0404e=C@@00dd00`1=C@0400==0P03aPT00ddN0003C@0000L00TdB0000
4`000d`000060003C00001T00d`<00C600@0C4a<0`05C0H01D`300=<0P04aP`00d`K0003C00000H0
00=<00004P0001@000==00001P000dd0000E00==3`04aP800dd200A=2004C@800dd300C63`03CAL0
00==00001P000dd0000C00005@02C0H000=<00004P03C1<00lH3009<0P03C0X00d`2009<1003aQ<0
0d`D0003C00000@00T`F00005`000dd000030003C@0000l00ddF00?60`03C@0404e=C@X00dd0101=
CDd400?65P03CA4000==00000`000dd0000F000060000d`000030003C00000/00d`I00C60`05C0@0
114400E<1004aQT00d`=0003C00000<000=<00005`0001T00Td30003C@0000T00TdL00C61004C@<0
1Q4300A=1@04aQ`00Td;0004C@00009=6P0001/000A<001<:002aPA<0`04C080214200A<0`04C0?6
:00014`004`L00007002C@0304d002D00lH;C@`A2dd4aRH000A=04e=7@0001h00T`U00G60P07C0@A
00<04A400Q400`0A4@024@M<0`05aRD00T`O00007`03aR801LH400A=11400dd04@054@0304dA00<A
14d500G68P03aR00000O00?68@05aPD00T`00`0A4@024@=<0Q42008A0d`44@0304a<00H01LHQ00?6
800001l01<HO00G61@03C@<A1Dd24@9=0Q45C@<A0dd600G67`04aR00000O00G67@000dc6aP02aPD0
0T`44@0504a<04`00a42C0<A00E<04a<00044@9<1P04aP03C00001/01LHP00008005aQT00dd01036
a/H5009=114200A=0Q4014d004d24@A=0P044@9=1P03aP0404e=CAT01LHQ00008@04aQH00d`40003
C00000D011400`1<C005C08A00A<001<0Q47C003014A008A20000d`0000200=<5P04aR80000R00C6
4P03C@H000==00001@044@M=00@04A4A14d34@0304e=00E=11480003C@0000@00ddB00C68`000280
1LH>00=<20000d`0000500<A1D`2009<00@04A4014`0100A4@02C0801D`34@P000=<00001P03C0h0
1LHS00008`000lI=C@0QC@<A0dd5009=00@04A4014d0100A4@02C@D00dd34B==0/HT00008`000lI<
C00QC08A00=<00001P02C0<A00<0C4`00T`0100A4A42C0P000=<4A408d`2aR@0000R00G61@03C@l0
00==00000`05C@T00Td24@0304e=00A=00<04A400Td900E=1P000dd0000=00==1@05aR<0000>009<
4@05aP@00T`A0003C00000801d`9009<0Q43C0800d`24@9<2@07C0D000=<00003`02C0@01LHA009<
3`00010000==00003P04aQP000A=000014d00`1=C@0:0004CA4A4@9=1002C@<A00==00002002C@03
04e=009=10000dd0000F00C640000dd0000?00004@02C0d01<HH0003C00000A<0`02C0X000=<4A40
0T`6009<0Q400d`00008009<0`04C0<000=<00005P04aPd00T`B00004`000dd0000900G65`000dd0
0004C@<00dd:0003CA4A009=1P02C@8A00==00002003C@<014d30003C@0001D01LH;0003C@000180
000D0003C00000P01<HG0003C00000=<1@02C0/00a400d`000060004C14A4@/00T`500=<0`000d`0
000E00C62P000d`0000C00005@02C@L000A=a/K65`000dd0C@03C@H00Td:0004CA4AC@X000A=4A5=
2P02C@H014d20003C@0001D00lH00dd00005009=5P0001L000=<00000`000d`0C00I00E<1P03C0T0
0T`24@`00Q42C0T00d`600A<00<0C00060000d`0C0050003C00001H0000H009=00<0CDd00P000dd0
000F00A=2002C@T01Dd<00E=2@02C@P01DdH0003C@00009=00<0CDd06@0001T00T`40003C00001D0
14`9009<1`08C0X024`7009<2@05C1L000=<00000P02C1X0000H009=00D0C@00C@0G00==2P03C@H0
14d00`1=C@02C@X014d00`1=C@02C@H00dd:00A=5`001Dd004d0009=6@0001L000=<00000P03C1D0
14`;009<1P03C0<014`:00A<0`03C0H00T`;00A<5P03C0@000=<00005P0001H000==00001@000dd0
000B00A=3002C@@014d300I=2006C@<014d4009=3004CAD000==00001@000dd0000E00005002C0L0
00A<04a<4@03C0d00d`300A<1002C0800T`8009<0P02C0@014`300=<3@03C1800T`00`1<0006009<
5@0001<000==00001`000dd00002C@h014d>009=0`03C@H00Td2009=2002C@800Td600==0`02C@h0
14d?009=0P000dd000070003C@000180000B0003C00000P000=<00000P0014c6a/H900A<3`02C003
04a<009<1P03C0800d`600=<0P03C0H014`00`1<C00?00A<2P04aP@000=<000020000d`0000A0000
2@0IC@03aTe=00C61004CA001dd7009=1002C@H00Td4009=1`07CA0014d500O66Dd:00003`000d`0
000:0003C00000<00lH00dc6aP04aPA<4@05C0T00T`4009<1P02C0@00T`900E<4@04C0030<K600S6
1@000d`0000:0003C00000h0000=009=3@000dd0000500;600==a/H00/H3CA<014d900==1003C@@0
0dd400==2@04CA<00dd8aPL000==00002`02C@h0000<0003C00000`000=<00002@02C004aTa<C1<0
14`:009<1P02C0@00T`6009<2P04C1<00d`4aP/000=<000030000d`0000;00002`000dd0000=0003
C@0000/00dd00lH0000@00==3002C@H00Td4009=1P02C@`00ddC009=00?6C@0030000dd0000=0003
C@0000X0000:0003C00000h000=<00003002C003aP0000h01D`;00=<1P03C0800d`600=<2`05C140
0lH>0003C00000h000=<00002@0001X000==00003@02aP03C@0000d01Td;009=2002C@800Td8009=
2`06CA000lH?0003C@0001T0000J0003C00000d02<H900=<00<0C4`03002C0P00T`2009<2002C0`0
0T`0101<C4`;00O63`000d`0000I0000500IC@S61004C@800Td;00==2006C@P00dd;009=0P04C@H0
2/HFCAD0000I0003C00000h03/H4C0800d`;009<2P04C0X00T`;00=<0P04C0803LH@0003C00001P0
000I0003C@0000h00lH300O60dd4009=3002C@X014d:009=3002C@@00dd9aP800lH@0003C@0001P0
000I0003C00000h00lH600?60d`5009<2`03C0X014`:00=<2`02C0D00d`5aPD00lH@0003C00001P0
000H0003C@0000l00lH9009=00?600000P03C@/00Td<009=3002C@/00dd5009=0/H800?64@000dd0
000G000060000d`0000?00?62@03aP@00T`<009<3002C0`00T`<009<1@03aPT00lHA0003C00001L0
000H0003C@0001000Td900?61002C@/00dd;00A=2`03C@/00Td500?62@02CA8000==00005`0001L0
00=<000040000d`0C00900?60P001<I<C4`;009<3004C0`00T`;00=<0/H200?62@000d`0C00B0003
C00001H0000Z0003C@1=00T01/H2C@03aP0000T00Td<00A=3002C@`00Td7aPT000==04d0:`0002X0
00A<001<1`07aP9<0/H900=<2`06C0/00d`:0003aTa<00S61`0014`004`[0000:@001Dd0001=00H0
3LH8009=3002C@800Td<009=2@0=aPH000E=0000C@0Z00006P0JC0K60`05aPL00T`<009<0P02C0`0
0T`800G60`06aQY<6`0002T000==00000P000dd000020003CLK600?61@04aPH00dd;00==0P03C@/0
0dd700C61@05aP03C@00008000==00000P000dd0000X0000:0000d`000030003C000009<0`03aPH0
1<H5009<3002C0@00T`<009<1P04aPH00lH3009<0P000d`000030003C00002L0000X0003C@0000<0
00==04d01@02C@L01LH4009=3002C@@00Td<009=1@05aPL00Td50003C@1=00D000==00009`0002P0
00=<00000`02C0H000=<04`01`04aP8000C6C4a<2P001<I<C4`400=<0lH800=<0/H200C61`000d`0
C006009<1@000d`0000W00009`000dd000030003C@1=00H000==04d02006aP9=00?600001@04aP9=
00?600000`02C@K61P02C@?600A=a/K620000dd0C@060003C@1=00D000==00009P0002L000A<0000
0T`30003C000008000A<001<1`07aP9<0/H300O60T`2aP<000?6C4`02LH20003aTa<00;600=<aT`0
0lH70004C000C0@000A<00000T`30003C00002H0000W0004C@00C@D000==00000P001Dd0001=00D0
6lH00`36aP0@aP9=0/H00dg6aP02aPD000E=0000C@040003C@0000<000A=001=:00002D09d`7aP<0
2LH400W614`00lI<aP03aQY<9P0002H00dd80004C@00C@@000==00000P0014g6a/H20003C@000080
0/H00dg6aP02aPL01lH800C60Td40003C@0000?600==00000P000dd000020004C@00C@P00ddW0000
9P000d`000080004C000C0D000A<04a<1P000d`00002009<0lH:00G62P02aP03C<I<00@000=<0000
1002C00304`000@000A<001<2P000d`0000U00009002C@/000A=001=1@02C@P000I=0000C@05aPT0
1LH900;600E=a/H0C@030003C@0000H00Td50004C@00C@/00TdU00008`000d`0C00<009<1@02C0X0
00=<04`00`04aPT01LH9009<0/H30003C01<00X00T`5009<30000d`0C00T00008@02C@8000==0000
2P02C@@000A=001=2@02C@D00lH00dd000050003CLK600?600==00001@0014g6a/H5009=2@0014d0
04d4009=30000dd00002CB80000P0005C00004`03@0014`00002C0<000=<00001P02C0P000=<04`0
1@001T`004`0C08000=<00000`000d`0C008009<200014`00002C0<000=<00002`001D`0001<0240
000O0003C@00008000==00002`02C@0304d000@000==00001002C@8000==00001@000dd00002C@03
04e=008000E=0000C@02009=00<0CDd00P000dd000050003C@00009=1P000dd000030004C@1=C@d0
00==00000P000dd0000N000090000d`0000;00=<1`000d`000020003C000008000=<00001@000d`0
00020003C000008000E<0000C0040003C000008000=<00001@000d`000020003C000008000=<0000
1@03C0d000=<00008`0002<000==00002`03C@P000E=0000C@060003C@0000D000E=04e=0002C@80
00E=0000C@02009=00D0CDd0C@070003C@0000@000E=0000C@0800==3@000dd0000R00008`000d`0
000;0004C000C0L000A<04a<1`000d`00005009<1@02C0D00T`5009<1`000d`00005009<00<0C000
1P0014`004`=0003C0000280000_00==2`000dd000070003C@0000D000==00001@000dd000030003
C@0000D000==00001@000dd000070003C@0000T00dd`0000;P000d`0C00:00=<2P000d`00002009<
00<0C0001@03C00404a<C0H000A<04a<10000d`0000800=<2P000d`0C00_0000;002C@8000==0000
1`0014d004d:0005C@0004d00`000dd000030005C@0004d00`000dd000030005C@0004d00`000dd0
00080004C@00C@T000==00000Td]0000:`000d`000020003C00000H000=<00000P000d`000070004
C000C0@000=<00000`001T`004`0C08000=<00000`000d`000020004C000C0T000=<00000P000d`0
00060003C000008000=<0000:P0002X000==00000P000dd000060003C@0000<000==00002002C@H0
00==00000P03C@<00dd40003C@0000@00Td:0003C@0000<000==00001P000dd000020003C@0002T0
000_0003C00000`000=<00001`02C0L000A<00000T`7009<0`000d`00005009<2@000d`0000<0003
C00002h0000_0003C@0000d000==00001002C@0304d000L000A=04e=2@02C@0304d000L000A=04e=
1P000dd0000=0003C@0002h0000^0003C00000h000=<00000`000d`000020003C00000D00T`00`1<
00080004C01<C0L000=<00000P000d`000030003C00000h000=<0000;@0004@000==00000`000dd0
00050003C@1=00/000==04d01`000dd000030003C@0004<000130003C00000@000=<0000100014`0
C4`;009<00<0C0001@000d`000040003C0000480001;0003C@0000D00Td;009=1`000dd0001:0000
D`000d`0000;0003C0000580001C009=2`02CE@0001C009<2`02C5@0001B0003C@1=00/000==04d0
D`00058000A<001<2@0014`004aC0000DP0014d004d90004C@00CE<0001A0005C00004`02@001D`0
001<0580001A0003C@00008000==00001@000dd000020003C@000500002f0000]P000;H0002f0000
]P000;H0002f0000]P000001\
\>"],
  ImageRangeCache->{{{0, 181}, {154, 0}} -> {-0.0258822, 0.0525667, 
  0.00581085, 0.00581085}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.14698 .59845 L
s
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.17503 .6848 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.41462 .76264 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.48806 .70928 L
s
P
p
0 .4 1 r
.02 w
.34044 .58332 m
.29387 .59845 L
s
P
p
0 .4 1 r
.02 w
.34044 .58332 m
.36922 .62294 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .28399 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .1932 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.50096 .04513 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.41462 .07319 L
s
P
p
0 .4 1 r
.02 w
.51609 .2386 m
.56505 .2386 L
s
P
p
0 .4 1 r
.02 w
.51609 .2386 m
.50096 .19203 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.0771 .4107 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.04905 .49704 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.19712 .70084 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.28791 .70084 L
s
P
p
0 .4 1 r
.02 w
.24251 .51217 m
.19594 .49704 L
s
P
p
0 .4 1 r
.02 w
.24251 .51217 m
.24251 .56114 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.7132 .48415 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.76656 .4107 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.68871 .17112 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.60237 .14306 L
s
P
p
0 .4 1 r
.02 w
.58724 .33653 m
.62685 .36531 L
s
P
p
0 .4 1 r
.02 w
.58724 .33653 m
.60237 .28996 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.13093 .21773 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.05749 .27109 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.05749 .52301 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.13093 .57637 L
s
P
p
0 .4 1 r
.02 w
.20511 .39705 m
.17633 .35744 L
s
P
p
0 .4 1 r
.02 w
.20511 .39705 m
.17633 .43666 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.34044 .58332 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.51609 .2386 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.24251 .51217 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.58724 .33653 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.20511 .39705 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.37508 .75375 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.44852 .80711 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.6881 .72927 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.71616 .64292 L
s
P
p
0 .4 1 r
.02 w
.5227 .62779 m
.49392 .66741 L
s
P
p
0 .4 1 r
.02 w
.5227 .62779 m
.56926 .64292 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.64149 .17149 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.58813 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.33622 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.28285 .17149 L
s
P
p
0 .4 1 r
.02 w
.46217 .24566 m
.50179 .21688 L
s
P
p
0 .4 1 r
.02 w
.46217 .24566 m
.42256 .21688 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.20819 .64292 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.23624 .72927 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.47582 .80711 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.54927 .75375 L
s
P
p
0 .4 1 r
.02 w
.40165 .62779 m
.35508 .64292 L
s
P
p
0 .4 1 r
.02 w
.40165 .62779 m
.43043 .66741 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .32846 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .23767 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.56216 .0896 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.47582 .11766 L
s
P
p
0 .4 1 r
.02 w
.5773 .28307 m
.62626 .28307 L
s
P
p
0 .4 1 r
.02 w
.5773 .28307 m
.56216 .2365 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.13831 .45517 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.11026 .54151 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.25833 .74531 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.34911 .74531 L
s
P
p
0 .4 1 r
.02 w
.30372 .55664 m
.25715 .54151 L
s
P
p
0 .4 1 r
.02 w
.30372 .55664 m
.30372 .60561 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5227 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.46217 .24566 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.40165 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5773 .28307 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.30372 .55664 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.65089 .74531 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.74167 .74531 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.88974 .54151 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.86169 .45517 L
s
P
p
0 .4 1 r
.02 w
.69628 .55664 m
.69628 .60561 L
s
P
p
0 .4 1 r
.02 w
.69628 .55664 m
.74285 .54151 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.52418 .11766 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.43784 .0896 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .23767 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .32846 L
s
P
p
0 .4 1 r
.02 w
.4227 .28307 m
.43784 .2365 L
s
P
p
0 .4 1 r
.02 w
.4227 .28307 m
.37374 .28307 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.45073 .75375 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.52418 .80711 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.76376 .72927 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.79181 .64292 L
s
P
p
0 .4 1 r
.02 w
.59835 .62779 m
.56957 .66741 L
s
P
p
0 .4 1 r
.02 w
.59835 .62779 m
.64492 .64292 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.71715 .17149 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.66378 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.41187 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.35851 .17149 L
s
P
p
0 .4 1 r
.02 w
.53783 .24566 m
.57744 .21688 L
s
P
p
0 .4 1 r
.02 w
.53783 .24566 m
.49821 .21688 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.28384 .64292 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.3119 .72927 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.55148 .80711 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.62492 .75375 L
s
P
p
0 .4 1 r
.02 w
.4773 .62779 m
.43074 .64292 L
s
P
p
0 .4 1 r
.02 w
.4773 .62779 m
.50608 .66741 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.69628 .55664 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4227 .28307 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.59835 .62779 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.53783 .24566 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4773 .62779 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.86907 .57637 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.94251 .52301 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.94251 .27109 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.86907 .21773 L
s
P
p
0 .4 1 r
.02 w
.79489 .39705 m
.82367 .43666 L
s
P
p
0 .4 1 r
.02 w
.79489 .39705 m
.82367 .35744 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.39763 .14306 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.31129 .17112 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.23344 .4107 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.2868 .48415 L
s
P
p
0 .4 1 r
.02 w
.41276 .33653 m
.39763 .28996 L
s
P
p
0 .4 1 r
.02 w
.41276 .33653 m
.37315 .36531 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.71209 .70084 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.80288 .70084 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.95095 .49704 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.9229 .4107 L
s
P
p
0 .4 1 r
.02 w
.75749 .51217 m
.75749 .56114 L
s
P
p
0 .4 1 r
.02 w
.75749 .51217 m
.80406 .49704 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.58538 .07319 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.49904 .04513 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .1932 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .28399 L
s
P
p
0 .4 1 r
.02 w
.48391 .2386 m
.49904 .19203 L
s
P
p
0 .4 1 r
.02 w
.48391 .2386 m
.43495 .2386 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.51194 .70928 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.58538 .76264 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.82497 .6848 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.85302 .59845 L
s
P
p
0 .4 1 r
.02 w
.65956 .58332 m
.63078 .62294 L
s
P
p
0 .4 1 r
.02 w
.65956 .58332 m
.70613 .59845 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.79489 .39705 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.41276 .33653 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.75749 .51217 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.48391 .2386 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.65956 .58332 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.40097 .39705 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.46217 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.53783 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.14698 .59845 L
s
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.17503 .6848 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.41462 .76264 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.48806 .70928 L
s
P
p
.2 0 1 r
.018 w
.34044 .58332 m
.29387 .59845 L
s
P
p
.2 0 1 r
.018 w
.34044 .58332 m
.36922 .62294 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .28399 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .1932 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.50096 .04513 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.41462 .07319 L
s
P
p
.2 0 1 r
.018 w
.51609 .2386 m
.56505 .2386 L
s
P
p
.2 0 1 r
.018 w
.51609 .2386 m
.50096 .19203 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.0771 .4107 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.04905 .49704 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.19712 .70084 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.28791 .70084 L
s
P
p
.2 0 1 r
.018 w
.24251 .51217 m
.19594 .49704 L
s
P
p
.2 0 1 r
.018 w
.24251 .51217 m
.24251 .56114 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.7132 .48415 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.76656 .4107 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.68871 .17112 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.60237 .14306 L
s
P
p
.2 0 1 r
.018 w
.58724 .33653 m
.62685 .36531 L
s
P
p
.2 0 1 r
.018 w
.58724 .33653 m
.60237 .28996 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.13093 .21773 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.05749 .27109 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.05749 .52301 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.13093 .57637 L
s
P
p
.2 0 1 r
.018 w
.20511 .39705 m
.17633 .35744 L
s
P
p
.2 0 1 r
.018 w
.20511 .39705 m
.17633 .43666 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.34044 .58332 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.51609 .2386 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.24251 .51217 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.58724 .33653 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.20511 .39705 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.37508 .75375 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.44852 .80711 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.6881 .72927 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.71616 .64292 L
s
P
p
.2 0 1 r
.018 w
.5227 .62779 m
.49392 .66741 L
s
P
p
.2 0 1 r
.018 w
.5227 .62779 m
.56926 .64292 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.64149 .17149 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.58813 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.33622 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.28285 .17149 L
s
P
p
.2 0 1 r
.018 w
.46217 .24566 m
.50179 .21688 L
s
P
p
.2 0 1 r
.018 w
.46217 .24566 m
.42256 .21688 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.20819 .64292 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.23624 .72927 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.47582 .80711 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.54927 .75375 L
s
P
p
.2 0 1 r
.018 w
.40165 .62779 m
.35508 .64292 L
s
P
p
.2 0 1 r
.018 w
.40165 .62779 m
.43043 .66741 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .32846 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .23767 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.56216 .0896 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.47582 .11766 L
s
P
p
.2 0 1 r
.018 w
.5773 .28307 m
.62626 .28307 L
s
P
p
.2 0 1 r
.018 w
.5773 .28307 m
.56216 .2365 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.13831 .45517 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.11026 .54151 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.25833 .74531 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.34911 .74531 L
s
P
p
.2 0 1 r
.018 w
.30372 .55664 m
.25715 .54151 L
s
P
p
.2 0 1 r
.018 w
.30372 .55664 m
.30372 .60561 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5227 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.46217 .24566 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.40165 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5773 .28307 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.30372 .55664 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.65089 .74531 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.74167 .74531 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.88974 .54151 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.86169 .45517 L
s
P
p
.2 0 1 r
.018 w
.69628 .55664 m
.69628 .60561 L
s
P
p
.2 0 1 r
.018 w
.69628 .55664 m
.74285 .54151 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.52418 .11766 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.43784 .0896 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .23767 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .32846 L
s
P
p
.2 0 1 r
.018 w
.4227 .28307 m
.43784 .2365 L
s
P
p
.2 0 1 r
.018 w
.4227 .28307 m
.37374 .28307 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.45073 .75375 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.52418 .80711 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.76376 .72927 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.79181 .64292 L
s
P
p
.2 0 1 r
.018 w
.59835 .62779 m
.56957 .66741 L
s
P
p
.2 0 1 r
.018 w
.59835 .62779 m
.64492 .64292 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.71715 .17149 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.66378 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.41187 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.35851 .17149 L
s
P
p
.2 0 1 r
.018 w
.53783 .24566 m
.57744 .21688 L
s
P
p
.2 0 1 r
.018 w
.53783 .24566 m
.49821 .21688 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.28384 .64292 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.3119 .72927 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.55148 .80711 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.62492 .75375 L
s
P
p
.2 0 1 r
.018 w
.4773 .62779 m
.43074 .64292 L
s
P
p
.2 0 1 r
.018 w
.4773 .62779 m
.50608 .66741 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.69628 .55664 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4227 .28307 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.59835 .62779 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.53783 .24566 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4773 .62779 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.86907 .57637 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.94251 .52301 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.94251 .27109 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.86907 .21773 L
s
P
p
.2 0 1 r
.018 w
.79489 .39705 m
.82367 .43666 L
s
P
p
.2 0 1 r
.018 w
.79489 .39705 m
.82367 .35744 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.39763 .14306 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.31129 .17112 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.23344 .4107 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.2868 .48415 L
s
P
p
.2 0 1 r
.018 w
.41276 .33653 m
.39763 .28996 L
s
P
p
.2 0 1 r
.018 w
.41276 .33653 m
.37315 .36531 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.71209 .70084 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.80288 .70084 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.95095 .49704 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.9229 .4107 L
s
P
p
.2 0 1 r
.018 w
.75749 .51217 m
.75749 .56114 L
s
P
p
.2 0 1 r
.018 w
.75749 .51217 m
.80406 .49704 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.58538 .07319 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.49904 .04513 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .1932 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .28399 L
s
P
p
.2 0 1 r
.018 w
.48391 .2386 m
.49904 .19203 L
s
P
p
.2 0 1 r
.018 w
.48391 .2386 m
.43495 .2386 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.51194 .70928 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.58538 .76264 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.82497 .6848 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.85302 .59845 L
s
P
p
.2 0 1 r
.018 w
.65956 .58332 m
.63078 .62294 L
s
P
p
.2 0 1 r
.018 w
.65956 .58332 m
.70613 .59845 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.79489 .39705 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.41276 .33653 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.75749 .51217 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.48391 .2386 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.65956 .58332 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.40097 .39705 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.46217 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.53783 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0608586 0.952381 [
[ 0 0 0 0 ]
[ 1 .83066 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .83066 L
0 .83066 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .53189 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .62025 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.21533 .69174 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.37271 .74288 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.45675 .71557 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.50869 .64408 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.29937 .57607 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.37271 .5999 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .30985 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.7063 .22581 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .14177 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.54512 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.45675 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.38526 .09644 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.56332 .22581 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.50093 .18048 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.12002 .36169 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .43318 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .52154 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.16534 .65542 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.24938 .68273 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.33342 .65542 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.20405 .47736 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.24938 .53975 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.66765 .48512 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.73914 .43318 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.76645 .34914 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.71531 .19176 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.64382 .13982 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.55546 .13982 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.62347 .34914 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.59964 .2758 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.18496 .1985 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.10092 .22581 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.04898 .2973 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.04898 .46278 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.10092 .53426 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.18496 .56157 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .34148 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .41859 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.3447 .56134 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.51566 .22581 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.24938 .49209 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.58491 .32113 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.21297 .38004 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.3581 .68736 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.41004 .75885 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.49408 .78616 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.65146 .73502 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .66353 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .57517 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.49408 .64318 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.56742 .61935 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.64471 .20467 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.61741 .12063 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.54592 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.38044 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.30895 .12063 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.28165 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.50174 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.42462 .20467 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .57517 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .66353 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.27491 .73502 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.43229 .78616 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.51632 .75885 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.56826 .68736 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.35895 .61935 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.43229 .64318 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .35313 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.76587 .26909 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .18505 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.60469 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.51632 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.44484 .13973 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.62289 .26909 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.56051 .22377 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.17959 .40497 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .47646 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .56483 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.22492 .6987 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.30895 .72601 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.39299 .6987 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.26363 .52065 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.30895 .58303 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.52209 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.46318 .23269 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.40427 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.57523 .26909 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.30895 .53537 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.60701 .6987 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.69105 .72601 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.77508 .6987 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .56483 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .47646 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.82041 .40497 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.69105 .58303 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.73637 .52065 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.55516 .13973 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.48368 .08779 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.39531 .08779 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .18505 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.23413 .26909 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .35313 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.43949 .22377 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.37711 .26909 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.43174 .68736 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.48368 .75885 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.56771 .78616 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.72509 .73502 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .66353 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .57517 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.56771 .64318 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.64105 .61935 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.71835 .20467 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.69105 .12063 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.61956 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.45408 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.38259 .12063 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.35529 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.57538 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.49826 .20467 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .57517 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .66353 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.34854 .73502 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.50592 .78616 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.58996 .75885 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.6419 .68736 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.43258 .61935 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.50592 .64318 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.69105 .53537 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.42477 .26909 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.59573 .60462 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.53682 .23269 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.47791 .60462 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.81504 .56157 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.89908 .53426 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.95102 .46278 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.95102 .2973 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.89908 .22581 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.81504 .1985 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .41859 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .34148 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.44454 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.35618 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.28469 .19176 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.23355 .34914 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.26086 .43318 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.33235 .48512 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.40036 .2758 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.37653 .34914 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.66658 .65542 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.75062 .68273 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.83466 .65542 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .52154 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .43318 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.87998 .36169 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.75062 .53975 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.79595 .47736 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.61474 .09644 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.54325 .04451 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.45488 .04451 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .14177 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.2937 .22581 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .30985 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.49907 .18048 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.43668 .22581 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.49131 .64408 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.54325 .71557 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.62729 .74288 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.78467 .69174 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .62025 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .53189 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.62729 .5999 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.70063 .57607 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.78703 .38004 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.41509 .32113 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.75062 .49209 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.48434 .22581 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.6553 .56134 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.40361 .38004 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.46318 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.53682 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.59639 .38004 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0540827 0.952381 [
[ 0 0 0 0 ]
[ 1 .84422 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .84422 L
0 .84422 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29305 .59865 m
.14738 .62172 L
s
P
p
.2 0 1 r
.002 w
.29305 .59865 m
.16164 .66561 L
s
P
p
.2 0 1 r
.002 w
.3687 .62323 m
.43566 .75464 L
s
P
p
.2 0 1 r
.002 w
.3687 .62323 m
.47299 .72752 L
s
P
p
0 .4 1 r
.018 w
.3398 .58346 m
.29305 .59865 L
s
P
p
0 .4 1 r
.018 w
.3398 .58346 m
.3687 .62323 L
s
P
p
.2 0 1 r
.002 w
.56532 .23735 m
.71098 .26042 L
s
P
p
.2 0 1 r
.002 w
.56532 .23735 m
.71098 .21428 L
s
P
p
.2 0 1 r
.002 w
.50096 .1906 m
.47789 .04493 L
s
P
p
.2 0 1 r
.002 w
.50096 .1906 m
.43401 .05919 L
s
P
p
0 .4 1 r
.018 w
.51615 .23735 m
.56532 .23735 L
s
P
p
0 .4 1 r
.018 w
.51615 .23735 m
.50096 .1906 L
s
P
p
.2 0 1 r
.002 w
.19473 .49683 m
.06332 .42988 L
s
P
p
.2 0 1 r
.002 w
.19473 .49683 m
.04906 .47376 L
s
P
p
.2 0 1 r
.002 w
.24148 .56118 m
.21841 .70685 L
s
P
p
.2 0 1 r
.002 w
.24148 .56118 m
.26455 .70685 L
s
P
p
0 .4 1 r
.018 w
.24148 .51202 m
.19473 .49683 L
s
P
p
0 .4 1 r
.018 w
.24148 .51202 m
.24148 .56118 L
s
P
p
.2 0 1 r
.002 w
.62736 .36457 m
.73165 .46886 L
s
P
p
.2 0 1 r
.002 w
.62736 .36457 m
.75877 .43153 L
s
P
p
.2 0 1 r
.002 w
.60278 .28892 m
.66974 .15751 L
s
P
p
.2 0 1 r
.002 w
.60278 .28892 m
.62585 .14325 L
s
P
p
0 .4 1 r
.018 w
.58759 .33567 m
.62736 .36457 L
s
P
p
0 .4 1 r
.018 w
.58759 .33567 m
.60278 .28892 L
s
P
p
.2 0 1 r
.002 w
.17503 .35667 m
.10807 .22526 L
s
P
p
.2 0 1 r
.002 w
.17503 .35667 m
.07074 .25238 L
s
P
p
.2 0 1 r
.002 w
.17503 .43621 m
.07074 .5405 L
s
P
p
.2 0 1 r
.002 w
.17503 .43621 m
.10807 .56762 L
s
P
p
0 .4 1 r
.018 w
.20393 .39644 m
.17503 .35667 L
s
P
p
0 .4 1 r
.018 w
.20393 .39644 m
.17503 .43621 L
s
P
p
.2 0 1 r
.016 w
.40057 .39644 m
.3398 .58346 L
s
P
p
.2 0 1 r
.016 w
.40057 .39644 m
.51615 .23735 L
s
P
p
.2 0 1 r
.016 w
.40057 .39644 m
.24148 .51202 L
s
P
p
.2 0 1 r
.016 w
.40057 .39644 m
.58759 .33567 L
s
P
p
.2 0 1 r
.016 w
.40057 .39644 m
.20393 .39644 L
s
P
p
.2 0 1 r
.002 w
.49389 .66788 m
.38961 .77216 L
s
P
p
.2 0 1 r
.002 w
.49389 .66788 m
.42694 .79929 L
s
P
p
.2 0 1 r
.002 w
.56954 .6433 m
.70095 .71025 L
s
P
p
.2 0 1 r
.002 w
.56954 .6433 m
.71521 .66637 L
s
P
p
0 .4 1 r
.018 w
.52279 .62811 m
.49389 .66788 L
s
P
p
0 .4 1 r
.018 w
.52279 .62811 m
.56954 .6433 L
s
P
p
.2 0 1 r
.002 w
.50179 .21555 m
.6332 .14859 L
s
P
p
.2 0 1 r
.002 w
.50179 .21555 m
.60608 .11126 L
s
P
p
.2 0 1 r
.002 w
.42225 .21555 m
.31796 .11126 L
s
P
p
.2 0 1 r
.002 w
.42225 .21555 m
.29084 .14859 L
s
P
p
0 .4 1 r
.018 w
.46202 .24444 m
.50179 .21555 L
s
P
p
0 .4 1 r
.018 w
.46202 .24444 m
.42225 .21555 L
s
P
p
.2 0 1 r
.002 w
.3545 .6433 m
.20883 .66637 L
s
P
p
.2 0 1 r
.002 w
.3545 .6433 m
.22309 .71025 L
s
P
p
.2 0 1 r
.002 w
.43015 .66788 m
.49711 .79929 L
s
P
p
.2 0 1 r
.002 w
.43015 .66788 m
.53444 .77216 L
s
P
p
0 .4 1 r
.018 w
.40125 .62811 m
.3545 .6433 L
s
P
p
0 .4 1 r
.018 w
.40125 .62811 m
.43015 .66788 L
s
P
p
.2 0 1 r
.002 w
.62677 .282 m
.77243 .30507 L
s
P
p
.2 0 1 r
.002 w
.62677 .282 m
.77243 .25893 L
s
P
p
.2 0 1 r
.002 w
.56241 .23524 m
.53934 .08958 L
s
P
p
.2 0 1 r
.002 w
.56241 .23524 m
.49546 .10384 L
s
P
p
0 .4 1 r
.018 w
.57761 .282 m
.62677 .282 L
s
P
p
0 .4 1 r
.018 w
.57761 .282 m
.56241 .23524 L
s
P
p
.2 0 1 r
.002 w
.25618 .54148 m
.12477 .47452 L
s
P
p
.2 0 1 r
.002 w
.25618 .54148 m
.11051 .51841 L
s
P
p
.2 0 1 r
.002 w
.30293 .60583 m
.27986 .7515 L
s
P
p
.2 0 1 r
.002 w
.30293 .60583 m
.326 .7515 L
s
P
p
0 .4 1 r
.018 w
.30293 .55667 m
.25618 .54148 L
s
P
p
0 .4 1 r
.018 w
.30293 .55667 m
.30293 .60583 L
s
P
p
.2 0 1 r
.016 w
.46202 .44109 m
.52279 .62811 L
s
P
p
.2 0 1 r
.016 w
.46202 .44109 m
.46202 .24444 L
s
P
p
.2 0 1 r
.016 w
.46202 .44109 m
.40125 .62811 L
s
P
p
.2 0 1 r
.016 w
.46202 .44109 m
.57761 .282 L
s
P
p
.2 0 1 r
.016 w
.46202 .44109 m
.30293 .55667 L
s
P
p
.2 0 1 r
.002 w
.69707 .60583 m
.674 .7515 L
s
P
p
.2 0 1 r
.002 w
.69707 .60583 m
.72014 .7515 L
s
P
p
.2 0 1 r
.002 w
.74382 .54148 m
.88949 .51841 L
s
P
p
.2 0 1 r
.002 w
.74382 .54148 m
.87523 .47452 L
s
P
p
0 .4 1 r
.018 w
.69707 .55667 m
.69707 .60583 L
s
P
p
0 .4 1 r
.018 w
.69707 .55667 m
.74382 .54148 L
s
P
p
.2 0 1 r
.002 w
.43759 .23524 m
.50454 .10384 L
s
P
p
.2 0 1 r
.002 w
.43759 .23524 m
.46066 .08958 L
s
P
p
.2 0 1 r
.002 w
.37323 .282 m
.22757 .25893 L
s
P
p
.2 0 1 r
.002 w
.37323 .282 m
.22757 .30507 L
s
P
p
0 .4 1 r
.018 w
.42239 .282 m
.43759 .23524 L
s
P
p
0 .4 1 r
.018 w
.42239 .282 m
.37323 .282 L
s
P
p
.2 0 1 r
.002 w
.56985 .66788 m
.46556 .77216 L
s
P
p
.2 0 1 r
.002 w
.56985 .66788 m
.50289 .79929 L
s
P
p
.2 0 1 r
.002 w
.6455 .6433 m
.77691 .71025 L
s
P
p
.2 0 1 r
.002 w
.6455 .6433 m
.79117 .66637 L
s
P
p
0 .4 1 r
.018 w
.59875 .62811 m
.56985 .66788 L
s
P
p
0 .4 1 r
.018 w
.59875 .62811 m
.6455 .6433 L
s
P
p
.2 0 1 r
.002 w
.57775 .21555 m
.70916 .14859 L
s
P
p
.2 0 1 r
.002 w
.57775 .21555 m
.68204 .11126 L
s
P
p
.2 0 1 r
.002 w
.49821 .21555 m
.39392 .11126 L
s
P
p
.2 0 1 r
.002 w
.49821 .21555 m
.3668 .14859 L
s
P
p
0 .4 1 r
.018 w
.53798 .24444 m
.57775 .21555 L
s
P
p
0 .4 1 r
.018 w
.53798 .24444 m
.49821 .21555 L
s
P
p
.2 0 1 r
.002 w
.43046 .6433 m
.28479 .66637 L
s
P
p
.2 0 1 r
.002 w
.43046 .6433 m
.29905 .71025 L
s
P
p
.2 0 1 r
.002 w
.50611 .66788 m
.57306 .79929 L
s
P
p
.2 0 1 r
.002 w
.50611 .66788 m
.61039 .77216 L
s
P
p
0 .4 1 r
.018 w
.47721 .62811 m
.43046 .6433 L
s
P
p
0 .4 1 r
.018 w
.47721 .62811 m
.50611 .66788 L
s
P
p
.2 0 1 r
.016 w
.53798 .44109 m
.69707 .55667 L
s
P
p
.2 0 1 r
.016 w
.53798 .44109 m
.42239 .282 L
s
P
p
.2 0 1 r
.016 w
.53798 .44109 m
.59875 .62811 L
s
P
p
.2 0 1 r
.016 w
.53798 .44109 m
.53798 .24444 L
s
P
p
.2 0 1 r
.016 w
.53798 .44109 m
.47721 .62811 L
s
P
p
.2 0 1 r
.002 w
.82497 .43621 m
.89193 .56762 L
s
P
p
.2 0 1 r
.002 w
.82497 .43621 m
.92926 .5405 L
s
P
p
.2 0 1 r
.002 w
.82497 .35667 m
.92926 .25238 L
s
P
p
.2 0 1 r
.002 w
.82497 .35667 m
.89193 .22526 L
s
P
p
0 .4 1 r
.018 w
.79607 .39644 m
.82497 .43621 L
s
P
p
0 .4 1 r
.018 w
.79607 .39644 m
.82497 .35667 L
s
P
p
.2 0 1 r
.002 w
.39722 .28892 m
.37415 .14325 L
s
P
p
.2 0 1 r
.002 w
.39722 .28892 m
.33026 .15751 L
s
P
p
.2 0 1 r
.002 w
.37264 .36457 m
.24123 .43153 L
s
P
p
.2 0 1 r
.002 w
.37264 .36457 m
.26835 .46886 L
s
P
p
0 .4 1 r
.018 w
.41241 .33567 m
.39722 .28892 L
s
P
p
0 .4 1 r
.018 w
.41241 .33567 m
.37264 .36457 L
s
P
p
.2 0 1 r
.002 w
.75852 .56118 m
.73545 .70685 L
s
P
p
.2 0 1 r
.002 w
.75852 .56118 m
.78159 .70685 L
s
P
p
.2 0 1 r
.002 w
.80527 .49683 m
.95094 .47376 L
s
P
p
.2 0 1 r
.002 w
.80527 .49683 m
.93668 .42988 L
s
P
p
0 .4 1 r
.018 w
.75852 .51202 m
.75852 .56118 L
s
P
p
0 .4 1 r
.018 w
.75852 .51202 m
.80527 .49683 L
s
P
p
.2 0 1 r
.002 w
.49904 .1906 m
.56599 .05919 L
s
P
p
.2 0 1 r
.002 w
.49904 .1906 m
.52211 .04493 L
s
P
p
.2 0 1 r
.002 w
.43468 .23735 m
.28902 .21428 L
s
P
p
.2 0 1 r
.002 w
.43468 .23735 m
.28902 .26042 L
s
P
p
0 .4 1 r
.018 w
.48385 .23735 m
.49904 .1906 L
s
P
p
0 .4 1 r
.018 w
.48385 .23735 m
.43468 .23735 L
s
P
p
.2 0 1 r
.002 w
.6313 .62323 m
.52701 .72752 L
s
P
p
.2 0 1 r
.002 w
.6313 .62323 m
.56434 .75464 L
s
P
p
.2 0 1 r
.002 w
.70695 .59865 m
.83836 .66561 L
s
P
p
.2 0 1 r
.002 w
.70695 .59865 m
.85262 .62172 L
s
P
p
0 .4 1 r
.018 w
.6602 .58346 m
.6313 .62323 L
s
P
p
0 .4 1 r
.018 w
.6602 .58346 m
.70695 .59865 L
s
P
p
.2 0 1 r
.016 w
.59943 .39644 m
.79607 .39644 L
s
P
p
.2 0 1 r
.016 w
.59943 .39644 m
.41241 .33567 L
s
P
p
.2 0 1 r
.016 w
.59943 .39644 m
.75852 .51202 L
s
P
p
.2 0 1 r
.016 w
.59943 .39644 m
.48385 .23735 L
s
P
p
.2 0 1 r
.016 w
.59943 .39644 m
.6602 .58346 L
s
P
p
1 .6 0 r
.016 w
.5 .3242 m
.40057 .39644 L
s
P
p
1 .6 0 r
.016 w
.5 .3242 m
.46202 .44109 L
s
P
p
1 .6 0 r
.016 w
.5 .3242 m
.53798 .44109 L
s
P
p
1 .6 0 r
.016 w
.5 .3242 m
.59943 .39644 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0536399 0.952381 [
[ 0 0 0 0 ]
[ 1 .8451 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .8451 L
0 .8451 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.28211 .60408 m
.15272 .60408 L
s
P
p
.2 0 1 r
.002 w
.28211 .60408 m
.17743 .68014 L
s
P
p
.2 0 1 r
.002 w
.36176 .62996 m
.40175 .75303 L
s
P
p
.2 0 1 r
.002 w
.36176 .62996 m
.46645 .70602 L
s
P
p
0 .4 1 r
.018 w
.33134 .58809 m
.28211 .60408 L
s
P
p
0 .4 1 r
.018 w
.33134 .58809 m
.36176 .62996 L
s
P
p
.2 0 1 r
.002 w
.56877 .22369 m
.69183 .26368 L
s
P
p
.2 0 1 r
.002 w
.56877 .22369 m
.69183 .18371 L
s
P
p
.2 0 1 r
.002 w
.50101 .17447 m
.50101 .04507 L
s
P
p
.2 0 1 r
.002 w
.50101 .17447 m
.42496 .06978 L
s
P
p
0 .4 1 r
.018 w
.51701 .22369 m
.56877 .22369 L
s
P
p
0 .4 1 r
.018 w
.51701 .22369 m
.50101 .17447 L
s
P
p
.2 0 1 r
.002 w
.17859 .49688 m
.07391 .42083 L
s
P
p
.2 0 1 r
.002 w
.17859 .49688 m
.0492 .49688 L
s
P
p
.2 0 1 r
.002 w
.22782 .56464 m
.18783 .6877 L
s
P
p
.2 0 1 r
.002 w
.22782 .56464 m
.26781 .6877 L
s
P
p
0 .4 1 r
.018 w
.22782 .51288 m
.17859 .49688 L
s
P
p
0 .4 1 r
.018 w
.22782 .51288 m
.22782 .56464 L
s
P
p
.2 0 1 r
.002 w
.63409 .35763 m
.71015 .46232 L
s
P
p
.2 0 1 r
.002 w
.63409 .35763 m
.75716 .39762 L
s
P
p
.2 0 1 r
.002 w
.60821 .27798 m
.68427 .1733 L
s
P
p
.2 0 1 r
.002 w
.60821 .27798 m
.60821 .14859 L
s
P
p
0 .4 1 r
.018 w
.59222 .32721 m
.63409 .35763 L
s
P
p
0 .4 1 r
.018 w
.59222 .32721 m
.60821 .27798 L
s
P
p
.2 0 1 r
.002 w
.15786 .34931 m
.11787 .22625 L
s
P
p
.2 0 1 r
.002 w
.15786 .34931 m
.05317 .27325 L
s
P
p
.2 0 1 r
.002 w
.15786 .43306 m
.05317 .50912 L
s
P
p
.2 0 1 r
.002 w
.15786 .43306 m
.11787 .55612 L
s
P
p
0 .4 1 r
.018 w
.18828 .39119 m
.15786 .34931 L
s
P
p
0 .4 1 r
.018 w
.18828 .39119 m
.15786 .43306 L
s
P
p
.2 0 1 r
.016 w
.39532 .39119 m
.33134 .58809 L
s
P
p
.2 0 1 r
.016 w
.39532 .39119 m
.51701 .22369 L
s
P
p
.2 0 1 r
.016 w
.39532 .39119 m
.22782 .51288 L
s
P
p
.2 0 1 r
.016 w
.39532 .39119 m
.59222 .32721 L
s
P
p
.2 0 1 r
.016 w
.39532 .39119 m
.18828 .39119 L
s
P
p
.2 0 1 r
.002 w
.49357 .67697 m
.38888 .75303 L
s
P
p
.2 0 1 r
.002 w
.49357 .67697 m
.45358 .80003 L
s
P
p
.2 0 1 r
.002 w
.57322 .65109 m
.6779 .72715 L
s
P
p
.2 0 1 r
.002 w
.57322 .65109 m
.70261 .65109 L
s
P
p
0 .4 1 r
.018 w
.52399 .6351 m
.49357 .67697 L
s
P
p
0 .4 1 r
.018 w
.52399 .6351 m
.57322 .65109 L
s
P
p
.2 0 1 r
.002 w
.50189 .20073 m
.62495 .16075 L
s
P
p
.2 0 1 r
.002 w
.50189 .20073 m
.57795 .09605 L
s
P
p
.2 0 1 r
.002 w
.41814 .20073 m
.34208 .09605 L
s
P
p
.2 0 1 r
.002 w
.41814 .20073 m
.29508 .16075 L
s
P
p
0 .4 1 r
.018 w
.46001 .23116 m
.50189 .20073 L
s
P
p
0 .4 1 r
.018 w
.46001 .23116 m
.41814 .20073 L
s
P
p
.2 0 1 r
.002 w
.34681 .65109 m
.21741 .65109 L
s
P
p
.2 0 1 r
.002 w
.34681 .65109 m
.24213 .72715 L
s
P
p
.2 0 1 r
.002 w
.42646 .67697 m
.46645 .80003 L
s
P
p
.2 0 1 r
.002 w
.42646 .67697 m
.53114 .75303 L
s
P
p
0 .4 1 r
.018 w
.39604 .6351 m
.34681 .65109 L
s
P
p
0 .4 1 r
.018 w
.39604 .6351 m
.42646 .67697 L
s
P
p
.2 0 1 r
.002 w
.63347 .2707 m
.75653 .31068 L
s
P
p
.2 0 1 r
.002 w
.63347 .2707 m
.75653 .23071 L
s
P
p
.2 0 1 r
.002 w
.56571 .22147 m
.56571 .09207 L
s
P
p
.2 0 1 r
.002 w
.56571 .22147 m
.48965 .11679 L
s
P
p
0 .4 1 r
.018 w
.58171 .2707 m
.63347 .2707 L
s
P
p
0 .4 1 r
.018 w
.58171 .2707 m
.56571 .22147 L
s
P
p
.2 0 1 r
.002 w
.24329 .54389 m
.13861 .46783 L
s
P
p
.2 0 1 r
.002 w
.24329 .54389 m
.1139 .54389 L
s
P
p
.2 0 1 r
.002 w
.29252 .61164 m
.25253 .73471 L
s
P
p
.2 0 1 r
.002 w
.29252 .61164 m
.3325 .73471 L
s
P
p
0 .4 1 r
.018 w
.29252 .55989 m
.24329 .54389 L
s
P
p
0 .4 1 r
.018 w
.29252 .55989 m
.29252 .61164 L
s
P
p
.2 0 1 r
.016 w
.46001 .43819 m
.52399 .6351 L
s
P
p
.2 0 1 r
.016 w
.46001 .43819 m
.46001 .23116 L
s
P
p
.2 0 1 r
.016 w
.46001 .43819 m
.39604 .6351 L
s
P
p
.2 0 1 r
.016 w
.46001 .43819 m
.58171 .2707 L
s
P
p
.2 0 1 r
.016 w
.46001 .43819 m
.29252 .55989 L
s
P
p
.2 0 1 r
.002 w
.70748 .61164 m
.6675 .73471 L
s
P
p
.2 0 1 r
.002 w
.70748 .61164 m
.74747 .73471 L
s
P
p
.2 0 1 r
.002 w
.75671 .54389 m
.8861 .54389 L
s
P
p
.2 0 1 r
.002 w
.75671 .54389 m
.86139 .46783 L
s
P
p
0 .4 1 r
.018 w
.70748 .55989 m
.70748 .61164 L
s
P
p
0 .4 1 r
.018 w
.70748 .55989 m
.75671 .54389 L
s
P
p
.2 0 1 r
.002 w
.43429 .22147 m
.51035 .11679 L
s
P
p
.2 0 1 r
.002 w
.43429 .22147 m
.43429 .09207 L
s
P
p
.2 0 1 r
.002 w
.36653 .2707 m
.24347 .23071 L
s
P
p
.2 0 1 r
.002 w
.36653 .2707 m
.24347 .31068 L
s
P
p
0 .4 1 r
.018 w
.41829 .2707 m
.43429 .22147 L
s
P
p
0 .4 1 r
.018 w
.41829 .2707 m
.36653 .2707 L
s
P
p
.2 0 1 r
.002 w
.57354 .67697 m
.46886 .75303 L
s
P
p
.2 0 1 r
.002 w
.57354 .67697 m
.53355 .80003 L
s
P
p
.2 0 1 r
.002 w
.65319 .65109 m
.75787 .72715 L
s
P
p
.2 0 1 r
.002 w
.65319 .65109 m
.78259 .65109 L
s
P
p
0 .4 1 r
.018 w
.60396 .6351 m
.57354 .67697 L
s
P
p
0 .4 1 r
.018 w
.60396 .6351 m
.65319 .65109 L
s
P
p
.2 0 1 r
.002 w
.58186 .20073 m
.70492 .16075 L
s
P
p
.2 0 1 r
.002 w
.58186 .20073 m
.65792 .09605 L
s
P
p
.2 0 1 r
.002 w
.49811 .20073 m
.42205 .09605 L
s
P
p
.2 0 1 r
.002 w
.49811 .20073 m
.37505 .16075 L
s
P
p
0 .4 1 r
.018 w
.53999 .23116 m
.58186 .20073 L
s
P
p
0 .4 1 r
.018 w
.53999 .23116 m
.49811 .20073 L
s
P
p
.2 0 1 r
.002 w
.42678 .65109 m
.29739 .65109 L
s
P
p
.2 0 1 r
.002 w
.42678 .65109 m
.3221 .72715 L
s
P
p
.2 0 1 r
.002 w
.50643 .67697 m
.54642 .80003 L
s
P
p
.2 0 1 r
.002 w
.50643 .67697 m
.61112 .75303 L
s
P
p
0 .4 1 r
.018 w
.47601 .6351 m
.42678 .65109 L
s
P
p
0 .4 1 r
.018 w
.47601 .6351 m
.50643 .67697 L
s
P
p
.2 0 1 r
.016 w
.53999 .43819 m
.70748 .55989 L
s
P
p
.2 0 1 r
.016 w
.53999 .43819 m
.41829 .2707 L
s
P
p
.2 0 1 r
.016 w
.53999 .43819 m
.60396 .6351 L
s
P
p
.2 0 1 r
.016 w
.53999 .43819 m
.53999 .23116 L
s
P
p
.2 0 1 r
.016 w
.53999 .43819 m
.47601 .6351 L
s
P
p
.2 0 1 r
.002 w
.84214 .43306 m
.88213 .55612 L
s
P
p
.2 0 1 r
.002 w
.84214 .43306 m
.94683 .50912 L
s
P
p
.2 0 1 r
.002 w
.84214 .34931 m
.94683 .27325 L
s
P
p
.2 0 1 r
.002 w
.84214 .34931 m
.88213 .22625 L
s
P
p
0 .4 1 r
.018 w
.81172 .39119 m
.84214 .43306 L
s
P
p
0 .4 1 r
.018 w
.81172 .39119 m
.84214 .34931 L
s
P
p
.2 0 1 r
.002 w
.39179 .27798 m
.39179 .14859 L
s
P
p
.2 0 1 r
.002 w
.39179 .27798 m
.31573 .1733 L
s
P
p
.2 0 1 r
.002 w
.36591 .35763 m
.24284 .39762 L
s
P
p
.2 0 1 r
.002 w
.36591 .35763 m
.28985 .46232 L
s
P
p
0 .4 1 r
.018 w
.40778 .32721 m
.39179 .27798 L
s
P
p
0 .4 1 r
.018 w
.40778 .32721 m
.36591 .35763 L
s
P
p
.2 0 1 r
.002 w
.77218 .56464 m
.73219 .6877 L
s
P
p
.2 0 1 r
.002 w
.77218 .56464 m
.81217 .6877 L
s
P
p
.2 0 1 r
.002 w
.82141 .49688 m
.9508 .49688 L
s
P
p
.2 0 1 r
.002 w
.82141 .49688 m
.92609 .42083 L
s
P
p
0 .4 1 r
.018 w
.77218 .51288 m
.77218 .56464 L
s
P
p
0 .4 1 r
.018 w
.77218 .51288 m
.82141 .49688 L
s
P
p
.2 0 1 r
.002 w
.49899 .17447 m
.57504 .06978 L
s
P
p
.2 0 1 r
.002 w
.49899 .17447 m
.49899 .04507 L
s
P
p
.2 0 1 r
.002 w
.43123 .22369 m
.30817 .18371 L
s
P
p
.2 0 1 r
.002 w
.43123 .22369 m
.30817 .26368 L
s
P
p
0 .4 1 r
.018 w
.48299 .22369 m
.49899 .17447 L
s
P
p
0 .4 1 r
.018 w
.48299 .22369 m
.43123 .22369 L
s
P
p
.2 0 1 r
.002 w
.63824 .62996 m
.53355 .70602 L
s
P
p
.2 0 1 r
.002 w
.63824 .62996 m
.59825 .75303 L
s
P
p
.2 0 1 r
.002 w
.71789 .60408 m
.82257 .68014 L
s
P
p
.2 0 1 r
.002 w
.71789 .60408 m
.84728 .60408 L
s
P
p
0 .4 1 r
.018 w
.66866 .58809 m
.63824 .62996 L
s
P
p
0 .4 1 r
.018 w
.66866 .58809 m
.71789 .60408 L
s
P
p
.2 0 1 r
.016 w
.60468 .39119 m
.81172 .39119 L
s
P
p
.2 0 1 r
.016 w
.60468 .39119 m
.40778 .32721 L
s
P
p
.2 0 1 r
.016 w
.60468 .39119 m
.77218 .51288 L
s
P
p
.2 0 1 r
.016 w
.60468 .39119 m
.48299 .22369 L
s
P
p
.2 0 1 r
.016 w
.60468 .39119 m
.66866 .58809 L
s
P
p
1 .6 0 r
.016 w
.5 .31513 m
.39532 .39119 L
s
P
p
1 .6 0 r
.016 w
.5 .31513 m
.46001 .43819 L
s
P
p
1 .6 0 r
.016 w
.5 .31513 m
.53999 .43819 L
s
P
p
1 .6 0 r
.016 w
.5 .31513 m
.60468 .39119 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.022 w
.29387 .59845 m
.14698 .59845 L
s
P
p
.2 0 1 r
.022 w
.29387 .59845 m
.17503 .6848 L
s
P
p
.2 0 1 r
.022 w
.36922 .62294 m
.41462 .76264 L
s
P
p
.2 0 1 r
.022 w
.36922 .62294 m
.48806 .70928 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.29387 .59845 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.36922 .62294 L
s
P
p
.2 0 1 r
.022 w
.56505 .2386 m
.70476 .28399 L
s
P
p
.2 0 1 r
.022 w
.56505 .2386 m
.70476 .1932 L
s
P
p
.2 0 1 r
.022 w
.50096 .19203 m
.50096 .04513 L
s
P
p
.2 0 1 r
.022 w
.50096 .19203 m
.41462 .07319 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.56505 .2386 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.50096 .19203 L
s
P
p
.2 0 1 r
.022 w
.19594 .49704 m
.0771 .4107 L
s
P
p
.2 0 1 r
.022 w
.19594 .49704 m
.04905 .49704 L
s
P
p
.2 0 1 r
.022 w
.24251 .56114 m
.19712 .70084 L
s
P
p
.2 0 1 r
.022 w
.24251 .56114 m
.28791 .70084 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.19594 .49704 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.24251 .56114 L
s
P
p
.2 0 1 r
.022 w
.62685 .36531 m
.7132 .48415 L
s
P
p
.2 0 1 r
.022 w
.62685 .36531 m
.76656 .4107 L
s
P
p
.2 0 1 r
.022 w
.60237 .28996 m
.68871 .17112 L
s
P
p
.2 0 1 r
.022 w
.60237 .28996 m
.60237 .14306 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.62685 .36531 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.60237 .28996 L
s
P
p
.2 0 1 r
.022 w
.17633 .35744 m
.13093 .21773 L
s
P
p
.2 0 1 r
.022 w
.17633 .35744 m
.05749 .27109 L
s
P
p
.2 0 1 r
.022 w
.17633 .43666 m
.05749 .52301 L
s
P
p
.2 0 1 r
.022 w
.17633 .43666 m
.13093 .57637 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .35744 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .43666 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.34044 .58332 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.51609 .2386 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.24251 .51217 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.58724 .33653 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.20511 .39705 L
s
P
p
.2 0 1 r
.022 w
.49392 .66741 m
.37508 .75375 L
s
P
p
.2 0 1 r
.022 w
.49392 .66741 m
.44852 .80711 L
s
P
p
.2 0 1 r
.022 w
.56926 .64292 m
.6881 .72927 L
s
P
p
.2 0 1 r
.022 w
.56926 .64292 m
.71616 .64292 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.49392 .66741 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.56926 .64292 L
s
P
p
.2 0 1 r
.022 w
.50179 .21688 m
.64149 .17149 L
s
P
p
.2 0 1 r
.022 w
.50179 .21688 m
.58813 .09804 L
s
P
p
.2 0 1 r
.022 w
.42256 .21688 m
.33622 .09804 L
s
P
p
.2 0 1 r
.022 w
.42256 .21688 m
.28285 .17149 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.50179 .21688 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.42256 .21688 L
s
P
p
.2 0 1 r
.022 w
.35508 .64292 m
.20819 .64292 L
s
P
p
.2 0 1 r
.022 w
.35508 .64292 m
.23624 .72927 L
s
P
p
.2 0 1 r
.022 w
.43043 .66741 m
.47582 .80711 L
s
P
p
.2 0 1 r
.022 w
.43043 .66741 m
.54927 .75375 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.35508 .64292 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.43043 .66741 L
s
P
p
.2 0 1 r
.022 w
.62626 .28307 m
.76597 .32846 L
s
P
p
.2 0 1 r
.022 w
.62626 .28307 m
.76597 .23767 L
s
P
p
.2 0 1 r
.022 w
.56216 .2365 m
.56216 .0896 L
s
P
p
.2 0 1 r
.022 w
.56216 .2365 m
.47582 .11766 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.62626 .28307 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.56216 .2365 L
s
P
p
.2 0 1 r
.022 w
.25715 .54151 m
.13831 .45517 L
s
P
p
.2 0 1 r
.022 w
.25715 .54151 m
.11026 .54151 L
s
P
p
.2 0 1 r
.022 w
.30372 .60561 m
.25833 .74531 L
s
P
p
.2 0 1 r
.022 w
.30372 .60561 m
.34911 .74531 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.25715 .54151 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.30372 .60561 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5227 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.46217 .24566 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.40165 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5773 .28307 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.30372 .55664 L
s
P
p
.2 0 1 r
.022 w
.69628 .60561 m
.65089 .74531 L
s
P
p
.2 0 1 r
.022 w
.69628 .60561 m
.74167 .74531 L
s
P
p
.2 0 1 r
.022 w
.74285 .54151 m
.88974 .54151 L
s
P
p
.2 0 1 r
.022 w
.74285 .54151 m
.86169 .45517 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.69628 .60561 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.74285 .54151 L
s
P
p
.2 0 1 r
.022 w
.43784 .2365 m
.52418 .11766 L
s
P
p
.2 0 1 r
.022 w
.43784 .2365 m
.43784 .0896 L
s
P
p
.2 0 1 r
.022 w
.37374 .28307 m
.23403 .23767 L
s
P
p
.2 0 1 r
.022 w
.37374 .28307 m
.23403 .32846 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.43784 .2365 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.37374 .28307 L
s
P
p
.2 0 1 r
.022 w
.56957 .66741 m
.45073 .75375 L
s
P
p
.2 0 1 r
.022 w
.56957 .66741 m
.52418 .80711 L
s
P
p
.2 0 1 r
.022 w
.64492 .64292 m
.76376 .72927 L
s
P
p
.2 0 1 r
.022 w
.64492 .64292 m
.79181 .64292 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.56957 .66741 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.64492 .64292 L
s
P
p
.2 0 1 r
.022 w
.57744 .21688 m
.71715 .17149 L
s
P
p
.2 0 1 r
.022 w
.57744 .21688 m
.66378 .09804 L
s
P
p
.2 0 1 r
.022 w
.49821 .21688 m
.41187 .09804 L
s
P
p
.2 0 1 r
.022 w
.49821 .21688 m
.35851 .17149 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.57744 .21688 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.49821 .21688 L
s
P
p
.2 0 1 r
.022 w
.43074 .64292 m
.28384 .64292 L
s
P
p
.2 0 1 r
.022 w
.43074 .64292 m
.3119 .72927 L
s
P
p
.2 0 1 r
.022 w
.50608 .66741 m
.55148 .80711 L
s
P
p
.2 0 1 r
.022 w
.50608 .66741 m
.62492 .75375 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.43074 .64292 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.50608 .66741 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.69628 .55664 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4227 .28307 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.59835 .62779 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.53783 .24566 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4773 .62779 L
s
P
p
.2 0 1 r
.022 w
.82367 .43666 m
.86907 .57637 L
s
P
p
.2 0 1 r
.022 w
.82367 .43666 m
.94251 .52301 L
s
P
p
.2 0 1 r
.022 w
.82367 .35744 m
.94251 .27109 L
s
P
p
.2 0 1 r
.022 w
.82367 .35744 m
.86907 .21773 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .43666 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .35744 L
s
P
p
.2 0 1 r
.022 w
.39763 .28996 m
.39763 .14306 L
s
P
p
.2 0 1 r
.022 w
.39763 .28996 m
.31129 .17112 L
s
P
p
.2 0 1 r
.022 w
.37315 .36531 m
.23344 .4107 L
s
P
p
.2 0 1 r
.022 w
.37315 .36531 m
.2868 .48415 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.39763 .28996 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.37315 .36531 L
s
P
p
.2 0 1 r
.022 w
.75749 .56114 m
.71209 .70084 L
s
P
p
.2 0 1 r
.022 w
.75749 .56114 m
.80288 .70084 L
s
P
p
.2 0 1 r
.022 w
.80406 .49704 m
.95095 .49704 L
s
P
p
.2 0 1 r
.022 w
.80406 .49704 m
.9229 .4107 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.75749 .56114 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.80406 .49704 L
s
P
p
.2 0 1 r
.022 w
.49904 .19203 m
.58538 .07319 L
s
P
p
.2 0 1 r
.022 w
.49904 .19203 m
.49904 .04513 L
s
P
p
.2 0 1 r
.022 w
.43495 .2386 m
.29524 .1932 L
s
P
p
.2 0 1 r
.022 w
.43495 .2386 m
.29524 .28399 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.49904 .19203 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.43495 .2386 L
s
P
p
.2 0 1 r
.022 w
.63078 .62294 m
.51194 .70928 L
s
P
p
.2 0 1 r
.022 w
.63078 .62294 m
.58538 .76264 L
s
P
p
.2 0 1 r
.022 w
.70613 .59845 m
.82497 .6848 L
s
P
p
.2 0 1 r
.022 w
.70613 .59845 m
.85302 .59845 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.63078 .62294 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.70613 .59845 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.79489 .39705 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.41276 .33653 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.75749 .51217 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.48391 .2386 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.65956 .58332 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.40097 .39705 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.46217 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.53783 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.002 w
.29387 .59845 m
.14698 .59845 L
s
P
p
0 .4 1 r
.002 w
.29387 .59845 m
.17503 .6848 L
s
P
p
0 .4 1 r
.002 w
.36922 .62294 m
.41462 .76264 L
s
P
p
0 .4 1 r
.002 w
.36922 .62294 m
.48806 .70928 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.29387 .59845 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.36922 .62294 L
s
P
p
0 .4 1 r
.002 w
.56505 .2386 m
.70476 .28399 L
s
P
p
0 .4 1 r
.002 w
.56505 .2386 m
.70476 .1932 L
s
P
p
0 .4 1 r
.002 w
.50096 .19203 m
.50096 .04513 L
s
P
p
0 .4 1 r
.002 w
.50096 .19203 m
.41462 .07319 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.56505 .2386 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.50096 .19203 L
s
P
p
0 .4 1 r
.002 w
.19594 .49704 m
.0771 .4107 L
s
P
p
0 .4 1 r
.002 w
.19594 .49704 m
.04905 .49704 L
s
P
p
0 .4 1 r
.002 w
.24251 .56114 m
.19712 .70084 L
s
P
p
0 .4 1 r
.002 w
.24251 .56114 m
.28791 .70084 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.19594 .49704 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.24251 .56114 L
s
P
p
0 .4 1 r
.002 w
.62685 .36531 m
.7132 .48415 L
s
P
p
0 .4 1 r
.002 w
.62685 .36531 m
.76656 .4107 L
s
P
p
0 .4 1 r
.002 w
.60237 .28996 m
.68871 .17112 L
s
P
p
0 .4 1 r
.002 w
.60237 .28996 m
.60237 .14306 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.62685 .36531 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.60237 .28996 L
s
P
p
0 .4 1 r
.002 w
.17633 .35744 m
.13093 .21773 L
s
P
p
0 .4 1 r
.002 w
.17633 .35744 m
.05749 .27109 L
s
P
p
0 .4 1 r
.002 w
.17633 .43666 m
.05749 .52301 L
s
P
p
0 .4 1 r
.002 w
.17633 .43666 m
.13093 .57637 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .35744 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .43666 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.34044 .58332 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.51609 .2386 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.24251 .51217 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.58724 .33653 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.20511 .39705 L
s
P
p
0 .4 1 r
.002 w
.49392 .66741 m
.37508 .75375 L
s
P
p
0 .4 1 r
.002 w
.49392 .66741 m
.44852 .80711 L
s
P
p
0 .4 1 r
.002 w
.56926 .64292 m
.6881 .72927 L
s
P
p
0 .4 1 r
.002 w
.56926 .64292 m
.71616 .64292 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.49392 .66741 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.56926 .64292 L
s
P
p
0 .4 1 r
.002 w
.50179 .21688 m
.64149 .17149 L
s
P
p
0 .4 1 r
.002 w
.50179 .21688 m
.58813 .09804 L
s
P
p
0 .4 1 r
.002 w
.42256 .21688 m
.33622 .09804 L
s
P
p
0 .4 1 r
.002 w
.42256 .21688 m
.28285 .17149 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.50179 .21688 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.42256 .21688 L
s
P
p
0 .4 1 r
.002 w
.35508 .64292 m
.20819 .64292 L
s
P
p
0 .4 1 r
.002 w
.35508 .64292 m
.23624 .72927 L
s
P
p
0 .4 1 r
.002 w
.43043 .66741 m
.47582 .80711 L
s
P
p
0 .4 1 r
.002 w
.43043 .66741 m
.54927 .75375 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.35508 .64292 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.43043 .66741 L
s
P
p
0 .4 1 r
.002 w
.62626 .28307 m
.76597 .32846 L
s
P
p
0 .4 1 r
.002 w
.62626 .28307 m
.76597 .23767 L
s
P
p
0 .4 1 r
.002 w
.56216 .2365 m
.56216 .0896 L
s
P
p
0 .4 1 r
.002 w
.56216 .2365 m
.47582 .11766 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.62626 .28307 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.56216 .2365 L
s
P
p
0 .4 1 r
.002 w
.25715 .54151 m
.13831 .45517 L
s
P
p
0 .4 1 r
.002 w
.25715 .54151 m
.11026 .54151 L
s
P
p
0 .4 1 r
.002 w
.30372 .60561 m
.25833 .74531 L
s
P
p
0 .4 1 r
.002 w
.30372 .60561 m
.34911 .74531 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.25715 .54151 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.30372 .60561 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5227 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.46217 .24566 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.40165 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5773 .28307 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.30372 .55664 L
s
P
p
0 .4 1 r
.002 w
.69628 .60561 m
.65089 .74531 L
s
P
p
0 .4 1 r
.002 w
.69628 .60561 m
.74167 .74531 L
s
P
p
0 .4 1 r
.002 w
.74285 .54151 m
.88974 .54151 L
s
P
p
0 .4 1 r
.002 w
.74285 .54151 m
.86169 .45517 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.69628 .60561 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.74285 .54151 L
s
P
p
0 .4 1 r
.002 w
.43784 .2365 m
.52418 .11766 L
s
P
p
0 .4 1 r
.002 w
.43784 .2365 m
.43784 .0896 L
s
P
p
0 .4 1 r
.002 w
.37374 .28307 m
.23403 .23767 L
s
P
p
0 .4 1 r
.002 w
.37374 .28307 m
.23403 .32846 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.43784 .2365 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.37374 .28307 L
s
P
p
0 .4 1 r
.002 w
.56957 .66741 m
.45073 .75375 L
s
P
p
0 .4 1 r
.002 w
.56957 .66741 m
.52418 .80711 L
s
P
p
0 .4 1 r
.002 w
.64492 .64292 m
.76376 .72927 L
s
P
p
0 .4 1 r
.002 w
.64492 .64292 m
.79181 .64292 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.56957 .66741 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.64492 .64292 L
s
P
p
0 .4 1 r
.002 w
.57744 .21688 m
.71715 .17149 L
s
P
p
0 .4 1 r
.002 w
.57744 .21688 m
.66378 .09804 L
s
P
p
0 .4 1 r
.002 w
.49821 .21688 m
.41187 .09804 L
s
P
p
0 .4 1 r
.002 w
.49821 .21688 m
.35851 .17149 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.57744 .21688 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.49821 .21688 L
s
P
p
0 .4 1 r
.002 w
.43074 .64292 m
.28384 .64292 L
s
P
p
0 .4 1 r
.002 w
.43074 .64292 m
.3119 .72927 L
s
P
p
0 .4 1 r
.002 w
.50608 .66741 m
.55148 .80711 L
s
P
p
0 .4 1 r
.002 w
.50608 .66741 m
.62492 .75375 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.43074 .64292 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.50608 .66741 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.69628 .55664 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4227 .28307 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.59835 .62779 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.53783 .24566 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4773 .62779 L
s
P
p
0 .4 1 r
.002 w
.82367 .43666 m
.86907 .57637 L
s
P
p
0 .4 1 r
.002 w
.82367 .43666 m
.94251 .52301 L
s
P
p
0 .4 1 r
.002 w
.82367 .35744 m
.94251 .27109 L
s
P
p
0 .4 1 r
.002 w
.82367 .35744 m
.86907 .21773 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .43666 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .35744 L
s
P
p
0 .4 1 r
.002 w
.39763 .28996 m
.39763 .14306 L
s
P
p
0 .4 1 r
.002 w
.39763 .28996 m
.31129 .17112 L
s
P
p
0 .4 1 r
.002 w
.37315 .36531 m
.23344 .4107 L
s
P
p
0 .4 1 r
.002 w
.37315 .36531 m
.2868 .48415 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.39763 .28996 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.37315 .36531 L
s
P
p
0 .4 1 r
.002 w
.75749 .56114 m
.71209 .70084 L
s
P
p
0 .4 1 r
.002 w
.75749 .56114 m
.80288 .70084 L
s
P
p
0 .4 1 r
.002 w
.80406 .49704 m
.95095 .49704 L
s
P
p
0 .4 1 r
.002 w
.80406 .49704 m
.9229 .4107 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.75749 .56114 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.80406 .49704 L
s
P
p
0 .4 1 r
.002 w
.49904 .19203 m
.58538 .07319 L
s
P
p
0 .4 1 r
.002 w
.49904 .19203 m
.49904 .04513 L
s
P
p
0 .4 1 r
.002 w
.43495 .2386 m
.29524 .1932 L
s
P
p
0 .4 1 r
.002 w
.43495 .2386 m
.29524 .28399 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.49904 .19203 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.43495 .2386 L
s
P
p
0 .4 1 r
.002 w
.63078 .62294 m
.51194 .70928 L
s
P
p
0 .4 1 r
.002 w
.63078 .62294 m
.58538 .76264 L
s
P
p
0 .4 1 r
.002 w
.70613 .59845 m
.82497 .6848 L
s
P
p
0 .4 1 r
.002 w
.70613 .59845 m
.85302 .59845 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.63078 .62294 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.70613 .59845 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.79489 .39705 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.41276 .33653 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.75749 .51217 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.48391 .2386 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.65956 .58332 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.40097 .39705 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.46217 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.53783 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0663263 0.952381 [
[ 0 0 0 0 ]
[ 1 .81973 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .81973 L
0 .81973 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.19594 .46539 m
.0771 .37905 L
s
P
p
.2 0 1 r
.002 w
.19594 .46539 m
.04905 .46539 L
s
P
p
.2 0 1 r
.002 w
.24251 .52948 m
.19712 .66919 L
s
P
p
.2 0 1 r
.002 w
.24251 .52948 m
.28791 .66919 L
s
P
p
0 .4 1 r
.018 w
.24251 .48052 m
.19594 .46539 L
s
P
p
0 .4 1 r
.018 w
.24251 .48052 m
.24251 .52948 L
s
P
p
.2 0 1 r
.002 w
.60599 .2654 m
.72483 .35175 L
s
P
p
.2 0 1 r
.002 w
.60599 .2654 m
.75288 .2654 L
s
P
p
.2 0 1 r
.002 w
.55942 .20131 m
.60481 .0616 L
s
P
p
.2 0 1 r
.002 w
.55942 .20131 m
.51403 .0616 L
s
P
p
0 .4 1 r
.018 w
.55942 .25027 m
.60599 .2654 L
s
P
p
0 .4 1 r
.018 w
.55942 .25027 m
.55942 .20131 L
s
P
p
.2 0 1 r
.016 w
.40097 .3654 m
.24251 .48052 L
s
P
p
.2 0 1 r
.016 w
.40097 .3654 m
.55942 .25027 L
s
P
p
.2 0 1 r
.002 w
.35508 .61127 m
.20819 .61127 L
s
P
p
.2 0 1 r
.002 w
.35508 .61127 m
.23624 .69761 L
s
P
p
.2 0 1 r
.002 w
.43043 .63575 m
.47582 .77546 L
s
P
p
.2 0 1 r
.002 w
.43043 .63575 m
.54927 .72209 L
s
P
p
0 .4 1 r
.018 w
.40165 .59614 m
.35508 .61127 L
s
P
p
0 .4 1 r
.018 w
.40165 .59614 m
.43043 .63575 L
s
P
p
.2 0 1 r
.002 w
.56926 .20846 m
.71616 .20846 L
s
P
p
.2 0 1 r
.002 w
.56926 .20846 m
.6881 .12212 L
s
P
p
.2 0 1 r
.002 w
.49392 .18398 m
.44852 .04427 L
s
P
p
.2 0 1 r
.002 w
.49392 .18398 m
.37508 .09763 L
s
P
p
0 .4 1 r
.018 w
.5227 .22359 m
.56926 .20846 L
s
P
p
0 .4 1 r
.018 w
.5227 .22359 m
.49392 .18398 L
s
P
p
.2 0 1 r
.016 w
.46217 .40986 m
.40165 .59614 L
s
P
p
.2 0 1 r
.016 w
.46217 .40986 m
.5227 .22359 L
s
P
p
.2 0 1 r
.002 w
.56957 .63575 m
.45073 .72209 L
s
P
p
.2 0 1 r
.002 w
.56957 .63575 m
.52418 .77546 L
s
P
p
.2 0 1 r
.002 w
.64492 .61127 m
.76376 .69761 L
s
P
p
.2 0 1 r
.002 w
.64492 .61127 m
.79181 .61127 L
s
P
p
0 .4 1 r
.018 w
.59835 .59614 m
.56957 .63575 L
s
P
p
0 .4 1 r
.018 w
.59835 .59614 m
.64492 .61127 L
s
P
p
.2 0 1 r
.002 w
.50608 .18398 m
.62492 .09763 L
s
P
p
.2 0 1 r
.002 w
.50608 .18398 m
.55148 .04427 L
s
P
p
.2 0 1 r
.002 w
.43074 .20846 m
.3119 .12212 L
s
P
p
.2 0 1 r
.002 w
.43074 .20846 m
.28384 .20846 L
s
P
p
0 .4 1 r
.018 w
.4773 .22359 m
.50608 .18398 L
s
P
p
0 .4 1 r
.018 w
.4773 .22359 m
.43074 .20846 L
s
P
p
.2 0 1 r
.016 w
.53783 .40986 m
.59835 .59614 L
s
P
p
.2 0 1 r
.016 w
.53783 .40986 m
.4773 .22359 L
s
P
p
.2 0 1 r
.002 w
.75749 .52948 m
.71209 .66919 L
s
P
p
.2 0 1 r
.002 w
.75749 .52948 m
.80288 .66919 L
s
P
p
.2 0 1 r
.002 w
.80406 .46539 m
.95095 .46539 L
s
P
p
.2 0 1 r
.002 w
.80406 .46539 m
.9229 .37905 L
s
P
p
0 .4 1 r
.018 w
.75749 .48052 m
.75749 .52948 L
s
P
p
0 .4 1 r
.018 w
.75749 .48052 m
.80406 .46539 L
s
P
p
.2 0 1 r
.002 w
.44058 .20131 m
.48597 .0616 L
s
P
p
.2 0 1 r
.002 w
.44058 .20131 m
.39519 .0616 L
s
P
p
.2 0 1 r
.002 w
.39401 .2654 m
.24712 .2654 L
s
P
p
.2 0 1 r
.002 w
.39401 .2654 m
.27517 .35175 L
s
P
p
0 .4 1 r
.018 w
.44058 .25027 m
.44058 .20131 L
s
P
p
0 .4 1 r
.018 w
.44058 .25027 m
.39401 .2654 L
s
P
p
.2 0 1 r
.016 w
.59903 .3654 m
.75749 .48052 L
s
P
p
.2 0 1 r
.016 w
.59903 .3654 m
.44058 .25027 L
s
P
p
1 .6 0 r
.016 w
.5 .29344 m
.40097 .3654 L
s
P
p
1 .6 0 r
.016 w
.5 .29344 m
.46217 .40986 L
s
P
p
1 .6 0 r
.016 w
.5 .29344 m
.53783 .40986 L
s
P
p
1 .6 0 r
.016 w
.5 .29344 m
.59903 .3654 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0452007 0.952381 [
[ 0 0 0 0 ]
[ 1 .86198 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .86198 L
0 .86198 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29525 .61675 m
.1545 .61675 L
s
P
p
.2 0 1 r
.002 w
.29525 .61675 m
.18138 .69948 L
s
P
p
.2 0 1 r
.002 w
.36745 .64021 m
.41094 .77407 L
s
P
p
.2 0 1 r
.002 w
.36745 .64021 m
.48131 .72294 L
s
P
p
0 .4 1 r
.018 w
.33987 .60226 m
.29525 .61675 L
s
P
p
0 .4 1 r
.018 w
.33987 .60226 m
.36745 .64021 L
s
P
p
.2 0 1 r
.002 w
.57612 .23067 m
.70998 .27416 L
s
P
p
.2 0 1 r
.002 w
.57612 .23067 m
.70998 .18717 L
s
P
p
.2 0 1 r
.002 w
.51471 .18605 m
.51471 .0453 L
s
P
p
.2 0 1 r
.002 w
.51471 .18605 m
.43198 .07218 L
s
P
p
0 .4 1 r
.018 w
.5292 .23067 m
.57612 .23067 L
s
P
p
0 .4 1 r
.018 w
.5292 .23067 m
.51471 .18605 L
s
P
p
.2 0 1 r
.002 w
.18969 .51106 m
.07582 .42834 L
s
P
p
.2 0 1 r
.002 w
.18969 .51106 m
.04894 .51106 L
s
P
p
.2 0 1 r
.002 w
.23431 .57248 m
.19082 .70634 L
s
P
p
.2 0 1 r
.002 w
.23431 .57248 m
.2778 .70634 L
s
P
p
0 .4 1 r
.018 w
.23431 .52556 m
.18969 .51106 L
s
P
p
0 .4 1 r
.018 w
.23431 .52556 m
.23431 .57248 L
s
P
p
.2 0 1 r
.002 w
.64385 .3638 m
.72658 .47767 L
s
P
p
.2 0 1 r
.002 w
.64385 .3638 m
.77771 .4073 L
s
P
p
.2 0 1 r
.002 w
.6204 .29161 m
.70313 .17774 L
s
P
p
.2 0 1 r
.002 w
.6204 .29161 m
.6204 .15086 L
s
P
p
0 .4 1 r
.018 w
.6059 .33623 m
.64385 .3638 L
s
P
p
0 .4 1 r
.018 w
.6059 .33623 m
.6204 .29161 L
s
P
p
.2 0 1 r
.002 w
.16641 .36351 m
.12292 .22965 L
s
P
p
.2 0 1 r
.002 w
.16641 .36351 m
.05255 .28078 L
s
P
p
.2 0 1 r
.002 w
.16641 .43942 m
.05255 .52215 L
s
P
p
.2 0 1 r
.002 w
.16641 .43942 m
.12292 .57328 L
s
P
p
0 .4 1 r
.018 w
.19399 .40147 m
.16641 .36351 L
s
P
p
0 .4 1 r
.018 w
.19399 .40147 m
.16641 .43942 L
s
P
p
.2 0 1 r
.016 w
.40511 .40147 m
.33987 .60226 L
s
P
p
.2 0 1 r
.016 w
.40511 .40147 m
.5292 .23067 L
s
P
p
.2 0 1 r
.016 w
.40511 .40147 m
.23431 .52556 L
s
P
p
.2 0 1 r
.016 w
.40511 .40147 m
.6059 .33623 L
s
P
p
.2 0 1 r
.016 w
.40511 .40147 m
.19399 .40147 L
s
P
p
.2 0 1 r
.002 w
.50142 .68282 m
.38755 .76555 L
s
P
p
.2 0 1 r
.002 w
.50142 .68282 m
.45793 .81668 L
s
P
p
.2 0 1 r
.002 w
.57362 .65936 m
.68748 .74209 L
s
P
p
.2 0 1 r
.002 w
.57362 .65936 m
.71436 .65936 L
s
P
p
0 .4 1 r
.018 w
.529 .64486 m
.50142 .68282 L
s
P
p
0 .4 1 r
.018 w
.529 .64486 m
.57362 .65936 L
s
P
p
.2 0 1 r
.002 w
.50171 .20538 m
.63557 .16188 L
s
P
p
.2 0 1 r
.002 w
.50171 .20538 m
.58444 .09151 L
s
P
p
.2 0 1 r
.002 w
.4258 .20538 m
.34307 .09151 L
s
P
p
.2 0 1 r
.002 w
.4258 .20538 m
.29194 .16188 L
s
P
p
0 .4 1 r
.018 w
.46376 .23295 m
.50171 .20538 L
s
P
p
0 .4 1 r
.018 w
.46376 .23295 m
.4258 .20538 L
s
P
p
.2 0 1 r
.002 w
.3539 .65936 m
.21315 .65936 L
s
P
p
.2 0 1 r
.002 w
.3539 .65936 m
.24003 .74209 L
s
P
p
.2 0 1 r
.002 w
.42609 .68282 m
.46959 .81668 L
s
P
p
.2 0 1 r
.002 w
.42609 .68282 m
.53996 .76555 L
s
P
p
0 .4 1 r
.018 w
.39852 .64486 m
.3539 .65936 L
s
P
p
0 .4 1 r
.018 w
.39852 .64486 m
.42609 .68282 L
s
P
p
.2 0 1 r
.002 w
.63477 .27328 m
.76862 .31677 L
s
P
p
.2 0 1 r
.002 w
.63477 .27328 m
.76862 .22978 L
s
P
p
.2 0 1 r
.002 w
.57335 .22866 m
.57335 .08791 L
s
P
p
.2 0 1 r
.002 w
.57335 .22866 m
.49062 .11479 L
s
P
p
0 .4 1 r
.018 w
.58785 .27328 m
.63477 .27328 L
s
P
p
0 .4 1 r
.018 w
.58785 .27328 m
.57335 .22866 L
s
P
p
.2 0 1 r
.002 w
.24833 .55367 m
.13447 .47094 L
s
P
p
.2 0 1 r
.002 w
.24833 .55367 m
.10759 .55367 L
s
P
p
.2 0 1 r
.002 w
.29295 .61509 m
.24946 .74895 L
s
P
p
.2 0 1 r
.002 w
.29295 .61509 m
.33645 .74895 L
s
P
p
0 .4 1 r
.018 w
.29295 .56817 m
.24833 .55367 L
s
P
p
0 .4 1 r
.018 w
.29295 .56817 m
.29295 .61509 L
s
P
p
.2 0 1 r
.016 w
.46376 .44408 m
.529 .64486 L
s
P
p
.2 0 1 r
.016 w
.46376 .44408 m
.46376 .23295 L
s
P
p
.2 0 1 r
.016 w
.46376 .44408 m
.39852 .64486 L
s
P
p
.2 0 1 r
.016 w
.46376 .44408 m
.58785 .27328 L
s
P
p
.2 0 1 r
.016 w
.46376 .44408 m
.29295 .56817 L
s
P
p
.2 0 1 r
.002 w
.70705 .61509 m
.66355 .74895 L
s
P
p
.2 0 1 r
.002 w
.70705 .61509 m
.75054 .74895 L
s
P
p
.2 0 1 r
.002 w
.75167 .55367 m
.89241 .55367 L
s
P
p
.2 0 1 r
.002 w
.75167 .55367 m
.86553 .47094 L
s
P
p
0 .4 1 r
.018 w
.70705 .56817 m
.70705 .61509 L
s
P
p
0 .4 1 r
.018 w
.70705 .56817 m
.75167 .55367 L
s
P
p
.2 0 1 r
.002 w
.42665 .22866 m
.50938 .11479 L
s
P
p
.2 0 1 r
.002 w
.42665 .22866 m
.42665 .08791 L
s
P
p
.2 0 1 r
.002 w
.36523 .27328 m
.23138 .22978 L
s
P
p
.2 0 1 r
.002 w
.36523 .27328 m
.23138 .31677 L
s
P
p
0 .4 1 r
.018 w
.41215 .27328 m
.42665 .22866 L
s
P
p
0 .4 1 r
.018 w
.41215 .27328 m
.36523 .27328 L
s
P
p
.2 0 1 r
.002 w
.57391 .68282 m
.46004 .76555 L
s
P
p
.2 0 1 r
.002 w
.57391 .68282 m
.53041 .81668 L
s
P
p
.2 0 1 r
.002 w
.6461 .65936 m
.75997 .74209 L
s
P
p
.2 0 1 r
.002 w
.6461 .65936 m
.78685 .65936 L
s
P
p
0 .4 1 r
.018 w
.60148 .64486 m
.57391 .68282 L
s
P
p
0 .4 1 r
.018 w
.60148 .64486 m
.6461 .65936 L
s
P
p
.2 0 1 r
.002 w
.5742 .20538 m
.70806 .16188 L
s
P
p
.2 0 1 r
.002 w
.5742 .20538 m
.65693 .09151 L
s
P
p
.2 0 1 r
.002 w
.49829 .20538 m
.41556 .09151 L
s
P
p
.2 0 1 r
.002 w
.49829 .20538 m
.36443 .16188 L
s
P
p
0 .4 1 r
.018 w
.53624 .23295 m
.5742 .20538 L
s
P
p
0 .4 1 r
.018 w
.53624 .23295 m
.49829 .20538 L
s
P
p
.2 0 1 r
.002 w
.42638 .65936 m
.28564 .65936 L
s
P
p
.2 0 1 r
.002 w
.42638 .65936 m
.31252 .74209 L
s
P
p
.2 0 1 r
.002 w
.49858 .68282 m
.54207 .81668 L
s
P
p
.2 0 1 r
.002 w
.49858 .68282 m
.61245 .76555 L
s
P
p
0 .4 1 r
.018 w
.471 .64486 m
.42638 .65936 L
s
P
p
0 .4 1 r
.018 w
.471 .64486 m
.49858 .68282 L
s
P
p
.2 0 1 r
.016 w
.53624 .44408 m
.70705 .56817 L
s
P
p
.2 0 1 r
.016 w
.53624 .44408 m
.41215 .27328 L
s
P
p
.2 0 1 r
.016 w
.53624 .44408 m
.60148 .64486 L
s
P
p
.2 0 1 r
.016 w
.53624 .44408 m
.53624 .23295 L
s
P
p
.2 0 1 r
.016 w
.53624 .44408 m
.471 .64486 L
s
P
p
.2 0 1 r
.002 w
.83359 .43942 m
.87708 .57328 L
s
P
p
.2 0 1 r
.002 w
.83359 .43942 m
.94745 .52215 L
s
P
p
.2 0 1 r
.002 w
.83359 .36351 m
.94745 .28078 L
s
P
p
.2 0 1 r
.002 w
.83359 .36351 m
.87708 .22965 L
s
P
p
0 .4 1 r
.018 w
.80601 .40147 m
.83359 .43942 L
s
P
p
0 .4 1 r
.018 w
.80601 .40147 m
.83359 .36351 L
s
P
p
.2 0 1 r
.002 w
.3796 .29161 m
.3796 .15086 L
s
P
p
.2 0 1 r
.002 w
.3796 .29161 m
.29687 .17774 L
s
P
p
.2 0 1 r
.002 w
.35615 .3638 m
.22229 .4073 L
s
P
p
.2 0 1 r
.002 w
.35615 .3638 m
.27342 .47767 L
s
P
p
0 .4 1 r
.018 w
.3941 .33623 m
.3796 .29161 L
s
P
p
0 .4 1 r
.018 w
.3941 .33623 m
.35615 .3638 L
s
P
p
.2 0 1 r
.002 w
.76569 .57248 m
.7222 .70634 L
s
P
p
.2 0 1 r
.002 w
.76569 .57248 m
.80918 .70634 L
s
P
p
.2 0 1 r
.002 w
.81031 .51106 m
.95106 .51106 L
s
P
p
.2 0 1 r
.002 w
.81031 .51106 m
.92418 .42834 L
s
P
p
0 .4 1 r
.018 w
.76569 .52556 m
.76569 .57248 L
s
P
p
0 .4 1 r
.018 w
.76569 .52556 m
.81031 .51106 L
s
P
p
.2 0 1 r
.002 w
.48529 .18605 m
.56802 .07218 L
s
P
p
.2 0 1 r
.002 w
.48529 .18605 m
.48529 .0453 L
s
P
p
.2 0 1 r
.002 w
.42388 .23067 m
.29002 .18717 L
s
P
p
.2 0 1 r
.002 w
.42388 .23067 m
.29002 .27416 L
s
P
p
0 .4 1 r
.018 w
.4708 .23067 m
.48529 .18605 L
s
P
p
0 .4 1 r
.018 w
.4708 .23067 m
.42388 .23067 L
s
P
p
.2 0 1 r
.002 w
.63255 .64021 m
.51869 .72294 L
s
P
p
.2 0 1 r
.002 w
.63255 .64021 m
.58906 .77407 L
s
P
p
.2 0 1 r
.002 w
.70475 .61675 m
.81862 .69948 L
s
P
p
.2 0 1 r
.002 w
.70475 .61675 m
.8455 .61675 L
s
P
p
0 .4 1 r
.018 w
.66013 .60226 m
.63255 .64021 L
s
P
p
0 .4 1 r
.018 w
.66013 .60226 m
.70475 .61675 L
s
P
p
.2 0 1 r
.016 w
.59489 .40147 m
.80601 .40147 L
s
P
p
.2 0 1 r
.016 w
.59489 .40147 m
.3941 .33623 L
s
P
p
.2 0 1 r
.016 w
.59489 .40147 m
.76569 .52556 L
s
P
p
.2 0 1 r
.016 w
.59489 .40147 m
.4708 .23067 L
s
P
p
.2 0 1 r
.016 w
.59489 .40147 m
.66013 .60226 L
s
P
p
1 .6 0 r
.016 w
.5 .33253 m
.40511 .40147 L
s
P
p
1 .6 0 r
.016 w
.5 .33253 m
.46376 .44408 L
s
P
p
1 .6 0 r
.016 w
.5 .33253 m
.53624 .44408 L
s
P
p
1 .6 0 r
.016 w
.5 .33253 m
.59489 .40147 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.14698 .59845 L
s
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.17503 .6848 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.41462 .76264 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.48806 .70928 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.29387 .59845 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.36922 .62294 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .28399 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .1932 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.50096 .04513 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.41462 .07319 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.56505 .2386 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.50096 .19203 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.0771 .4107 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.04905 .49704 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.19712 .70084 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.28791 .70084 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.19594 .49704 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.24251 .56114 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.7132 .48415 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.76656 .4107 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.68871 .17112 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.60237 .14306 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.62685 .36531 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.60237 .28996 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.13093 .21773 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.05749 .27109 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.05749 .52301 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.13093 .57637 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .35744 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .43666 L
s
P
p
.2 0 1 r
.018 w
.40097 .39705 m
.34044 .58332 L
s
P
p
.2 0 1 r
.018 w
.40097 .39705 m
.51609 .2386 L
s
P
p
.2 0 1 r
.018 w
.40097 .39705 m
.24251 .51217 L
s
P
p
.2 0 1 r
.018 w
.40097 .39705 m
.58724 .33653 L
s
P
p
.2 0 1 r
.018 w
.40097 .39705 m
.20511 .39705 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.37508 .75375 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.44852 .80711 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.6881 .72927 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.71616 .64292 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.49392 .66741 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.56926 .64292 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.64149 .17149 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.58813 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.33622 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.28285 .17149 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.50179 .21688 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.42256 .21688 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.20819 .64292 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.23624 .72927 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.47582 .80711 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.54927 .75375 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.35508 .64292 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.43043 .66741 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .32846 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .23767 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.56216 .0896 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.47582 .11766 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.62626 .28307 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.56216 .2365 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.13831 .45517 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.11026 .54151 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.25833 .74531 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.34911 .74531 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.25715 .54151 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.30372 .60561 L
s
P
p
.2 0 1 r
.018 w
.46217 .44152 m
.5227 .62779 L
s
P
p
.2 0 1 r
.018 w
.46217 .44152 m
.46217 .24566 L
s
P
p
.2 0 1 r
.018 w
.46217 .44152 m
.40165 .62779 L
s
P
p
.2 0 1 r
.018 w
.46217 .44152 m
.5773 .28307 L
s
P
p
.2 0 1 r
.018 w
.46217 .44152 m
.30372 .55664 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.65089 .74531 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.74167 .74531 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.88974 .54151 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.86169 .45517 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.69628 .60561 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.74285 .54151 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.52418 .11766 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.43784 .0896 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .23767 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .32846 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.43784 .2365 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.37374 .28307 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.45073 .75375 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.52418 .80711 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.76376 .72927 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.79181 .64292 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.56957 .66741 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.64492 .64292 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.71715 .17149 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.66378 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.41187 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.35851 .17149 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.57744 .21688 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.49821 .21688 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.28384 .64292 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.3119 .72927 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.55148 .80711 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.62492 .75375 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.43074 .64292 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.50608 .66741 L
s
P
p
.2 0 1 r
.018 w
.53783 .44152 m
.69628 .55664 L
s
P
p
.2 0 1 r
.018 w
.53783 .44152 m
.4227 .28307 L
s
P
p
.2 0 1 r
.018 w
.53783 .44152 m
.59835 .62779 L
s
P
p
.2 0 1 r
.018 w
.53783 .44152 m
.53783 .24566 L
s
P
p
.2 0 1 r
.018 w
.53783 .44152 m
.4773 .62779 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.86907 .57637 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.94251 .52301 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.94251 .27109 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.86907 .21773 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .43666 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .35744 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.39763 .14306 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.31129 .17112 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.23344 .4107 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.2868 .48415 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.39763 .28996 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.37315 .36531 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.71209 .70084 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.80288 .70084 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.95095 .49704 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.9229 .4107 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.75749 .56114 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.80406 .49704 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.58538 .07319 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.49904 .04513 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .1932 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .28399 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.49904 .19203 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.43495 .2386 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.51194 .70928 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.58538 .76264 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.82497 .6848 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.85302 .59845 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.63078 .62294 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.70613 .59845 L
s
P
p
.2 0 1 r
.018 w
.59903 .39705 m
.79489 .39705 L
s
P
p
.2 0 1 r
.018 w
.59903 .39705 m
.41276 .33653 L
s
P
p
.2 0 1 r
.018 w
.59903 .39705 m
.75749 .51217 L
s
P
p
.2 0 1 r
.018 w
.59903 .39705 m
.48391 .2386 L
s
P
p
.2 0 1 r
.018 w
.59903 .39705 m
.65956 .58332 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.40097 .39705 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.46217 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.53783 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.14698 .59845 L
s
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.17503 .6848 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.41462 .76264 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.48806 .70928 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.29387 .59845 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.36922 .62294 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .28399 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .1932 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.50096 .04513 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.41462 .07319 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.56505 .2386 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.50096 .19203 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.0771 .4107 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.04905 .49704 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.19712 .70084 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.28791 .70084 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.19594 .49704 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.24251 .56114 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.7132 .48415 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.76656 .4107 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.68871 .17112 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.60237 .14306 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.62685 .36531 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.60237 .28996 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.13093 .21773 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.05749 .27109 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.05749 .52301 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.13093 .57637 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .35744 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .43666 L
s
P
p
0 .4 1 r
.016 w
.40097 .39705 m
.34044 .58332 L
s
P
p
0 .4 1 r
.016 w
.40097 .39705 m
.51609 .2386 L
s
P
p
0 .4 1 r
.016 w
.40097 .39705 m
.24251 .51217 L
s
P
p
0 .4 1 r
.016 w
.40097 .39705 m
.58724 .33653 L
s
P
p
0 .4 1 r
.016 w
.40097 .39705 m
.20511 .39705 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.37508 .75375 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.44852 .80711 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.6881 .72927 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.71616 .64292 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.49392 .66741 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.56926 .64292 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.64149 .17149 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.58813 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.33622 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.28285 .17149 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.50179 .21688 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.42256 .21688 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.20819 .64292 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.23624 .72927 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.47582 .80711 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.54927 .75375 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.35508 .64292 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.43043 .66741 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .32846 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .23767 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.56216 .0896 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.47582 .11766 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.62626 .28307 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.56216 .2365 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.13831 .45517 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.11026 .54151 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.25833 .74531 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.34911 .74531 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.25715 .54151 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.30372 .60561 L
s
P
p
0 .4 1 r
.016 w
.46217 .44152 m
.5227 .62779 L
s
P
p
0 .4 1 r
.016 w
.46217 .44152 m
.46217 .24566 L
s
P
p
0 .4 1 r
.016 w
.46217 .44152 m
.40165 .62779 L
s
P
p
0 .4 1 r
.016 w
.46217 .44152 m
.5773 .28307 L
s
P
p
0 .4 1 r
.016 w
.46217 .44152 m
.30372 .55664 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.65089 .74531 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.74167 .74531 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.88974 .54151 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.86169 .45517 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.69628 .60561 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.74285 .54151 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.52418 .11766 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.43784 .0896 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .23767 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .32846 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.43784 .2365 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.37374 .28307 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.45073 .75375 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.52418 .80711 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.76376 .72927 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.79181 .64292 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.56957 .66741 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.64492 .64292 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.71715 .17149 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.66378 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.41187 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.35851 .17149 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.57744 .21688 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.49821 .21688 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.28384 .64292 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.3119 .72927 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.55148 .80711 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.62492 .75375 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.43074 .64292 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.50608 .66741 L
s
P
p
0 .4 1 r
.016 w
.53783 .44152 m
.69628 .55664 L
s
P
p
0 .4 1 r
.016 w
.53783 .44152 m
.4227 .28307 L
s
P
p
0 .4 1 r
.016 w
.53783 .44152 m
.59835 .62779 L
s
P
p
0 .4 1 r
.016 w
.53783 .44152 m
.53783 .24566 L
s
P
p
0 .4 1 r
.016 w
.53783 .44152 m
.4773 .62779 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.86907 .57637 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.94251 .52301 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.94251 .27109 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.86907 .21773 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .43666 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .35744 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.39763 .14306 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.31129 .17112 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.23344 .4107 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.2868 .48415 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.39763 .28996 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.37315 .36531 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.71209 .70084 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.80288 .70084 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.95095 .49704 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.9229 .4107 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.75749 .56114 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.80406 .49704 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.58538 .07319 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.49904 .04513 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .1932 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .28399 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.49904 .19203 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.43495 .2386 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.51194 .70928 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.58538 .76264 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.82497 .6848 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.85302 .59845 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.63078 .62294 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.70613 .59845 L
s
P
p
0 .4 1 r
.016 w
.59903 .39705 m
.79489 .39705 L
s
P
p
0 .4 1 r
.016 w
.59903 .39705 m
.41276 .33653 L
s
P
p
0 .4 1 r
.016 w
.59903 .39705 m
.75749 .51217 L
s
P
p
0 .4 1 r
.016 w
.59903 .39705 m
.48391 .2386 L
s
P
p
0 .4 1 r
.016 w
.59903 .39705 m
.65956 .58332 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.40097 .39705 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.46217 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.53783 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0760741 0.952381 [
[ 0 0 0 0 ]
[ 1 .80023 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .80023 L
0 .80023 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.33703 .57809 m
.25648 .68896 L
s
P
p
.2 0 1 r
.002 w
.33703 .57809 m
.33703 .71513 L
s
P
p
0 .4 1 r
.018 w
.35115 .53464 m
.33703 .57809 L
s
P
p
.2 0 1 r
.002 w
.54186 .17609 m
.65273 .09554 L
s
P
p
.2 0 1 r
.002 w
.54186 .17609 m
.58421 .04575 L
s
P
p
0 .4 1 r
.018 w
.51501 .21304 m
.54186 .17609 L
s
P
p
.2 0 1 r
.002 w
.22283 .49512 m
.0925 .53746 L
s
P
p
.2 0 1 r
.002 w
.22283 .49512 m
.14228 .60598 L
s
P
p
0 .4 1 r
.018 w
.25979 .46827 m
.22283 .49512 L
s
P
p
.2 0 1 r
.002 w
.62483 .29029 m
.76187 .29029 L
s
P
p
.2 0 1 r
.002 w
.62483 .29029 m
.7357 .20974 L
s
P
p
0 .4 1 r
.018 w
.58139 .3044 m
.62483 .29029 L
s
P
p
.2 0 1 r
.002 w
.17921 .36087 m
.04888 .31852 L
s
P
p
.2 0 1 r
.002 w
.17921 .36087 m
.04888 .40321 L
s
P
p
0 .4 1 r
.018 w
.22489 .36087 m
.17921 .36087 L
s
P
p
.2 0 1 r
.016 w
.40761 .36087 m
.35115 .53464 L
s
P
p
.2 0 1 r
.016 w
.40761 .36087 m
.51501 .21304 L
s
P
p
.2 0 1 r
.016 w
.40761 .36087 m
.25979 .46827 L
s
P
p
.2 0 1 r
.016 w
.40761 .36087 m
.58139 .3044 L
s
P
p
.2 0 1 r
.016 w
.40761 .36087 m
.22489 .36087 L
s
P
p
.2 0 1 r
.002 w
.53529 .61957 m
.53529 .75661 L
s
P
p
.2 0 1 r
.002 w
.53529 .61957 m
.61584 .73044 L
s
P
p
0 .4 1 r
.018 w
.52117 .57613 m
.53529 .61957 L
s
P
p
.2 0 1 r
.002 w
.46471 .17395 m
.50706 .04362 L
s
P
p
.2 0 1 r
.002 w
.46471 .17395 m
.42236 .04362 L
s
P
p
0 .4 1 r
.018 w
.46471 .21963 m
.46471 .17395 L
s
P
p
.2 0 1 r
.002 w
.39413 .61957 m
.31358 .73044 L
s
P
p
.2 0 1 r
.002 w
.39413 .61957 m
.39413 .75661 L
s
P
p
0 .4 1 r
.018 w
.40825 .57613 m
.39413 .61957 L
s
P
p
.2 0 1 r
.002 w
.59896 .21757 m
.70983 .13702 L
s
P
p
.2 0 1 r
.002 w
.59896 .21757 m
.64131 .08724 L
s
P
p
0 .4 1 r
.018 w
.57211 .25453 m
.59896 .21757 L
s
P
p
.2 0 1 r
.002 w
.27993 .5366 m
.1496 .57895 L
s
P
p
.2 0 1 r
.002 w
.27993 .5366 m
.19938 .64747 L
s
P
p
0 .4 1 r
.018 w
.31689 .50975 m
.27993 .5366 L
s
P
p
.2 0 1 r
.016 w
.46471 .40235 m
.52117 .57613 L
s
P
p
.2 0 1 r
.016 w
.46471 .40235 m
.46471 .21963 L
s
P
p
.2 0 1 r
.016 w
.46471 .40235 m
.40825 .57613 L
s
P
p
.2 0 1 r
.016 w
.46471 .40235 m
.57211 .25453 L
s
P
p
.2 0 1 r
.016 w
.46471 .40235 m
.31689 .50975 L
s
P
p
.2 0 1 r
.002 w
.72007 .5366 m
.80062 .64747 L
s
P
p
.2 0 1 r
.002 w
.72007 .5366 m
.8504 .57895 L
s
P
p
0 .4 1 r
.018 w
.68311 .50975 m
.72007 .5366 L
s
P
p
.2 0 1 r
.002 w
.40104 .21757 m
.35869 .08724 L
s
P
p
.2 0 1 r
.002 w
.40104 .21757 m
.29017 .13702 L
s
P
p
0 .4 1 r
.018 w
.42789 .25453 m
.40104 .21757 L
s
P
p
.2 0 1 r
.002 w
.60587 .61957 m
.60587 .75661 L
s
P
p
.2 0 1 r
.002 w
.60587 .61957 m
.68642 .73044 L
s
P
p
0 .4 1 r
.018 w
.59175 .57613 m
.60587 .61957 L
s
P
p
.2 0 1 r
.002 w
.53529 .17395 m
.57764 .04362 L
s
P
p
.2 0 1 r
.002 w
.53529 .17395 m
.49294 .04362 L
s
P
p
0 .4 1 r
.018 w
.53529 .21963 m
.53529 .17395 L
s
P
p
.2 0 1 r
.002 w
.46471 .61957 m
.38416 .73044 L
s
P
p
.2 0 1 r
.002 w
.46471 .61957 m
.46471 .75661 L
s
P
p
0 .4 1 r
.018 w
.47883 .57613 m
.46471 .61957 L
s
P
p
.2 0 1 r
.016 w
.53529 .40235 m
.68311 .50975 L
s
P
p
.2 0 1 r
.016 w
.53529 .40235 m
.42789 .25453 L
s
P
p
.2 0 1 r
.016 w
.53529 .40235 m
.59175 .57613 L
s
P
p
.2 0 1 r
.016 w
.53529 .40235 m
.53529 .21963 L
s
P
p
.2 0 1 r
.016 w
.53529 .40235 m
.47883 .57613 L
s
P
p
.2 0 1 r
.002 w
.82079 .36087 m
.95112 .40321 L
s
P
p
.2 0 1 r
.002 w
.82079 .36087 m
.95112 .31852 L
s
P
p
0 .4 1 r
.018 w
.77511 .36087 m
.82079 .36087 L
s
P
p
.2 0 1 r
.002 w
.37517 .29029 m
.2643 .20974 L
s
P
p
.2 0 1 r
.002 w
.37517 .29029 m
.23813 .29029 L
s
P
p
0 .4 1 r
.018 w
.41861 .3044 m
.37517 .29029 L
s
P
p
.2 0 1 r
.002 w
.77717 .49512 m
.85772 .60598 L
s
P
p
.2 0 1 r
.002 w
.77717 .49512 m
.9075 .53746 L
s
P
p
0 .4 1 r
.018 w
.74021 .46827 m
.77717 .49512 L
s
P
p
.2 0 1 r
.002 w
.45814 .17609 m
.41579 .04575 L
s
P
p
.2 0 1 r
.002 w
.45814 .17609 m
.34727 .09554 L
s
P
p
0 .4 1 r
.018 w
.48499 .21304 m
.45814 .17609 L
s
P
p
.2 0 1 r
.002 w
.66297 .57809 m
.66297 .71513 L
s
P
p
.2 0 1 r
.002 w
.66297 .57809 m
.74352 .68896 L
s
P
p
0 .4 1 r
.018 w
.64885 .53464 m
.66297 .57809 L
s
P
p
.2 0 1 r
.016 w
.59239 .36087 m
.77511 .36087 L
s
P
p
.2 0 1 r
.016 w
.59239 .36087 m
.41861 .3044 L
s
P
p
.2 0 1 r
.016 w
.59239 .36087 m
.74021 .46827 L
s
P
p
.2 0 1 r
.016 w
.59239 .36087 m
.48499 .21304 L
s
P
p
.2 0 1 r
.016 w
.59239 .36087 m
.64885 .53464 L
s
P
p
1 .6 0 r
.016 w
.5 .29374 m
.40761 .36087 L
s
P
p
1 .6 0 r
.016 w
.5 .29374 m
.46471 .40235 L
s
P
p
1 .6 0 r
.016 w
.5 .29374 m
.53529 .40235 L
s
P
p
1 .6 0 r
.016 w
.5 .29374 m
.59239 .36087 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0556897 0.952381 [
[ 0 0 0 0 ]
[ 1 .841 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .841 L
0 .841 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.28988 .59169 m
.14326 .56846 L
s
P
p
.2 0 1 r
.002 w
.28988 .59169 m
.15761 .65908 L
s
P
p
.2 0 1 r
.002 w
.37374 .61893 m
.44114 .7512 L
s
P
p
.2 0 1 r
.002 w
.37374 .61893 m
.50601 .68633 L
s
P
p
0 .4 1 r
.018 w
.33875 .58394 m
.28988 .59169 L
s
P
p
0 .4 1 r
.018 w
.33875 .58394 m
.37374 .61893 L
s
P
p
.2 0 1 r
.002 w
.56513 .24331 m
.6974 .31071 L
s
P
p
.2 0 1 r
.002 w
.56513 .24331 m
.71176 .22009 L
s
P
p
.2 0 1 r
.002 w
.4938 .19148 m
.47057 .04486 L
s
P
p
.2 0 1 r
.002 w
.4938 .19148 m
.38883 .08651 L
s
P
p
0 .4 1 r
.018 w
.51626 .23557 m
.56513 .24331 L
s
P
p
0 .4 1 r
.018 w
.51626 .23557 m
.4938 .19148 L
s
P
p
.2 0 1 r
.002 w
.1957 .48958 m
.09073 .38461 L
s
P
p
.2 0 1 r
.002 w
.1957 .48958 m
.04908 .46635 L
s
P
p
.2 0 1 r
.002 w
.24753 .56092 m
.22431 .70754 L
s
P
p
.2 0 1 r
.002 w
.24753 .56092 m
.31492 .69318 L
s
P
p
0 .4 1 r
.018 w
.23979 .51204 m
.1957 .48958 L
s
P
p
0 .4 1 r
.018 w
.23979 .51204 m
.24753 .56092 L
s
P
p
.2 0 1 r
.002 w
.62315 .36953 m
.69055 .50179 L
s
P
p
.2 0 1 r
.002 w
.62315 .36953 m
.75542 .43692 L
s
P
p
.2 0 1 r
.002 w
.5959 .28566 m
.6633 .15339 L
s
P
p
.2 0 1 r
.002 w
.5959 .28566 m
.57268 .13904 L
s
P
p
0 .4 1 r
.018 w
.58816 .33454 m
.62315 .36953 L
s
P
p
0 .4 1 r
.018 w
.58816 .33454 m
.5959 .28566 L
s
P
p
.2 0 1 r
.002 w
.17952 .35161 m
.1563 .20499 L
s
P
p
.2 0 1 r
.002 w
.17952 .35161 m
.07455 .24664 L
s
P
p
.2 0 1 r
.002 w
.17952 .43979 m
.07455 .54476 L
s
P
p
.2 0 1 r
.002 w
.17952 .43979 m
.1563 .58641 L
s
P
p
0 .4 1 r
.018 w
.20199 .3957 m
.17952 .35161 L
s
P
p
0 .4 1 r
.018 w
.20199 .3957 m
.17952 .43979 L
s
P
p
.2 0 1 r
.016 w
.39992 .3957 m
.33875 .58394 L
s
P
p
.2 0 1 r
.016 w
.39992 .3957 m
.51626 .23557 L
s
P
p
.2 0 1 r
.016 w
.39992 .3957 m
.23979 .51204 L
s
P
p
.2 0 1 r
.016 w
.39992 .3957 m
.58816 .33454 L
s
P
p
.2 0 1 r
.016 w
.39992 .3957 m
.20199 .3957 L
s
P
p
.2 0 1 r
.002 w
.48795 .66387 m
.35568 .73127 L
s
P
p
.2 0 1 r
.002 w
.48795 .66387 m
.42055 .79614 L
s
P
p
.2 0 1 r
.002 w
.57181 .63662 m
.70408 .70402 L
s
P
p
.2 0 1 r
.002 w
.57181 .63662 m
.71843 .6134 L
s
P
p
0 .4 1 r
.018 w
.52294 .62888 m
.48795 .66387 L
s
P
p
0 .4 1 r
.018 w
.52294 .62888 m
.57181 .63662 L
s
P
p
.2 0 1 r
.002 w
.50586 .22024 m
.65248 .19702 L
s
P
p
.2 0 1 r
.002 w
.50586 .22024 m
.61083 .11527 L
s
P
p
.2 0 1 r
.002 w
.41768 .22024 m
.31271 .11527 L
s
P
p
.2 0 1 r
.002 w
.41768 .22024 m
.27106 .19702 L
s
P
p
0 .4 1 r
.018 w
.46177 .24271 m
.50586 .22024 L
s
P
p
0 .4 1 r
.018 w
.46177 .24271 m
.41768 .22024 L
s
P
p
.2 0 1 r
.002 w
.35173 .63662 m
.20511 .6134 L
s
P
p
.2 0 1 r
.002 w
.35173 .63662 m
.21947 .70402 L
s
P
p
.2 0 1 r
.002 w
.4356 .66387 m
.50299 .79614 L
s
P
p
.2 0 1 r
.002 w
.4356 .66387 m
.56787 .73127 L
s
P
p
0 .4 1 r
.018 w
.40061 .62888 m
.35173 .63662 L
s
P
p
0 .4 1 r
.018 w
.40061 .62888 m
.4356 .66387 L
s
P
p
.2 0 1 r
.002 w
.62699 .28825 m
.75926 .35564 L
s
P
p
.2 0 1 r
.002 w
.62699 .28825 m
.77361 .26503 L
s
P
p
.2 0 1 r
.002 w
.55565 .23642 m
.53243 .0898 L
s
P
p
.2 0 1 r
.002 w
.55565 .23642 m
.45068 .13145 L
s
P
p
0 .4 1 r
.018 w
.57811 .28051 m
.62699 .28825 L
s
P
p
0 .4 1 r
.018 w
.57811 .28051 m
.55565 .23642 L
s
P
p
.2 0 1 r
.002 w
.25755 .53452 m
.15258 .42955 L
s
P
p
.2 0 1 r
.002 w
.25755 .53452 m
.11093 .51129 L
s
P
p
.2 0 1 r
.002 w
.30938 .60585 m
.28616 .75248 L
s
P
p
.2 0 1 r
.002 w
.30938 .60585 m
.37678 .73812 L
s
P
p
0 .4 1 r
.018 w
.30164 .55698 m
.25755 .53452 L
s
P
p
0 .4 1 r
.018 w
.30164 .55698 m
.30938 .60585 L
s
P
p
.2 0 1 r
.016 w
.46177 .44064 m
.52294 .62888 L
s
P
p
.2 0 1 r
.016 w
.46177 .44064 m
.46177 .24271 L
s
P
p
.2 0 1 r
.016 w
.46177 .44064 m
.40061 .62888 L
s
P
p
.2 0 1 r
.016 w
.46177 .44064 m
.57811 .28051 L
s
P
p
.2 0 1 r
.016 w
.46177 .44064 m
.30164 .55698 L
s
P
p
.2 0 1 r
.002 w
.69062 .60585 m
.62322 .73812 L
s
P
p
.2 0 1 r
.002 w
.69062 .60585 m
.71384 .75248 L
s
P
p
.2 0 1 r
.002 w
.74245 .53452 m
.88907 .51129 L
s
P
p
.2 0 1 r
.002 w
.74245 .53452 m
.84742 .42955 L
s
P
p
0 .4 1 r
.018 w
.69836 .55698 m
.69062 .60585 L
s
P
p
0 .4 1 r
.018 w
.69836 .55698 m
.74245 .53452 L
s
P
p
.2 0 1 r
.002 w
.44435 .23642 m
.54932 .13145 L
s
P
p
.2 0 1 r
.002 w
.44435 .23642 m
.46757 .0898 L
s
P
p
.2 0 1 r
.002 w
.37301 .28825 m
.22639 .26503 L
s
P
p
.2 0 1 r
.002 w
.37301 .28825 m
.24074 .35564 L
s
P
p
0 .4 1 r
.018 w
.42189 .28051 m
.44435 .23642 L
s
P
p
0 .4 1 r
.018 w
.42189 .28051 m
.37301 .28825 L
s
P
p
.2 0 1 r
.002 w
.5644 .66387 m
.43213 .73127 L
s
P
p
.2 0 1 r
.002 w
.5644 .66387 m
.49701 .79614 L
s
P
p
.2 0 1 r
.002 w
.64827 .63662 m
.78053 .70402 L
s
P
p
.2 0 1 r
.002 w
.64827 .63662 m
.79489 .6134 L
s
P
p
0 .4 1 r
.018 w
.59939 .62888 m
.5644 .66387 L
s
P
p
0 .4 1 r
.018 w
.59939 .62888 m
.64827 .63662 L
s
P
p
.2 0 1 r
.002 w
.58232 .22024 m
.72894 .19702 L
s
P
p
.2 0 1 r
.002 w
.58232 .22024 m
.68729 .11527 L
s
P
p
.2 0 1 r
.002 w
.49414 .22024 m
.38917 .11527 L
s
P
p
.2 0 1 r
.002 w
.49414 .22024 m
.34752 .19702 L
s
P
p
0 .4 1 r
.018 w
.53823 .24271 m
.58232 .22024 L
s
P
p
0 .4 1 r
.018 w
.53823 .24271 m
.49414 .22024 L
s
P
p
.2 0 1 r
.002 w
.42819 .63662 m
.28157 .6134 L
s
P
p
.2 0 1 r
.002 w
.42819 .63662 m
.29592 .70402 L
s
P
p
.2 0 1 r
.002 w
.51205 .66387 m
.57945 .79614 L
s
P
p
.2 0 1 r
.002 w
.51205 .66387 m
.64432 .73127 L
s
P
p
0 .4 1 r
.018 w
.47706 .62888 m
.42819 .63662 L
s
P
p
0 .4 1 r
.018 w
.47706 .62888 m
.51205 .66387 L
s
P
p
.2 0 1 r
.016 w
.53823 .44064 m
.69836 .55698 L
s
P
p
.2 0 1 r
.016 w
.53823 .44064 m
.42189 .28051 L
s
P
p
.2 0 1 r
.016 w
.53823 .44064 m
.59939 .62888 L
s
P
p
.2 0 1 r
.016 w
.53823 .44064 m
.53823 .24271 L
s
P
p
.2 0 1 r
.016 w
.53823 .44064 m
.47706 .62888 L
s
P
p
.2 0 1 r
.002 w
.82048 .43979 m
.8437 .58641 L
s
P
p
.2 0 1 r
.002 w
.82048 .43979 m
.92545 .54476 L
s
P
p
.2 0 1 r
.002 w
.82048 .35161 m
.92545 .24664 L
s
P
p
.2 0 1 r
.002 w
.82048 .35161 m
.8437 .20499 L
s
P
p
0 .4 1 r
.018 w
.79801 .3957 m
.82048 .43979 L
s
P
p
0 .4 1 r
.018 w
.79801 .3957 m
.82048 .35161 L
s
P
p
.2 0 1 r
.002 w
.4041 .28566 m
.42732 .13904 L
s
P
p
.2 0 1 r
.002 w
.4041 .28566 m
.3367 .15339 L
s
P
p
.2 0 1 r
.002 w
.37685 .36953 m
.24458 .43692 L
s
P
p
.2 0 1 r
.002 w
.37685 .36953 m
.30945 .50179 L
s
P
p
0 .4 1 r
.018 w
.41184 .33454 m
.4041 .28566 L
s
P
p
0 .4 1 r
.018 w
.41184 .33454 m
.37685 .36953 L
s
P
p
.2 0 1 r
.002 w
.75247 .56092 m
.68508 .69318 L
s
P
p
.2 0 1 r
.002 w
.75247 .56092 m
.77569 .70754 L
s
P
p
.2 0 1 r
.002 w
.8043 .48958 m
.95092 .46635 L
s
P
p
.2 0 1 r
.002 w
.8043 .48958 m
.90927 .38461 L
s
P
p
0 .4 1 r
.018 w
.76021 .51204 m
.75247 .56092 L
s
P
p
0 .4 1 r
.018 w
.76021 .51204 m
.8043 .48958 L
s
P
p
.2 0 1 r
.002 w
.5062 .19148 m
.61117 .08651 L
s
P
p
.2 0 1 r
.002 w
.5062 .19148 m
.52943 .04486 L
s
P
p
.2 0 1 r
.002 w
.43487 .24331 m
.28824 .22009 L
s
P
p
.2 0 1 r
.002 w
.43487 .24331 m
.3026 .31071 L
s
P
p
0 .4 1 r
.018 w
.48374 .23557 m
.5062 .19148 L
s
P
p
0 .4 1 r
.018 w
.48374 .23557 m
.43487 .24331 L
s
P
p
.2 0 1 r
.002 w
.62626 .61893 m
.49399 .68633 L
s
P
p
.2 0 1 r
.002 w
.62626 .61893 m
.55886 .7512 L
s
P
p
.2 0 1 r
.002 w
.71012 .59169 m
.84239 .65908 L
s
P
p
.2 0 1 r
.002 w
.71012 .59169 m
.85674 .56846 L
s
P
p
0 .4 1 r
.018 w
.66125 .58394 m
.62626 .61893 L
s
P
p
0 .4 1 r
.018 w
.66125 .58394 m
.71012 .59169 L
s
P
p
.2 0 1 r
.016 w
.60008 .3957 m
.79801 .3957 L
s
P
p
.2 0 1 r
.016 w
.60008 .3957 m
.41184 .33454 L
s
P
p
.2 0 1 r
.016 w
.60008 .3957 m
.76021 .51204 L
s
P
p
.2 0 1 r
.016 w
.60008 .3957 m
.48374 .23557 L
s
P
p
.2 0 1 r
.016 w
.60008 .3957 m
.66125 .58394 L
s
P
p
1 .6 0 r
.016 w
.5 .32299 m
.39992 .3957 L
s
P
p
1 .6 0 r
.016 w
.5 .32299 m
.46177 .44064 L
s
P
p
1 .6 0 r
.016 w
.5 .32299 m
.53823 .44064 L
s
P
p
1 .6 0 r
.016 w
.5 .32299 m
.60008 .3957 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0481864 0.952381 [
[ 0 0 0 0 ]
[ 1 .85601 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85601 L
0 .85601 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.28179 .60077 m
.14207 .60077 L
s
P
p
.2 0 1 r
.002 w
.28179 .60077 m
.16876 .6829 L
s
P
p
.2 0 1 r
.002 w
.3893 .6357 m
.43247 .76858 L
s
P
p
.2 0 1 r
.002 w
.3893 .6357 m
.50233 .71783 L
s
P
p
0 .4 1 r
.018 w
.34823 .57918 m
.28179 .60077 L
s
P
p
0 .4 1 r
.018 w
.34823 .57918 m
.3893 .6357 L
s
P
p
.2 0 1 r
.002 w
.58516 .25129 m
.71805 .29447 L
s
P
p
.2 0 1 r
.002 w
.58516 .25129 m
.71805 .20811 L
s
P
p
.2 0 1 r
.002 w
.49372 .18485 m
.49372 .04513 L
s
P
p
.2 0 1 r
.002 w
.49372 .18485 m
.41159 .07181 L
s
P
p
0 .4 1 r
.018 w
.5153 .25129 m
.58516 .25129 L
s
P
p
0 .4 1 r
.018 w
.5153 .25129 m
.49372 .18485 L
s
P
p
.2 0 1 r
.002 w
.18865 .48992 m
.07561 .40779 L
s
P
p
.2 0 1 r
.002 w
.18865 .48992 m
.04892 .48992 L
s
P
p
.2 0 1 r
.002 w
.25509 .58137 m
.21191 .71425 L
s
P
p
.2 0 1 r
.002 w
.25509 .58137 m
.29826 .71425 L
s
P
p
0 .4 1 r
.018 w
.25509 .51151 m
.18865 .48992 L
s
P
p
0 .4 1 r
.018 w
.25509 .51151 m
.25509 .58137 L
s
P
p
.2 0 1 r
.002 w
.6395 .3855 m
.72162 .49854 L
s
P
p
.2 0 1 r
.002 w
.6395 .3855 m
.77238 .42868 L
s
P
p
.2 0 1 r
.002 w
.60457 .278 m
.68669 .16496 L
s
P
p
.2 0 1 r
.002 w
.60457 .278 m
.60457 .13827 L
s
P
p
0 .4 1 r
.018 w
.58298 .34444 m
.6395 .3855 L
s
P
p
0 .4 1 r
.018 w
.58298 .34444 m
.60457 .278 L
s
P
p
.2 0 1 r
.002 w
.17844 .34549 m
.13527 .2126 L
s
P
p
.2 0 1 r
.002 w
.17844 .34549 m
.06541 .26336 L
s
P
p
.2 0 1 r
.002 w
.17844 .45852 m
.06541 .54065 L
s
P
p
.2 0 1 r
.002 w
.17844 .45852 m
.13527 .59141 L
s
P
p
0 .4 1 r
.018 w
.21951 .40201 m
.17844 .34549 L
s
P
p
0 .4 1 r
.018 w
.21951 .40201 m
.17844 .45852 L
s
P
p
.2 0 1 r
.016 w
.4058 .40201 m
.34823 .57918 L
s
P
p
.2 0 1 r
.016 w
.4058 .40201 m
.5153 .25129 L
s
P
p
.2 0 1 r
.016 w
.4058 .40201 m
.25509 .51151 L
s
P
p
.2 0 1 r
.016 w
.4058 .40201 m
.58298 .34444 L
s
P
p
.2 0 1 r
.016 w
.4058 .40201 m
.21951 .40201 L
s
P
p
.2 0 1 r
.002 w
.48053 .678 m
.36749 .76012 L
s
P
p
.2 0 1 r
.002 w
.48053 .678 m
.43735 .81088 L
s
P
p
.2 0 1 r
.002 w
.58803 .64307 m
.70107 .72519 L
s
P
p
.2 0 1 r
.002 w
.58803 .64307 m
.72775 .64307 L
s
P
p
0 .4 1 r
.018 w
.52159 .62148 m
.48053 .678 L
s
P
p
0 .4 1 r
.018 w
.52159 .62148 m
.58803 .64307 L
s
P
p
.2 0 1 r
.002 w
.52054 .21694 m
.65342 .17377 L
s
P
p
.2 0 1 r
.002 w
.52054 .21694 m
.60266 .10391 L
s
P
p
.2 0 1 r
.002 w
.4075 .21694 m
.32538 .10391 L
s
P
p
.2 0 1 r
.002 w
.4075 .21694 m
.27462 .17377 L
s
P
p
0 .4 1 r
.018 w
.46402 .25801 m
.52054 .21694 L
s
P
p
0 .4 1 r
.018 w
.46402 .25801 m
.4075 .21694 L
s
P
p
.2 0 1 r
.002 w
.34001 .64307 m
.20029 .64307 L
s
P
p
.2 0 1 r
.002 w
.34001 .64307 m
.22697 .72519 L
s
P
p
.2 0 1 r
.002 w
.44751 .678 m
.49069 .81088 L
s
P
p
.2 0 1 r
.002 w
.44751 .678 m
.56055 .76012 L
s
P
p
0 .4 1 r
.018 w
.40645 .62148 m
.34001 .64307 L
s
P
p
0 .4 1 r
.018 w
.40645 .62148 m
.44751 .678 L
s
P
p
.2 0 1 r
.002 w
.64338 .29359 m
.77626 .33676 L
s
P
p
.2 0 1 r
.002 w
.64338 .29359 m
.77626 .25041 L
s
P
p
.2 0 1 r
.002 w
.55193 .22715 m
.55193 .08742 L
s
P
p
.2 0 1 r
.002 w
.55193 .22715 m
.46981 .11411 L
s
P
p
0 .4 1 r
.018 w
.57352 .29359 m
.64338 .29359 L
s
P
p
0 .4 1 r
.018 w
.57352 .29359 m
.55193 .22715 L
s
P
p
.2 0 1 r
.002 w
.24686 .53222 m
.13383 .45009 L
s
P
p
.2 0 1 r
.002 w
.24686 .53222 m
.10714 .53222 L
s
P
p
.2 0 1 r
.002 w
.3133 .62366 m
.27013 .75655 L
s
P
p
.2 0 1 r
.002 w
.3133 .62366 m
.35648 .75655 L
s
P
p
0 .4 1 r
.018 w
.3133 .5538 m
.24686 .53222 L
s
P
p
0 .4 1 r
.018 w
.3133 .5538 m
.3133 .62366 L
s
P
p
.2 0 1 r
.016 w
.46402 .4443 m
.52159 .62148 L
s
P
p
.2 0 1 r
.016 w
.46402 .4443 m
.46402 .25801 L
s
P
p
.2 0 1 r
.016 w
.46402 .4443 m
.40645 .62148 L
s
P
p
.2 0 1 r
.016 w
.46402 .4443 m
.57352 .29359 L
s
P
p
.2 0 1 r
.016 w
.46402 .4443 m
.3133 .5538 L
s
P
p
.2 0 1 r
.002 w
.6867 .62366 m
.64352 .75655 L
s
P
p
.2 0 1 r
.002 w
.6867 .62366 m
.72987 .75655 L
s
P
p
.2 0 1 r
.002 w
.75314 .53222 m
.89286 .53222 L
s
P
p
.2 0 1 r
.002 w
.75314 .53222 m
.86617 .45009 L
s
P
p
0 .4 1 r
.018 w
.6867 .5538 m
.6867 .62366 L
s
P
p
0 .4 1 r
.018 w
.6867 .5538 m
.75314 .53222 L
s
P
p
.2 0 1 r
.002 w
.44807 .22715 m
.53019 .11411 L
s
P
p
.2 0 1 r
.002 w
.44807 .22715 m
.44807 .08742 L
s
P
p
.2 0 1 r
.002 w
.35662 .29359 m
.22374 .25041 L
s
P
p
.2 0 1 r
.002 w
.35662 .29359 m
.22374 .33676 L
s
P
p
0 .4 1 r
.018 w
.42648 .29359 m
.44807 .22715 L
s
P
p
0 .4 1 r
.018 w
.42648 .29359 m
.35662 .29359 L
s
P
p
.2 0 1 r
.002 w
.55249 .678 m
.43945 .76012 L
s
P
p
.2 0 1 r
.002 w
.55249 .678 m
.50931 .81088 L
s
P
p
.2 0 1 r
.002 w
.65999 .64307 m
.77303 .72519 L
s
P
p
.2 0 1 r
.002 w
.65999 .64307 m
.79971 .64307 L
s
P
p
0 .4 1 r
.018 w
.59355 .62148 m
.55249 .678 L
s
P
p
0 .4 1 r
.018 w
.59355 .62148 m
.65999 .64307 L
s
P
p
.2 0 1 r
.002 w
.5925 .21694 m
.72538 .17377 L
s
P
p
.2 0 1 r
.002 w
.5925 .21694 m
.67462 .10391 L
s
P
p
.2 0 1 r
.002 w
.47946 .21694 m
.39734 .10391 L
s
P
p
.2 0 1 r
.002 w
.47946 .21694 m
.34658 .17377 L
s
P
p
0 .4 1 r
.018 w
.53598 .25801 m
.5925 .21694 L
s
P
p
0 .4 1 r
.018 w
.53598 .25801 m
.47946 .21694 L
s
P
p
.2 0 1 r
.002 w
.41197 .64307 m
.27225 .64307 L
s
P
p
.2 0 1 r
.002 w
.41197 .64307 m
.29893 .72519 L
s
P
p
.2 0 1 r
.002 w
.51947 .678 m
.56265 .81088 L
s
P
p
.2 0 1 r
.002 w
.51947 .678 m
.63251 .76012 L
s
P
p
0 .4 1 r
.018 w
.47841 .62148 m
.41197 .64307 L
s
P
p
0 .4 1 r
.018 w
.47841 .62148 m
.51947 .678 L
s
P
p
.2 0 1 r
.016 w
.53598 .4443 m
.6867 .5538 L
s
P
p
.2 0 1 r
.016 w
.53598 .4443 m
.42648 .29359 L
s
P
p
.2 0 1 r
.016 w
.53598 .4443 m
.59355 .62148 L
s
P
p
.2 0 1 r
.016 w
.53598 .4443 m
.53598 .25801 L
s
P
p
.2 0 1 r
.016 w
.53598 .4443 m
.47841 .62148 L
s
P
p
.2 0 1 r
.002 w
.82156 .45852 m
.86473 .59141 L
s
P
p
.2 0 1 r
.002 w
.82156 .45852 m
.93459 .54065 L
s
P
p
.2 0 1 r
.002 w
.82156 .34549 m
.93459 .26336 L
s
P
p
.2 0 1 r
.002 w
.82156 .34549 m
.86473 .2126 L
s
P
p
0 .4 1 r
.018 w
.78049 .40201 m
.82156 .45852 L
s
P
p
0 .4 1 r
.018 w
.78049 .40201 m
.82156 .34549 L
s
P
p
.2 0 1 r
.002 w
.39543 .278 m
.39543 .13827 L
s
P
p
.2 0 1 r
.002 w
.39543 .278 m
.31331 .16496 L
s
P
p
.2 0 1 r
.002 w
.3605 .3855 m
.22762 .42868 L
s
P
p
.2 0 1 r
.002 w
.3605 .3855 m
.27838 .49854 L
s
P
p
0 .4 1 r
.018 w
.41702 .34444 m
.39543 .278 L
s
P
p
0 .4 1 r
.018 w
.41702 .34444 m
.3605 .3855 L
s
P
p
.2 0 1 r
.002 w
.74491 .58137 m
.70174 .71425 L
s
P
p
.2 0 1 r
.002 w
.74491 .58137 m
.78809 .71425 L
s
P
p
.2 0 1 r
.002 w
.81135 .48992 m
.95108 .48992 L
s
P
p
.2 0 1 r
.002 w
.81135 .48992 m
.92439 .40779 L
s
P
p
0 .4 1 r
.018 w
.74491 .51151 m
.74491 .58137 L
s
P
p
0 .4 1 r
.018 w
.74491 .51151 m
.81135 .48992 L
s
P
p
.2 0 1 r
.002 w
.50628 .18485 m
.58841 .07181 L
s
P
p
.2 0 1 r
.002 w
.50628 .18485 m
.50628 .04513 L
s
P
p
.2 0 1 r
.002 w
.41484 .25129 m
.28195 .20811 L
s
P
p
.2 0 1 r
.002 w
.41484 .25129 m
.28195 .29447 L
s
P
p
0 .4 1 r
.018 w
.4847 .25129 m
.50628 .18485 L
s
P
p
0 .4 1 r
.018 w
.4847 .25129 m
.41484 .25129 L
s
P
p
.2 0 1 r
.002 w
.6107 .6357 m
.49767 .71783 L
s
P
p
.2 0 1 r
.002 w
.6107 .6357 m
.56753 .76858 L
s
P
p
.2 0 1 r
.002 w
.71821 .60077 m
.83124 .6829 L
s
P
p
.2 0 1 r
.002 w
.71821 .60077 m
.85793 .60077 L
s
P
p
0 .4 1 r
.018 w
.65177 .57918 m
.6107 .6357 L
s
P
p
0 .4 1 r
.018 w
.65177 .57918 m
.71821 .60077 L
s
P
p
.2 0 1 r
.016 w
.5942 .40201 m
.78049 .40201 L
s
P
p
.2 0 1 r
.016 w
.5942 .40201 m
.41702 .34444 L
s
P
p
.2 0 1 r
.016 w
.5942 .40201 m
.74491 .51151 L
s
P
p
.2 0 1 r
.016 w
.5942 .40201 m
.4847 .25129 L
s
P
p
.2 0 1 r
.016 w
.5942 .40201 m
.65177 .57918 L
s
P
p
1 .6 0 r
.016 w
.5 .33357 m
.4058 .40201 L
s
P
p
1 .6 0 r
.016 w
.5 .33357 m
.46402 .4443 L
s
P
p
1 .6 0 r
.016 w
.5 .33357 m
.53598 .4443 L
s
P
p
1 .6 0 r
.016 w
.5 .33357 m
.5942 .40201 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.172483 0.952381 [
[ 0 0 0 0 ]
[ 1 .60741 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .60741 L
0 .60741 L
closepath
clip
newpath
p
P
p
1 .6 0 r
.016 w
.5 .044 m
.05816 .36502 L
s
P
p
1 .6 0 r
.016 w
.5 .044 m
.33123 .56341 L
s
P
p
1 .6 0 r
.016 w
.5 .044 m
.66877 .56341 L
s
P
p
1 .6 0 r
.016 w
.5 .044 m
.94184 .36502 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0492176 0.952381 [
[ 0 0 0 0 ]
[ 1 .85395 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85395 L
0 .85395 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.38504 .65346 m
.24108 .70023 L
s
P
p
.2 0 1 r
.002 w
.38504 .65346 m
.29606 .77592 L
s
P
p
.2 0 1 r
.002 w
.46668 .65346 m
.55565 .77592 L
s
P
p
.2 0 1 r
.002 w
.46668 .65346 m
.61064 .70023 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.38504 .65346 L
s
P
p
0 .4 1 r
.018 w
.42586 .6238 m
.46668 .65346 L
s
P
p
.2 0 1 r
.002 w
.53621 .21443 m
.68758 .21443 L
s
P
p
.2 0 1 r
.002 w
.53621 .21443 m
.65867 .12546 L
s
P
p
.2 0 1 r
.002 w
.45857 .18921 m
.41179 .04525 L
s
P
p
.2 0 1 r
.002 w
.45857 .18921 m
.33611 .10023 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.53621 .21443 L
s
P
p
0 .4 1 r
.018 w
.48822 .23003 m
.45857 .18921 L
s
P
p
.2 0 1 r
.002 w
.25677 .58525 m
.11281 .53848 L
s
P
p
.2 0 1 r
.002 w
.25677 .58525 m
.11281 .63203 L
s
P
p
.2 0 1 r
.002 w
.32282 .63324 m
.32282 .78461 L
s
P
p
.2 0 1 r
.002 w
.32282 .63324 m
.41179 .7557 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.25677 .58525 L
s
P
p
0 .4 1 r
.018 w
.30723 .58525 m
.32282 .63324 L
s
P
p
.2 0 1 r
.002 w
.63712 .31894 m
.75958 .40791 L
s
P
p
.2 0 1 r
.002 w
.63712 .31894 m
.78849 .31894 L
s
P
p
.2 0 1 r
.002 w
.58914 .25289 m
.63591 .10893 L
s
P
p
.2 0 1 r
.002 w
.58914 .25289 m
.54236 .10893 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.63712 .31894 L
s
P
p
0 .4 1 r
.018 w
.58914 .30334 m
.58914 .25289 L
s
P
p
.2 0 1 r
.002 w
.19309 .45468 m
.10412 .33222 L
s
P
p
.2 0 1 r
.002 w
.19309 .45468 m
.04913 .40791 L
s
P
p
.2 0 1 r
.002 w
.21832 .53233 m
.12934 .65479 L
s
P
p
.2 0 1 r
.002 w
.21832 .53233 m
.21832 .6837 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.19309 .45468 L
s
P
p
0 .4 1 r
.018 w
.23391 .48434 m
.21832 .53233 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.42586 .6238 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.48822 .23003 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.30723 .58525 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.58914 .30334 L
s
P
p
.2 0 1 r
.016 w
.42586 .42197 m
.23391 .48434 L
s
P
p
.2 0 1 r
.002 w
.60304 .65733 m
.51407 .77979 L
s
P
p
.2 0 1 r
.002 w
.60304 .65733 m
.60304 .8087 L
s
P
p
.2 0 1 r
.002 w
.66909 .60934 m
.81305 .65612 L
s
P
p
.2 0 1 r
.002 w
.66909 .60934 m
.81305 .56257 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.60304 .65733 L
s
P
p
0 .4 1 r
.018 w
.61863 .60934 m
.66909 .60934 L
s
P
p
.2 0 1 r
.002 w
.46729 .2133 m
.58975 .12432 L
s
P
p
.2 0 1 r
.002 w
.46729 .2133 m
.51407 .06934 L
s
P
p
.2 0 1 r
.002 w
.38965 .23853 m
.26719 .14955 L
s
P
p
.2 0 1 r
.002 w
.38965 .23853 m
.23828 .23853 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.46729 .2133 L
s
P
p
0 .4 1 r
.018 w
.43763 .25412 m
.38965 .23853 L
s
P
p
.2 0 1 r
.002 w
.45918 .67755 m
.31522 .72432 L
s
P
p
.2 0 1 r
.002 w
.45918 .67755 m
.37021 .80001 L
s
P
p
.2 0 1 r
.002 w
.54082 .67755 m
.62979 .80001 L
s
P
p
.2 0 1 r
.002 w
.54082 .67755 m
.68478 .72432 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.45918 .67755 L
s
P
p
0 .4 1 r
.018 w
.5 .64789 m
.54082 .67755 L
s
P
p
.2 0 1 r
.002 w
.61035 .23853 m
.76172 .23853 L
s
P
p
.2 0 1 r
.002 w
.61035 .23853 m
.73281 .14955 L
s
P
p
.2 0 1 r
.002 w
.53271 .2133 m
.48593 .06934 L
s
P
p
.2 0 1 r
.002 w
.53271 .2133 m
.41025 .12432 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.61035 .23853 L
s
P
p
0 .4 1 r
.018 w
.56237 .25412 m
.53271 .2133 L
s
P
p
.2 0 1 r
.002 w
.33091 .60934 m
.18695 .56257 L
s
P
p
.2 0 1 r
.002 w
.33091 .60934 m
.18695 .65612 L
s
P
p
.2 0 1 r
.002 w
.39696 .65733 m
.39696 .8087 L
s
P
p
.2 0 1 r
.002 w
.39696 .65733 m
.48593 .77979 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.33091 .60934 L
s
P
p
0 .4 1 r
.018 w
.38137 .60934 m
.39696 .65733 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.61863 .60934 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.43763 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.5 .64789 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.56237 .25412 L
s
P
p
.2 0 1 r
.016 w
.5 .44606 m
.38137 .60934 L
s
P
p
.2 0 1 r
.002 w
.78168 .53233 m
.78168 .6837 L
s
P
p
.2 0 1 r
.002 w
.78168 .53233 m
.87066 .65479 L
s
P
p
.2 0 1 r
.002 w
.80691 .45468 m
.95087 .40791 L
s
P
p
.2 0 1 r
.002 w
.80691 .45468 m
.89588 .33222 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.78168 .53233 L
s
P
p
0 .4 1 r
.018 w
.76609 .48434 m
.80691 .45468 L
s
P
p
.2 0 1 r
.002 w
.41086 .25289 m
.45764 .10893 L
s
P
p
.2 0 1 r
.002 w
.41086 .25289 m
.36409 .10893 L
s
P
p
.2 0 1 r
.002 w
.36288 .31894 m
.21151 .31894 L
s
P
p
.2 0 1 r
.002 w
.36288 .31894 m
.24042 .40791 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.41086 .25289 L
s
P
p
0 .4 1 r
.018 w
.41086 .30334 m
.36288 .31894 L
s
P
p
.2 0 1 r
.002 w
.67718 .63324 m
.58821 .7557 L
s
P
p
.2 0 1 r
.002 w
.67718 .63324 m
.67718 .78461 L
s
P
p
.2 0 1 r
.002 w
.74323 .58525 m
.88719 .63203 L
s
P
p
.2 0 1 r
.002 w
.74323 .58525 m
.88719 .53848 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.67718 .63324 L
s
P
p
0 .4 1 r
.018 w
.69277 .58525 m
.74323 .58525 L
s
P
p
.2 0 1 r
.002 w
.54143 .18921 m
.66389 .10023 L
s
P
p
.2 0 1 r
.002 w
.54143 .18921 m
.58821 .04525 L
s
P
p
.2 0 1 r
.002 w
.46379 .21443 m
.34133 .12546 L
s
P
p
.2 0 1 r
.002 w
.46379 .21443 m
.31242 .21443 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.54143 .18921 L
s
P
p
0 .4 1 r
.018 w
.51178 .23003 m
.46379 .21443 L
s
P
p
.2 0 1 r
.002 w
.53332 .65346 m
.38936 .70023 L
s
P
p
.2 0 1 r
.002 w
.53332 .65346 m
.44435 .77592 L
s
P
p
.2 0 1 r
.002 w
.61496 .65346 m
.70394 .77592 L
s
P
p
.2 0 1 r
.002 w
.61496 .65346 m
.75892 .70023 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.53332 .65346 L
s
P
p
0 .4 1 r
.018 w
.57414 .6238 m
.61496 .65346 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.76609 .48434 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.41086 .30334 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.69277 .58525 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.51178 .23003 L
s
P
p
.2 0 1 r
.016 w
.57414 .42197 m
.57414 .6238 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.42586 .42197 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.5 .44606 L
s
P
p
1 .6 0 r
.016 w
.5 .31992 m
.57414 .42197 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0350795 0.952381 [
[ 0 0 0 0 ]
[ 1 .88222 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88222 L
0 .88222 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.29503 .74969 L
s
P
p
.2 0 1 r
.002 w
.4359 .67792 m
.36412 .81879 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.63191 .77637 L
s
P
p
.2 0 1 r
.002 w
.52012 .66458 m
.67628 .68931 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.4359 .67792 L
s
P
p
0 .4 1 r
.018 w
.47316 .64065 m
.52012 .66458 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.67628 .17558 L
s
P
p
.2 0 1 r
.002 w
.52012 .20031 m
.63191 .08852 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.36412 .0461 L
s
P
p
.2 0 1 r
.002 w
.4359 .18697 m
.29503 .11519 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.52012 .20031 L
s
P
p
0 .4 1 r
.018 w
.47316 .22424 m
.4359 .18697 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.13628 .60378 L
s
P
p
.2 0 1 r
.002 w
.29243 .62851 m
.15156 .70029 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.39314 .82338 L
s
P
p
.2 0 1 r
.002 w
.36841 .66723 m
.4802 .77902 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.29243 .62851 L
s
P
p
0 .4 1 r
.018 w
.34448 .62027 m
.36841 .66723 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.78217 .3634 L
s
P
p
.2 0 1 r
.002 w
.6413 .29163 m
.79745 .2669 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.60573 .07518 L
s
P
p
.2 0 1 r
.002 w
.581 .23133 m
.50922 .09046 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.6413 .29163 L
s
P
p
0 .4 1 r
.018 w
.58925 .28338 m
.581 .23133 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.09361 .39243 L
s
P
p
.2 0 1 r
.002 w
.2054 .50422 m
.04925 .47949 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.17234 .72107 L
s
P
p
.2 0 1 r
.002 w
.24412 .5802 m
.26885 .73635 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.2054 .50422 L
s
P
p
0 .4 1 r
.018 w
.25236 .52815 m
.24412 .5802 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .64065 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.47316 .22424 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.34448 .62027 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.58925 .28338 L
s
P
p
.2 0 1 r
.016 w
.44019 .43244 m
.25236 .52815 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.43937 .79176 L
s
P
p
.2 0 1 r
.002 w
.55117 .67997 m
.52643 .83612 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.76801 .71303 L
s
P
p
.2 0 1 r
.002 w
.62714 .64125 m
.7833 .61652 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.55117 .67997 L
s
P
p
0 .4 1 r
.018 w
.57509 .63301 m
.62714 .64125 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.62455 .12793 L
s
P
p
.2 0 1 r
.002 w
.48368 .19971 m
.55545 .05884 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.28766 .10125 L
s
P
p
.2 0 1 r
.002 w
.39946 .21305 m
.2433 .18832 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.48368 .19971 L
s
P
p
0 .4 1 r
.018 w
.44641 .23697 m
.39946 .21305 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.2433 .70205 L
s
P
p
.2 0 1 r
.002 w
.39946 .67731 m
.28766 .78911 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.55545 .83152 L
s
P
p
.2 0 1 r
.002 w
.48368 .69065 m
.62455 .76243 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.39946 .67731 L
s
P
p
0 .4 1 r
.018 w
.44641 .65339 m
.48368 .69065 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.7833 .27384 L
s
P
p
.2 0 1 r
.002 w
.62714 .24911 m
.76801 .17733 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.52643 .05424 L
s
P
p
.2 0 1 r
.002 w
.55117 .2104 m
.43937 .0986 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.62714 .24911 L
s
P
p
0 .4 1 r
.018 w
.57509 .25736 m
.55117 .2104 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.13741 .51422 L
s
P
p
.2 0 1 r
.002 w
.27828 .586 m
.12212 .61073 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.31384 .80245 L
s
P
p
.2 0 1 r
.002 w
.33857 .64629 m
.41035 .78716 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.27828 .586 L
s
P
p
0 .4 1 r
.018 w
.33033 .59424 m
.33857 .64629 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .63301 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .23697 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.44641 .65339 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.57509 .25736 L
s
P
p
.2 0 1 r
.016 w
.47939 .44518 m
.33033 .59424 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.58965 .78716 L
s
P
p
.2 0 1 r
.002 w
.66143 .64629 m
.68616 .80245 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.87788 .61073 L
s
P
p
.2 0 1 r
.002 w
.72172 .586 m
.86259 .51422 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.66143 .64629 L
s
P
p
0 .4 1 r
.018 w
.66967 .59424 m
.72172 .586 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.56063 .0986 L
s
P
p
.2 0 1 r
.002 w
.44883 .2104 m
.47357 .05424 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.23199 .17733 L
s
P
p
.2 0 1 r
.002 w
.37286 .24911 m
.2167 .27384 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.44883 .2104 L
s
P
p
0 .4 1 r
.018 w
.42491 .25736 m
.37286 .24911 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.37545 .76243 L
s
P
p
.2 0 1 r
.002 w
.51632 .69065 m
.44455 .83152 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.71234 .78911 L
s
P
p
.2 0 1 r
.002 w
.60054 .67731 m
.7567 .70205 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.51632 .69065 L
s
P
p
0 .4 1 r
.018 w
.55359 .65339 m
.60054 .67731 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.7567 .18832 L
s
P
p
.2 0 1 r
.002 w
.60054 .21305 m
.71234 .10125 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.44455 .05884 L
s
P
p
.2 0 1 r
.002 w
.51632 .19971 m
.37545 .12793 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.60054 .21305 L
s
P
p
0 .4 1 r
.018 w
.55359 .23697 m
.51632 .19971 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.2167 .61652 L
s
P
p
.2 0 1 r
.002 w
.37286 .64125 m
.23199 .71303 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.47357 .83612 L
s
P
p
.2 0 1 r
.002 w
.44883 .67997 m
.56063 .79176 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.37286 .64125 L
s
P
p
0 .4 1 r
.018 w
.42491 .63301 m
.44883 .67997 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.66967 .59424 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .25736 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .65339 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.55359 .23697 L
s
P
p
.2 0 1 r
.016 w
.52061 .44518 m
.42491 .63301 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.73115 .73635 L
s
P
p
.2 0 1 r
.002 w
.75588 .5802 m
.82766 .72107 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.95075 .47949 L
s
P
p
.2 0 1 r
.002 w
.7946 .50422 m
.90639 .39243 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.75588 .5802 L
s
P
p
0 .4 1 r
.018 w
.74764 .52815 m
.7946 .50422 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.49078 .09046 L
s
P
p
.2 0 1 r
.002 w
.419 .23133 m
.39427 .07518 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.20255 .2669 L
s
P
p
.2 0 1 r
.002 w
.3587 .29163 m
.21783 .3634 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.419 .23133 L
s
P
p
0 .4 1 r
.018 w
.41075 .28338 m
.3587 .29163 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.5198 .77902 L
s
P
p
.2 0 1 r
.002 w
.63159 .66723 m
.60686 .82338 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.84844 .70029 L
s
P
p
.2 0 1 r
.002 w
.70757 .62851 m
.86372 .60378 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.63159 .66723 L
s
P
p
0 .4 1 r
.018 w
.65552 .62027 m
.70757 .62851 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.70497 .11519 L
s
P
p
.2 0 1 r
.002 w
.5641 .18697 m
.63588 .0461 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.36809 .08852 L
s
P
p
.2 0 1 r
.002 w
.47988 .20031 m
.32372 .17558 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.5641 .18697 L
s
P
p
0 .4 1 r
.018 w
.52684 .22424 m
.47988 .20031 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.32372 .68931 L
s
P
p
.2 0 1 r
.002 w
.47988 .66458 m
.36809 .77637 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.63588 .81879 L
s
P
p
.2 0 1 r
.002 w
.5641 .67792 m
.70497 .74969 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.47988 .66458 L
s
P
p
0 .4 1 r
.018 w
.52684 .64065 m
.5641 .67792 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.74764 .52815 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.41075 .28338 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.65552 .62027 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .22424 L
s
P
p
.2 0 1 r
.016 w
.55981 .43244 m
.52684 .64065 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.44019 .43244 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.47939 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.52061 .44518 L
s
P
p
1 .6 0 r
.016 w
.5 .31505 m
.55981 .43244 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0624966 0.952381 [
[ 0 0 0 0 ]
[ 1 .82739 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .82739 L
0 .82739 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.28352 .57455 m
.14277 .57455 L
s
P
p
.2 0 1 r
.002 w
.28352 .57455 m
.16965 .65728 L
s
P
p
.2 0 1 r
.002 w
.35572 .59801 m
.39921 .73187 L
s
P
p
.2 0 1 r
.002 w
.35572 .59801 m
.46959 .68074 L
s
P
p
0 .4 1 r
.018 w
.32814 .56006 m
.28352 .57455 L
s
P
p
0 .4 1 r
.018 w
.32814 .56006 m
.35572 .59801 L
s
P
p
.2 0 1 r
.002 w
.54335 .22975 m
.67721 .27325 L
s
P
p
.2 0 1 r
.002 w
.54335 .22975 m
.67721 .18626 L
s
P
p
.2 0 1 r
.002 w
.48194 .18513 m
.48194 .04439 L
s
P
p
.2 0 1 r
.002 w
.48194 .18513 m
.39921 .07127 L
s
P
p
0 .4 1 r
.018 w
.49644 .22975 m
.54335 .22975 L
s
P
p
0 .4 1 r
.018 w
.49644 .22975 m
.48194 .18513 L
s
P
p
.2 0 1 r
.002 w
.18969 .47739 m
.07582 .39466 L
s
P
p
.2 0 1 r
.002 w
.18969 .47739 m
.04894 .47739 L
s
P
p
.2 0 1 r
.002 w
.23431 .5388 m
.19082 .67266 L
s
P
p
.2 0 1 r
.002 w
.23431 .5388 m
.2778 .67266 L
s
P
p
0 .4 1 r
.018 w
.23431 .49188 m
.18969 .47739 L
s
P
p
0 .4 1 r
.018 w
.23431 .49188 m
.23431 .5388 L
s
P
p
.2 0 1 r
.002 w
.60257 .35116 m
.6853 .46503 L
s
P
p
.2 0 1 r
.002 w
.60257 .35116 m
.73643 .39466 L
s
P
p
.2 0 1 r
.002 w
.57911 .27897 m
.66184 .1651 L
s
P
p
.2 0 1 r
.002 w
.57911 .27897 m
.57911 .13822 L
s
P
p
0 .4 1 r
.018 w
.56461 .32359 m
.60257 .35116 L
s
P
p
0 .4 1 r
.018 w
.56461 .32359 m
.57911 .27897 L
s
P
p
.2 0 1 r
.002 w
.17089 .34362 m
.1274 .20976 L
s
P
p
.2 0 1 r
.002 w
.17089 .34362 m
.05703 .26089 L
s
P
p
.2 0 1 r
.002 w
.17089 .41953 m
.05703 .50226 L
s
P
p
.2 0 1 r
.002 w
.17089 .41953 m
.1274 .55339 L
s
P
p
0 .4 1 r
.018 w
.19847 .38158 m
.17089 .34362 L
s
P
p
0 .4 1 r
.018 w
.19847 .38158 m
.17089 .41953 L
s
P
p
.2 0 1 r
.016 w
.38613 .38158 m
.32814 .56006 L
s
P
p
.2 0 1 r
.016 w
.38613 .38158 m
.49644 .22975 L
s
P
p
.2 0 1 r
.016 w
.38613 .38158 m
.23431 .49188 L
s
P
p
.2 0 1 r
.016 w
.38613 .38158 m
.56461 .32359 L
s
P
p
.2 0 1 r
.016 w
.38613 .38158 m
.19847 .38158 L
s
P
p
.2 0 1 r
.002 w
.48692 .64914 m
.37305 .73187 L
s
P
p
.2 0 1 r
.002 w
.48692 .64914 m
.44343 .783 L
s
P
p
.2 0 1 r
.002 w
.55912 .62568 m
.67298 .70841 L
s
P
p
.2 0 1 r
.002 w
.55912 .62568 m
.69987 .62568 L
s
P
p
0 .4 1 r
.018 w
.5145 .61119 m
.48692 .64914 L
s
P
p
0 .4 1 r
.018 w
.5145 .61119 m
.55912 .62568 L
s
P
p
.2 0 1 r
.002 w
.49446 .21747 m
.62832 .17397 L
s
P
p
.2 0 1 r
.002 w
.49446 .21747 m
.57719 .1036 L
s
P
p
.2 0 1 r
.002 w
.41855 .21747 m
.33582 .1036 L
s
P
p
.2 0 1 r
.002 w
.41855 .21747 m
.28469 .17397 L
s
P
p
0 .4 1 r
.018 w
.45651 .24504 m
.49446 .21747 L
s
P
p
0 .4 1 r
.018 w
.45651 .24504 m
.41855 .21747 L
s
P
p
.2 0 1 r
.002 w
.3539 .62568 m
.21315 .62568 L
s
P
p
.2 0 1 r
.002 w
.3539 .62568 m
.24003 .70841 L
s
P
p
.2 0 1 r
.002 w
.42609 .64914 m
.46959 .783 L
s
P
p
.2 0 1 r
.002 w
.42609 .64914 m
.53996 .73187 L
s
P
p
0 .4 1 r
.018 w
.39852 .61119 m
.3539 .62568 L
s
P
p
0 .4 1 r
.018 w
.39852 .61119 m
.42609 .64914 L
s
P
p
.2 0 1 r
.002 w
.61373 .28088 m
.74759 .32438 L
s
P
p
.2 0 1 r
.002 w
.61373 .28088 m
.74759 .23739 L
s
P
p
.2 0 1 r
.002 w
.55231 .23626 m
.55231 .09552 L
s
P
p
.2 0 1 r
.002 w
.55231 .23626 m
.46959 .1224 L
s
P
p
0 .4 1 r
.018 w
.56681 .28088 m
.61373 .28088 L
s
P
p
0 .4 1 r
.018 w
.56681 .28088 m
.55231 .23626 L
s
P
p
.2 0 1 r
.002 w
.26006 .52852 m
.1462 .44579 L
s
P
p
.2 0 1 r
.002 w
.26006 .52852 m
.11932 .52852 L
s
P
p
.2 0 1 r
.002 w
.30468 .58993 m
.26119 .72379 L
s
P
p
.2 0 1 r
.002 w
.30468 .58993 m
.34818 .72379 L
s
P
p
0 .4 1 r
.018 w
.30468 .54301 m
.26006 .52852 L
s
P
p
0 .4 1 r
.018 w
.30468 .54301 m
.30468 .58993 L
s
P
p
.2 0 1 r
.016 w
.45651 .43271 m
.5145 .61119 L
s
P
p
.2 0 1 r
.016 w
.45651 .43271 m
.45651 .24504 L
s
P
p
.2 0 1 r
.016 w
.45651 .43271 m
.39852 .61119 L
s
P
p
.2 0 1 r
.016 w
.45651 .43271 m
.56681 .28088 L
s
P
p
.2 0 1 r
.016 w
.45651 .43271 m
.30468 .54301 L
s
P
p
.2 0 1 r
.002 w
.69532 .58993 m
.65182 .72379 L
s
P
p
.2 0 1 r
.002 w
.69532 .58993 m
.73881 .72379 L
s
P
p
.2 0 1 r
.002 w
.73994 .52852 m
.88068 .52852 L
s
P
p
.2 0 1 r
.002 w
.73994 .52852 m
.8538 .44579 L
s
P
p
0 .4 1 r
.018 w
.69532 .54301 m
.69532 .58993 L
s
P
p
0 .4 1 r
.018 w
.69532 .54301 m
.73994 .52852 L
s
P
p
.2 0 1 r
.002 w
.44769 .23626 m
.53041 .1224 L
s
P
p
.2 0 1 r
.002 w
.44769 .23626 m
.44769 .09552 L
s
P
p
.2 0 1 r
.002 w
.38627 .28088 m
.25241 .23739 L
s
P
p
.2 0 1 r
.002 w
.38627 .28088 m
.25241 .32438 L
s
P
p
0 .4 1 r
.018 w
.43319 .28088 m
.44769 .23626 L
s
P
p
0 .4 1 r
.018 w
.43319 .28088 m
.38627 .28088 L
s
P
p
.2 0 1 r
.002 w
.57391 .64914 m
.46004 .73187 L
s
P
p
.2 0 1 r
.002 w
.57391 .64914 m
.53041 .783 L
s
P
p
.2 0 1 r
.002 w
.6461 .62568 m
.75997 .70841 L
s
P
p
.2 0 1 r
.002 w
.6461 .62568 m
.78685 .62568 L
s
P
p
0 .4 1 r
.018 w
.60148 .61119 m
.57391 .64914 L
s
P
p
0 .4 1 r
.018 w
.60148 .61119 m
.6461 .62568 L
s
P
p
.2 0 1 r
.002 w
.58145 .21747 m
.71531 .17397 L
s
P
p
.2 0 1 r
.002 w
.58145 .21747 m
.66418 .1036 L
s
P
p
.2 0 1 r
.002 w
.50554 .21747 m
.42281 .1036 L
s
P
p
.2 0 1 r
.002 w
.50554 .21747 m
.37168 .17397 L
s
P
p
0 .4 1 r
.018 w
.54349 .24504 m
.58145 .21747 L
s
P
p
0 .4 1 r
.018 w
.54349 .24504 m
.50554 .21747 L
s
P
p
.2 0 1 r
.002 w
.44088 .62568 m
.30013 .62568 L
s
P
p
.2 0 1 r
.002 w
.44088 .62568 m
.32702 .70841 L
s
P
p
.2 0 1 r
.002 w
.51308 .64914 m
.55657 .783 L
s
P
p
.2 0 1 r
.002 w
.51308 .64914 m
.62695 .73187 L
s
P
p
0 .4 1 r
.018 w
.4855 .61119 m
.44088 .62568 L
s
P
p
0 .4 1 r
.018 w
.4855 .61119 m
.51308 .64914 L
s
P
p
.2 0 1 r
.016 w
.54349 .43271 m
.69532 .54301 L
s
P
p
.2 0 1 r
.016 w
.54349 .43271 m
.43319 .28088 L
s
P
p
.2 0 1 r
.016 w
.54349 .43271 m
.60148 .61119 L
s
P
p
.2 0 1 r
.016 w
.54349 .43271 m
.54349 .24504 L
s
P
p
.2 0 1 r
.016 w
.54349 .43271 m
.4855 .61119 L
s
P
p
.2 0 1 r
.002 w
.82911 .41953 m
.8726 .55339 L
s
P
p
.2 0 1 r
.002 w
.82911 .41953 m
.94297 .50226 L
s
P
p
.2 0 1 r
.002 w
.82911 .34362 m
.94297 .26089 L
s
P
p
.2 0 1 r
.002 w
.82911 .34362 m
.8726 .20976 L
s
P
p
0 .4 1 r
.018 w
.80153 .38158 m
.82911 .41953 L
s
P
p
0 .4 1 r
.018 w
.80153 .38158 m
.82911 .34362 L
s
P
p
.2 0 1 r
.002 w
.42089 .27897 m
.42089 .13822 L
s
P
p
.2 0 1 r
.002 w
.42089 .27897 m
.33816 .1651 L
s
P
p
.2 0 1 r
.002 w
.39743 .35116 m
.26357 .39466 L
s
P
p
.2 0 1 r
.002 w
.39743 .35116 m
.3147 .46503 L
s
P
p
0 .4 1 r
.018 w
.43539 .32359 m
.42089 .27897 L
s
P
p
0 .4 1 r
.018 w
.43539 .32359 m
.39743 .35116 L
s
P
p
.2 0 1 r
.002 w
.76569 .5388 m
.7222 .67266 L
s
P
p
.2 0 1 r
.002 w
.76569 .5388 m
.80918 .67266 L
s
P
p
.2 0 1 r
.002 w
.81031 .47739 m
.95106 .47739 L
s
P
p
.2 0 1 r
.002 w
.81031 .47739 m
.92418 .39466 L
s
P
p
0 .4 1 r
.018 w
.76569 .49188 m
.76569 .5388 L
s
P
p
0 .4 1 r
.018 w
.76569 .49188 m
.81031 .47739 L
s
P
p
.2 0 1 r
.002 w
.51806 .18513 m
.60079 .07127 L
s
P
p
.2 0 1 r
.002 w
.51806 .18513 m
.51806 .04439 L
s
P
p
.2 0 1 r
.002 w
.45665 .22975 m
.32279 .18626 L
s
P
p
.2 0 1 r
.002 w
.45665 .22975 m
.32279 .27325 L
s
P
p
0 .4 1 r
.018 w
.50356 .22975 m
.51806 .18513 L
s
P
p
0 .4 1 r
.018 w
.50356 .22975 m
.45665 .22975 L
s
P
p
.2 0 1 r
.002 w
.64428 .59801 m
.53041 .68074 L
s
P
p
.2 0 1 r
.002 w
.64428 .59801 m
.60079 .73187 L
s
P
p
.2 0 1 r
.002 w
.71648 .57455 m
.83035 .65728 L
s
P
p
.2 0 1 r
.002 w
.71648 .57455 m
.85723 .57455 L
s
P
p
0 .4 1 r
.018 w
.67186 .56006 m
.64428 .59801 L
s
P
p
0 .4 1 r
.018 w
.67186 .56006 m
.71648 .57455 L
s
P
p
.2 0 1 r
.016 w
.61387 .38158 m
.80153 .38158 L
s
P
p
.2 0 1 r
.016 w
.61387 .38158 m
.43539 .32359 L
s
P
p
.2 0 1 r
.016 w
.61387 .38158 m
.76569 .49188 L
s
P
p
.2 0 1 r
.016 w
.61387 .38158 m
.50356 .22975 L
s
P
p
.2 0 1 r
.016 w
.61387 .38158 m
.67186 .56006 L
s
P
p
1 .6 0 r
.016 w
.5 .29885 m
.38613 .38158 L
s
P
p
1 .6 0 r
.016 w
.5 .29885 m
.45651 .43271 L
s
P
p
1 .6 0 r
.016 w
.5 .29885 m
.54349 .43271 L
s
P
p
1 .6 0 r
.016 w
.5 .29885 m
.61387 .38158 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.14698 .59845 L
s
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.17503 .6848 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.41462 .76264 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.48806 .70928 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.29387 .59845 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.36922 .62294 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .28399 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .1932 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.50096 .04513 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.41462 .07319 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.56505 .2386 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.50096 .19203 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.0771 .4107 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.04905 .49704 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.19712 .70084 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.28791 .70084 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.19594 .49704 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.24251 .56114 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.7132 .48415 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.76656 .4107 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.68871 .17112 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.60237 .14306 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.62685 .36531 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.60237 .28996 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.13093 .21773 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.05749 .27109 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.05749 .52301 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.13093 .57637 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .35744 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .43666 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.34044 .58332 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.51609 .2386 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.24251 .51217 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.58724 .33653 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.20511 .39705 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.37508 .75375 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.44852 .80711 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.6881 .72927 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.71616 .64292 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.49392 .66741 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.56926 .64292 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.64149 .17149 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.58813 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.33622 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.28285 .17149 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.50179 .21688 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.42256 .21688 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.20819 .64292 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.23624 .72927 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.47582 .80711 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.54927 .75375 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.35508 .64292 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.43043 .66741 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .32846 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .23767 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.56216 .0896 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.47582 .11766 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.62626 .28307 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.56216 .2365 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.13831 .45517 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.11026 .54151 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.25833 .74531 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.34911 .74531 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.25715 .54151 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.30372 .60561 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5227 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.46217 .24566 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.40165 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5773 .28307 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.30372 .55664 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.65089 .74531 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.74167 .74531 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.88974 .54151 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.86169 .45517 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.69628 .60561 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.74285 .54151 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.52418 .11766 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.43784 .0896 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .23767 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .32846 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.43784 .2365 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.37374 .28307 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.45073 .75375 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.52418 .80711 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.76376 .72927 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.79181 .64292 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.56957 .66741 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.64492 .64292 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.71715 .17149 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.66378 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.41187 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.35851 .17149 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.57744 .21688 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.49821 .21688 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.28384 .64292 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.3119 .72927 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.55148 .80711 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.62492 .75375 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.43074 .64292 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.50608 .66741 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.69628 .55664 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4227 .28307 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.59835 .62779 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.53783 .24566 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4773 .62779 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.86907 .57637 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.94251 .52301 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.94251 .27109 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.86907 .21773 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .43666 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .35744 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.39763 .14306 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.31129 .17112 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.23344 .4107 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.2868 .48415 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.39763 .28996 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.37315 .36531 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.71209 .70084 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.80288 .70084 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.95095 .49704 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.9229 .4107 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.75749 .56114 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.80406 .49704 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.58538 .07319 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.49904 .04513 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .1932 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .28399 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.49904 .19203 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.43495 .2386 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.51194 .70928 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.58538 .76264 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.82497 .6848 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.85302 .59845 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.63078 .62294 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.70613 .59845 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.79489 .39705 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.41276 .33653 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.75749 .51217 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.48391 .2386 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.65956 .58332 L
s
P
p
1 .6 0 r
.014 w
.5 .3251 m
.40097 .39705 L
s
P
p
1 .6 0 r
.014 w
.5 .3251 m
.46217 .44152 L
s
P
p
1 .6 0 r
.014 w
.5 .3251 m
.53783 .44152 L
s
P
p
1 .6 0 r
.014 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.14698 .59845 L
s
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.17503 .6848 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.41462 .76264 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.48806 .70928 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.29387 .59845 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.36922 .62294 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .28399 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .1932 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.50096 .04513 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.41462 .07319 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.56505 .2386 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.50096 .19203 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.0771 .4107 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.04905 .49704 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.19712 .70084 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.28791 .70084 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.19594 .49704 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.24251 .56114 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.7132 .48415 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.76656 .4107 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.68871 .17112 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.60237 .14306 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.62685 .36531 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.60237 .28996 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.13093 .21773 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.05749 .27109 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.05749 .52301 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.13093 .57637 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .35744 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .43666 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.34044 .58332 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.51609 .2386 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.24251 .51217 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.58724 .33653 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.20511 .39705 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.37508 .75375 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.44852 .80711 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.6881 .72927 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.71616 .64292 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.49392 .66741 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.56926 .64292 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.64149 .17149 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.58813 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.33622 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.28285 .17149 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.50179 .21688 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.42256 .21688 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.20819 .64292 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.23624 .72927 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.47582 .80711 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.54927 .75375 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.35508 .64292 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.43043 .66741 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .32846 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .23767 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.56216 .0896 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.47582 .11766 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.62626 .28307 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.56216 .2365 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.13831 .45517 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.11026 .54151 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.25833 .74531 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.34911 .74531 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.25715 .54151 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.30372 .60561 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5227 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.46217 .24566 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.40165 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5773 .28307 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.30372 .55664 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.65089 .74531 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.74167 .74531 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.88974 .54151 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.86169 .45517 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.69628 .60561 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.74285 .54151 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.52418 .11766 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.43784 .0896 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .23767 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .32846 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.43784 .2365 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.37374 .28307 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.45073 .75375 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.52418 .80711 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.76376 .72927 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.79181 .64292 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.56957 .66741 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.64492 .64292 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.71715 .17149 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.66378 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.41187 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.35851 .17149 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.57744 .21688 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.49821 .21688 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.28384 .64292 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.3119 .72927 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.55148 .80711 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.62492 .75375 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.43074 .64292 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.50608 .66741 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.69628 .55664 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4227 .28307 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.59835 .62779 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.53783 .24566 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4773 .62779 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.86907 .57637 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.94251 .52301 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.94251 .27109 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.86907 .21773 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .43666 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .35744 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.39763 .14306 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.31129 .17112 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.23344 .4107 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.2868 .48415 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.39763 .28996 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.37315 .36531 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.71209 .70084 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.80288 .70084 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.95095 .49704 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.9229 .4107 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.75749 .56114 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.80406 .49704 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.58538 .07319 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.49904 .04513 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .1932 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .28399 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.49904 .19203 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.43495 .2386 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.51194 .70928 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.58538 .76264 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.82497 .6848 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.85302 .59845 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.63078 .62294 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.70613 .59845 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.79489 .39705 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.41276 .33653 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.75749 .51217 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.48391 .2386 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.65956 .58332 L
s
P
p
.8 1 0 r
.016 w
.5 .3251 m
.40097 .39705 L
s
P
p
.8 1 0 r
.016 w
.5 .3251 m
.46217 .44152 L
s
P
p
.8 1 0 r
.016 w
.5 .3251 m
.53783 .44152 L
s
P
p
.8 1 0 r
.016 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.197885 0.952381 [
[ 0 0 0 0 ]
[ 1 .55661 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .55661 L
0 .55661 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.19594 .20924 m
.0771 .1229 L
s
P
p
.2 0 1 r
.002 w
.19594 .20924 m
.04905 .20924 L
s
P
p
.2 0 1 r
.002 w
.24251 .27334 m
.19712 .41304 L
s
P
p
.2 0 1 r
.002 w
.24251 .27334 m
.28791 .41304 L
s
P
p
0 .4 1 r
.018 w
.24251 .22437 m
.19594 .20924 L
s
P
p
0 .4 1 r
.018 w
.24251 .22437 m
.24251 .27334 L
s
P
p
.2 0 1 r
.016 w
.40097 .10925 m
.24251 .22437 L
s
P
p
.2 0 1 r
.002 w
.35508 .35512 m
.20819 .35512 L
s
P
p
.2 0 1 r
.002 w
.35508 .35512 m
.23624 .44147 L
s
P
p
.2 0 1 r
.002 w
.43043 .37961 m
.47582 .51931 L
s
P
p
.2 0 1 r
.002 w
.43043 .37961 m
.54927 .46595 L
s
P
p
0 .4 1 r
.018 w
.40165 .33999 m
.35508 .35512 L
s
P
p
0 .4 1 r
.018 w
.40165 .33999 m
.43043 .37961 L
s
P
p
.2 0 1 r
.016 w
.46217 .15372 m
.40165 .33999 L
s
P
p
.2 0 1 r
.002 w
.56957 .37961 m
.45073 .46595 L
s
P
p
.2 0 1 r
.002 w
.56957 .37961 m
.52418 .51931 L
s
P
p
.2 0 1 r
.002 w
.64492 .35512 m
.76376 .44147 L
s
P
p
.2 0 1 r
.002 w
.64492 .35512 m
.79181 .35512 L
s
P
p
0 .4 1 r
.018 w
.59835 .33999 m
.56957 .37961 L
s
P
p
0 .4 1 r
.018 w
.59835 .33999 m
.64492 .35512 L
s
P
p
.2 0 1 r
.016 w
.53783 .15372 m
.59835 .33999 L
s
P
p
.2 0 1 r
.002 w
.75749 .27334 m
.71209 .41304 L
s
P
p
.2 0 1 r
.002 w
.75749 .27334 m
.80288 .41304 L
s
P
p
.2 0 1 r
.002 w
.80406 .20924 m
.95095 .20924 L
s
P
p
.2 0 1 r
.002 w
.80406 .20924 m
.9229 .1229 L
s
P
p
0 .4 1 r
.018 w
.75749 .22437 m
.75749 .27334 L
s
P
p
0 .4 1 r
.018 w
.75749 .22437 m
.80406 .20924 L
s
P
p
.2 0 1 r
.016 w
.59903 .10925 m
.75749 .22437 L
s
P
p
1 .6 0 r
.016 w
.5 .0373 m
.40097 .10925 L
s
P
p
1 .6 0 r
.016 w
.5 .0373 m
.46217 .15372 L
s
P
p
1 .6 0 r
.016 w
.5 .0373 m
.53783 .15372 L
s
P
p
1 .6 0 r
.016 w
.5 .0373 m
.59903 .10925 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{35, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`0001L000==000080000dd0000O0003C@1=01l00Td00`1=C@0P0003C@000200
00==000080000lH0000F00005002C00304`0009<7002C00304`0009<6`001T`0C4`0C08000=<0000
6P02C00304a<01h000E<04`0C00M009<00<0C0000T`L00;600<0aP000/HE00004P000dd0C@06C@03
04d001L000==04d01Td00`1=000H00I=00<0CDd060001Dd004d000==00<0C@000TdG0008C@00C@1=
04d20003C@0001H000==04d01Td00`1=000G0003aP3600K600<0aP004P00018000=<04`01d`I0003
C01<00M<600=C1D034`00`1<C00F0003C01<00I<00<0C0006009C1X02<H00`36000B0000400?CA@0
3ddF00]=6002C@0304e=00I=5P07C@03aTe=00E=500?CA@03lHA00002`000d`0000200M<00?6C<H0
14`50003C00000P000=<00000P0>C0D000=<00002P000d`0C007C003aTc600I<00<0C0004004C007
aTa<aTc60004C1H01D`01<I<a/H2C14000=<00000`06C003aTc600E<10000d`000080003aP0000<0
3/H40003aP0000X0000;0003C@0000M=00G6CDe=aP06C@<000==000020000dd0000BC@<000==0000
1`0014d004d200E=00G6CDe=aP05C@8000A=001=2@000dd00005009=00G6CDe=aP03C@H000==0000
200014d00003C@0804e=aTd0CLH2C@0404e=C@<000==0000200014d00006C@;60Td00lI=C@04C@<0
00==000020001<H00008aP9=1<H01036a/H20003aP0000X00009009<00<0C0000P05C00304a<009<
0/H2C0@000A<04a<1P02C00304`000801D`00`1<C006C0@000A<04a<1`000d`0000=C0;614`01@1<
001<00L00d`200M<00G6C4a<aP02C00304a<009<0P03C0H000=<04`01@02C0;600L0C01<04c6009<
1@000d`0C006009<00<0C0000`09C0;60d`30004C01<C0H00/H00`36000300C614`00`1<aP03aP<0
00C60<K62P0000/00Td200==0P000lH0C@03C@03aP00009=0`02C@X00Td200==0P000dd0C@04C@80
0Td3009=2003C@0304d000800Td00`36C@04C@04aP1=C@<000==04d00Td8009=00<0CDd00dd2aPE=
0/H5C@0304e=00T00Td3009=0`000lH0C@02C@0304d000800Td3009=2@02C@<00Td20003aTe=00==
00?600000Td3009=2P02aP<00/H20003aTe=009=00@0C@000lH200;6300000`000=<04`01@02C0<A
0T`40004C000C0`000=<04`01@02C0<A0T`40004C000C0/00d`2009<0P02C0<A0T`2009<0P03C0/0
00=<00001@02C0<A0T`70003C00000T00T`7009<0a42C0L00T`;0004C000C0@00T`34@9<100014`0
04`<0004aP00aP@00T`34@9<1@000lH0aP0=00003@000lH00002000;CLH04DdACA40aTd010000lH0
000<0003C@0000800Td01`0ACA5=4@000Td40003C@0000X000==0<H01Dd02LH04DdACA40aP04C@04
0<H0C@`000?600000P002dg6015=4DdA0<I=00@000?600002`000lH00002009=00W6015=4DdA0<H0
0Td40003aP0000/000?600000P002dg6015=4DdA0<I=00@000?6000030000lH0000200;600L04DdA
CA4000;610000lH0000<00003@07C0074D`AC1404@06C1001T`01a5<4D`A01401T`=0003C00000I<
00LAC15<4@0A00I<0P000d`0000;00I<00LAC4`AC00A00I<3`07C0074D`AC1404@07C0l01T`01a5<
4D`A01401T`@009<0/H02Dc64D`AC1404@06C0l00009009=00@0CLI=0`001dd0CDdA01400Td01`1=
001=0<H00dd7009=00@0CDe=0`001dd0CDdA01400Td01P1=001=00A=2P02C@801Td00a404@06C@80
00?6C@002002C@8000C604d00Td02@1=015=4@1=0002C@0404d0aP800Td6009=00<0aP000`02C@06
04e=4@0A0Td00`1=C@040004aP1=C@L00dd00lH0C@020007C@1=CA404@02C@0304d0008000==aTd0
0Td800C600H0aP00aP02C@034@0A009=00<0C@000P03aP030<K600X0000;00=<0`002D`0C4`0C01<
0002C00304`000800d`:00=<0`002D`0C4`0C01<0002C00304`000800d`800E<00@0C4`00d`01@1<
04`000=<00<0C4`00T`0101<C4`800=<0P02C00;04`0C1404D`0C0000T`200=<2P02C0<00T`0201<
C01<04`00T`00`1<C003009<2P03C0<000U<04a<04`0C0000T`00`1<000200=<2P03aP<000W604a<
04`0C0000T`00`1<000200?6300000T01Dd00lH0C@020009C@1=04d0C@1=008000A=0<K614d600I=
00d0C@00C@1=04d0C@1=008000==04d01Dd60003C@1=00A=0P02C@0704d0C@1=0002C@8000==aTd0
0Td00`1=000500A=0/H0101=0002C@0504d0C@000Td20004C@36aPA=1P05C@0404d0009=0P000dd0
C@02009=0P000dd0aP04C@H01Dd00lH0C@020009C@1=04d0C@1=008000A=0<K614d600K600d0aP00
C@1=04d0C@1=008000==0<H01LH:00002@001D`004`0009<0P02C00704`0C01<0002C0800T`01@1<
001<00H000E<001<0002C0800T`01`1<04`0C0000T`2009<00D0C000C00600=<00<0C4`00/H02P1<
C01<04`0C002C0030<K6009<00@0C4a<1`06C0800T`01`1<04`0C0000T`200I<1`000d`0C002000@
C000C01<04`0C01<04`0C08000I<001<04`60005C000C0000T`2009<00L0C01<04`0009<0P02C005
04`004`01P001lH00<H0aT`00P02C00704`0C01<0002C08000A<aP360P000lH0000800002P05C@;6
0Td20005C@1=04d00P02C@;614d:00Q=0P001Dd0C@1=008024d90003C@1=009=00C604e=0P001Dd0
C@1=00800Td00`36C@02C@0304d000H000I=001=04d2aP9=0P001Dd0C@1=00800Td2aP03C@1=0080
00==00001P04C@04aTd0C@8000E=04d0C@020003C@1=00;60dd:00A=0/H2C@8000E=04d0C@02009=
0/H4C@X01/H2C@8000E=04d0C@02009=1/H<00002`05C0;600a<04`0C01<04`0C<H6C0X024`02@1<
04`0C01<0008C0X000=<04`01D`02`1<04`0C01<04c600A<00<0C0002@0024`0001<0<I<0P001D`0
C01<008000A<aP1<0`000d`0000;0005aP36aT`00P001D`0C01<008000E<a/H0aP0=00E<0/H02d`0
C01<04`0C01<00;61D`:00O600]<04`0C01<04`0C007aP`0000>009=00l0aP36C@1=04d0CLH0aP00
0Td@009=00<0C@000Td01@1=04d0009=00<0C@000Td?00Y=00D0CDe=aP06C@d014d2aP0;0<I=04d0
C@1=aP000/H4C@`014d03lH0aP1=04d0C@1=0<H0aP04C@h00Td03`360<I=04d0C@1=aP360002CA00
0/H02P360<I=04d0C@02aP030<H000;63`0000h01d`2aP040<I<aPI<4009C00304a<00M<3P02C003
04a<00A<00G6C4a<aP06C00304a<00d01D`02<I<C<I<04c60T`01<I<C002C0h024`01/I<04c6C0;6
1D`?00M<0/H01P36C<I<aPA<4009aP030<K600O63`0000d00Td03P1=C@1=0<I=aTg604d00Td00`1=
C@0>009=00H0CDd0C@05C@0304d0009=00<0CDd03@000dd0C@0?C@0504e=04d030000dd0C@06C@05
aTg60<H01dd00`1=000<0003C@00009=00H0C@36CLH2C@0304d0009=0P000dd0000<009=00h0CDd0
C@36CLI=aP1=009=00<0CDd03P02aP060<K60<H01LH00`360002aP030<K600h0000=0007C01<C01<
0004C00704a<04`0C0020003C00000`000M<001<04`000A<00L0C4`0C01<008000=<00003@02C003
04a<00U<00<0C0000T`@00A<0P07C0800T`00`1<000@00E<00<0C4`00d`00`1<C003C10000M<001<
04`000M<00@0C01<0P000d`0000<0007aP00aP360007aP040<H0aP8000?60000300000h00Td00`1=
C@04C@0304e=00A=00<0C@004@000dd0C@05C@0304e=00A=00<0C@004P04C@0304e=00==00<0CDd0
0TdD009=0P000dd0C@04C@800TdC0005C@1=C@000Td00`1=0002C@0504e=04d04P000dd0C@05C@03
04e=00A=00<0C@004@000lH0aP05aP030<K600C600<0aP003`0001@000M<04`0C01<01`000M<04`0
C01<01`014`00`1<C00K0005C01<C0000d`K009<00D0C01<0002C1/000M<04`0C01<01`000O60<H0
aP3601D0000E009=00<0CDd07P02C@0304e=01h000E=04d0C@0N0005C@1=04d07`000dd0C@0O009=
00<0CDd07P02aP030<K601H0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0
003o00<0003o00<0003o00<0000E0005C00004`07`02C28000=<000080000d`000120003C01<0240
00=<00005P0001@014d00`1=C@0J0003C@1=00==00D0CDd0C@0J009=00<0C@000TdL009=00<0C@00
0TdL009=00<0C@000TdK0006C@00C@1=0P000dd0000I009=00<0C@000TdE00004`02C00504a<C000
0T`I0003C01<00I<00<0C0005`000d`0C006C00304`001L000=<04`01T`00`1<000G00A<00<0C000
14`G0009C000C01<04`0009<00<0C0005@000d`00007C08000=<0000400001400Td01@1=CDd000==
00<0CDd05@02C@0304e=00==00D0CDe=0002CAH000==04d01ddJ00U=6@001dd0CDd0C@000Td00`1=
000F0003C@0000M=0P000dd0000E0003C@1=00I=00<0C@004P0001<000E<04a<0002C00304`001H0
1T`2aPM<500?C1@03d`D009<00<0C0000T`01P1<C01<009<5P000d`00005C08000=<00005006C003
0<H000I<4@0001@000M=aP360<I=01P000I=04e=04d2aP03CLI=00==40000dd0000200M=00?6CLH0
14d50003C@0000P000==00000P07C@03aTg600A=1@000dd0000?009=0P000lH0aP02009=4P0014d0
0007C@03aTe=00E=0`000dd000090003C@0000801Td2aP9=00?6CDd00Td40003C@0000X0000@00E<
00G6C01<aP05C0l000=<00001T`2aP04C01<aPI<0`000d`000080003C00000M<00G6C4a<aP06C0<0
00=<0000200014`00004C00304c600C600=<04`00d`30003C00000`00T`30003aP1<009<00<0aP00
0P02C0`000A<001<0`05C0;60T`2aPA<0`0014`004`80003C000009<0`0014c6a/H2C003aTa<00<0
0T`20003C00000X0000?00A=0/H2C@0404e=aPE=30000dd0C@0400E=00L0C@1=04g600==10000dd0
C@06009=00<0C@000P05C@0304e=009=0/H2C@@000A=04e=1P02C@0304d000<014d7aP03C@0000<0
00A=04e=3P0014d00005C@<000==00003@0014d0C@04C@0404e=aP==00?6CDd00P03C@0404d0C@L0
0Td00`1=000200==00<0a/H00dd2aP0404e=C@<000A=04e=2P00018000=<00000P000a4000020003
C00000h00T`200=<0P000lI<0003C00304c600800T`3009<2@02C0800d`20003aP1<00=<00?60000
0T`3009<2P02C0<00T`200O60P02C0<00T`A0003C000009<00<0C4`00P000d`0000?0003C01<00@0
00=<a/H014`00`1<aP02C0<000=<04`02P02C0<00T`3aPE<0lH2C0<00T`<00004@000dd0000200<A
10000dd0000>009=1P000lI=C@034@9=1`02C@/000==04d01@02C@<A0Td40004C@00C@`000A=001=
1002aP<A0/H40004C@00C@T00Td400A=00?6CDd00a42C@03aTe=009=1002C@T00Td2009=0P02C@<A
0Td2009=0P02C@d000?6CDd01002C@<A0Td4009=00?600003000010000=<00000P001A404@0A00@0
00=<00003P001<H00002C00:aP004D`AC140aP=<0`000lH0000;0003aP00008000]<aP0AC15<4@36
C0040003aP0000`000?600000P002dc601764LHA0<I<00@000?600002P02C0P000DAC15<4@08009<
30000lH0C002000;C<H04D`AC140aT`00P000d`0aP0>0003aP0000@000S64D`AC140aPD000?60000
300000T00Td80009CA404@0A015=00P000==00002@07C@074DdACA404@07C@l01Td01a5=CA5=0140
1Td@0007aTe=CLI=4@02aP044LH04@K63@02C@03aTe=00A=00LACA5=4@0A00I=00?6CDd02@0014d0
0006C@074De=4Dd04@07C@8000==00001P0014d00005C@08aQ5=CA5=0146C@<00Td:00002`000d`0
0003009<0`000a404@03009<1@000d`00006009<00<0aP000`02C00604a<4@0A0T`00`1<00040003
aP1<00L00T`0101<aT`3000;C01<015<4@1<04`00P000d`0aP03C0P00d`00lI<0002000;C0360176
4@360<H00P000d`0aP03C0L00T`6009<00H0C4`A0142C00304a<00H00T`8009<0180aP1<04`0C00A
C140C01<04`20003aTa<00X000=<00000d`0301<04`04D`A04`0C08000E<aP00C00<000030001Dd0
001=00D000==04d01@001Dd0001=00/00Td3009=00P0CDd0C@1=009=00<0C@000`02C@X00dd3000=
C@1=04dA015=04d0C@0300==2P03C@<000e=0<H0aQ404LH0aP3600<00dd?0003C@00009=00D0C@1=
0002C@8000==00002`04C@04aP1=00==00L0CA404Dd000==00@0C@3614d8009=01760000C@1=04dA
015=04d0C@030003aTe=00`0000900A<0/H00d`000030005C00004`01@000dc6aP04C0L000E<04a<
0002C00304a<008000=<04`00P0014`004`2009<00<0C0001P05C003aP1<00800T`01@1<04`0009<
0P0014`0a/H4C0H01D`00lH0C00200;600D0aP360002aP8000C60<K614`<000=C00004`0C01<04`0
C0030003C00000`00d`01<H0C003C00504`0C0000d`00`1<0002aP9<2006C00404`0009<00D0C01<
0002C08000A<0<K614`:00003`000lH000030005C@0004d01@000lH0000:00A=00k6C@00C@1=04d0
C@1=009=0P000dg6aP04C@H000E=001=0002C@800Td01`1=04d0C@000Td2009=00D0C@00C@060007
C@00C@1=aP0200;600L0aP360<H000;60P001<I=04d20003C@0000L00Td01<H00002C@0704d0C@1=
0002C@<000?6CDd02P06C@0;04e=C@1=04d0C@000dd00`1=C@04C@P01Dd2aP0:04e=04d0C@1=009=
00<0aTd01Dd;00003`000lH000030005C00004`01@000lH0000;00E<00C6C01<0P001D`0C01<0080
0T`2aPA<2P04C0;60T`20005C01<04`00P02C0;614`:00A<1<H20005aP360<H00P04aPA<2@02C080
0T`00lI<C0020005C01<04`00P02C003aTa<00800T`70006C000C01<0/H2C08000E<04`0C002009<
0/H00d`0C0020003C00000@000A<001<0P001<H0C4`20005C01<04`00P02C0050<H004`00P000d`0
000800003`000dd000020003C@0000<000==00000P000dd0000<0005C@00aP000/H024d004d0C@1=
0P0014g60<H30003C@0000P000Q=0000C@36C@8000E=04d0C@020004CLH0C@<000==000020001Td0
001=00;60P001LH0aP3600800/H00`1=00020003C@0000X00Td04@1=0<H0C@1=04d0C@3604d0009=
3@04C@;600Q=001=04d0C@8000==a/H014d;0008C@000<H0aTd20005C@1=04d00P0014g60<H30003
C@0000X0000>00A<0/H00d`000030003C<I<00A<3P04C00<aP3604`0C01<04`00/H5C0`014`2aP0;
0<I<04`0C01<aP000/H4C0`014`2aP0;0<K60<H0aP1<aP000/H4C0`00T`03`1<003604`0C01<04`0
aP020004C01<C0h01d`02@1<04`0C<I<aP03C0h014`2aP090<I<aT`0C<I<00C614`=00003P000dd0
C@040005aP00CLH00`02C@0304d000l01dd01/I=04g6C@;614d@00M=0/H01P36CLI=aPA=4007C@;6
00H0aTg6CLH4C@h000==04d00P02C@090<H0aP360<H0009=0P000dd0C@0=009=00<0CDd00/H014g6
C@04C@04aTe=009=3`06C@04aTd0aP8000==a/H01Dd>00003@0014`0C4`400=<00<0C0000`0014`0
04`>00E<00/0C036C<H0C01<0002C00304`000h00T`03P1<C01<0<I<aTc604`00T`00`1<C00>009<
00h0C4`0C036C<I<aP1<009<00<0C4`03P004T`004`0C01<04`0C01<04`0C08000=<00002`000d`0
C006C005aTa<C<H01d`00`1<000<009<00@0C4`00T`00lI<0002C00304`0009<00@0C01<3@0000h0
00==00001003C@0304d000@000==00003P000dd0C@04C@0304e=00==00D0CDd0C@020003C@0000`0
00M=001=04d000M=00@0C@1=0P000dd0000<0007C@00C@1=0007C@0404d0C@8000==00003P000dd0
0005C@0304e=00==0P000dd0000?0003C@1=00i=00<0C@003`05C@0304e=00E=00<0CDd00dd?0000
5@02C00304`001P000E<04a<0002C00304`0009<00D0C4`0C00B0003C01<00E<00<0C4`014`00`1<
000A0003C01<00E<00<0C4`014`00`1<000D000;C01<04`0C01<04`05P000d`0C004C00304a<00=<
00<0C0004@000d`0C002C00904a<C01<04`000=<00<0C0003P0001H000==04d07@02C@0604d0C@1=
70001dd0C@1=04d070001dd0C@1=04d06@002Dd0CDd0C@1=0002C@0304d001@000==00000P02C@03
04e=00@000==00004P001Dd0CDd0009=00@0CDd00Td00`1=000@00005P000d`0C00P0003C01<01l0
0T`00`1<C00N009<00<0C4`0@@000d`0C0020003C00001/000E<04`0C00F0000o`030000o`030000
o`030000o`030000o`030000o`030000o`030000o`030000o`030000F@000d`000050003C00009h0
000g0003C@0000<000==00006@04C@0304e=009=7@000dd0C@0Q0003C@00020000==0000>@0003L0
00A<04a<0P000d`0000F0003C00000U<0P000d`0000F0007C01<04`0C00L009<00<0C0000T`L009<
00<0C0000T`h0000=@0;CAH00Td0101=C@03C@0304e=009=5`000dd0C@02C@0604e=C@1=60000dd0
C@06C@0304d001L000==04d01Td00`1=000e0000<`000d`00009C00304a<01H02d`H0003C01<009<
00<0C4`00P000d`0000G00U<6P09C3L0000F00<A6`0014d0C@03C@03aTd0009=5008C@;600==aTd0
1DdC00m=500?CA@03ddK00034@0001H0000E00054@0A01406P05C003aP3600E<5@04C0?600@0C<K6
0d`F00I<00@0aT`00d`@0003C00000801d`00lI<aP05C0@000=<000020000d`0000300I<00?6C<H0
1D`40003C00001<00a4G00004`024@03014A00800Q4F00A=00S6CDg6CLI=aPE=5002C@;60Td00`1=
C@02aP==3`0014d00002C@800dd00lI=aP02aP03C@00009=0`000dd000080004C@00009=00T0C@1=
aTd0CLH00dd00`1=C@030003C@0000P000A=00000Td0101=04d2aP9=00G6CDe=0002C@<000==0000
4P001A404@0A01H0000B00074@0001404@0300034@0001P000O6C01<04c601D01D`2aP=<00D0C4a<
aP05C0/00d`500A<00G6C4a<aP04C0D00d`6009<00<0C0000`04C005aT`0C<H014`40004C01<C0H0
0T`00`1<000300A<00G6C4a<aP04C0@000A<04a<1`000d`000060009C1404@0A015<00P00T`:0000
4@000a40000200034@0A00@000<A00005`03C@0404e=CAP000==00000P02C@034De=00<00Td?009=
1002C@;600E=4A4AC@02aP9=1002C@X00Td300==0/H5C@;60dd3009=2P02C@@00Td2aPE=0/H3C@<0
0Td:0003C@0000<00Td300034@0A00<00Td50003C@0000X0000?008A100011400145008A3@0014`0
0005C006aP00C15<0P000lI<C003C0<000=<00002`000d`00003009<00<AC4`01@000d`0000=0003
C000009<10001A5<4D`A00@00T`20003C00000X000=<00000T`3009<0a42C0<00T`20003C00000X0
00=<00000T`3009<0ml2C0<00T`20003C00000X000E<0000C0050003C01<00D000E<0000C00=0000
3P000a40000400054@0001401P000a40000:0003C@0000<00Td40003CA5=00@00Td50003C@0000X0
00==000010001DdA4A5=00H000==00003@000lH00002009=00@ACDdA0Td00a5=C@040003aP0000`0
00?600000P002dg6015=4DdA0<I=00@000?6000030000lH00002000;CLH0gTgNCMh0aTd010000lH0
000800A=0/H00dd000030005C@0004d01@000dg6aP04C@X0000<008A1`001A40000A00L00Q4900=<
0`000d`000030005C14A4D`01@0014`00003C0L00T`90005C15<4D`02@02C0L00T`200I<00TAC00A
C140C1401T`20003C00000X01T`01a5<C15<01401T`@00I<00OOC4cOC03O00I<4@000lH000030005
C00004`01@000lH0000>00002`000a40000600034@00008000<A00001`000a400008009=1P02C@05
4@0A01400Td6009=2`000dd000050004CA4A008A00==00001@000dd00009009=00?600000P02C@80
00<ACA400P02C@@000?6CDd02@03C@03aP1=008000]=04d04DdA04d0C@020003C@3600==2003C@03
aP1=008000]=04d0gTgN04d0C@030003CLI=009=3@000lH000030005C@0004d01@000lH0000>0000
2P000a40000700034@0000<000<A00001`000a4000090003aP0000=<0P001D`04@1<00800d`00`36
aP0:00E<1002C00404a<009<00<0C4`010000d`0C002C0P00d`300=<00L0C1404D`000=<0`03C0X0
0d`3000=C01<04`A015<04`0C00300=<2P03C0<000e<04`0C=l0gd`0C01<00<00d`>0003C0000080
00=<00000`000d`000020003C00000h0000900034@0000L000<A000010000a40000800034@0000T0
0Td4009=00<0C@000Td40003C@0000`00dd01<H0CDd200M=0P02C@040<I=C@T01Dd01LH0CDd0009=
00D0C@1=0002C@0404e=00;614d600E=00?604d00P02C@0504d0C@000Td20004C@36aPA=1P05C@03
aP1=00800Td01@1=04d0009=0P0014d0a/H4C@/00Td30003aTd000@000==aP000P02C@l0000C0003
4@0000@000<A000050000lH000020003C01<00A<00<0C0000`000lH0000=00=<1007C0@00T`;0005
C000C0000T`20003C000009<00<0C4`00P000d`00002C00504`004`01P001D`004`0009<0P02C007
04`0C01<0002C0800T`01@1<001<00H000E<001<0002C0800T`01`1<04`0C0000T`2009<00D0C000
C00;00A<00S60036C01<aP8000?6C4`00T`?00004`000a40000500034@00010014d30008C@00C@1=
04d20004C@0000A=3P001Td0001=009=00D0CDd0C@030003aP0000`014d2aP9=0P001Dd0C@1=0080
0Td2aPA=2P04C@;60Td20005C@1=04d00P02C@;614d:00A=0/H2C@8000E=04d0C@02009=0/H4C@`0
00A=001=10001Dd0C@1=00@000A=001=3P00018000<A00001P000a40000B00E<0P02C00304`0009<
0P000dc6aP02C0`01D`2aP9<00@0C4`00T`00`1<C002aPE<2P05C0;600Q<001<04`0C08000=<a/H0
1D`:0008C00004`0aT`20005C01<04`00P0014c604`30003C00000P000Q<0000C036C08000E<04`0
C0020004C<H0C0<000=<000030000d`00003009<00<0C4`01@000d`0000>00004P000a4000060003
4@0001400dd03@1=CLI=aTd0C@1=aTd00/H5C@h01Dd2aP9=00?6CDd00/H00dg6aP02CA000Td02P36
a/I=0<I=aP02C@;600<0CDd03P04C@;600/0aTd0C@1=04g60002aPA=3004C@;600/0aTd0C@1=04g6
0002aPA=5@02C@0304e=01H0000B00034@0000L000<A00003`000d`0C002C0030<I<00;600D0aTc6
0002aP04C<H0009<00<0C0002`02C00304a<00;60T`00lH0aP02C0;60T`00`1<C00>00Q<00G60<H0
aP07C1001d`2aP060<I<aTc614`@00M<0/H01P36C<I<aPA<60000d`0C00G00004@000a4000080003
4@00018000E=04e=0004C@0304e=009=00D0CDd0C@0>009=00<0CDd00dd2aP04CLI=aPM=00<0C@00
2`02C@8014d01036CLH2C@0304d0009=0P000dd0000<009=00h0CDd0C@36CLI=aP1=009=00<0CDd0
3P02C@0>04e=04d0aTg6CLH0C@02C@0304e=01L000==04d05`00038000=<04`034`00`1<000>0004
C01<00e<00D0C4`0C00@00i<00<0C4`040001d`004`0C0000T`00`1<0002C00404`0C08000=<0000
30001d`004`0C0001d`0101<04`20003C00002l0000d0003C@1=00==00<0CDd014dE009=00<0CDd0
1dd00`1=000C0003C@0000E=00<0CDd00dd20003C@00010000E=04e=0003C@0504e=C@000Td00`1=
000A0003C@1=00E=00<0CDd014d00`1=000b0000<`02C08014`00`1<C0020003C00001<00T`00`1<
C002C00304a<009<00<0C4`06P000d`0C00M00A<00<0C4`00T`K0007C01<04`0C00h0000=P02C@D0
0TdH0009C@1=C@1=04d0009=00<0C@006@02C@0304e=01h00Td00`1=C@0N009=00<0CDd0>@0005/0
0T`00`1<C02R0000o`030000o`030000o`030000o`030000o`030000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.109415,
   0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110613, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.10942, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438, 
  72.5625}} -> {-3.74027, -0.110613, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.109418, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277,
   -0.110613, 0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.1939, -0.109415, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.270008, -1.2634, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  69.375, 37.5625}} -> {-1.42777, -1.26686, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26686, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.88594, -1.2634, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277,
   -1.26687, 0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.1939, -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.270008, -2.41738, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.74027, -2.42311, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277,
   -2.42311, 0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1939, -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .83066 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0608586 0.952381 [
[ 0 0 0 0 ]
[ 1 .83066 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .83066 L
0 .83066 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .53189 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .62025 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.21533 .69174 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.37271 .74288 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.45675 .71557 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.50869 .64408 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.29937 .57607 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.37271 .5999 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .30985 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.7063 .22581 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .14177 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.54512 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.45675 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.38526 .09644 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.56332 .22581 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.50093 .18048 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.12002 .36169 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .43318 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .52154 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.16534 .65542 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.24938 .68273 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.33342 .65542 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.20405 .47736 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.24938 .53975 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.66765 .48512 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.73914 .43318 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.76645 .34914 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.71531 .19176 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.64382 .13982 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.55546 .13982 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.62347 .34914 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.59964 .2758 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.18496 .1985 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.10092 .22581 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.04898 .2973 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.04898 .46278 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.10092 .53426 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.18496 .56157 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .34148 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .41859 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.3447 .56134 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.51566 .22581 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.24938 .49209 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.58491 .32113 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.21297 .38004 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.3581 .68736 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.41004 .75885 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.49408 .78616 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.65146 .73502 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .66353 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .57517 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.49408 .64318 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.56742 .61935 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.64471 .20467 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.61741 .12063 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.54592 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.38044 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.30895 .12063 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.28165 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.50174 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.42462 .20467 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .57517 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .66353 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.27491 .73502 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.43229 .78616 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.51632 .75885 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.56826 .68736 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.35895 .61935 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.43229 .64318 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .35313 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.76587 .26909 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .18505 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.60469 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.51632 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.44484 .13973 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.62289 .26909 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.56051 .22377 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.17959 .40497 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .47646 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .56483 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.22492 .6987 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.30895 .72601 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.39299 .6987 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.26363 .52065 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.30895 .58303 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.52209 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.46318 .23269 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.40427 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.57523 .26909 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.30895 .53537 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.60701 .6987 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.69105 .72601 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.77508 .6987 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .56483 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .47646 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.82041 .40497 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.69105 .58303 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.73637 .52065 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.55516 .13973 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.48368 .08779 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.39531 .08779 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .18505 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.23413 .26909 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .35313 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.43949 .22377 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.37711 .26909 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.43174 .68736 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.48368 .75885 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.56771 .78616 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.72509 .73502 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .66353 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .57517 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.56771 .64318 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.64105 .61935 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.71835 .20467 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.69105 .12063 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.61956 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.45408 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.38259 .12063 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.35529 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.57538 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.49826 .20467 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .57517 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .66353 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.34854 .73502 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.50592 .78616 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.58996 .75885 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.6419 .68736 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.43258 .61935 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.50592 .64318 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.69105 .53537 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.42477 .26909 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.59573 .60462 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.53682 .23269 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.47791 .60462 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.81504 .56157 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.89908 .53426 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.95102 .46278 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.95102 .2973 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.89908 .22581 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.81504 .1985 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .41859 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .34148 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.44454 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.35618 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.28469 .19176 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.23355 .34914 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.26086 .43318 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.33235 .48512 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.40036 .2758 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.37653 .34914 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.66658 .65542 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.75062 .68273 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.83466 .65542 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .52154 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .43318 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.87998 .36169 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.75062 .53975 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.79595 .47736 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.61474 .09644 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.54325 .04451 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.45488 .04451 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .14177 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.2937 .22581 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .30985 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.49907 .18048 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.43668 .22581 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.49131 .64408 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.54325 .71557 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.62729 .74288 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.78467 .69174 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .62025 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .53189 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.62729 .5999 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.70063 .57607 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.78703 .38004 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.41509 .32113 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.75062 .49209 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.48434 .22581 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.6553 .56134 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.40361 .38004 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.46318 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.53682 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.59639 .38004 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{184, 152},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002h0000V0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000;P0002h0000^0000;P0002h0000^0000;P0
002h0000^00005<000==00003@000dd0001B0000D`000d`0000=0003C0000580001D0003C@0000/0
00==0000D`0005@000=<00002`000d`0001C0000A@000dd0000;009=3@02C@d000==0000A00004D0
00=<00002`000d`0C00;0003C01<00d000=<0000A00004D000==00002`000dd0C@0;0003C@1=00d0
00==0000A00004H000=<04`02`02C08000=<00000`000d`00002C0/000=<04`0A`0004H000==04d0
2`001Dd0C@1=00D000E=04d0C@0;0003C@1=04L0001600=<2`001D`0C01<00D000E<04`0C00;00=<
A`0004L00dd;00==1`03C@/00de80000A`0014`0C4`:0003C01<00L000=<04`02P02C00304`004L0
00170005C@1=04d02@000dd0C@070003C@1=00T000E=04d0C@180000>002C0`00d`0101<04`9009<
1`02C0T000A<04`00d`<009<>@0003X000==00002`000dd0C@02009=1`000dd0C@050003C@1=00L0
0Td20003C@1=00d000==0000>@0003/000=<00002P03C0@000=<000010000d`0C0050003C01<00H0
00=<00000P03C0`000=<0000>P0003`00Td;00==1002C@<000A=04e=1@02C@0304d000800Td400==
2`02CCd0000j009<0P0014`004`70004C01<C0@00T`20005C01<04`00`001D`0C01<00800T`4009<
00<0C0001P0014`004`2009<>`0003`000I=001=04d70005C@1=04d00`002Dd0C@1=04d0C@030009
C@1=04d0C@1=00<000E=04d0C@070003C@1=008000==0000>`0003d000=<00000T`80004C01<009<
00@0C0000T`2009<0`02C0800T`20008C01<C01<04`8009<0P000d`0000l0000?P02C@8000==0000
1@000dd0C@03000CC@0004d0C@1=04d0C@1=04d0C@030007C@0004d0C@070003C@00009=?`000400
00A<04a<1P000d`0C003009<0P000d`00002C00504`0C0000T`20003C000009<0`000d`0C006009<
00<0C000@00004400Td00`1=00050003C@1=008000A=04e=1003C@0404e=C@@00Td01`1=001=04d0
1P0014d0CDe20000@P02C00304a<00@000E<04`0C003009<10001Dc6a/I<00@00T`30005C01<04`0
1002C00304a<04<00013009=0P002Dd0001=04d0C@030003C@1=00<000E=a/K6C@030003C@1=00<0
00E=04d0C@030003C@00009=A00003000T`A0003C01<008000I<0000C002C08000E<0000C00200C6
00A<001<0`000d`00002C00304`0008000I<001<04`A009<<@00038000A=04e=3P000dd0C@02009=
00@0C@1=0`000dd00002009=1LH2C@@000Q=0000C@1=009=0P000dd0C@0>009=00<0C@00<P0003<0
0T`00`1<000<0003C000009<0P02C00304`0008000A<00000T`01036a/H2C00304a<00<000I<0000
C002C0800T`20003C00000/000A<04a<=000028000==000040000dd0C@0<0003C@00008000==0000
0/H2C@0304d0008000==00001lH20006C@0004d01<H20003C@00008000==00002P000dd0C@0B0003
C@000240000R0003C00000h09D`7aPM<1LHIC10000=<00008@00028000==00004P02C@0304d000T0
00==00000`03C@03aTg6009=0`0;aP<01lH00dd000030003C@0000P000A=04e=50000dd0000Q0000
8P000d`0000D0003C01<00T000=<00001@000dc6aP04aP030<K600C600<0a/H01<H00`36aP04aP03
C00000D000=<00001`000d`0C00F0003C0000240000R0003C@0001D014d80003C@0000<000==0<H0
3<H00`36aP0;aP0304d000@000==00001P04CAL000==00008@00018000=<00003@000d`0000A01Q<
2LH2C004aP00009<2/HIC18000=<00003@000d`0000A00004P000dd0000=0003C@0001P000==04d0
1P000dd00003009=2LH2C@04aP00009=0/H2C@K60Td50003C@0000@000==04d06P000dd0000=0003
C@000140000C0003C00000`000=<00006@03C0H000A<00000T`01036a/H2009<00?604`00T`200=<
0P02C003aP0000?600<0C4`00`000d`0000400=<6`000d`0000<0003C0000180000D0003C@0000/0
00==00006`03C@@000==00000Td00`36aP02aP800Td300I=0`02C@<01<H00`1=C@020003C@000080
0ddM0003C@0000/000==00004`0001D000=<00002P000d`0000L00=<0`001T`0C01<00C60P02C0@0
14`4009<0`04aP0604`0C01<0`03C1h000=<00002P000d`0000D00005@000dd0000:0003C@0001h0
0Td2009=00@0C@000lH3009=1@02C@D00Td400?60P0014d0CDd2009=80000dd0000:0003C@0001@0
000F0003C00000T000=<00007`001lI<C<I<aT`01LH3009<1004C0@00T`400c68@000d`000090003
C00001D0000G0003C@0000P000==00001P0KC@06aTe=aTg60Td2aP<00Td300I=0`02C@@000?6CDd0
2LHIC@P000==000020000dd0000F000060000d`000070003C00001h000=<a/H01/H2C003aP000080
0T`200=<0P03C0800T`5009<2LH00d`0000N0003C00000L000=<00005`0001P000==00001`000dd0
000M0003C@0000<00lH0101=CDd4009=0P02C@@00Td2009=1003C@800lH50003C@0001d000==0000
1`000dd0000G00006@000d`000060003C00001/00T`600C600@0C4a<0`02C00404a<C0@00d`00`1<
C00300=<0P04aPH00T`M0003C00000H000=<0000600001X000==00001@000dd0000J0003C@0000H0
1<H200==0P05C@H01Dd200==0`04aPP000==00006P000dd000050003C@0001T0000K0003C00000@0
00=<00006002C0X00lH3009<0P04C0P014`2009<1003aPX00T`J0003C00000@000=<00006P0000T0
0dd@0003C@0000<000==00005`02C@/01<H200==00@0CDe=2P03C@0404e=C@<01<H;009=6@000dd0
00030003C@0000h00dd:00003003C0d000=<00000`000d`0000F0003C00000/01<H300I<2P06C0@0
1<H=0003C00001H000=<00000`000d`0000;00=<3@0000l00dd;0003C@00008000==00005@000dd0
000=00?61004C@@0114400A=1@03aPl000==00005@000dd000020003C@0000T00dd@00004P03C0T0
00E<0000C00F0003C00000h01<H300A<0`064@<014`400C640000d`0000D0005C00004`02@03C1<0
000E00==1`0014d004dD009=4002aPA=0P04C@80214200A=0`03C@?64002CA@000A=001=1`03CAH0
000H00=<100014`004`C0003C00000h01<H:C0`A2T`5aQ0000=<00004@0014`004`400=<6@0001/0
0dd20003C@1=018000==00003P06aP801Td44@03014A008A00<04A400Q47C@801/H@0003C@000100
00==04d00P03CA`0000N00=<0lH?009<4006aP<014`44@9<1Q400`1<4@034@A<1006aQ000T`?00?6
0d`O00008@03aPh000==00003`05aPD00Td00`0A4@024@==0Q4014d04A43C@@A00<0CDd01P05aQ40
00==00003003aR80000Q00C61P0IC0C61@03C0<A0T`00`1<C0024@9<0Q42C00304a<00<A0d`600C6
6D`600C68P0002401LH:0003C@00010000A=a/K61@02C@@A00D0CDd0C@034@9=0a44C@03014A008A
0Td600?600==000040000dd0000800G68P0001H000=<00002@05aQX00T`20003C00000<00T`44@80
14`24@04C000C08A1D`00`0A4@024@9<1P000d`00002C1X01LH;0003C00001D0000F0003C@0000X0
1<HI0005C@0004d01P044@0304e=00E=0Q44C@8A00<0CDd01Dd44@L000E=0000C@0I00C630000dd0
000E00005`000d`0000:00C65`000d`000020003C00000<01147C004014A4@A<0a400`1<C005C0@A
1P000d`000020003C00001D01<H<0003C00001H0000H0003C@0000T01LHD009=1@000dd0000200<A
1Dd2009=00@04A4014d0100A4@02C@<014d34@D000==00000`02CA@01LH;0003C@0001L0000I0003
C00000T000?6C4`084`34@=<1@02C004014A00A<00@04A400T`6009<0a4RC0;62`000d`0000H0000
6@000dd000090003aTe=021=0Q400dd00006009=0a46C@<A0Td9008A8Td2aP/000==0000600001X0
00=<00001`05aQ0000=<00001`07C0T00T`24@=<0P03C08A0T`900I<00<0C00020000d`0000>00G6
2@000d`0000I00006`000dd0000500G640000dd0000700Q=2@02C@8A0Td4009=0Q42C@T01dd00`1=
00080003C@0000h01LH70003C@0001X0000K0003C00000<000=<0<H00lH?009<2P03C0800T`:0005
C14A4D`01P001D`A4A5<00X00T`200A<2P02C0l01<H00`1<00040003C00001X0000L0003C@000080
00==a/H00/H?0003C@0000P014d3009=2P000ddA4@02C@H00Td24@03C@0000P00Td300A=2`000dd0
000=00C600==00000P000dd0000K00007@001T`00036C0?63@02C0X014`300=<2P0014`A4D`80004
C14AC0X00d`300A<2`02C0d01LH30003C00001`0000N0003C@1=00;600==aP0030000dd0000800E=
1002C@X000A=4A4A2P034@03C@0000P00Td500A=2`000dd0000;00C600==04d07`0001d00d`01@36
a/I<00`000=<00002004C00304`000<00T`9009<0Q4<008A0T`9009<1@05C0/000=<00002P001Dc6
a/H000=<7P0000`00dd;00==0P001Td0CDd0C@/000==00002003C@8000==00000P03C@P01Td:00I=
2003C@D000==04d00Td;0003C@0000T000I=04e=04d200==2`03C@d0000?00=<1@03C0H000=<04`0
0P000d`0000A00A<0`000d`00002009<1`08C0X024`7009<1@000d`00004C1@000I<001<04`600=<
1@03C100000B00E=2002C@0304d0008000==00003`04C@@000==00000P02C@H014d00`1=C@02C@X0
14d00`1=C@02C@H00Td50004C@0000A=4P001Td0001=009=2005CA<0000A00=<00@0C4a<1`0014`0
C4`30003C00000d014`50003C00000<00T`500=<0`05C0P01D`300=<1@02C0H000=<00000P04C100
00A<00000T`00`1<000600=<00@0C4a<4P0000h00dd700==0`001Dd0001=00@000==00002`04C@H0
00==00000P03C@<014d300==00<0CDd02002C@0404e=C@<014d300==1@000dd0000300A=3P000dd0
00020005C@0004d00`03C@L00dd?00002`03C0d00d`4009<10000d`0000900=<20000d`00002009<
0`04C0@00T`2009<2002C0800T`400A<0`02C0D000=<00001@03C0`000=<00000P02C0@00d`=00=<
300000T00TdA0003C@1=009=00<0CDd01@000dd0000600A=20000dd00003009=0P03C@H00Td200==
1P03C@800Td600==0P02C@H000==00001@04C@T000==00000`02C@0604e=C@1=4@02C@X0000L0003
C00000800d`4aP0304`000H014`90003C00000801d`600=<0`02C0H00T`300=<1P07C0D000=<0000
1P04C0P000=<0<H00lH3C0@000=<00006`0001L00dd00`1=0005009=1/H00dd0000200A=2`000dd0
000200I=1`02C@@00Td6009=1002C@L01Td50003C@0000P014d500O60Td60003C@1=009=600001X0
0d`300=<00<0a/H01LH00dc6aP04C0/000=<00000`04C0T00T`400=<1003C0@00T`900A<1P000d`0
000800A<00<0a/H02<H0101<C4`300=<6`0001T000A=00000dd20004C@0000G600==aTd00Td=0003
C@00008014d:009=1@02C@@00Td5009=2P04C@D000==00002P03C@S60`000dd00003C@<000==0000
600001P000=<04`00T`300=<1P03aP=<4P04C0X00d`5009<1002C0D00d`:00A<4P03C0C61P03C0<0
0d`00`1<000H00005`03C@P014d6009=00?600003`04C@/00Td600==0P03C@H00Td;00A=4P02C@03
aP0000@014d800==600001@014`:0004C00000=<0`02aP03C00000d01T`;009<1`02C0800T`7009<
2`06C1000lH300=<0`000d`0000800A<5@0001400dd20003C@0000T000==00001003C@;600==0000
3006C@/00dd7009=0P02C@L00dd;00I=3`03aP==1P000dd000090003C@0000==4P0000h00d`40003
C00000X000=<00001`03C0C62@03C0800T`;009<2006C0P00T`;009<0P03C0X01lH90003C00000X0
00=<00000P03C0l0000<009=1`000dd0000:0003C@0000L00/H00dg6aP05aP@014d3009=2`02C@T0
14d9009=2`02C@<014d500[62@000dd0000:0003C@0000D00Td=000050000d`0000;0003C00000H0
0d`;aPA<0`03C0X00d`900A<2@03C0X00d`300A<00<0a/H02lH00d`000060003C00000/000=<0000
4`0001<000==00002003C@0304d000@00dd01036a/H200O60dd5009=2`02C@X014d:009=2`02C@D0
0dd8aP800lH0101=CDd50003C@1=009=2P000dd0000B00004P000d`0000<00=<00@0C4a<1003aPD0
0lH3C0H00T`;009<2`02C0/00T`;009<1P03C0C61@03aP@00d`0101<C4`>0003C0000140000R00E=
1@03aPP00Td00lH0000300==2P03C@/00Td;00==2P03C@H00Td00lH0000600?61@05CB<0000O00A<
1003C0800lH800?61@02C0/00T`;00A<2`02C0/00T`600?62003aP800d`400A<800001`00dd30003
C@0000D01Dd800?61@02C@/00Td;00A=2`02C@/00Td600?62005C@L000A=00000ddM00006@03C0H0
00=<00001P000d`0C002C0L00lH200;60d`;009<2`04C0/00T`;00=<0lH200?61`03C00304`000L0
00=<00001003C1X0000G009=2@000dd000050004C@00C@800dd400O60Td00lH0000800==2P06C@X0
0dd;009=2<H400==0P0014d004d70003C@0000L00TdH0000:P0014`004`20003C00000=<2<H2C0;6
2@02C0/00T`2009<2`02C0X000?6C4`02LH3C08000A<001<0P000d`0000Y0000:@03C@0304d00080
00A=000014d:aPP00Td;009=0P02C@/00Td900g600E=0000C@030003C@00009=:P0002P000A<0000
0d`300=<00@0a/K60d`300G61P03C0X00d`200=<2P03C0L01LH3009<1<H0101<C4`400=<0P000d`0
000W0000:0000dd000020003C@1=009=00D0C@00C@03aP800dd00`36aP02aPH00Td;009=1002C@/0
0Td700C600@0CDe=0P03aP05C@00C@001Dd40003C@0002L0000W0003C00000800d`300A<00@0C4a<
1@03C0?61@02C0/00T`4009<2`02C0H01<H2C0D00d`00`1<0003C0800d`40003C00002H0000V0003
C@0000==00<0C@001@05C@0304d000D000G6CDe=aP020004aTe=C@T000C6CDe=1003C@;62003C@?6
00<0a/H00lH60004C@1=00==1P000dd0C@02C@8000==00009@0002D014`40003C00000@00d`00`1<
C002C0H00lH3C004aTa<aPH01<H2C003aP0000<00T`5aPH00T`3aP03C<K600;61P000d`0C005C0H0
00=<00000P04C2H0000S00==1`000dd000030006C@1=C@1=0P03C@@01/H3C@;60P07aP9=0/H30003
aTe=00S60P000lI=C@03C@K61003C@0304d0009=00<0C@0010000dd0000500==900002000d`00`1<
00070003C000008000=<04`00P02C0<000A<04a<2lH3C0g600<0a/H03<H3C0C60T`4aPA<0`02C080
00=<04`010000d`000060003C01<009<8@0001h00Td30003C@0000L000E=0000C@020003C@00009=
10000dd00007aP<00lH00dg6aP04aP<02LH300C60dd3aP<000==aTd01<H00dd0C@04009=0P0014d0
04d30003C@0000L000A=00000TdO00008`000d`000070007C00004`0C0040003C00000800d`4aP04
C000C0800d`4aP9<1@07aPD00d`5aP04C000C08000=<0<H00/H0101<C4`30003C000008000=<04`0
0`000d`000070003C0000280000R0003C@0000P000I=001=04d500E=00@0C@1=0`000dd00003C@80
0/H00dg6000200==0`05aP<00dd300C60P03C@8000M=0000C@1=008014d50003C@1=008000==0000
20000dd0000Q00008@000d`000090003C01<008000=<00000P04C0@000=<00000P03C00304`00080
00?6C<H00/H500=<1LH3C0D01LH30003C01<009<10000d`000020003C01<009<0`001T`004`0C0/0
00=<00008000020000==00002P02C@8000==00000dd0101=04d30003C@1=00A=100014d004d4aP03
C@0000@000==a/H014d700C600A=001=1005C@0304d0008000==04d00P03C@0404d0009=30000dd0
000O000080000d`0000:0003C00000A<100014`004`200=<0`000d`000020005C000C0000lH00`1<
C004C00304a<00?600D0C4a<0003C0?600D0C000C0040004C00000=<0P0014`004`500=<0P000d`0
000:0003C00001l0000O0003C@0000/014d70003C@0000==0`0014d004d5009=0`02C@0304e=00A=
00@0CDd00Td200E=00<0CDd00`02C@D000A=001=0`03C@8000==00001P03C@d000==00007P0001h0
00=<00002P03C00304`000L00d`00`1<C0040003C01<00D00T`300=<1P03C00304a<009<1@03C0<0
0T`50003C01<00@00T`0101<C4`80003C01<00=<2`000d`0000M0000:@03C@0304e=00L00dd30003
C@0000@00Td40003C@0000A=0P000dd000020003C@0000A=00<0C@000`000dd00004C@8000==0000
0P02C@H000A=00000dd7009=00@0C@1=:P0002X000A<001<2P0014`004`7009<1004C08000A<001<
1004C00304`000=<0`0014`004`200A<1002C0L000A<001<2P0014`004`[0000:P0014d004d:0003
C@1=00T000==04d00Td40003C@1=00<014d30003C@1=00<014d30003C@1=00@00dd00`1=00080003
C@1=00X000A=001=:`0002T000=<00000T`:009<2@03C00304`000D00T`00`1<C003C0@000=<04`0
1002C00304a<00=<1P000d`0C002C0T00T`:009<0P000d`0000X0000:0001Td004d0C@X00Td7009=
00@0CDe=1`03C@<00Td40003C@1=00@00Td4009=1`03C@0304e=00L00Td:0003C@1=008000==0000
9`0002L000E<0000C00<0003C00000T00d`80003C00000800T`40003C01<00@00T`40003C00000H0
0d`;0003C00000X000E<0000C00X0000:P000dd0000:009=2`02C@0304d000H00Td20004C@00C@<0
00==04d00`0014d004d2009=1`0014d0CDd;009=30000dd0000Y0000:@000d`0000;009<2`001D`0
001<00H000A<04a<10001T`004`0C08000=<00000P02C00304`000D000E<0000C00;009<3@000d`0
000X0000=P000dd0C@0:009=2P0014d0CDd40006C@00C@1=0P000dd00002009=00<0C@002@02C@X0
00==04d0=`0003D000A<001<2@000d`0C00:0004C01<C0D000M<04`0C01<00D00T`00`1<00090003
C01<00T000A<001<=P0003@000E=0000C@090003C@1=00X00Td20003C@0000<00Td00`1=C@050003
C@00009=2P000dd0C@090005C@0004d0=@0003@000E<0000C0080004C000C0X00T`8009<00<0C4`0
2002C0X000A<001<20001D`0001<03D0000c0003C@0000X000E=0000C@0:0003C@0000P000==04d0
2P000dd000080005C@0004d030000dd0000b0000<P000d`0000:0003C000008000=<00001`02C0X0
0d`:009<2@000d`000020003C00000X000=<0000<@0004@000==00001P000dd0C@0:0003C@1=00X0
00==04d020000dd000130000A0000d`000060003C01<00X000=<04`02P000d`0C0080003C00004<0
001<0004C@00C@T00Td00`1=C@090004C@00CDd0001;0005C00004`020001d`0C01<04`020001D`0
001<04`0001?0003C@0000P000==04d02P000dd0001>0000C`000d`000080003C01<00X000=<0000
CP0004l000==000020000dd0C@0:0003C@0004h0001?0003C00000P000=<04`02P000d`0001>0000
C`000dd000080003C@1=00X000==0000CP000;P0002h0000^0000;P0002h0000^0000;P0002h0000
\
\>"],
  ImageRangeCache->{{{0, 183}, {151, 0}} -> {-0.0285196, 0.0638972, 
  0.00577617, 0.00577617}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0608586 0.952381 [
[ 0 0 0 0 ]
[ 1 .83066 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .83066 L
0 .83066 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .53189 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .62025 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.21533 .69174 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.37271 .74288 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.45675 .71557 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.50869 .64408 L
s
P
p
0 .4 1 r
.016 w
.3447 .56134 m
.29937 .57607 L
s
P
p
0 .4 1 r
.016 w
.3447 .56134 m
.37271 .5999 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .30985 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.7063 .22581 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .14177 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.54512 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.45675 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.38526 .09644 L
s
P
p
0 .4 1 r
.016 w
.51566 .22581 m
.56332 .22581 L
s
P
p
0 .4 1 r
.016 w
.51566 .22581 m
.50093 .18048 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.12002 .36169 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .43318 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .52154 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.16534 .65542 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.24938 .68273 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.33342 .65542 L
s
P
p
0 .4 1 r
.016 w
.24938 .49209 m
.20405 .47736 L
s
P
p
0 .4 1 r
.016 w
.24938 .49209 m
.24938 .53975 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.66765 .48512 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.73914 .43318 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.76645 .34914 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.71531 .19176 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.64382 .13982 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.55546 .13982 L
s
P
p
0 .4 1 r
.016 w
.58491 .32113 m
.62347 .34914 L
s
P
p
0 .4 1 r
.016 w
.58491 .32113 m
.59964 .2758 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.18496 .1985 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.10092 .22581 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.04898 .2973 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.04898 .46278 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.10092 .53426 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.18496 .56157 L
s
P
p
0 .4 1 r
.016 w
.21297 .38004 m
.18496 .34148 L
s
P
p
0 .4 1 r
.016 w
.21297 .38004 m
.18496 .41859 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.3447 .56134 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.51566 .22581 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.24938 .49209 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.58491 .32113 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.21297 .38004 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.3581 .68736 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.41004 .75885 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.49408 .78616 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.65146 .73502 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .66353 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .57517 L
s
P
p
0 .4 1 r
.016 w
.52209 .60462 m
.49408 .64318 L
s
P
p
0 .4 1 r
.016 w
.52209 .60462 m
.56742 .61935 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.64471 .20467 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.61741 .12063 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.54592 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.38044 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.30895 .12063 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.28165 .20467 L
s
P
p
0 .4 1 r
.016 w
.46318 .23269 m
.50174 .20467 L
s
P
p
0 .4 1 r
.016 w
.46318 .23269 m
.42462 .20467 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .57517 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .66353 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.27491 .73502 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.43229 .78616 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.51632 .75885 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.56826 .68736 L
s
P
p
0 .4 1 r
.016 w
.40427 .60462 m
.35895 .61935 L
s
P
p
0 .4 1 r
.016 w
.40427 .60462 m
.43229 .64318 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .35313 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.76587 .26909 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .18505 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.60469 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.51632 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.44484 .13973 L
s
P
p
0 .4 1 r
.016 w
.57523 .26909 m
.62289 .26909 L
s
P
p
0 .4 1 r
.016 w
.57523 .26909 m
.56051 .22377 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.17959 .40497 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .47646 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .56483 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.22492 .6987 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.30895 .72601 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.39299 .6987 L
s
P
p
0 .4 1 r
.016 w
.30895 .53537 m
.26363 .52065 L
s
P
p
0 .4 1 r
.016 w
.30895 .53537 m
.30895 .58303 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.52209 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.46318 .23269 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.40427 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.57523 .26909 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.30895 .53537 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.60701 .6987 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.69105 .72601 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.77508 .6987 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .56483 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .47646 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.82041 .40497 L
s
P
p
0 .4 1 r
.016 w
.69105 .53537 m
.69105 .58303 L
s
P
p
0 .4 1 r
.016 w
.69105 .53537 m
.73637 .52065 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.55516 .13973 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.48368 .08779 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.39531 .08779 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .18505 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.23413 .26909 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .35313 L
s
P
p
0 .4 1 r
.016 w
.42477 .26909 m
.43949 .22377 L
s
P
p
0 .4 1 r
.016 w
.42477 .26909 m
.37711 .26909 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.43174 .68736 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.48368 .75885 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.56771 .78616 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.72509 .73502 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .66353 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .57517 L
s
P
p
0 .4 1 r
.016 w
.59573 .60462 m
.56771 .64318 L
s
P
p
0 .4 1 r
.016 w
.59573 .60462 m
.64105 .61935 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.71835 .20467 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.69105 .12063 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.61956 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.45408 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.38259 .12063 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.35529 .20467 L
s
P
p
0 .4 1 r
.016 w
.53682 .23269 m
.57538 .20467 L
s
P
p
0 .4 1 r
.016 w
.53682 .23269 m
.49826 .20467 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .57517 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .66353 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.34854 .73502 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.50592 .78616 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.58996 .75885 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.6419 .68736 L
s
P
p
0 .4 1 r
.016 w
.47791 .60462 m
.43258 .61935 L
s
P
p
0 .4 1 r
.016 w
.47791 .60462 m
.50592 .64318 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.69105 .53537 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.42477 .26909 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.59573 .60462 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.53682 .23269 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.47791 .60462 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.81504 .56157 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.89908 .53426 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.95102 .46278 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.95102 .2973 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.89908 .22581 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.81504 .1985 L
s
P
p
0 .4 1 r
.016 w
.78703 .38004 m
.81504 .41859 L
s
P
p
0 .4 1 r
.016 w
.78703 .38004 m
.81504 .34148 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.44454 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.35618 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.28469 .19176 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.23355 .34914 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.26086 .43318 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.33235 .48512 L
s
P
p
0 .4 1 r
.016 w
.41509 .32113 m
.40036 .2758 L
s
P
p
0 .4 1 r
.016 w
.41509 .32113 m
.37653 .34914 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.66658 .65542 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.75062 .68273 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.83466 .65542 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .52154 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .43318 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.87998 .36169 L
s
P
p
0 .4 1 r
.016 w
.75062 .49209 m
.75062 .53975 L
s
P
p
0 .4 1 r
.016 w
.75062 .49209 m
.79595 .47736 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.61474 .09644 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.54325 .04451 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.45488 .04451 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .14177 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.2937 .22581 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .30985 L
s
P
p
0 .4 1 r
.016 w
.48434 .22581 m
.49907 .18048 L
s
P
p
0 .4 1 r
.016 w
.48434 .22581 m
.43668 .22581 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.49131 .64408 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.54325 .71557 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.62729 .74288 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.78467 .69174 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .62025 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .53189 L
s
P
p
0 .4 1 r
.016 w
.6553 .56134 m
.62729 .5999 L
s
P
p
0 .4 1 r
.016 w
.6553 .56134 m
.70063 .57607 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.78703 .38004 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.41509 .32113 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.75062 .49209 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.48434 .22581 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.6553 .56134 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.40361 .38004 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.46318 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.53682 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.59639 .38004 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0608586 0.952381 [
[ 0 0 0 0 ]
[ 1 .83066 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .83066 L
0 .83066 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .53189 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .62025 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.21533 .69174 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.37271 .74288 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.45675 .71557 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.50869 .64408 L
s
P
p
0 1 1 r
.018 w
.3447 .56134 m
.29937 .57607 L
s
P
p
0 1 1 r
.018 w
.3447 .56134 m
.37271 .5999 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .30985 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.7063 .22581 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .14177 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.54512 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.45675 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.38526 .09644 L
s
P
p
0 1 1 r
.018 w
.51566 .22581 m
.56332 .22581 L
s
P
p
0 1 1 r
.018 w
.51566 .22581 m
.50093 .18048 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.12002 .36169 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .43318 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .52154 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.16534 .65542 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.24938 .68273 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.33342 .65542 L
s
P
p
0 1 1 r
.018 w
.24938 .49209 m
.20405 .47736 L
s
P
p
0 1 1 r
.018 w
.24938 .49209 m
.24938 .53975 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.66765 .48512 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.73914 .43318 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.76645 .34914 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.71531 .19176 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.64382 .13982 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.55546 .13982 L
s
P
p
0 1 1 r
.018 w
.58491 .32113 m
.62347 .34914 L
s
P
p
0 1 1 r
.018 w
.58491 .32113 m
.59964 .2758 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.18496 .1985 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.10092 .22581 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.04898 .2973 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.04898 .46278 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.10092 .53426 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.18496 .56157 L
s
P
p
0 1 1 r
.018 w
.21297 .38004 m
.18496 .34148 L
s
P
p
0 1 1 r
.018 w
.21297 .38004 m
.18496 .41859 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.3447 .56134 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.51566 .22581 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.24938 .49209 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.58491 .32113 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.21297 .38004 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.3581 .68736 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.41004 .75885 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.49408 .78616 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.65146 .73502 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .66353 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .57517 L
s
P
p
0 1 1 r
.018 w
.52209 .60462 m
.49408 .64318 L
s
P
p
0 1 1 r
.018 w
.52209 .60462 m
.56742 .61935 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.64471 .20467 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.61741 .12063 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.54592 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.38044 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.30895 .12063 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.28165 .20467 L
s
P
p
0 1 1 r
.018 w
.46318 .23269 m
.50174 .20467 L
s
P
p
0 1 1 r
.018 w
.46318 .23269 m
.42462 .20467 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .57517 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .66353 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.27491 .73502 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.43229 .78616 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.51632 .75885 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.56826 .68736 L
s
P
p
0 1 1 r
.018 w
.40427 .60462 m
.35895 .61935 L
s
P
p
0 1 1 r
.018 w
.40427 .60462 m
.43229 .64318 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .35313 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.76587 .26909 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .18505 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.60469 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.51632 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.44484 .13973 L
s
P
p
0 1 1 r
.018 w
.57523 .26909 m
.62289 .26909 L
s
P
p
0 1 1 r
.018 w
.57523 .26909 m
.56051 .22377 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.17959 .40497 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .47646 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .56483 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.22492 .6987 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.30895 .72601 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.39299 .6987 L
s
P
p
0 1 1 r
.018 w
.30895 .53537 m
.26363 .52065 L
s
P
p
0 1 1 r
.018 w
.30895 .53537 m
.30895 .58303 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.52209 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.46318 .23269 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.40427 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.57523 .26909 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.30895 .53537 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.60701 .6987 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.69105 .72601 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.77508 .6987 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .56483 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .47646 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.82041 .40497 L
s
P
p
0 1 1 r
.018 w
.69105 .53537 m
.69105 .58303 L
s
P
p
0 1 1 r
.018 w
.69105 .53537 m
.73637 .52065 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.55516 .13973 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.48368 .08779 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.39531 .08779 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .18505 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.23413 .26909 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .35313 L
s
P
p
0 1 1 r
.018 w
.42477 .26909 m
.43949 .22377 L
s
P
p
0 1 1 r
.018 w
.42477 .26909 m
.37711 .26909 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.43174 .68736 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.48368 .75885 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.56771 .78616 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.72509 .73502 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .66353 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .57517 L
s
P
p
0 1 1 r
.018 w
.59573 .60462 m
.56771 .64318 L
s
P
p
0 1 1 r
.018 w
.59573 .60462 m
.64105 .61935 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.71835 .20467 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.69105 .12063 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.61956 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.45408 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.38259 .12063 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.35529 .20467 L
s
P
p
0 1 1 r
.018 w
.53682 .23269 m
.57538 .20467 L
s
P
p
0 1 1 r
.018 w
.53682 .23269 m
.49826 .20467 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .57517 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .66353 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.34854 .73502 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.50592 .78616 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.58996 .75885 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.6419 .68736 L
s
P
p
0 1 1 r
.018 w
.47791 .60462 m
.43258 .61935 L
s
P
p
0 1 1 r
.018 w
.47791 .60462 m
.50592 .64318 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.69105 .53537 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.42477 .26909 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.59573 .60462 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.53682 .23269 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.47791 .60462 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.81504 .56157 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.89908 .53426 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.95102 .46278 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.95102 .2973 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.89908 .22581 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.81504 .1985 L
s
P
p
0 1 1 r
.018 w
.78703 .38004 m
.81504 .41859 L
s
P
p
0 1 1 r
.018 w
.78703 .38004 m
.81504 .34148 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.44454 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.35618 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.28469 .19176 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.23355 .34914 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.26086 .43318 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.33235 .48512 L
s
P
p
0 1 1 r
.018 w
.41509 .32113 m
.40036 .2758 L
s
P
p
0 1 1 r
.018 w
.41509 .32113 m
.37653 .34914 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.66658 .65542 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.75062 .68273 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.83466 .65542 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .52154 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .43318 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.87998 .36169 L
s
P
p
0 1 1 r
.018 w
.75062 .49209 m
.75062 .53975 L
s
P
p
0 1 1 r
.018 w
.75062 .49209 m
.79595 .47736 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.61474 .09644 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.54325 .04451 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.45488 .04451 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .14177 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.2937 .22581 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .30985 L
s
P
p
0 1 1 r
.018 w
.48434 .22581 m
.49907 .18048 L
s
P
p
0 1 1 r
.018 w
.48434 .22581 m
.43668 .22581 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.49131 .64408 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.54325 .71557 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.62729 .74288 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.78467 .69174 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .62025 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .53189 L
s
P
p
0 1 1 r
.018 w
.6553 .56134 m
.62729 .5999 L
s
P
p
0 1 1 r
.018 w
.6553 .56134 m
.70063 .57607 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.78703 .38004 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.41509 .32113 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.75062 .49209 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.48434 .22581 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.6553 .56134 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.40361 .38004 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.46318 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.53682 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.59639 .38004 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.14698 .59845 L
s
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.17503 .6848 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.41462 .76264 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.48806 .70928 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.29387 .59845 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.36922 .62294 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .28399 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .1932 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.50096 .04513 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.41462 .07319 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.56505 .2386 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.50096 .19203 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.0771 .4107 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.04905 .49704 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.19712 .70084 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.28791 .70084 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.19594 .49704 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.24251 .56114 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.7132 .48415 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.76656 .4107 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.68871 .17112 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.60237 .14306 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.62685 .36531 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.60237 .28996 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.13093 .21773 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.05749 .27109 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.05749 .52301 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.13093 .57637 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .35744 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .43666 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.34044 .58332 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.51609 .2386 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.24251 .51217 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.58724 .33653 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.20511 .39705 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.37508 .75375 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.44852 .80711 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.6881 .72927 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.71616 .64292 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.49392 .66741 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.56926 .64292 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.64149 .17149 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.58813 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.33622 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.28285 .17149 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.50179 .21688 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.42256 .21688 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.20819 .64292 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.23624 .72927 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.47582 .80711 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.54927 .75375 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.35508 .64292 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.43043 .66741 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .32846 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .23767 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.56216 .0896 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.47582 .11766 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.62626 .28307 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.56216 .2365 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.13831 .45517 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.11026 .54151 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.25833 .74531 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.34911 .74531 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.25715 .54151 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.30372 .60561 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5227 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.46217 .24566 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.40165 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5773 .28307 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.30372 .55664 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.65089 .74531 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.74167 .74531 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.88974 .54151 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.86169 .45517 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.69628 .60561 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.74285 .54151 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.52418 .11766 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.43784 .0896 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .23767 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .32846 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.43784 .2365 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.37374 .28307 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.45073 .75375 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.52418 .80711 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.76376 .72927 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.79181 .64292 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.56957 .66741 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.64492 .64292 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.71715 .17149 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.66378 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.41187 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.35851 .17149 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.57744 .21688 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.49821 .21688 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.28384 .64292 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.3119 .72927 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.55148 .80711 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.62492 .75375 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.43074 .64292 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.50608 .66741 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.69628 .55664 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4227 .28307 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.59835 .62779 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.53783 .24566 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4773 .62779 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.86907 .57637 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.94251 .52301 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.94251 .27109 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.86907 .21773 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .43666 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .35744 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.39763 .14306 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.31129 .17112 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.23344 .4107 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.2868 .48415 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.39763 .28996 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.37315 .36531 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.71209 .70084 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.80288 .70084 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.95095 .49704 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.9229 .4107 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.75749 .56114 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.80406 .49704 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.58538 .07319 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.49904 .04513 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .1932 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .28399 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.49904 .19203 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.43495 .2386 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.51194 .70928 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.58538 .76264 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.82497 .6848 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.85302 .59845 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.63078 .62294 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.70613 .59845 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.79489 .39705 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.41276 .33653 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.75749 .51217 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.48391 .2386 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.65956 .58332 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.40097 .39705 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.46217 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.53783 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0704782 0.952381 [
[ 0 0 0 0 ]
[ 1 .81142 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .81142 L
0 .81142 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.30242 .56745 m
.18851 .48469 L
s
P
p
.2 0 1 r
.002 w
.30242 .56745 m
.16851 .61096 L
s
P
p
.2 0 1 r
.002 w
.30242 .56745 m
.25891 .70137 L
s
P
p
.2 0 1 r
.002 w
.37465 .59092 m
.33114 .72483 L
s
P
p
.2 0 1 r
.002 w
.37465 .59092 m
.45741 .70483 L
s
P
p
.2 0 1 r
.002 w
.37465 .59092 m
.51545 .59092 L
s
P
p
0 .4 1 r
.018 w
.34706 .55295 m
.30242 .56745 L
s
P
p
0 .4 1 r
.018 w
.34706 .55295 m
.37465 .59092 L
s
P
p
.2 0 1 r
.002 w
.56236 .22252 m
.64512 .33643 L
s
P
p
.2 0 1 r
.002 w
.56236 .22252 m
.70316 .22252 L
s
P
p
.2 0 1 r
.002 w
.56236 .22252 m
.64512 .1086 L
s
P
p
.2 0 1 r
.002 w
.50092 .17788 m
.58368 .06397 L
s
P
p
.2 0 1 r
.002 w
.50092 .17788 m
.45741 .04397 L
s
P
p
.2 0 1 r
.002 w
.50092 .17788 m
.36701 .13437 L
s
P
p
0 .4 1 r
.018 w
.51542 .22252 m
.56236 .22252 L
s
P
p
0 .4 1 r
.018 w
.51542 .22252 m
.50092 .17788 L
s
P
p
.2 0 1 r
.002 w
.20855 .47025 m
.16504 .33633 L
s
P
p
.2 0 1 r
.002 w
.20855 .47025 m
.07464 .42674 L
s
P
p
.2 0 1 r
.002 w
.20855 .47025 m
.09464 .55301 L
s
P
p
.2 0 1 r
.002 w
.25319 .53168 m
.13928 .61445 L
s
P
p
.2 0 1 r
.002 w
.25319 .53168 m
.25319 .67249 L
s
P
p
.2 0 1 r
.002 w
.25319 .53168 m
.3671 .61445 L
s
P
p
0 .4 1 r
.018 w
.25319 .48475 m
.20855 .47025 L
s
P
p
0 .4 1 r
.018 w
.25319 .48475 m
.25319 .53168 L
s
P
p
.2 0 1 r
.002 w
.62159 .34397 m
.62159 .48478 L
s
P
p
.2 0 1 r
.002 w
.62159 .34397 m
.73551 .42674 L
s
P
p
.2 0 1 r
.002 w
.62159 .34397 m
.75551 .30046 L
s
P
p
.2 0 1 r
.002 w
.59813 .27175 m
.73204 .22824 L
s
P
p
.2 0 1 r
.002 w
.59813 .27175 m
.64164 .13784 L
s
P
p
.2 0 1 r
.002 w
.59813 .27175 m
.51536 .15784 L
s
P
p
0 .4 1 r
.018 w
.58362 .31639 m
.62159 .34397 L
s
P
p
0 .4 1 r
.018 w
.58362 .31639 m
.59813 .27175 L
s
P
p
.2 0 1 r
.002 w
.18975 .33643 m
.23326 .20252 L
s
P
p
.2 0 1 r
.002 w
.18975 .33643 m
.10698 .22252 L
s
P
p
.2 0 1 r
.002 w
.18975 .33643 m
.04894 .33643 L
s
P
p
.2 0 1 r
.002 w
.18975 .41237 m
.04894 .41237 L
s
P
p
.2 0 1 r
.002 w
.18975 .41237 m
.10698 .52628 L
s
P
p
.2 0 1 r
.002 w
.18975 .41237 m
.23326 .54628 L
s
P
p
0 .4 1 r
.018 w
.21733 .3744 m
.18975 .33643 L
s
P
p
0 .4 1 r
.018 w
.21733 .3744 m
.18975 .41237 L
s
P
p
.2 0 1 r
.016 w
.40507 .3744 m
.34706 .55295 L
s
P
p
.2 0 1 r
.016 w
.40507 .3744 m
.51542 .22252 L
s
P
p
.2 0 1 r
.016 w
.40507 .3744 m
.25319 .48475 L
s
P
p
.2 0 1 r
.016 w
.40507 .3744 m
.58362 .31639 L
s
P
p
.2 0 1 r
.016 w
.40507 .3744 m
.21733 .3744 L
s
P
p
.2 0 1 r
.002 w
.49417 .63355 m
.35336 .63355 L
s
P
p
.2 0 1 r
.002 w
.49417 .63355 m
.41141 .74746 L
s
P
p
.2 0 1 r
.002 w
.49417 .63355 m
.53768 .76746 L
s
P
p
.2 0 1 r
.002 w
.56639 .61008 m
.6099 .74399 L
s
P
p
.2 0 1 r
.002 w
.56639 .61008 m
.70031 .65359 L
s
P
p
.2 0 1 r
.002 w
.56639 .61008 m
.68031 .52732 L
s
P
p
0 .4 1 r
.018 w
.52176 .59557 m
.49417 .63355 L
s
P
p
0 .4 1 r
.018 w
.52176 .59557 m
.56639 .61008 L
s
P
p
.2 0 1 r
.002 w
.50171 .2017 m
.63562 .24521 L
s
P
p
.2 0 1 r
.002 w
.50171 .2017 m
.61562 .11894 L
s
P
p
.2 0 1 r
.002 w
.50171 .2017 m
.50171 .0609 L
s
P
p
.2 0 1 r
.002 w
.42577 .2017 m
.42577 .0609 L
s
P
p
.2 0 1 r
.002 w
.42577 .2017 m
.31186 .11894 L
s
P
p
.2 0 1 r
.002 w
.42577 .2017 m
.29186 .24521 L
s
P
p
0 .4 1 r
.018 w
.46374 .22929 m
.50171 .2017 L
s
P
p
0 .4 1 r
.018 w
.46374 .22929 m
.42577 .2017 L
s
P
p
.2 0 1 r
.002 w
.36109 .61008 m
.24718 .52732 L
s
P
p
.2 0 1 r
.002 w
.36109 .61008 m
.22718 .65359 L
s
P
p
.2 0 1 r
.002 w
.36109 .61008 m
.31758 .74399 L
s
P
p
.2 0 1 r
.002 w
.43331 .63355 m
.3898 .76746 L
s
P
p
.2 0 1 r
.002 w
.43331 .63355 m
.51608 .74746 L
s
P
p
.2 0 1 r
.002 w
.43331 .63355 m
.57412 .63355 L
s
P
p
0 .4 1 r
.018 w
.40573 .59557 m
.36109 .61008 L
s
P
p
0 .4 1 r
.018 w
.40573 .59557 m
.43331 .63355 L
s
P
p
.2 0 1 r
.002 w
.62103 .26514 m
.70379 .37905 L
s
P
p
.2 0 1 r
.002 w
.62103 .26514 m
.76183 .26514 L
s
P
p
.2 0 1 r
.002 w
.62103 .26514 m
.70379 .15123 L
s
P
p
.2 0 1 r
.002 w
.55959 .2205 m
.64235 .10659 L
s
P
p
.2 0 1 r
.002 w
.55959 .2205 m
.51608 .08659 L
s
P
p
.2 0 1 r
.002 w
.55959 .2205 m
.42567 .17699 L
s
P
p
0 .4 1 r
.018 w
.57409 .26514 m
.62103 .26514 L
s
P
p
0 .4 1 r
.018 w
.57409 .26514 m
.55959 .2205 L
s
P
p
.2 0 1 r
.002 w
.26722 .51287 m
.22371 .37896 L
s
P
p
.2 0 1 r
.002 w
.26722 .51287 m
.13331 .46936 L
s
P
p
.2 0 1 r
.002 w
.26722 .51287 m
.15331 .59563 L
s
P
p
.2 0 1 r
.002 w
.31186 .57431 m
.19794 .65707 L
s
P
p
.2 0 1 r
.002 w
.31186 .57431 m
.31186 .71511 L
s
P
p
.2 0 1 r
.002 w
.31186 .57431 m
.42577 .65707 L
s
P
p
0 .4 1 r
.018 w
.31186 .52737 m
.26722 .51287 L
s
P
p
0 .4 1 r
.018 w
.31186 .52737 m
.31186 .57431 L
s
P
p
.2 0 1 r
.016 w
.46374 .41702 m
.52176 .59557 L
s
P
p
.2 0 1 r
.016 w
.46374 .41702 m
.46374 .22929 L
s
P
p
.2 0 1 r
.016 w
.46374 .41702 m
.40573 .59557 L
s
P
p
.2 0 1 r
.016 w
.46374 .41702 m
.57409 .26514 L
s
P
p
.2 0 1 r
.016 w
.46374 .41702 m
.31186 .52737 L
s
P
p
.2 0 1 r
.002 w
.68814 .57431 m
.57423 .65707 L
s
P
p
.2 0 1 r
.002 w
.68814 .57431 m
.68814 .71511 L
s
P
p
.2 0 1 r
.002 w
.68814 .57431 m
.80206 .65707 L
s
P
p
.2 0 1 r
.002 w
.73278 .51287 m
.84669 .59563 L
s
P
p
.2 0 1 r
.002 w
.73278 .51287 m
.86669 .46936 L
s
P
p
.2 0 1 r
.002 w
.73278 .51287 m
.77629 .37896 L
s
P
p
0 .4 1 r
.018 w
.68814 .52737 m
.68814 .57431 L
s
P
p
0 .4 1 r
.018 w
.68814 .52737 m
.73278 .51287 L
s
P
p
.2 0 1 r
.002 w
.44041 .2205 m
.57433 .17699 L
s
P
p
.2 0 1 r
.002 w
.44041 .2205 m
.48392 .08659 L
s
P
p
.2 0 1 r
.002 w
.44041 .2205 m
.35765 .10659 L
s
P
p
.2 0 1 r
.002 w
.37897 .26514 m
.29621 .15123 L
s
P
p
.2 0 1 r
.002 w
.37897 .26514 m
.23817 .26514 L
s
P
p
.2 0 1 r
.002 w
.37897 .26514 m
.29621 .37905 L
s
P
p
0 .4 1 r
.018 w
.42591 .26514 m
.44041 .2205 L
s
P
p
0 .4 1 r
.018 w
.42591 .26514 m
.37897 .26514 L
s
P
p
.2 0 1 r
.002 w
.56669 .63355 m
.42588 .63355 L
s
P
p
.2 0 1 r
.002 w
.56669 .63355 m
.48392 .74746 L
s
P
p
.2 0 1 r
.002 w
.56669 .63355 m
.6102 .76746 L
s
P
p
.2 0 1 r
.002 w
.63891 .61008 m
.68242 .74399 L
s
P
p
.2 0 1 r
.002 w
.63891 .61008 m
.77282 .65359 L
s
P
p
.2 0 1 r
.002 w
.63891 .61008 m
.75282 .52732 L
s
P
p
0 .4 1 r
.018 w
.59427 .59557 m
.56669 .63355 L
s
P
p
0 .4 1 r
.018 w
.59427 .59557 m
.63891 .61008 L
s
P
p
.2 0 1 r
.002 w
.57423 .2017 m
.70814 .24521 L
s
P
p
.2 0 1 r
.002 w
.57423 .2017 m
.68814 .11894 L
s
P
p
.2 0 1 r
.002 w
.57423 .2017 m
.57423 .0609 L
s
P
p
.2 0 1 r
.002 w
.49829 .2017 m
.49829 .0609 L
s
P
p
.2 0 1 r
.002 w
.49829 .2017 m
.38438 .11894 L
s
P
p
.2 0 1 r
.002 w
.49829 .2017 m
.36438 .24521 L
s
P
p
0 .4 1 r
.018 w
.53626 .22929 m
.57423 .2017 L
s
P
p
0 .4 1 r
.018 w
.53626 .22929 m
.49829 .2017 L
s
P
p
.2 0 1 r
.002 w
.43361 .61008 m
.31969 .52732 L
s
P
p
.2 0 1 r
.002 w
.43361 .61008 m
.29969 .65359 L
s
P
p
.2 0 1 r
.002 w
.43361 .61008 m
.3901 .74399 L
s
P
p
.2 0 1 r
.002 w
.50583 .63355 m
.46232 .76746 L
s
P
p
.2 0 1 r
.002 w
.50583 .63355 m
.58859 .74746 L
s
P
p
.2 0 1 r
.002 w
.50583 .63355 m
.64664 .63355 L
s
P
p
0 .4 1 r
.018 w
.47824 .59557 m
.43361 .61008 L
s
P
p
0 .4 1 r
.018 w
.47824 .59557 m
.50583 .63355 L
s
P
p
.2 0 1 r
.016 w
.53626 .41702 m
.68814 .52737 L
s
P
p
.2 0 1 r
.016 w
.53626 .41702 m
.42591 .26514 L
s
P
p
.2 0 1 r
.016 w
.53626 .41702 m
.59427 .59557 L
s
P
p
.2 0 1 r
.016 w
.53626 .41702 m
.53626 .22929 L
s
P
p
.2 0 1 r
.016 w
.53626 .41702 m
.47824 .59557 L
s
P
p
.2 0 1 r
.002 w
.81025 .41237 m
.76674 .54628 L
s
P
p
.2 0 1 r
.002 w
.81025 .41237 m
.89302 .52628 L
s
P
p
.2 0 1 r
.002 w
.81025 .41237 m
.95106 .41237 L
s
P
p
.2 0 1 r
.002 w
.81025 .33643 m
.95106 .33643 L
s
P
p
.2 0 1 r
.002 w
.81025 .33643 m
.89302 .22252 L
s
P
p
.2 0 1 r
.002 w
.81025 .33643 m
.76674 .20252 L
s
P
p
0 .4 1 r
.018 w
.78267 .3744 m
.81025 .41237 L
s
P
p
0 .4 1 r
.018 w
.78267 .3744 m
.81025 .33643 L
s
P
p
.2 0 1 r
.002 w
.40187 .27175 m
.48464 .15784 L
s
P
p
.2 0 1 r
.002 w
.40187 .27175 m
.35836 .13784 L
s
P
p
.2 0 1 r
.002 w
.40187 .27175 m
.26796 .22824 L
s
P
p
.2 0 1 r
.002 w
.37841 .34397 m
.24449 .30046 L
s
P
p
.2 0 1 r
.002 w
.37841 .34397 m
.26449 .42674 L
s
P
p
.2 0 1 r
.002 w
.37841 .34397 m
.37841 .48478 L
s
P
p
0 .4 1 r
.018 w
.41638 .31639 m
.40187 .27175 L
s
P
p
0 .4 1 r
.018 w
.41638 .31639 m
.37841 .34397 L
s
P
p
.2 0 1 r
.002 w
.74681 .53168 m
.6329 .61445 L
s
P
p
.2 0 1 r
.002 w
.74681 .53168 m
.74681 .67249 L
s
P
p
.2 0 1 r
.002 w
.74681 .53168 m
.86072 .61445 L
s
P
p
.2 0 1 r
.002 w
.79145 .47025 m
.90536 .55301 L
s
P
p
.2 0 1 r
.002 w
.79145 .47025 m
.92536 .42674 L
s
P
p
.2 0 1 r
.002 w
.79145 .47025 m
.83496 .33633 L
s
P
p
0 .4 1 r
.018 w
.74681 .48475 m
.74681 .53168 L
s
P
p
0 .4 1 r
.018 w
.74681 .48475 m
.79145 .47025 L
s
P
p
.2 0 1 r
.002 w
.49908 .17788 m
.63299 .13437 L
s
P
p
.2 0 1 r
.002 w
.49908 .17788 m
.54259 .04397 L
s
P
p
.2 0 1 r
.002 w
.49908 .17788 m
.41632 .06397 L
s
P
p
.2 0 1 r
.002 w
.43764 .22252 m
.35488 .1086 L
s
P
p
.2 0 1 r
.002 w
.43764 .22252 m
.29684 .22252 L
s
P
p
.2 0 1 r
.002 w
.43764 .22252 m
.35488 .33643 L
s
P
p
0 .4 1 r
.018 w
.48458 .22252 m
.49908 .17788 L
s
P
p
0 .4 1 r
.018 w
.48458 .22252 m
.43764 .22252 L
s
P
p
.2 0 1 r
.002 w
.62535 .59092 m
.48455 .59092 L
s
P
p
.2 0 1 r
.002 w
.62535 .59092 m
.54259 .70483 L
s
P
p
.2 0 1 r
.002 w
.62535 .59092 m
.66886 .72483 L
s
P
p
.2 0 1 r
.002 w
.69758 .56745 m
.74109 .70137 L
s
P
p
.2 0 1 r
.002 w
.69758 .56745 m
.83149 .61096 L
s
P
p
.2 0 1 r
.002 w
.69758 .56745 m
.81149 .48469 L
s
P
p
0 .4 1 r
.018 w
.65294 .55295 m
.62535 .59092 L
s
P
p
0 .4 1 r
.018 w
.65294 .55295 m
.69758 .56745 L
s
P
p
.2 0 1 r
.016 w
.59493 .3744 m
.78267 .3744 L
s
P
p
.2 0 1 r
.016 w
.59493 .3744 m
.41638 .31639 L
s
P
p
.2 0 1 r
.016 w
.59493 .3744 m
.74681 .48475 L
s
P
p
.2 0 1 r
.016 w
.59493 .3744 m
.48458 .22252 L
s
P
p
.2 0 1 r
.016 w
.59493 .3744 m
.65294 .55295 L
s
P
p
1 .6 0 r
.016 w
.5 .30543 m
.40507 .3744 L
s
P
p
1 .6 0 r
.016 w
.5 .30543 m
.46374 .41702 L
s
P
p
1 .6 0 r
.016 w
.5 .30543 m
.53626 .41702 L
s
P
p
1 .6 0 r
.016 w
.5 .30543 m
.59493 .3744 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0659865 0.952381 [
[ 0 0 0 0 ]
[ 1 .82041 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .82041 L
0 .82041 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.28882 .58001 m
.16954 .54126 L
s
P
p
.2 0 1 r
.002 w
.28882 .58001 m
.16954 .61877 L
s
P
p
.2 0 1 r
.002 w
.28882 .58001 m
.2151 .68147 L
s
P
p
.2 0 1 r
.002 w
.36602 .60509 m
.36602 .73051 L
s
P
p
.2 0 1 r
.002 w
.36602 .60509 m
.43973 .70656 L
s
P
p
.2 0 1 r
.002 w
.36602 .60509 m
.48529 .64385 L
s
P
p
0 .4 1 r
.018 w
.33653 .56451 m
.28882 .58001 L
s
P
p
0 .4 1 r
.018 w
.33653 .56451 m
.36602 .60509 L
s
P
p
.2 0 1 r
.002 w
.56665 .21133 m
.66811 .28504 L
s
P
p
.2 0 1 r
.002 w
.56665 .21133 m
.69206 .21133 L
s
P
p
.2 0 1 r
.002 w
.56665 .21133 m
.66811 .13761 L
s
P
p
.2 0 1 r
.002 w
.50098 .16362 m
.53974 .04434 L
s
P
p
.2 0 1 r
.002 w
.50098 .16362 m
.46223 .04434 L
s
P
p
.2 0 1 r
.002 w
.50098 .16362 m
.39952 .0899 L
s
P
p
0 .4 1 r
.018 w
.51648 .21133 m
.56665 .21133 L
s
P
p
0 .4 1 r
.018 w
.51648 .21133 m
.50098 .16362 L
s
P
p
.2 0 1 r
.002 w
.18849 .47611 m
.11477 .37465 L
s
P
p
.2 0 1 r
.002 w
.18849 .47611 m
.06921 .43736 L
s
P
p
.2 0 1 r
.002 w
.18849 .47611 m
.06921 .51487 L
s
P
p
.2 0 1 r
.002 w
.2362 .54178 m
.16248 .64324 L
s
P
p
.2 0 1 r
.002 w
.2362 .54178 m
.2362 .66719 L
s
P
p
.2 0 1 r
.002 w
.2362 .54178 m
.30992 .64324 L
s
P
p
0 .4 1 r
.018 w
.2362 .49161 m
.18849 .47611 L
s
P
p
0 .4 1 r
.018 w
.2362 .49161 m
.2362 .54178 L
s
P
p
.2 0 1 r
.002 w
.62996 .34115 m
.66872 .46042 L
s
P
p
.2 0 1 r
.002 w
.62996 .34115 m
.73143 .41486 L
s
P
p
.2 0 1 r
.002 w
.62996 .34115 m
.75538 .34115 L
s
P
p
.2 0 1 r
.002 w
.60488 .26395 m
.70634 .19023 L
s
P
p
.2 0 1 r
.002 w
.60488 .26395 m
.64364 .14467 L
s
P
p
.2 0 1 r
.002 w
.60488 .26395 m
.56613 .14467 L
s
P
p
0 .4 1 r
.018 w
.58938 .31166 m
.62996 .34115 L
s
P
p
0 .4 1 r
.018 w
.58938 .31166 m
.60488 .26395 L
s
P
p
.2 0 1 r
.002 w
.16839 .33308 m
.16839 .20767 L
s
P
p
.2 0 1 r
.002 w
.16839 .33308 m
.09467 .23162 L
s
P
p
.2 0 1 r
.002 w
.16839 .33308 m
.04911 .29433 L
s
P
p
.2 0 1 r
.002 w
.16839 .41425 m
.04911 .45301 L
s
P
p
.2 0 1 r
.002 w
.16839 .41425 m
.09467 .51571 L
s
P
p
.2 0 1 r
.002 w
.16839 .41425 m
.16839 .53967 L
s
P
p
0 .4 1 r
.018 w
.19788 .37367 m
.16839 .33308 L
s
P
p
0 .4 1 r
.018 w
.19788 .37367 m
.16839 .41425 L
s
P
p
.2 0 1 r
.016 w
.39854 .37367 m
.33653 .56451 L
s
P
p
.2 0 1 r
.016 w
.39854 .37367 m
.51648 .21133 L
s
P
p
.2 0 1 r
.016 w
.39854 .37367 m
.2362 .49161 L
s
P
p
.2 0 1 r
.016 w
.39854 .37367 m
.58938 .31166 L
s
P
p
.2 0 1 r
.016 w
.39854 .37367 m
.19788 .37367 L
s
P
p
.2 0 1 r
.002 w
.49377 .65065 m
.37449 .68941 L
s
P
p
.2 0 1 r
.002 w
.49377 .65065 m
.42005 .75211 L
s
P
p
.2 0 1 r
.002 w
.49377 .65065 m
.49377 .77607 L
s
P
p
.2 0 1 r
.002 w
.57096 .62557 m
.64468 .72703 L
s
P
p
.2 0 1 r
.002 w
.57096 .62557 m
.69024 .66432 L
s
P
p
.2 0 1 r
.002 w
.57096 .62557 m
.69024 .58681 L
s
P
p
0 .4 1 r
.018 w
.52325 .61007 m
.49377 .65065 L
s
P
p
0 .4 1 r
.018 w
.52325 .61007 m
.57096 .62557 L
s
P
p
.2 0 1 r
.002 w
.50183 .18908 m
.62724 .18908 L
s
P
p
.2 0 1 r
.002 w
.50183 .18908 m
.60329 .11536 L
s
P
p
.2 0 1 r
.002 w
.50183 .18908 m
.54058 .0698 L
s
P
p
.2 0 1 r
.002 w
.42066 .18908 m
.38191 .0698 L
s
P
p
.2 0 1 r
.002 w
.42066 .18908 m
.3192 .11536 L
s
P
p
.2 0 1 r
.002 w
.42066 .18908 m
.29525 .18908 L
s
P
p
0 .4 1 r
.018 w
.46124 .21856 m
.50183 .18908 L
s
P
p
0 .4 1 r
.018 w
.46124 .21856 m
.42066 .18908 L
s
P
p
.2 0 1 r
.002 w
.35153 .62557 m
.23225 .58681 L
s
P
p
.2 0 1 r
.002 w
.35153 .62557 m
.23225 .66432 L
s
P
p
.2 0 1 r
.002 w
.35153 .62557 m
.27781 .72703 L
s
P
p
.2 0 1 r
.002 w
.42872 .65065 m
.42872 .77607 L
s
P
p
.2 0 1 r
.002 w
.42872 .65065 m
.50244 .75211 L
s
P
p
.2 0 1 r
.002 w
.42872 .65065 m
.548 .68941 L
s
P
p
0 .4 1 r
.018 w
.39924 .61007 m
.35153 .62557 L
s
P
p
0 .4 1 r
.018 w
.39924 .61007 m
.42872 .65065 L
s
P
p
.2 0 1 r
.002 w
.62936 .25689 m
.73082 .3306 L
s
P
p
.2 0 1 r
.002 w
.62936 .25689 m
.75477 .25689 L
s
P
p
.2 0 1 r
.002 w
.62936 .25689 m
.73082 .18317 L
s
P
p
.2 0 1 r
.002 w
.56369 .20918 m
.60244 .0899 L
s
P
p
.2 0 1 r
.002 w
.56369 .20918 m
.52493 .0899 L
s
P
p
.2 0 1 r
.002 w
.56369 .20918 m
.46223 .13546 L
s
P
p
0 .4 1 r
.018 w
.57919 .25689 m
.62936 .25689 L
s
P
p
0 .4 1 r
.018 w
.57919 .25689 m
.56369 .20918 L
s
P
p
.2 0 1 r
.002 w
.2512 .52167 m
.17748 .42021 L
s
P
p
.2 0 1 r
.002 w
.2512 .52167 m
.13192 .48292 L
s
P
p
.2 0 1 r
.002 w
.2512 .52167 m
.13192 .56043 L
s
P
p
.2 0 1 r
.002 w
.29891 .58734 m
.22519 .6888 L
s
P
p
.2 0 1 r
.002 w
.29891 .58734 m
.29891 .71275 L
s
P
p
.2 0 1 r
.002 w
.29891 .58734 m
.37262 .6888 L
s
P
p
0 .4 1 r
.018 w
.29891 .53717 m
.2512 .52167 L
s
P
p
0 .4 1 r
.018 w
.29891 .53717 m
.29891 .58734 L
s
P
p
.2 0 1 r
.016 w
.46124 .41923 m
.52325 .61007 L
s
P
p
.2 0 1 r
.016 w
.46124 .41923 m
.46124 .21856 L
s
P
p
.2 0 1 r
.016 w
.46124 .41923 m
.39924 .61007 L
s
P
p
.2 0 1 r
.016 w
.46124 .41923 m
.57919 .25689 L
s
P
p
.2 0 1 r
.016 w
.46124 .41923 m
.29891 .53717 L
s
P
p
.2 0 1 r
.002 w
.70109 .58734 m
.62738 .6888 L
s
P
p
.2 0 1 r
.002 w
.70109 .58734 m
.70109 .71275 L
s
P
p
.2 0 1 r
.002 w
.70109 .58734 m
.77481 .6888 L
s
P
p
.2 0 1 r
.002 w
.7488 .52167 m
.86808 .56043 L
s
P
p
.2 0 1 r
.002 w
.7488 .52167 m
.86808 .48292 L
s
P
p
.2 0 1 r
.002 w
.7488 .52167 m
.82252 .42021 L
s
P
p
0 .4 1 r
.018 w
.70109 .53717 m
.70109 .58734 L
s
P
p
0 .4 1 r
.018 w
.70109 .53717 m
.7488 .52167 L
s
P
p
.2 0 1 r
.002 w
.43631 .20918 m
.53777 .13546 L
s
P
p
.2 0 1 r
.002 w
.43631 .20918 m
.47507 .0899 L
s
P
p
.2 0 1 r
.002 w
.43631 .20918 m
.39756 .0899 L
s
P
p
.2 0 1 r
.002 w
.37064 .25689 m
.26918 .18317 L
s
P
p
.2 0 1 r
.002 w
.37064 .25689 m
.24523 .25689 L
s
P
p
.2 0 1 r
.002 w
.37064 .25689 m
.26918 .3306 L
s
P
p
0 .4 1 r
.018 w
.42081 .25689 m
.43631 .20918 L
s
P
p
0 .4 1 r
.018 w
.42081 .25689 m
.37064 .25689 L
s
P
p
.2 0 1 r
.002 w
.57128 .65065 m
.452 .68941 L
s
P
p
.2 0 1 r
.002 w
.57128 .65065 m
.49756 .75211 L
s
P
p
.2 0 1 r
.002 w
.57128 .65065 m
.57128 .77607 L
s
P
p
.2 0 1 r
.002 w
.64847 .62557 m
.72219 .72703 L
s
P
p
.2 0 1 r
.002 w
.64847 .62557 m
.76775 .66432 L
s
P
p
.2 0 1 r
.002 w
.64847 .62557 m
.76775 .58681 L
s
P
p
0 .4 1 r
.018 w
.60076 .61007 m
.57128 .65065 L
s
P
p
0 .4 1 r
.018 w
.60076 .61007 m
.64847 .62557 L
s
P
p
.2 0 1 r
.002 w
.57934 .18908 m
.70475 .18908 L
s
P
p
.2 0 1 r
.002 w
.57934 .18908 m
.6808 .11536 L
s
P
p
.2 0 1 r
.002 w
.57934 .18908 m
.61809 .0698 L
s
P
p
.2 0 1 r
.002 w
.49817 .18908 m
.45942 .0698 L
s
P
p
.2 0 1 r
.002 w
.49817 .18908 m
.39671 .11536 L
s
P
p
.2 0 1 r
.002 w
.49817 .18908 m
.37276 .18908 L
s
P
p
0 .4 1 r
.018 w
.53876 .21856 m
.57934 .18908 L
s
P
p
0 .4 1 r
.018 w
.53876 .21856 m
.49817 .18908 L
s
P
p
.2 0 1 r
.002 w
.42904 .62557 m
.30976 .58681 L
s
P
p
.2 0 1 r
.002 w
.42904 .62557 m
.30976 .66432 L
s
P
p
.2 0 1 r
.002 w
.42904 .62557 m
.35532 .72703 L
s
P
p
.2 0 1 r
.002 w
.50623 .65065 m
.50623 .77607 L
s
P
p
.2 0 1 r
.002 w
.50623 .65065 m
.57995 .75211 L
s
P
p
.2 0 1 r
.002 w
.50623 .65065 m
.62551 .68941 L
s
P
p
0 .4 1 r
.018 w
.47675 .61007 m
.42904 .62557 L
s
P
p
0 .4 1 r
.018 w
.47675 .61007 m
.50623 .65065 L
s
P
p
.2 0 1 r
.016 w
.53876 .41923 m
.70109 .53717 L
s
P
p
.2 0 1 r
.016 w
.53876 .41923 m
.42081 .25689 L
s
P
p
.2 0 1 r
.016 w
.53876 .41923 m
.60076 .61007 L
s
P
p
.2 0 1 r
.016 w
.53876 .41923 m
.53876 .21856 L
s
P
p
.2 0 1 r
.016 w
.53876 .41923 m
.47675 .61007 L
s
P
p
.2 0 1 r
.002 w
.83161 .41425 m
.83161 .53967 L
s
P
p
.2 0 1 r
.002 w
.83161 .41425 m
.90533 .51571 L
s
P
p
.2 0 1 r
.002 w
.83161 .41425 m
.95089 .45301 L
s
P
p
.2 0 1 r
.002 w
.83161 .33308 m
.95089 .29433 L
s
P
p
.2 0 1 r
.002 w
.83161 .33308 m
.90533 .23162 L
s
P
p
.2 0 1 r
.002 w
.83161 .33308 m
.83161 .20767 L
s
P
p
0 .4 1 r
.018 w
.80212 .37367 m
.83161 .41425 L
s
P
p
0 .4 1 r
.018 w
.80212 .37367 m
.83161 .33308 L
s
P
p
.2 0 1 r
.002 w
.39512 .26395 m
.43387 .14467 L
s
P
p
.2 0 1 r
.002 w
.39512 .26395 m
.35636 .14467 L
s
P
p
.2 0 1 r
.002 w
.39512 .26395 m
.29366 .19023 L
s
P
p
.2 0 1 r
.002 w
.37004 .34115 m
.24462 .34115 L
s
P
p
.2 0 1 r
.002 w
.37004 .34115 m
.26857 .41486 L
s
P
p
.2 0 1 r
.002 w
.37004 .34115 m
.33128 .46042 L
s
P
p
0 .4 1 r
.018 w
.41062 .31166 m
.39512 .26395 L
s
P
p
0 .4 1 r
.018 w
.41062 .31166 m
.37004 .34115 L
s
P
p
.2 0 1 r
.002 w
.7638 .54178 m
.69008 .64324 L
s
P
p
.2 0 1 r
.002 w
.7638 .54178 m
.7638 .66719 L
s
P
p
.2 0 1 r
.002 w
.7638 .54178 m
.83752 .64324 L
s
P
p
.2 0 1 r
.002 w
.81151 .47611 m
.93079 .51487 L
s
P
p
.2 0 1 r
.002 w
.81151 .47611 m
.93079 .43736 L
s
P
p
.2 0 1 r
.002 w
.81151 .47611 m
.88523 .37465 L
s
P
p
0 .4 1 r
.018 w
.7638 .49161 m
.7638 .54178 L
s
P
p
0 .4 1 r
.018 w
.7638 .49161 m
.81151 .47611 L
s
P
p
.2 0 1 r
.002 w
.49902 .16362 m
.60048 .0899 L
s
P
p
.2 0 1 r
.002 w
.49902 .16362 m
.53777 .04434 L
s
P
p
.2 0 1 r
.002 w
.49902 .16362 m
.46026 .04434 L
s
P
p
.2 0 1 r
.002 w
.43335 .21133 m
.33189 .13761 L
s
P
p
.2 0 1 r
.002 w
.43335 .21133 m
.30794 .21133 L
s
P
p
.2 0 1 r
.002 w
.43335 .21133 m
.33189 .28504 L
s
P
p
0 .4 1 r
.018 w
.48352 .21133 m
.49902 .16362 L
s
P
p
0 .4 1 r
.018 w
.48352 .21133 m
.43335 .21133 L
s
P
p
.2 0 1 r
.002 w
.63398 .60509 m
.51471 .64385 L
s
P
p
.2 0 1 r
.002 w
.63398 .60509 m
.56027 .70656 L
s
P
p
.2 0 1 r
.002 w
.63398 .60509 m
.63398 .73051 L
s
P
p
.2 0 1 r
.002 w
.71118 .58001 m
.7849 .68147 L
s
P
p
.2 0 1 r
.002 w
.71118 .58001 m
.83046 .61877 L
s
P
p
.2 0 1 r
.002 w
.71118 .58001 m
.83046 .54126 L
s
P
p
0 .4 1 r
.018 w
.66347 .56451 m
.63398 .60509 L
s
P
p
0 .4 1 r
.018 w
.66347 .56451 m
.71118 .58001 L
s
P
p
.2 0 1 r
.016 w
.60146 .37367 m
.80212 .37367 L
s
P
p
.2 0 1 r
.016 w
.60146 .37367 m
.41062 .31166 L
s
P
p
.2 0 1 r
.016 w
.60146 .37367 m
.7638 .49161 L
s
P
p
.2 0 1 r
.016 w
.60146 .37367 m
.48352 .21133 L
s
P
p
.2 0 1 r
.016 w
.60146 .37367 m
.66347 .56451 L
s
P
p
1 .6 0 r
.016 w
.5 .29995 m
.39854 .37367 L
s
P
p
1 .6 0 r
.016 w
.5 .29995 m
.46124 .41923 L
s
P
p
1 .6 0 r
.016 w
.5 .29995 m
.53876 .41923 L
s
P
p
1 .6 0 r
.016 w
.5 .29995 m
.60146 .37367 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0608586 0.952381 [
[ 0 0 0 0 ]
[ 1 .83066 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .83066 L
0 .83066 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.004 w
.29937 .57607 m
.16339 .53189 L
s
P
p
.2 0 1 r
.004 w
.29937 .57607 m
.16339 .62025 L
s
P
p
.2 0 1 r
.004 w
.29937 .57607 m
.21533 .69174 L
s
P
p
.2 0 1 r
.004 w
.37271 .5999 m
.37271 .74288 L
s
P
p
.2 0 1 r
.004 w
.37271 .5999 m
.45675 .71557 L
s
P
p
.2 0 1 r
.004 w
.37271 .5999 m
.50869 .64408 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.29937 .57607 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.37271 .5999 L
s
P
p
.2 0 1 r
.004 w
.56332 .22581 m
.67899 .30985 L
s
P
p
.2 0 1 r
.004 w
.56332 .22581 m
.7063 .22581 L
s
P
p
.2 0 1 r
.004 w
.56332 .22581 m
.67899 .14177 L
s
P
p
.2 0 1 r
.004 w
.50093 .18048 m
.54512 .04451 L
s
P
p
.2 0 1 r
.004 w
.50093 .18048 m
.45675 .04451 L
s
P
p
.2 0 1 r
.004 w
.50093 .18048 m
.38526 .09644 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.56332 .22581 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.50093 .18048 L
s
P
p
.2 0 1 r
.004 w
.20405 .47736 m
.12002 .36169 L
s
P
p
.2 0 1 r
.004 w
.20405 .47736 m
.06808 .43318 L
s
P
p
.2 0 1 r
.004 w
.20405 .47736 m
.06808 .52154 L
s
P
p
.2 0 1 r
.004 w
.24938 .53975 m
.16534 .65542 L
s
P
p
.2 0 1 r
.004 w
.24938 .53975 m
.24938 .68273 L
s
P
p
.2 0 1 r
.004 w
.24938 .53975 m
.33342 .65542 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.20405 .47736 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.24938 .53975 L
s
P
p
.2 0 1 r
.004 w
.62347 .34914 m
.66765 .48512 L
s
P
p
.2 0 1 r
.004 w
.62347 .34914 m
.73914 .43318 L
s
P
p
.2 0 1 r
.004 w
.62347 .34914 m
.76645 .34914 L
s
P
p
.2 0 1 r
.004 w
.59964 .2758 m
.71531 .19176 L
s
P
p
.2 0 1 r
.004 w
.59964 .2758 m
.64382 .13982 L
s
P
p
.2 0 1 r
.004 w
.59964 .2758 m
.55546 .13982 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.62347 .34914 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.59964 .2758 L
s
P
p
.2 0 1 r
.004 w
.18496 .34148 m
.18496 .1985 L
s
P
p
.2 0 1 r
.004 w
.18496 .34148 m
.10092 .22581 L
s
P
p
.2 0 1 r
.004 w
.18496 .34148 m
.04898 .2973 L
s
P
p
.2 0 1 r
.004 w
.18496 .41859 m
.04898 .46278 L
s
P
p
.2 0 1 r
.004 w
.18496 .41859 m
.10092 .53426 L
s
P
p
.2 0 1 r
.004 w
.18496 .41859 m
.18496 .56157 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .34148 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .41859 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.3447 .56134 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.51566 .22581 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.24938 .49209 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.58491 .32113 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.21297 .38004 L
s
P
p
.2 0 1 r
.004 w
.49408 .64318 m
.3581 .68736 L
s
P
p
.2 0 1 r
.004 w
.49408 .64318 m
.41004 .75885 L
s
P
p
.2 0 1 r
.004 w
.49408 .64318 m
.49408 .78616 L
s
P
p
.2 0 1 r
.004 w
.56742 .61935 m
.65146 .73502 L
s
P
p
.2 0 1 r
.004 w
.56742 .61935 m
.7034 .66353 L
s
P
p
.2 0 1 r
.004 w
.56742 .61935 m
.7034 .57517 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.49408 .64318 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.56742 .61935 L
s
P
p
.2 0 1 r
.004 w
.50174 .20467 m
.64471 .20467 L
s
P
p
.2 0 1 r
.004 w
.50174 .20467 m
.61741 .12063 L
s
P
p
.2 0 1 r
.004 w
.50174 .20467 m
.54592 .06869 L
s
P
p
.2 0 1 r
.004 w
.42462 .20467 m
.38044 .06869 L
s
P
p
.2 0 1 r
.004 w
.42462 .20467 m
.30895 .12063 L
s
P
p
.2 0 1 r
.004 w
.42462 .20467 m
.28165 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.50174 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.42462 .20467 L
s
P
p
.2 0 1 r
.004 w
.35895 .61935 m
.22297 .57517 L
s
P
p
.2 0 1 r
.004 w
.35895 .61935 m
.22297 .66353 L
s
P
p
.2 0 1 r
.004 w
.35895 .61935 m
.27491 .73502 L
s
P
p
.2 0 1 r
.004 w
.43229 .64318 m
.43229 .78616 L
s
P
p
.2 0 1 r
.004 w
.43229 .64318 m
.51632 .75885 L
s
P
p
.2 0 1 r
.004 w
.43229 .64318 m
.56826 .68736 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.35895 .61935 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.43229 .64318 L
s
P
p
.2 0 1 r
.004 w
.62289 .26909 m
.73856 .35313 L
s
P
p
.2 0 1 r
.004 w
.62289 .26909 m
.76587 .26909 L
s
P
p
.2 0 1 r
.004 w
.62289 .26909 m
.73856 .18505 L
s
P
p
.2 0 1 r
.004 w
.56051 .22377 m
.60469 .08779 L
s
P
p
.2 0 1 r
.004 w
.56051 .22377 m
.51632 .08779 L
s
P
p
.2 0 1 r
.004 w
.56051 .22377 m
.44484 .13973 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.62289 .26909 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.56051 .22377 L
s
P
p
.2 0 1 r
.004 w
.26363 .52065 m
.17959 .40497 L
s
P
p
.2 0 1 r
.004 w
.26363 .52065 m
.12765 .47646 L
s
P
p
.2 0 1 r
.004 w
.26363 .52065 m
.12765 .56483 L
s
P
p
.2 0 1 r
.004 w
.30895 .58303 m
.22492 .6987 L
s
P
p
.2 0 1 r
.004 w
.30895 .58303 m
.30895 .72601 L
s
P
p
.2 0 1 r
.004 w
.30895 .58303 m
.39299 .6987 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.26363 .52065 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.30895 .58303 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.52209 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.46318 .23269 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.40427 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.57523 .26909 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.30895 .53537 L
s
P
p
.2 0 1 r
.004 w
.69105 .58303 m
.60701 .6987 L
s
P
p
.2 0 1 r
.004 w
.69105 .58303 m
.69105 .72601 L
s
P
p
.2 0 1 r
.004 w
.69105 .58303 m
.77508 .6987 L
s
P
p
.2 0 1 r
.004 w
.73637 .52065 m
.87235 .56483 L
s
P
p
.2 0 1 r
.004 w
.73637 .52065 m
.87235 .47646 L
s
P
p
.2 0 1 r
.004 w
.73637 .52065 m
.82041 .40497 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.69105 .58303 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.73637 .52065 L
s
P
p
.2 0 1 r
.004 w
.43949 .22377 m
.55516 .13973 L
s
P
p
.2 0 1 r
.004 w
.43949 .22377 m
.48368 .08779 L
s
P
p
.2 0 1 r
.004 w
.43949 .22377 m
.39531 .08779 L
s
P
p
.2 0 1 r
.004 w
.37711 .26909 m
.26144 .18505 L
s
P
p
.2 0 1 r
.004 w
.37711 .26909 m
.23413 .26909 L
s
P
p
.2 0 1 r
.004 w
.37711 .26909 m
.26144 .35313 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.43949 .22377 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.37711 .26909 L
s
P
p
.2 0 1 r
.004 w
.56771 .64318 m
.43174 .68736 L
s
P
p
.2 0 1 r
.004 w
.56771 .64318 m
.48368 .75885 L
s
P
p
.2 0 1 r
.004 w
.56771 .64318 m
.56771 .78616 L
s
P
p
.2 0 1 r
.004 w
.64105 .61935 m
.72509 .73502 L
s
P
p
.2 0 1 r
.004 w
.64105 .61935 m
.77703 .66353 L
s
P
p
.2 0 1 r
.004 w
.64105 .61935 m
.77703 .57517 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.56771 .64318 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.64105 .61935 L
s
P
p
.2 0 1 r
.004 w
.57538 .20467 m
.71835 .20467 L
s
P
p
.2 0 1 r
.004 w
.57538 .20467 m
.69105 .12063 L
s
P
p
.2 0 1 r
.004 w
.57538 .20467 m
.61956 .06869 L
s
P
p
.2 0 1 r
.004 w
.49826 .20467 m
.45408 .06869 L
s
P
p
.2 0 1 r
.004 w
.49826 .20467 m
.38259 .12063 L
s
P
p
.2 0 1 r
.004 w
.49826 .20467 m
.35529 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.57538 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.49826 .20467 L
s
P
p
.2 0 1 r
.004 w
.43258 .61935 m
.2966 .57517 L
s
P
p
.2 0 1 r
.004 w
.43258 .61935 m
.2966 .66353 L
s
P
p
.2 0 1 r
.004 w
.43258 .61935 m
.34854 .73502 L
s
P
p
.2 0 1 r
.004 w
.50592 .64318 m
.50592 .78616 L
s
P
p
.2 0 1 r
.004 w
.50592 .64318 m
.58996 .75885 L
s
P
p
.2 0 1 r
.004 w
.50592 .64318 m
.6419 .68736 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.43258 .61935 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.50592 .64318 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.69105 .53537 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.42477 .26909 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.59573 .60462 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.53682 .23269 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.47791 .60462 L
s
P
p
.2 0 1 r
.004 w
.81504 .41859 m
.81504 .56157 L
s
P
p
.2 0 1 r
.004 w
.81504 .41859 m
.89908 .53426 L
s
P
p
.2 0 1 r
.004 w
.81504 .41859 m
.95102 .46278 L
s
P
p
.2 0 1 r
.004 w
.81504 .34148 m
.95102 .2973 L
s
P
p
.2 0 1 r
.004 w
.81504 .34148 m
.89908 .22581 L
s
P
p
.2 0 1 r
.004 w
.81504 .34148 m
.81504 .1985 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .41859 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .34148 L
s
P
p
.2 0 1 r
.004 w
.40036 .2758 m
.44454 .13982 L
s
P
p
.2 0 1 r
.004 w
.40036 .2758 m
.35618 .13982 L
s
P
p
.2 0 1 r
.004 w
.40036 .2758 m
.28469 .19176 L
s
P
p
.2 0 1 r
.004 w
.37653 .34914 m
.23355 .34914 L
s
P
p
.2 0 1 r
.004 w
.37653 .34914 m
.26086 .43318 L
s
P
p
.2 0 1 r
.004 w
.37653 .34914 m
.33235 .48512 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.40036 .2758 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.37653 .34914 L
s
P
p
.2 0 1 r
.004 w
.75062 .53975 m
.66658 .65542 L
s
P
p
.2 0 1 r
.004 w
.75062 .53975 m
.75062 .68273 L
s
P
p
.2 0 1 r
.004 w
.75062 .53975 m
.83466 .65542 L
s
P
p
.2 0 1 r
.004 w
.79595 .47736 m
.93192 .52154 L
s
P
p
.2 0 1 r
.004 w
.79595 .47736 m
.93192 .43318 L
s
P
p
.2 0 1 r
.004 w
.79595 .47736 m
.87998 .36169 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.75062 .53975 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.79595 .47736 L
s
P
p
.2 0 1 r
.004 w
.49907 .18048 m
.61474 .09644 L
s
P
p
.2 0 1 r
.004 w
.49907 .18048 m
.54325 .04451 L
s
P
p
.2 0 1 r
.004 w
.49907 .18048 m
.45488 .04451 L
s
P
p
.2 0 1 r
.004 w
.43668 .22581 m
.32101 .14177 L
s
P
p
.2 0 1 r
.004 w
.43668 .22581 m
.2937 .22581 L
s
P
p
.2 0 1 r
.004 w
.43668 .22581 m
.32101 .30985 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.49907 .18048 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.43668 .22581 L
s
P
p
.2 0 1 r
.004 w
.62729 .5999 m
.49131 .64408 L
s
P
p
.2 0 1 r
.004 w
.62729 .5999 m
.54325 .71557 L
s
P
p
.2 0 1 r
.004 w
.62729 .5999 m
.62729 .74288 L
s
P
p
.2 0 1 r
.004 w
.70063 .57607 m
.78467 .69174 L
s
P
p
.2 0 1 r
.004 w
.70063 .57607 m
.83661 .62025 L
s
P
p
.2 0 1 r
.004 w
.70063 .57607 m
.83661 .53189 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.62729 .5999 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.70063 .57607 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.78703 .38004 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.41509 .32113 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.75062 .49209 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.48434 .22581 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.6553 .56134 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.40361 .38004 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.46318 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.53682 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.59639 .38004 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0608586 0.952381 [
[ 0 0 0 0 ]
[ 1 .83066 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .83066 L
0 .83066 L
closepath
clip
newpath
p
P
p
.8 0 1 r
.002 w
.29937 .57607 m
.16339 .53189 L
s
P
p
.8 0 1 r
.002 w
.29937 .57607 m
.16339 .62025 L
s
P
p
.8 0 1 r
.002 w
.29937 .57607 m
.21533 .69174 L
s
P
p
.8 0 1 r
.002 w
.37271 .5999 m
.37271 .74288 L
s
P
p
.8 0 1 r
.002 w
.37271 .5999 m
.45675 .71557 L
s
P
p
.8 0 1 r
.002 w
.37271 .5999 m
.50869 .64408 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.29937 .57607 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.37271 .5999 L
s
P
p
.8 0 1 r
.002 w
.56332 .22581 m
.67899 .30985 L
s
P
p
.8 0 1 r
.002 w
.56332 .22581 m
.7063 .22581 L
s
P
p
.8 0 1 r
.002 w
.56332 .22581 m
.67899 .14177 L
s
P
p
.8 0 1 r
.002 w
.50093 .18048 m
.54512 .04451 L
s
P
p
.8 0 1 r
.002 w
.50093 .18048 m
.45675 .04451 L
s
P
p
.8 0 1 r
.002 w
.50093 .18048 m
.38526 .09644 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.56332 .22581 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.50093 .18048 L
s
P
p
.8 0 1 r
.002 w
.20405 .47736 m
.12002 .36169 L
s
P
p
.8 0 1 r
.002 w
.20405 .47736 m
.06808 .43318 L
s
P
p
.8 0 1 r
.002 w
.20405 .47736 m
.06808 .52154 L
s
P
p
.8 0 1 r
.002 w
.24938 .53975 m
.16534 .65542 L
s
P
p
.8 0 1 r
.002 w
.24938 .53975 m
.24938 .68273 L
s
P
p
.8 0 1 r
.002 w
.24938 .53975 m
.33342 .65542 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.20405 .47736 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.24938 .53975 L
s
P
p
.8 0 1 r
.002 w
.62347 .34914 m
.66765 .48512 L
s
P
p
.8 0 1 r
.002 w
.62347 .34914 m
.73914 .43318 L
s
P
p
.8 0 1 r
.002 w
.62347 .34914 m
.76645 .34914 L
s
P
p
.8 0 1 r
.002 w
.59964 .2758 m
.71531 .19176 L
s
P
p
.8 0 1 r
.002 w
.59964 .2758 m
.64382 .13982 L
s
P
p
.8 0 1 r
.002 w
.59964 .2758 m
.55546 .13982 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.62347 .34914 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.59964 .2758 L
s
P
p
.8 0 1 r
.002 w
.18496 .34148 m
.18496 .1985 L
s
P
p
.8 0 1 r
.002 w
.18496 .34148 m
.10092 .22581 L
s
P
p
.8 0 1 r
.002 w
.18496 .34148 m
.04898 .2973 L
s
P
p
.8 0 1 r
.002 w
.18496 .41859 m
.04898 .46278 L
s
P
p
.8 0 1 r
.002 w
.18496 .41859 m
.10092 .53426 L
s
P
p
.8 0 1 r
.002 w
.18496 .41859 m
.18496 .56157 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .34148 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .41859 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.3447 .56134 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.51566 .22581 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.24938 .49209 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.58491 .32113 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.21297 .38004 L
s
P
p
.8 0 1 r
.002 w
.49408 .64318 m
.3581 .68736 L
s
P
p
.8 0 1 r
.002 w
.49408 .64318 m
.41004 .75885 L
s
P
p
.8 0 1 r
.002 w
.49408 .64318 m
.49408 .78616 L
s
P
p
.8 0 1 r
.002 w
.56742 .61935 m
.65146 .73502 L
s
P
p
.8 0 1 r
.002 w
.56742 .61935 m
.7034 .66353 L
s
P
p
.8 0 1 r
.002 w
.56742 .61935 m
.7034 .57517 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.49408 .64318 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.56742 .61935 L
s
P
p
.8 0 1 r
.002 w
.50174 .20467 m
.64471 .20467 L
s
P
p
.8 0 1 r
.002 w
.50174 .20467 m
.61741 .12063 L
s
P
p
.8 0 1 r
.002 w
.50174 .20467 m
.54592 .06869 L
s
P
p
.8 0 1 r
.002 w
.42462 .20467 m
.38044 .06869 L
s
P
p
.8 0 1 r
.002 w
.42462 .20467 m
.30895 .12063 L
s
P
p
.8 0 1 r
.002 w
.42462 .20467 m
.28165 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.50174 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.42462 .20467 L
s
P
p
.8 0 1 r
.002 w
.35895 .61935 m
.22297 .57517 L
s
P
p
.8 0 1 r
.002 w
.35895 .61935 m
.22297 .66353 L
s
P
p
.8 0 1 r
.002 w
.35895 .61935 m
.27491 .73502 L
s
P
p
.8 0 1 r
.002 w
.43229 .64318 m
.43229 .78616 L
s
P
p
.8 0 1 r
.002 w
.43229 .64318 m
.51632 .75885 L
s
P
p
.8 0 1 r
.002 w
.43229 .64318 m
.56826 .68736 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.35895 .61935 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.43229 .64318 L
s
P
p
.8 0 1 r
.002 w
.62289 .26909 m
.73856 .35313 L
s
P
p
.8 0 1 r
.002 w
.62289 .26909 m
.76587 .26909 L
s
P
p
.8 0 1 r
.002 w
.62289 .26909 m
.73856 .18505 L
s
P
p
.8 0 1 r
.002 w
.56051 .22377 m
.60469 .08779 L
s
P
p
.8 0 1 r
.002 w
.56051 .22377 m
.51632 .08779 L
s
P
p
.8 0 1 r
.002 w
.56051 .22377 m
.44484 .13973 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.62289 .26909 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.56051 .22377 L
s
P
p
.8 0 1 r
.002 w
.26363 .52065 m
.17959 .40497 L
s
P
p
.8 0 1 r
.002 w
.26363 .52065 m
.12765 .47646 L
s
P
p
.8 0 1 r
.002 w
.26363 .52065 m
.12765 .56483 L
s
P
p
.8 0 1 r
.002 w
.30895 .58303 m
.22492 .6987 L
s
P
p
.8 0 1 r
.002 w
.30895 .58303 m
.30895 .72601 L
s
P
p
.8 0 1 r
.002 w
.30895 .58303 m
.39299 .6987 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.26363 .52065 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.30895 .58303 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.52209 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.46318 .23269 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.40427 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.57523 .26909 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.30895 .53537 L
s
P
p
.8 0 1 r
.002 w
.69105 .58303 m
.60701 .6987 L
s
P
p
.8 0 1 r
.002 w
.69105 .58303 m
.69105 .72601 L
s
P
p
.8 0 1 r
.002 w
.69105 .58303 m
.77508 .6987 L
s
P
p
.8 0 1 r
.002 w
.73637 .52065 m
.87235 .56483 L
s
P
p
.8 0 1 r
.002 w
.73637 .52065 m
.87235 .47646 L
s
P
p
.8 0 1 r
.002 w
.73637 .52065 m
.82041 .40497 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.69105 .58303 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.73637 .52065 L
s
P
p
.8 0 1 r
.002 w
.43949 .22377 m
.55516 .13973 L
s
P
p
.8 0 1 r
.002 w
.43949 .22377 m
.48368 .08779 L
s
P
p
.8 0 1 r
.002 w
.43949 .22377 m
.39531 .08779 L
s
P
p
.8 0 1 r
.002 w
.37711 .26909 m
.26144 .18505 L
s
P
p
.8 0 1 r
.002 w
.37711 .26909 m
.23413 .26909 L
s
P
p
.8 0 1 r
.002 w
.37711 .26909 m
.26144 .35313 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.43949 .22377 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.37711 .26909 L
s
P
p
.8 0 1 r
.002 w
.56771 .64318 m
.43174 .68736 L
s
P
p
.8 0 1 r
.002 w
.56771 .64318 m
.48368 .75885 L
s
P
p
.8 0 1 r
.002 w
.56771 .64318 m
.56771 .78616 L
s
P
p
.8 0 1 r
.002 w
.64105 .61935 m
.72509 .73502 L
s
P
p
.8 0 1 r
.002 w
.64105 .61935 m
.77703 .66353 L
s
P
p
.8 0 1 r
.002 w
.64105 .61935 m
.77703 .57517 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.56771 .64318 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.64105 .61935 L
s
P
p
.8 0 1 r
.002 w
.57538 .20467 m
.71835 .20467 L
s
P
p
.8 0 1 r
.002 w
.57538 .20467 m
.69105 .12063 L
s
P
p
.8 0 1 r
.002 w
.57538 .20467 m
.61956 .06869 L
s
P
p
.8 0 1 r
.002 w
.49826 .20467 m
.45408 .06869 L
s
P
p
.8 0 1 r
.002 w
.49826 .20467 m
.38259 .12063 L
s
P
p
.8 0 1 r
.002 w
.49826 .20467 m
.35529 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.57538 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.49826 .20467 L
s
P
p
.8 0 1 r
.002 w
.43258 .61935 m
.2966 .57517 L
s
P
p
.8 0 1 r
.002 w
.43258 .61935 m
.2966 .66353 L
s
P
p
.8 0 1 r
.002 w
.43258 .61935 m
.34854 .73502 L
s
P
p
.8 0 1 r
.002 w
.50592 .64318 m
.50592 .78616 L
s
P
p
.8 0 1 r
.002 w
.50592 .64318 m
.58996 .75885 L
s
P
p
.8 0 1 r
.002 w
.50592 .64318 m
.6419 .68736 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.43258 .61935 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.50592 .64318 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.69105 .53537 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.42477 .26909 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.59573 .60462 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.53682 .23269 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.47791 .60462 L
s
P
p
.8 0 1 r
.002 w
.81504 .41859 m
.81504 .56157 L
s
P
p
.8 0 1 r
.002 w
.81504 .41859 m
.89908 .53426 L
s
P
p
.8 0 1 r
.002 w
.81504 .41859 m
.95102 .46278 L
s
P
p
.8 0 1 r
.002 w
.81504 .34148 m
.95102 .2973 L
s
P
p
.8 0 1 r
.002 w
.81504 .34148 m
.89908 .22581 L
s
P
p
.8 0 1 r
.002 w
.81504 .34148 m
.81504 .1985 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .41859 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .34148 L
s
P
p
.8 0 1 r
.002 w
.40036 .2758 m
.44454 .13982 L
s
P
p
.8 0 1 r
.002 w
.40036 .2758 m
.35618 .13982 L
s
P
p
.8 0 1 r
.002 w
.40036 .2758 m
.28469 .19176 L
s
P
p
.8 0 1 r
.002 w
.37653 .34914 m
.23355 .34914 L
s
P
p
.8 0 1 r
.002 w
.37653 .34914 m
.26086 .43318 L
s
P
p
.8 0 1 r
.002 w
.37653 .34914 m
.33235 .48512 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.40036 .2758 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.37653 .34914 L
s
P
p
.8 0 1 r
.002 w
.75062 .53975 m
.66658 .65542 L
s
P
p
.8 0 1 r
.002 w
.75062 .53975 m
.75062 .68273 L
s
P
p
.8 0 1 r
.002 w
.75062 .53975 m
.83466 .65542 L
s
P
p
.8 0 1 r
.002 w
.79595 .47736 m
.93192 .52154 L
s
P
p
.8 0 1 r
.002 w
.79595 .47736 m
.93192 .43318 L
s
P
p
.8 0 1 r
.002 w
.79595 .47736 m
.87998 .36169 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.75062 .53975 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.79595 .47736 L
s
P
p
.8 0 1 r
.002 w
.49907 .18048 m
.61474 .09644 L
s
P
p
.8 0 1 r
.002 w
.49907 .18048 m
.54325 .04451 L
s
P
p
.8 0 1 r
.002 w
.49907 .18048 m
.45488 .04451 L
s
P
p
.8 0 1 r
.002 w
.43668 .22581 m
.32101 .14177 L
s
P
p
.8 0 1 r
.002 w
.43668 .22581 m
.2937 .22581 L
s
P
p
.8 0 1 r
.002 w
.43668 .22581 m
.32101 .30985 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.49907 .18048 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.43668 .22581 L
s
P
p
.8 0 1 r
.002 w
.62729 .5999 m
.49131 .64408 L
s
P
p
.8 0 1 r
.002 w
.62729 .5999 m
.54325 .71557 L
s
P
p
.8 0 1 r
.002 w
.62729 .5999 m
.62729 .74288 L
s
P
p
.8 0 1 r
.002 w
.70063 .57607 m
.78467 .69174 L
s
P
p
.8 0 1 r
.002 w
.70063 .57607 m
.83661 .62025 L
s
P
p
.8 0 1 r
.002 w
.70063 .57607 m
.83661 .53189 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.62729 .5999 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.70063 .57607 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.78703 .38004 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.41509 .32113 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.75062 .49209 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.48434 .22581 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.6553 .56134 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.40361 .38004 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.46318 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.53682 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.59639 .38004 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0284975 0.952381 [
[ 0 0 0 0 ]
[ 1 .89539 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .89539 L
0 .89539 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.43163 .65463 m
.28967 .70075 L
s
P
p
.2 0 1 r
.002 w
.43163 .65463 m
.34389 .77538 L
s
P
p
.2 0 1 r
.002 w
.43163 .65463 m
.43163 .80389 L
s
P
p
.2 0 1 r
.002 w
.50819 .62975 m
.59592 .7505 L
s
P
p
.2 0 1 r
.002 w
.50819 .62975 m
.65014 .67587 L
s
P
p
.2 0 1 r
.002 w
.50819 .62975 m
.65014 .58362 L
s
P
p
0 .4 1 r
.018 w
.46087 .61437 m
.43163 .65463 L
s
P
p
0 .4 1 r
.018 w
.46087 .61437 m
.50819 .62975 L
s
P
p
.2 0 1 r
.002 w
.50819 .22045 m
.65014 .26658 L
s
P
p
.2 0 1 r
.002 w
.50819 .22045 m
.65014 .17433 L
s
P
p
.2 0 1 r
.002 w
.50819 .22045 m
.59592 .0997 L
s
P
p
.2 0 1 r
.002 w
.43163 .19558 m
.43163 .04631 L
s
P
p
.2 0 1 r
.002 w
.43163 .19558 m
.34389 .07482 L
s
P
p
.2 0 1 r
.002 w
.43163 .19558 m
.28967 .14945 L
s
P
p
0 .4 1 r
.018 w
.46087 .23583 m
.50819 .22045 L
s
P
p
0 .4 1 r
.018 w
.46087 .23583 m
.43163 .19558 L
s
P
p
.2 0 1 r
.002 w
.19105 .5267 m
.10331 .40595 L
s
P
p
.2 0 1 r
.002 w
.19105 .5267 m
.04909 .48058 L
s
P
p
.2 0 1 r
.002 w
.19105 .5267 m
.04909 .57283 L
s
P
p
.2 0 1 r
.002 w
.23837 .59183 m
.15063 .71259 L
s
P
p
.2 0 1 r
.002 w
.23837 .59183 m
.23837 .74109 L
s
P
p
.2 0 1 r
.002 w
.23837 .59183 m
.3261 .71259 L
s
P
p
0 .4 1 r
.018 w
.23837 .54208 m
.19105 .5267 L
s
P
p
0 .4 1 r
.018 w
.23837 .54208 m
.23837 .59183 L
s
P
p
.2 0 1 r
.002 w
.62763 .46535 m
.62763 .61461 L
s
P
p
.2 0 1 r
.002 w
.62763 .46535 m
.71536 .58611 L
s
P
p
.2 0 1 r
.002 w
.62763 .46535 m
.76959 .51148 L
s
P
p
.2 0 1 r
.002 w
.62763 .38485 m
.76959 .33872 L
s
P
p
.2 0 1 r
.002 w
.62763 .38485 m
.71536 .26409 L
s
P
p
.2 0 1 r
.002 w
.62763 .38485 m
.62763 .23559 L
s
P
p
0 .4 1 r
.018 w
.59839 .4251 m
.62763 .46535 L
s
P
p
0 .4 1 r
.018 w
.59839 .4251 m
.62763 .38485 L
s
P
p
.2 0 1 r
.002 w
.23837 .25837 m
.3261 .13761 L
s
P
p
.2 0 1 r
.002 w
.23837 .25837 m
.23837 .10911 L
s
P
p
.2 0 1 r
.002 w
.23837 .25837 m
.15063 .13761 L
s
P
p
.2 0 1 r
.002 w
.19105 .3235 m
.04909 .27737 L
s
P
p
.2 0 1 r
.002 w
.19105 .3235 m
.04909 .36962 L
s
P
p
.2 0 1 r
.002 w
.19105 .3235 m
.10331 .44425 L
s
P
p
0 .4 1 r
.018 w
.23837 .30812 m
.23837 .25837 L
s
P
p
0 .4 1 r
.018 w
.23837 .30812 m
.19105 .3235 L
s
P
p
.2 0 1 r
.016 w
.39937 .4251 m
.46087 .61437 L
s
P
p
.2 0 1 r
.016 w
.39937 .4251 m
.46087 .23583 L
s
P
p
.2 0 1 r
.016 w
.39937 .4251 m
.23837 .54208 L
s
P
p
.2 0 1 r
.016 w
.39937 .4251 m
.59839 .4251 L
s
P
p
.2 0 1 r
.016 w
.39937 .4251 m
.23837 .30812 L
s
P
p
.2 0 1 r
.002 w
.62257 .63702 m
.53484 .75777 L
s
P
p
.2 0 1 r
.002 w
.62257 .63702 m
.62257 .78628 L
s
P
p
.2 0 1 r
.002 w
.62257 .63702 m
.7103 .75777 L
s
P
p
.2 0 1 r
.002 w
.66989 .57189 m
.81184 .61801 L
s
P
p
.2 0 1 r
.002 w
.66989 .57189 m
.81184 .52576 L
s
P
p
.2 0 1 r
.002 w
.66989 .57189 m
.75762 .45113 L
s
P
p
0 .4 1 r
.018 w
.62257 .58726 m
.62257 .63702 L
s
P
p
0 .4 1 r
.018 w
.62257 .58726 m
.66989 .57189 L
s
P
p
.2 0 1 r
.002 w
.42931 .24076 m
.57126 .19464 L
s
P
p
.2 0 1 r
.002 w
.42931 .24076 m
.51704 .12001 L
s
P
p
.2 0 1 r
.002 w
.42931 .24076 m
.42931 .0915 L
s
P
p
.2 0 1 r
.002 w
.35275 .26564 m
.26501 .14488 L
s
P
p
.2 0 1 r
.002 w
.35275 .26564 m
.21079 .21951 L
s
P
p
.2 0 1 r
.002 w
.35275 .26564 m
.21079 .31176 L
s
P
p
0 .4 1 r
.018 w
.40006 .28101 m
.42931 .24076 L
s
P
p
0 .4 1 r
.018 w
.40006 .28101 m
.35275 .26564 L
s
P
p
.2 0 1 r
.002 w
.35275 .67493 m
.21079 .62881 L
s
P
p
.2 0 1 r
.002 w
.35275 .67493 m
.21079 .72106 L
s
P
p
.2 0 1 r
.002 w
.35275 .67493 m
.26501 .79569 L
s
P
p
.2 0 1 r
.002 w
.42931 .69981 m
.42931 .84907 L
s
P
p
.2 0 1 r
.002 w
.42931 .69981 m
.51704 .82057 L
s
P
p
.2 0 1 r
.002 w
.42931 .69981 m
.57126 .74593 L
s
P
p
0 .4 1 r
.018 w
.40006 .65956 m
.35275 .67493 L
s
P
p
0 .4 1 r
.018 w
.40006 .65956 m
.42931 .69981 L
s
P
p
.2 0 1 r
.002 w
.66989 .36868 m
.75762 .48944 L
s
P
p
.2 0 1 r
.002 w
.66989 .36868 m
.81184 .41481 L
s
P
p
.2 0 1 r
.002 w
.66989 .36868 m
.81184 .32256 L
s
P
p
.2 0 1 r
.002 w
.62257 .30355 m
.7103 .1828 L
s
P
p
.2 0 1 r
.002 w
.62257 .30355 m
.62257 .15429 L
s
P
p
.2 0 1 r
.002 w
.62257 .30355 m
.53484 .1828 L
s
P
p
0 .4 1 r
.018 w
.62257 .35331 m
.66989 .36868 L
s
P
p
0 .4 1 r
.018 w
.62257 .35331 m
.62257 .30355 L
s
P
p
.2 0 1 r
.002 w
.2333 .43003 m
.2333 .28077 L
s
P
p
.2 0 1 r
.002 w
.2333 .43003 m
.14557 .30928 L
s
P
p
.2 0 1 r
.002 w
.2333 .43003 m
.09135 .38391 L
s
P
p
.2 0 1 r
.002 w
.2333 .51054 m
.09135 .55666 L
s
P
p
.2 0 1 r
.002 w
.2333 .51054 m
.14557 .63129 L
s
P
p
.2 0 1 r
.002 w
.2333 .51054 m
.2333 .6598 L
s
P
p
0 .4 1 r
.018 w
.26255 .47029 m
.2333 .43003 L
s
P
p
0 .4 1 r
.018 w
.26255 .47029 m
.2333 .51054 L
s
P
p
.2 0 1 r
.016 w
.46156 .47029 m
.62257 .58726 L
s
P
p
.2 0 1 r
.016 w
.46156 .47029 m
.40006 .28101 L
s
P
p
.2 0 1 r
.016 w
.46156 .47029 m
.40006 .65956 L
s
P
p
.2 0 1 r
.016 w
.46156 .47029 m
.62257 .35331 L
s
P
p
.2 0 1 r
.016 w
.46156 .47029 m
.26255 .47029 L
s
P
p
.2 0 1 r
.002 w
.7667 .51054 m
.7667 .6598 L
s
P
p
.2 0 1 r
.002 w
.7667 .51054 m
.85443 .63129 L
s
P
p
.2 0 1 r
.002 w
.7667 .51054 m
.90865 .55666 L
s
P
p
.2 0 1 r
.002 w
.7667 .43003 m
.90865 .38391 L
s
P
p
.2 0 1 r
.002 w
.7667 .43003 m
.85443 .30928 L
s
P
p
.2 0 1 r
.002 w
.7667 .43003 m
.7667 .28077 L
s
P
p
0 .4 1 r
.018 w
.73745 .47029 m
.7667 .51054 L
s
P
p
0 .4 1 r
.018 w
.73745 .47029 m
.7667 .43003 L
s
P
p
.2 0 1 r
.002 w
.37743 .30355 m
.46516 .1828 L
s
P
p
.2 0 1 r
.002 w
.37743 .30355 m
.37743 .15429 L
s
P
p
.2 0 1 r
.002 w
.37743 .30355 m
.2897 .1828 L
s
P
p
.2 0 1 r
.002 w
.33011 .36868 m
.18816 .32256 L
s
P
p
.2 0 1 r
.002 w
.33011 .36868 m
.18816 .41481 L
s
P
p
.2 0 1 r
.002 w
.33011 .36868 m
.24238 .48944 L
s
P
p
0 .4 1 r
.018 w
.37743 .35331 m
.37743 .30355 L
s
P
p
0 .4 1 r
.018 w
.37743 .35331 m
.33011 .36868 L
s
P
p
.2 0 1 r
.002 w
.57069 .69981 m
.42874 .74593 L
s
P
p
.2 0 1 r
.002 w
.57069 .69981 m
.48296 .82057 L
s
P
p
.2 0 1 r
.002 w
.57069 .69981 m
.57069 .84907 L
s
P
p
.2 0 1 r
.002 w
.64725 .67493 m
.73499 .79569 L
s
P
p
.2 0 1 r
.002 w
.64725 .67493 m
.78921 .72106 L
s
P
p
.2 0 1 r
.002 w
.64725 .67493 m
.78921 .62881 L
s
P
p
0 .4 1 r
.018 w
.59994 .65956 m
.57069 .69981 L
s
P
p
0 .4 1 r
.018 w
.59994 .65956 m
.64725 .67493 L
s
P
p
.2 0 1 r
.002 w
.64725 .26564 m
.78921 .31176 L
s
P
p
.2 0 1 r
.002 w
.64725 .26564 m
.78921 .21951 L
s
P
p
.2 0 1 r
.002 w
.64725 .26564 m
.73499 .14488 L
s
P
p
.2 0 1 r
.002 w
.57069 .24076 m
.57069 .0915 L
s
P
p
.2 0 1 r
.002 w
.57069 .24076 m
.48296 .12001 L
s
P
p
.2 0 1 r
.002 w
.57069 .24076 m
.42874 .19464 L
s
P
p
0 .4 1 r
.018 w
.59994 .28101 m
.64725 .26564 L
s
P
p
0 .4 1 r
.018 w
.59994 .28101 m
.57069 .24076 L
s
P
p
.2 0 1 r
.002 w
.33011 .57189 m
.24238 .45113 L
s
P
p
.2 0 1 r
.002 w
.33011 .57189 m
.18816 .52576 L
s
P
p
.2 0 1 r
.002 w
.33011 .57189 m
.18816 .61801 L
s
P
p
.2 0 1 r
.002 w
.37743 .63702 m
.2897 .75777 L
s
P
p
.2 0 1 r
.002 w
.37743 .63702 m
.37743 .78628 L
s
P
p
.2 0 1 r
.002 w
.37743 .63702 m
.46516 .75777 L
s
P
p
0 .4 1 r
.018 w
.37743 .58726 m
.33011 .57189 L
s
P
p
0 .4 1 r
.018 w
.37743 .58726 m
.37743 .63702 L
s
P
p
.2 0 1 r
.016 w
.53844 .47029 m
.73745 .47029 L
s
P
p
.2 0 1 r
.016 w
.53844 .47029 m
.37743 .35331 L
s
P
p
.2 0 1 r
.016 w
.53844 .47029 m
.59994 .65956 L
s
P
p
.2 0 1 r
.016 w
.53844 .47029 m
.59994 .28101 L
s
P
p
.2 0 1 r
.016 w
.53844 .47029 m
.37743 .58726 L
s
P
p
.2 0 1 r
.002 w
.80895 .3235 m
.89669 .44425 L
s
P
p
.2 0 1 r
.002 w
.80895 .3235 m
.95091 .36962 L
s
P
p
.2 0 1 r
.002 w
.80895 .3235 m
.95091 .27737 L
s
P
p
.2 0 1 r
.002 w
.76163 .25837 m
.84937 .13761 L
s
P
p
.2 0 1 r
.002 w
.76163 .25837 m
.76163 .10911 L
s
P
p
.2 0 1 r
.002 w
.76163 .25837 m
.6739 .13761 L
s
P
p
0 .4 1 r
.018 w
.76163 .30812 m
.80895 .3235 L
s
P
p
0 .4 1 r
.018 w
.76163 .30812 m
.76163 .25837 L
s
P
p
.2 0 1 r
.002 w
.37237 .38485 m
.37237 .23559 L
s
P
p
.2 0 1 r
.002 w
.37237 .38485 m
.28464 .26409 L
s
P
p
.2 0 1 r
.002 w
.37237 .38485 m
.23041 .33872 L
s
P
p
.2 0 1 r
.002 w
.37237 .46535 m
.23041 .51148 L
s
P
p
.2 0 1 r
.002 w
.37237 .46535 m
.28464 .58611 L
s
P
p
.2 0 1 r
.002 w
.37237 .46535 m
.37237 .61461 L
s
P
p
0 .4 1 r
.018 w
.40161 .4251 m
.37237 .38485 L
s
P
p
0 .4 1 r
.018 w
.40161 .4251 m
.37237 .46535 L
s
P
p
.2 0 1 r
.002 w
.76163 .59183 m
.6739 .71259 L
s
P
p
.2 0 1 r
.002 w
.76163 .59183 m
.76163 .74109 L
s
P
p
.2 0 1 r
.002 w
.76163 .59183 m
.84937 .71259 L
s
P
p
.2 0 1 r
.002 w
.80895 .5267 m
.95091 .57283 L
s
P
p
.2 0 1 r
.002 w
.80895 .5267 m
.95091 .48058 L
s
P
p
.2 0 1 r
.002 w
.80895 .5267 m
.89669 .40595 L
s
P
p
0 .4 1 r
.018 w
.76163 .54208 m
.76163 .59183 L
s
P
p
0 .4 1 r
.018 w
.76163 .54208 m
.80895 .5267 L
s
P
p
.2 0 1 r
.002 w
.56837 .19558 m
.71033 .14945 L
s
P
p
.2 0 1 r
.002 w
.56837 .19558 m
.65611 .07482 L
s
P
p
.2 0 1 r
.002 w
.56837 .19558 m
.56837 .04631 L
s
P
p
.2 0 1 r
.002 w
.49181 .22045 m
.40408 .0997 L
s
P
p
.2 0 1 r
.002 w
.49181 .22045 m
.34986 .17433 L
s
P
p
.2 0 1 r
.002 w
.49181 .22045 m
.34986 .26658 L
s
P
p
0 .4 1 r
.018 w
.53913 .23583 m
.56837 .19558 L
s
P
p
0 .4 1 r
.018 w
.53913 .23583 m
.49181 .22045 L
s
P
p
.2 0 1 r
.002 w
.49181 .62975 m
.34986 .58362 L
s
P
p
.2 0 1 r
.002 w
.49181 .62975 m
.34986 .67587 L
s
P
p
.2 0 1 r
.002 w
.49181 .62975 m
.40408 .7505 L
s
P
p
.2 0 1 r
.002 w
.56837 .65463 m
.56837 .80389 L
s
P
p
.2 0 1 r
.002 w
.56837 .65463 m
.65611 .77538 L
s
P
p
.2 0 1 r
.002 w
.56837 .65463 m
.71033 .70075 L
s
P
p
0 .4 1 r
.018 w
.53913 .61437 m
.49181 .62975 L
s
P
p
0 .4 1 r
.018 w
.53913 .61437 m
.56837 .65463 L
s
P
p
.2 0 1 r
.016 w
.60063 .4251 m
.76163 .30812 L
s
P
p
.2 0 1 r
.016 w
.60063 .4251 m
.40161 .4251 L
s
P
p
.2 0 1 r
.016 w
.60063 .4251 m
.76163 .54208 L
s
P
p
.2 0 1 r
.016 w
.60063 .4251 m
.53913 .23583 L
s
P
p
.2 0 1 r
.016 w
.60063 .4251 m
.53913 .61437 L
s
P
p
1 .6 0 r
.016 w
.5 .35199 m
.39937 .4251 L
s
P
p
1 .6 0 r
.016 w
.5 .35199 m
.46156 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .35199 m
.53844 .47029 L
s
P
p
1 .6 0 r
.016 w
.5 .35199 m
.60063 .4251 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.062395 0.952381 [
[ 0 0 0 0 ]
[ 1 .82759 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .82759 L
0 .82759 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29602 .56131 m
.1525 .51468 L
s
P
p
.2 0 1 r
.002 w
.29602 .56131 m
.1525 .60795 L
s
P
p
.2 0 1 r
.002 w
.29602 .56131 m
.20732 .6834 L
s
P
p
.2 0 1 r
.002 w
.37342 .58646 m
.37342 .73737 L
s
P
p
.2 0 1 r
.002 w
.37342 .58646 m
.46212 .70855 L
s
P
p
.2 0 1 r
.002 w
.37342 .58646 m
.51694 .6331 L
s
P
p
0 .4 1 r
.018 w
.34386 .54577 m
.29602 .56131 L
s
P
p
0 .4 1 r
.018 w
.34386 .54577 m
.37342 .58646 L
s
P
p
.2 0 1 r
.002 w
.55205 .2359 m
.67413 .3246 L
s
P
p
.2 0 1 r
.002 w
.55205 .2359 m
.70295 .2359 L
s
P
p
.2 0 1 r
.002 w
.55205 .2359 m
.67413 .1472 L
s
P
p
.2 0 1 r
.002 w
.4862 .18806 m
.53283 .04454 L
s
P
p
.2 0 1 r
.002 w
.4862 .18806 m
.43957 .04454 L
s
P
p
.2 0 1 r
.002 w
.4862 .18806 m
.36412 .09936 L
s
P
p
0 .4 1 r
.018 w
.50175 .2359 m
.55205 .2359 L
s
P
p
0 .4 1 r
.018 w
.50175 .2359 m
.4862 .18806 L
s
P
p
.2 0 1 r
.002 w
.20799 .46627 m
.11929 .34418 L
s
P
p
.2 0 1 r
.002 w
.20799 .46627 m
.06447 .41964 L
s
P
p
.2 0 1 r
.002 w
.20799 .46627 m
.06447 .5129 L
s
P
p
.2 0 1 r
.002 w
.25583 .53211 m
.16713 .6542 L
s
P
p
.2 0 1 r
.002 w
.25583 .53211 m
.25583 .68302 L
s
P
p
.2 0 1 r
.002 w
.25583 .53211 m
.34453 .6542 L
s
P
p
0 .4 1 r
.018 w
.25583 .48181 m
.20799 .46627 L
s
P
p
0 .4 1 r
.018 w
.25583 .48181 m
.25583 .53211 L
s
P
p
.2 0 1 r
.002 w
.6064 .35349 m
.65303 .49701 L
s
P
p
.2 0 1 r
.002 w
.6064 .35349 m
.72848 .44219 L
s
P
p
.2 0 1 r
.002 w
.6064 .35349 m
.7573 .35349 L
s
P
p
.2 0 1 r
.002 w
.58125 .27609 m
.70333 .18739 L
s
P
p
.2 0 1 r
.002 w
.58125 .27609 m
.62788 .13257 L
s
P
p
.2 0 1 r
.002 w
.58125 .27609 m
.53461 .13257 L
s
P
p
0 .4 1 r
.018 w
.5657 .32393 m
.6064 .35349 L
s
P
p
0 .4 1 r
.018 w
.5657 .32393 m
.58125 .27609 L
s
P
p
.2 0 1 r
.002 w
.19264 .33764 m
.19264 .18673 L
s
P
p
.2 0 1 r
.002 w
.19264 .33764 m
.10394 .21555 L
s
P
p
.2 0 1 r
.002 w
.19264 .33764 m
.04912 .291 L
s
P
p
.2 0 1 r
.002 w
.19264 .41902 m
.04912 .46566 L
s
P
p
.2 0 1 r
.002 w
.19264 .41902 m
.10394 .54111 L
s
P
p
.2 0 1 r
.002 w
.19264 .41902 m
.19264 .56993 L
s
P
p
0 .4 1 r
.018 w
.22221 .37833 m
.19264 .33764 L
s
P
p
0 .4 1 r
.018 w
.22221 .37833 m
.19264 .41902 L
s
P
p
.2 0 1 r
.016 w
.39826 .37833 m
.34386 .54577 L
s
P
p
.2 0 1 r
.016 w
.39826 .37833 m
.50175 .2359 L
s
P
p
.2 0 1 r
.016 w
.39826 .37833 m
.25583 .48181 L
s
P
p
.2 0 1 r
.016 w
.39826 .37833 m
.5657 .32393 L
s
P
p
.2 0 1 r
.016 w
.39826 .37833 m
.22221 .37833 L
s
P
p
.2 0 1 r
.002 w
.48598 .63215 m
.34246 .67878 L
s
P
p
.2 0 1 r
.002 w
.48598 .63215 m
.39728 .75423 L
s
P
p
.2 0 1 r
.002 w
.48598 .63215 m
.48598 .78305 L
s
P
p
.2 0 1 r
.002 w
.56338 .607 m
.65208 .72908 L
s
P
p
.2 0 1 r
.002 w
.56338 .607 m
.7069 .65363 L
s
P
p
.2 0 1 r
.002 w
.56338 .607 m
.7069 .56036 L
s
P
p
0 .4 1 r
.018 w
.51554 .59145 m
.48598 .63215 L
s
P
p
0 .4 1 r
.018 w
.51554 .59145 m
.56338 .607 L
s
P
p
.2 0 1 r
.002 w
.50183 .21839 m
.65274 .21839 L
s
P
p
.2 0 1 r
.002 w
.50183 .21839 m
.62392 .12969 L
s
P
p
.2 0 1 r
.002 w
.50183 .21839 m
.54847 .07487 L
s
P
p
.2 0 1 r
.002 w
.42044 .21839 m
.37381 .07487 L
s
P
p
.2 0 1 r
.002 w
.42044 .21839 m
.29836 .12969 L
s
P
p
.2 0 1 r
.002 w
.42044 .21839 m
.26954 .21839 L
s
P
p
0 .4 1 r
.018 w
.46114 .24796 m
.50183 .21839 L
s
P
p
0 .4 1 r
.018 w
.46114 .24796 m
.42044 .21839 L
s
P
p
.2 0 1 r
.002 w
.3589 .607 m
.21538 .56036 L
s
P
p
.2 0 1 r
.002 w
.3589 .607 m
.21538 .65363 L
s
P
p
.2 0 1 r
.002 w
.3589 .607 m
.2702 .72908 L
s
P
p
.2 0 1 r
.002 w
.4363 .63215 m
.4363 .78305 L
s
P
p
.2 0 1 r
.002 w
.4363 .63215 m
.525 .75423 L
s
P
p
.2 0 1 r
.002 w
.4363 .63215 m
.57982 .67878 L
s
P
p
0 .4 1 r
.018 w
.40674 .59145 m
.3589 .607 L
s
P
p
0 .4 1 r
.018 w
.40674 .59145 m
.4363 .63215 L
s
P
p
.2 0 1 r
.002 w
.61492 .28158 m
.73701 .37028 L
s
P
p
.2 0 1 r
.002 w
.61492 .28158 m
.76583 .28158 L
s
P
p
.2 0 1 r
.002 w
.61492 .28158 m
.73701 .19288 L
s
P
p
.2 0 1 r
.002 w
.54908 .23374 m
.59571 .09022 L
s
P
p
.2 0 1 r
.002 w
.54908 .23374 m
.50245 .09022 L
s
P
p
.2 0 1 r
.002 w
.54908 .23374 m
.42699 .14504 L
s
P
p
0 .4 1 r
.018 w
.56462 .28158 m
.61492 .28158 L
s
P
p
0 .4 1 r
.018 w
.56462 .28158 m
.54908 .23374 L
s
P
p
.2 0 1 r
.002 w
.27087 .51195 m
.18217 .38987 L
s
P
p
.2 0 1 r
.002 w
.27087 .51195 m
.12735 .46532 L
s
P
p
.2 0 1 r
.002 w
.27087 .51195 m
.12735 .55858 L
s
P
p
.2 0 1 r
.002 w
.31871 .5778 m
.23001 .69988 L
s
P
p
.2 0 1 r
.002 w
.31871 .5778 m
.31871 .7287 L
s
P
p
.2 0 1 r
.002 w
.31871 .5778 m
.40741 .69988 L
s
P
p
0 .4 1 r
.018 w
.31871 .5275 m
.27087 .51195 L
s
P
p
0 .4 1 r
.018 w
.31871 .5275 m
.31871 .5778 L
s
P
p
.2 0 1 r
.016 w
.46114 .42401 m
.51554 .59145 L
s
P
p
.2 0 1 r
.016 w
.46114 .42401 m
.46114 .24796 L
s
P
p
.2 0 1 r
.016 w
.46114 .42401 m
.40674 .59145 L
s
P
p
.2 0 1 r
.016 w
.46114 .42401 m
.56462 .28158 L
s
P
p
.2 0 1 r
.016 w
.46114 .42401 m
.31871 .5275 L
s
P
p
.2 0 1 r
.002 w
.68129 .5778 m
.59259 .69988 L
s
P
p
.2 0 1 r
.002 w
.68129 .5778 m
.68129 .7287 L
s
P
p
.2 0 1 r
.002 w
.68129 .5778 m
.76999 .69988 L
s
P
p
.2 0 1 r
.002 w
.72913 .51195 m
.87265 .55858 L
s
P
p
.2 0 1 r
.002 w
.72913 .51195 m
.87265 .46532 L
s
P
p
.2 0 1 r
.002 w
.72913 .51195 m
.81783 .38987 L
s
P
p
0 .4 1 r
.018 w
.68129 .5275 m
.68129 .5778 L
s
P
p
0 .4 1 r
.018 w
.68129 .5275 m
.72913 .51195 L
s
P
p
.2 0 1 r
.002 w
.45092 .23374 m
.57301 .14504 L
s
P
p
.2 0 1 r
.002 w
.45092 .23374 m
.49755 .09022 L
s
P
p
.2 0 1 r
.002 w
.45092 .23374 m
.40429 .09022 L
s
P
p
.2 0 1 r
.002 w
.38508 .28158 m
.26299 .19288 L
s
P
p
.2 0 1 r
.002 w
.38508 .28158 m
.23417 .28158 L
s
P
p
.2 0 1 r
.002 w
.38508 .28158 m
.26299 .37028 L
s
P
p
0 .4 1 r
.018 w
.43538 .28158 m
.45092 .23374 L
s
P
p
0 .4 1 r
.018 w
.43538 .28158 m
.38508 .28158 L
s
P
p
.2 0 1 r
.002 w
.5637 .63215 m
.42018 .67878 L
s
P
p
.2 0 1 r
.002 w
.5637 .63215 m
.475 .75423 L
s
P
p
.2 0 1 r
.002 w
.5637 .63215 m
.5637 .78305 L
s
P
p
.2 0 1 r
.002 w
.6411 .607 m
.7298 .72908 L
s
P
p
.2 0 1 r
.002 w
.6411 .607 m
.78462 .65363 L
s
P
p
.2 0 1 r
.002 w
.6411 .607 m
.78462 .56036 L
s
P
p
0 .4 1 r
.018 w
.59326 .59145 m
.5637 .63215 L
s
P
p
0 .4 1 r
.018 w
.59326 .59145 m
.6411 .607 L
s
P
p
.2 0 1 r
.002 w
.57956 .21839 m
.73046 .21839 L
s
P
p
.2 0 1 r
.002 w
.57956 .21839 m
.70164 .12969 L
s
P
p
.2 0 1 r
.002 w
.57956 .21839 m
.62619 .07487 L
s
P
p
.2 0 1 r
.002 w
.49817 .21839 m
.45153 .07487 L
s
P
p
.2 0 1 r
.002 w
.49817 .21839 m
.37608 .12969 L
s
P
p
.2 0 1 r
.002 w
.49817 .21839 m
.34726 .21839 L
s
P
p
0 .4 1 r
.018 w
.53886 .24796 m
.57956 .21839 L
s
P
p
0 .4 1 r
.018 w
.53886 .24796 m
.49817 .21839 L
s
P
p
.2 0 1 r
.002 w
.43662 .607 m
.2931 .56036 L
s
P
p
.2 0 1 r
.002 w
.43662 .607 m
.2931 .65363 L
s
P
p
.2 0 1 r
.002 w
.43662 .607 m
.34792 .72908 L
s
P
p
.2 0 1 r
.002 w
.51402 .63215 m
.51402 .78305 L
s
P
p
.2 0 1 r
.002 w
.51402 .63215 m
.60272 .75423 L
s
P
p
.2 0 1 r
.002 w
.51402 .63215 m
.65754 .67878 L
s
P
p
0 .4 1 r
.018 w
.48446 .59145 m
.43662 .607 L
s
P
p
0 .4 1 r
.018 w
.48446 .59145 m
.51402 .63215 L
s
P
p
.2 0 1 r
.016 w
.53886 .42401 m
.68129 .5275 L
s
P
p
.2 0 1 r
.016 w
.53886 .42401 m
.43538 .28158 L
s
P
p
.2 0 1 r
.016 w
.53886 .42401 m
.59326 .59145 L
s
P
p
.2 0 1 r
.016 w
.53886 .42401 m
.53886 .24796 L
s
P
p
.2 0 1 r
.016 w
.53886 .42401 m
.48446 .59145 L
s
P
p
.2 0 1 r
.002 w
.80736 .41902 m
.80736 .56993 L
s
P
p
.2 0 1 r
.002 w
.80736 .41902 m
.89606 .54111 L
s
P
p
.2 0 1 r
.002 w
.80736 .41902 m
.95088 .46566 L
s
P
p
.2 0 1 r
.002 w
.80736 .33764 m
.95088 .291 L
s
P
p
.2 0 1 r
.002 w
.80736 .33764 m
.89606 .21555 L
s
P
p
.2 0 1 r
.002 w
.80736 .33764 m
.80736 .18673 L
s
P
p
0 .4 1 r
.018 w
.77779 .37833 m
.80736 .41902 L
s
P
p
0 .4 1 r
.018 w
.77779 .37833 m
.80736 .33764 L
s
P
p
.2 0 1 r
.002 w
.41875 .27609 m
.46539 .13257 L
s
P
p
.2 0 1 r
.002 w
.41875 .27609 m
.37212 .13257 L
s
P
p
.2 0 1 r
.002 w
.41875 .27609 m
.29667 .18739 L
s
P
p
.2 0 1 r
.002 w
.3936 .35349 m
.2427 .35349 L
s
P
p
.2 0 1 r
.002 w
.3936 .35349 m
.27152 .44219 L
s
P
p
.2 0 1 r
.002 w
.3936 .35349 m
.34697 .49701 L
s
P
p
0 .4 1 r
.018 w
.4343 .32393 m
.41875 .27609 L
s
P
p
0 .4 1 r
.018 w
.4343 .32393 m
.3936 .35349 L
s
P
p
.2 0 1 r
.002 w
.74417 .53211 m
.65547 .6542 L
s
P
p
.2 0 1 r
.002 w
.74417 .53211 m
.74417 .68302 L
s
P
p
.2 0 1 r
.002 w
.74417 .53211 m
.83287 .6542 L
s
P
p
.2 0 1 r
.002 w
.79201 .46627 m
.93553 .5129 L
s
P
p
.2 0 1 r
.002 w
.79201 .46627 m
.93553 .41964 L
s
P
p
.2 0 1 r
.002 w
.79201 .46627 m
.88071 .34418 L
s
P
p
0 .4 1 r
.018 w
.74417 .48181 m
.74417 .53211 L
s
P
p
0 .4 1 r
.018 w
.74417 .48181 m
.79201 .46627 L
s
P
p
.2 0 1 r
.002 w
.5138 .18806 m
.63588 .09936 L
s
P
p
.2 0 1 r
.002 w
.5138 .18806 m
.56043 .04454 L
s
P
p
.2 0 1 r
.002 w
.5138 .18806 m
.46717 .04454 L
s
P
p
.2 0 1 r
.002 w
.44795 .2359 m
.32587 .1472 L
s
P
p
.2 0 1 r
.002 w
.44795 .2359 m
.29705 .2359 L
s
P
p
.2 0 1 r
.002 w
.44795 .2359 m
.32587 .3246 L
s
P
p
0 .4 1 r
.018 w
.49825 .2359 m
.5138 .18806 L
s
P
p
0 .4 1 r
.018 w
.49825 .2359 m
.44795 .2359 L
s
P
p
.2 0 1 r
.002 w
.62658 .58646 m
.48306 .6331 L
s
P
p
.2 0 1 r
.002 w
.62658 .58646 m
.53788 .70855 L
s
P
p
.2 0 1 r
.002 w
.62658 .58646 m
.62658 .73737 L
s
P
p
.2 0 1 r
.002 w
.70398 .56131 m
.79268 .6834 L
s
P
p
.2 0 1 r
.002 w
.70398 .56131 m
.8475 .60795 L
s
P
p
.2 0 1 r
.002 w
.70398 .56131 m
.8475 .51468 L
s
P
p
0 .4 1 r
.018 w
.65614 .54577 m
.62658 .58646 L
s
P
p
0 .4 1 r
.018 w
.65614 .54577 m
.70398 .56131 L
s
P
p
.2 0 1 r
.016 w
.60174 .37833 m
.77779 .37833 L
s
P
p
.2 0 1 r
.016 w
.60174 .37833 m
.4343 .32393 L
s
P
p
.2 0 1 r
.016 w
.60174 .37833 m
.74417 .48181 L
s
P
p
.2 0 1 r
.016 w
.60174 .37833 m
.49825 .2359 L
s
P
p
.2 0 1 r
.016 w
.60174 .37833 m
.65614 .54577 L
s
P
p
1 .6 0 r
.016 w
.5 .30441 m
.39826 .37833 L
s
P
p
1 .6 0 r
.016 w
.5 .30441 m
.46114 .42401 L
s
P
p
1 .6 0 r
.016 w
.5 .30441 m
.53886 .42401 L
s
P
p
1 .6 0 r
.016 w
.5 .30441 m
.60174 .37833 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0608586 0.952381 [
[ 0 0 0 0 ]
[ 1 .83066 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .83066 L
0 .83066 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .53189 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .62025 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.21533 .69174 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.37271 .74288 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.45675 .71557 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.50869 .64408 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.29937 .57607 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.37271 .5999 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .30985 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.7063 .22581 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .14177 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.54512 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.45675 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.38526 .09644 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.56332 .22581 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.50093 .18048 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.12002 .36169 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .43318 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .52154 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.16534 .65542 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.24938 .68273 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.33342 .65542 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.20405 .47736 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.24938 .53975 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.66765 .48512 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.73914 .43318 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.76645 .34914 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.71531 .19176 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.64382 .13982 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.55546 .13982 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.62347 .34914 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.59964 .2758 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.18496 .1985 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.10092 .22581 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.04898 .2973 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.04898 .46278 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.10092 .53426 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.18496 .56157 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .34148 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .41859 L
s
P
p
.2 0 1 r
.014 w
.40361 .38004 m
.3447 .56134 L
s
P
p
.2 0 1 r
.014 w
.40361 .38004 m
.51566 .22581 L
s
P
p
.2 0 1 r
.014 w
.40361 .38004 m
.24938 .49209 L
s
P
p
.2 0 1 r
.014 w
.40361 .38004 m
.58491 .32113 L
s
P
p
.2 0 1 r
.014 w
.40361 .38004 m
.21297 .38004 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.3581 .68736 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.41004 .75885 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.49408 .78616 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.65146 .73502 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .66353 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .57517 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.49408 .64318 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.56742 .61935 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.64471 .20467 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.61741 .12063 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.54592 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.38044 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.30895 .12063 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.28165 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.50174 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.42462 .20467 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .57517 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .66353 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.27491 .73502 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.43229 .78616 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.51632 .75885 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.56826 .68736 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.35895 .61935 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.43229 .64318 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .35313 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.76587 .26909 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .18505 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.60469 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.51632 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.44484 .13973 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.62289 .26909 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.56051 .22377 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.17959 .40497 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .47646 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .56483 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.22492 .6987 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.30895 .72601 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.39299 .6987 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.26363 .52065 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.30895 .58303 L
s
P
p
.2 0 1 r
.014 w
.46318 .42332 m
.52209 .60462 L
s
P
p
.2 0 1 r
.014 w
.46318 .42332 m
.46318 .23269 L
s
P
p
.2 0 1 r
.014 w
.46318 .42332 m
.40427 .60462 L
s
P
p
.2 0 1 r
.014 w
.46318 .42332 m
.57523 .26909 L
s
P
p
.2 0 1 r
.014 w
.46318 .42332 m
.30895 .53537 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.60701 .6987 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.69105 .72601 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.77508 .6987 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .56483 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .47646 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.82041 .40497 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.69105 .58303 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.73637 .52065 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.55516 .13973 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.48368 .08779 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.39531 .08779 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .18505 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.23413 .26909 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .35313 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.43949 .22377 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.37711 .26909 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.43174 .68736 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.48368 .75885 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.56771 .78616 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.72509 .73502 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .66353 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .57517 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.56771 .64318 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.64105 .61935 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.71835 .20467 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.69105 .12063 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.61956 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.45408 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.38259 .12063 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.35529 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.57538 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.49826 .20467 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .57517 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .66353 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.34854 .73502 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.50592 .78616 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.58996 .75885 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.6419 .68736 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.43258 .61935 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.50592 .64318 L
s
P
p
.2 0 1 r
.014 w
.53682 .42332 m
.69105 .53537 L
s
P
p
.2 0 1 r
.014 w
.53682 .42332 m
.42477 .26909 L
s
P
p
.2 0 1 r
.014 w
.53682 .42332 m
.59573 .60462 L
s
P
p
.2 0 1 r
.014 w
.53682 .42332 m
.53682 .23269 L
s
P
p
.2 0 1 r
.014 w
.53682 .42332 m
.47791 .60462 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.81504 .56157 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.89908 .53426 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.95102 .46278 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.95102 .2973 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.89908 .22581 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.81504 .1985 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .41859 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .34148 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.44454 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.35618 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.28469 .19176 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.23355 .34914 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.26086 .43318 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.33235 .48512 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.40036 .2758 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.37653 .34914 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.66658 .65542 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.75062 .68273 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.83466 .65542 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .52154 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .43318 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.87998 .36169 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.75062 .53975 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.79595 .47736 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.61474 .09644 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.54325 .04451 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.45488 .04451 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .14177 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.2937 .22581 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .30985 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.49907 .18048 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.43668 .22581 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.49131 .64408 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.54325 .71557 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.62729 .74288 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.78467 .69174 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .62025 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .53189 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.62729 .5999 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.70063 .57607 L
s
P
p
.2 0 1 r
.014 w
.59639 .38004 m
.78703 .38004 L
s
P
p
.2 0 1 r
.014 w
.59639 .38004 m
.41509 .32113 L
s
P
p
.2 0 1 r
.014 w
.59639 .38004 m
.75062 .49209 L
s
P
p
.2 0 1 r
.014 w
.59639 .38004 m
.48434 .22581 L
s
P
p
.2 0 1 r
.014 w
.59639 .38004 m
.6553 .56134 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.40361 .38004 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.46318 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.53682 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.59639 .38004 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0608586 0.952381 [
[ 0 0 0 0 ]
[ 1 .83066 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .83066 L
0 .83066 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .53189 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .62025 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.21533 .69174 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.37271 .74288 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.45675 .71557 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.50869 .64408 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.29937 .57607 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.37271 .5999 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .30985 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.7063 .22581 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .14177 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.54512 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.45675 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.38526 .09644 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.56332 .22581 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.50093 .18048 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.12002 .36169 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .43318 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .52154 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.16534 .65542 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.24938 .68273 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.33342 .65542 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.20405 .47736 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.24938 .53975 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.66765 .48512 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.73914 .43318 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.76645 .34914 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.71531 .19176 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.64382 .13982 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.55546 .13982 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.62347 .34914 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.59964 .2758 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.18496 .1985 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.10092 .22581 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.04898 .2973 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.04898 .46278 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.10092 .53426 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.18496 .56157 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .34148 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .41859 L
s
P
p
0 .4 1 r
.016 w
.40361 .38004 m
.3447 .56134 L
s
P
p
0 .4 1 r
.016 w
.40361 .38004 m
.51566 .22581 L
s
P
p
0 .4 1 r
.016 w
.40361 .38004 m
.24938 .49209 L
s
P
p
0 .4 1 r
.016 w
.40361 .38004 m
.58491 .32113 L
s
P
p
0 .4 1 r
.016 w
.40361 .38004 m
.21297 .38004 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.3581 .68736 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.41004 .75885 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.49408 .78616 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.65146 .73502 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .66353 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .57517 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.49408 .64318 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.56742 .61935 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.64471 .20467 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.61741 .12063 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.54592 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.38044 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.30895 .12063 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.28165 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.50174 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.42462 .20467 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .57517 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .66353 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.27491 .73502 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.43229 .78616 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.51632 .75885 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.56826 .68736 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.35895 .61935 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.43229 .64318 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .35313 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.76587 .26909 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .18505 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.60469 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.51632 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.44484 .13973 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.62289 .26909 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.56051 .22377 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.17959 .40497 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .47646 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .56483 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.22492 .6987 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.30895 .72601 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.39299 .6987 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.26363 .52065 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.30895 .58303 L
s
P
p
0 .4 1 r
.016 w
.46318 .42332 m
.52209 .60462 L
s
P
p
0 .4 1 r
.016 w
.46318 .42332 m
.46318 .23269 L
s
P
p
0 .4 1 r
.016 w
.46318 .42332 m
.40427 .60462 L
s
P
p
0 .4 1 r
.016 w
.46318 .42332 m
.57523 .26909 L
s
P
p
0 .4 1 r
.016 w
.46318 .42332 m
.30895 .53537 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.60701 .6987 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.69105 .72601 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.77508 .6987 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .56483 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .47646 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.82041 .40497 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.69105 .58303 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.73637 .52065 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.55516 .13973 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.48368 .08779 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.39531 .08779 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .18505 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.23413 .26909 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .35313 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.43949 .22377 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.37711 .26909 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.43174 .68736 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.48368 .75885 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.56771 .78616 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.72509 .73502 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .66353 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .57517 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.56771 .64318 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.64105 .61935 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.71835 .20467 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.69105 .12063 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.61956 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.45408 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.38259 .12063 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.35529 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.57538 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.49826 .20467 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .57517 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .66353 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.34854 .73502 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.50592 .78616 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.58996 .75885 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.6419 .68736 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.43258 .61935 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.50592 .64318 L
s
P
p
0 .4 1 r
.016 w
.53682 .42332 m
.69105 .53537 L
s
P
p
0 .4 1 r
.016 w
.53682 .42332 m
.42477 .26909 L
s
P
p
0 .4 1 r
.016 w
.53682 .42332 m
.59573 .60462 L
s
P
p
0 .4 1 r
.016 w
.53682 .42332 m
.53682 .23269 L
s
P
p
0 .4 1 r
.016 w
.53682 .42332 m
.47791 .60462 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.81504 .56157 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.89908 .53426 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.95102 .46278 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.95102 .2973 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.89908 .22581 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.81504 .1985 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .41859 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .34148 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.44454 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.35618 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.28469 .19176 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.23355 .34914 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.26086 .43318 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.33235 .48512 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.40036 .2758 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.37653 .34914 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.66658 .65542 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.75062 .68273 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.83466 .65542 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .52154 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .43318 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.87998 .36169 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.75062 .53975 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.79595 .47736 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.61474 .09644 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.54325 .04451 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.45488 .04451 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .14177 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.2937 .22581 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .30985 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.49907 .18048 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.43668 .22581 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.49131 .64408 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.54325 .71557 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.62729 .74288 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.78467 .69174 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .62025 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .53189 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.62729 .5999 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.70063 .57607 L
s
P
p
0 .4 1 r
.016 w
.59639 .38004 m
.78703 .38004 L
s
P
p
0 .4 1 r
.016 w
.59639 .38004 m
.41509 .32113 L
s
P
p
0 .4 1 r
.016 w
.59639 .38004 m
.75062 .49209 L
s
P
p
0 .4 1 r
.016 w
.59639 .38004 m
.48434 .22581 L
s
P
p
0 .4 1 r
.016 w
.59639 .38004 m
.6553 .56134 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.40361 .38004 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.46318 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.53682 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.59639 .38004 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.081587 0.952381 [
[ 0 0 0 0 ]
[ 1 .78921 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78921 L
0 .78921 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.27517 .37889 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.20765 .42794 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.18186 .50732 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.23015 .65597 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.29768 .70502 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.38114 .70502 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .61316 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.53337 .53378 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .4544 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.3169 .50732 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.33941 .57659 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.39833 .53378 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.54125 .38833 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.62063 .36254 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.66968 .29501 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.66968 .13872 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.62063 .0712 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.54125 .04541 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.3926 .0937 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .16122 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .24469 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .25328 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .18045 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.47198 .20296 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.29111 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.20765 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.14012 .34618 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.09183 .49483 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.11762 .57421 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.18514 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.34144 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.40896 .57421 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.43475 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.24938 .42556 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.22687 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.2997 .49483 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.50083 .46116 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.5802 .48695 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.65958 .46116 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .33471 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .25125 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.70239 .18373 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.55374 .13543 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.47437 .16122 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.42531 .22875 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.5802 .35191 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.62301 .29298 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.55374 .27048 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.35206 .24035 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.28454 .19129 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.20108 .19129 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .28316 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.04884 .36254 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .44191 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.20108 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.28454 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.35206 .48472 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .31972 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.18388 .36254 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .40535 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.35332 .53378 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.51479 .21687 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.26329 .46837 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.5802 .30689 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.2289 .36254 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .49528 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.34081 .57466 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .65404 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.49304 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.57651 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.64403 .69685 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.69233 .5482 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.66653 .46883 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.59901 .41977 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.47585 .57466 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.53478 .61747 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.55728 .5482 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.58741 .34652 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .279 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .19554 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.5446 .06909 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.46522 .0433 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.38585 .06909 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .19554 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .279 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.34304 .34652 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.50804 .23727 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.46522 .17834 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.42241 .23727 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.33144 .41977 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.26391 .46883 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.23812 .5482 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.28642 .69685 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.35394 .74591 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.4374 .74591 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .65404 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.58964 .57466 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .49528 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.37317 .5482 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.39567 .61747 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.4546 .57466 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.59752 .42921 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.67689 .40342 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.72595 .33589 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.72595 .1796 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.67689 .11208 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.59752 .08629 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.44887 .13458 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .20211 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .28557 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .29416 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .22133 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.52825 .24384 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.34738 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.26391 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.19639 .38706 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.14809 .53571 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.17389 .61509 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.24141 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.3977 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.46522 .61509 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.49102 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.30564 .46644 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.28314 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.35597 .53571 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.52087 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.46522 .22336 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.40958 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.57106 .25775 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.31956 .50925 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.50898 .53571 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.53478 .61509 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.6023 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.75859 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.82611 .61509 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.85191 .53571 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.80361 .38706 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.73609 .33801 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.65262 .33801 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.64403 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.71686 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.69436 .46644 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .28557 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .20211 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.55113 .13458 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.40248 .08629 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.32311 .11208 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.27405 .1796 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.27405 .33589 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.32311 .40342 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.40248 .42921 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.47175 .24384 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .22133 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .29416 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .49528 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.41036 .57466 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .65404 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.5626 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.64606 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.71358 .69685 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.76188 .5482 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.73609 .46883 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.66856 .41977 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.5454 .57466 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.60433 .61747 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.62683 .5482 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.65696 .34652 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .279 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .19554 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.61415 .06909 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.53478 .0433 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.4554 .06909 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .19554 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .279 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.41259 .34652 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.57759 .23727 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.53478 .17834 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.49196 .23727 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.40099 .41977 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.33347 .46883 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.30767 .5482 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.35597 .69685 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.42349 .74591 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.50696 .74591 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .65404 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.65919 .57466 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .49528 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.44272 .5482 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.46522 .61747 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.52415 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.68044 .50925 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.42894 .25775 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.59042 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.53478 .22336 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.47913 .57466 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.64794 .48472 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.71546 .53378 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.79892 .53378 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .44191 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.95116 .36254 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .28316 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.79892 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.71546 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.64794 .24035 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .40535 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.81612 .36254 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .31972 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.57469 .22875 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.52563 .16122 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.44626 .13543 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.29761 .18373 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .25125 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .33471 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.34042 .46116 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.4198 .48695 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.49917 .46116 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.44626 .27048 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.37699 .29298 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.4198 .35191 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.56525 .49483 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.59104 .57421 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.65856 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.81486 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.88238 .57421 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.90817 .49483 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.85988 .34618 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.79235 .29713 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.70889 .29713 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.7003 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.77313 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.75062 .42556 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .24469 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .16122 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.6074 .0937 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.45875 .04541 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.37937 .0712 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.33032 .13872 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.33032 .29501 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.37937 .36254 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.45875 .38833 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.52802 .20296 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .18045 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .25328 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .4544 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.46663 .53378 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .61316 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.61886 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.70232 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.76985 .65597 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.81814 .50732 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.79235 .42794 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.72483 .37889 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.60167 .53378 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.66059 .57659 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.6831 .50732 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.7711 .36254 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.4198 .30689 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.73671 .46837 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.48521 .21687 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.64668 .53378 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.40896 .36254 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.46522 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.53478 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.59104 .36254 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0654114 0.952381 [
[ 0 0 0 0 ]
[ 1 .82156 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .82156 L
0 .82156 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.30689 .57684 m
.16899 .555 L
s
P
p
.2 0 1 r
.002 w
.30689 .57684 m
.18249 .64023 L
s
P
p
.2 0 1 r
.002 w
.30689 .57684 m
.2435 .70124 L
s
P
p
.2 0 1 r
.002 w
.36948 .59718 m
.34764 .73508 L
s
P
p
.2 0 1 r
.002 w
.36948 .59718 m
.43286 .72158 L
s
P
p
.2 0 1 r
.002 w
.36948 .59718 m
.49388 .66057 L
s
P
p
0 .4 1 r
.018 w
.34835 .55572 m
.30689 .57684 L
s
P
p
0 .4 1 r
.018 w
.34835 .55572 m
.36948 .59718 L
s
P
p
.2 0 1 r
.002 w
.56126 .2208 m
.68565 .28418 L
s
P
p
.2 0 1 r
.002 w
.56126 .2208 m
.69915 .19896 L
s
P
p
.2 0 1 r
.002 w
.56126 .2208 m
.65998 .12207 L
s
P
p
.2 0 1 r
.002 w
.50801 .18211 m
.5714 .05772 L
s
P
p
.2 0 1 r
.002 w
.50801 .18211 m
.48617 .04422 L
s
P
p
.2 0 1 r
.002 w
.50801 .18211 m
.40929 .08339 L
s
P
p
0 .4 1 r
.018 w
.51529 .22808 m
.56126 .2208 L
s
P
p
0 .4 1 r
.018 w
.51529 .22808 m
.50801 .18211 L
s
P
p
.2 0 1 r
.002 w
.20931 .48081 m
.11059 .38209 L
s
P
p
.2 0 1 r
.002 w
.20931 .48081 m
.07142 .45897 L
s
P
p
.2 0 1 r
.002 w
.20931 .48081 m
.08491 .5442 L
s
P
p
.2 0 1 r
.002 w
.248 .53406 m
.14927 .63278 L
s
P
p
.2 0 1 r
.002 w
.248 .53406 m
.22616 .67195 L
s
P
p
.2 0 1 r
.002 w
.248 .53406 m
.31138 .65845 L
s
P
p
0 .4 1 r
.018 w
.25528 .48809 m
.20931 .48081 L
s
P
p
0 .4 1 r
.018 w
.25528 .48809 m
.248 .53406 L
s
P
p
.2 0 1 r
.002 w
.62438 .34228 m
.68776 .46668 L
s
P
p
.2 0 1 r
.002 w
.62438 .34228 m
.74878 .40566 L
s
P
p
.2 0 1 r
.002 w
.62438 .34228 m
.76228 .32044 L
s
P
p
.2 0 1 r
.002 w
.60404 .27969 m
.72844 .2163 L
s
P
p
.2 0 1 r
.002 w
.60404 .27969 m
.66743 .15529 L
s
P
p
.2 0 1 r
.002 w
.60404 .27969 m
.5822 .14179 L
s
P
p
0 .4 1 r
.018 w
.58292 .32115 m
.62438 .34228 L
s
P
p
0 .4 1 r
.018 w
.58292 .32115 m
.60404 .27969 L
s
P
p
.2 0 1 r
.002 w
.18682 .34577 m
.16498 .20787 L
s
P
p
.2 0 1 r
.002 w
.18682 .34577 m
.0881 .24705 L
s
P
p
.2 0 1 r
.002 w
.18682 .34577 m
.04892 .32393 L
s
P
p
.2 0 1 r
.002 w
.18682 .41158 m
.04892 .43342 L
s
P
p
.2 0 1 r
.002 w
.18682 .41158 m
.0881 .5103 L
s
P
p
.2 0 1 r
.002 w
.18682 .41158 m
.16498 .54948 L
s
P
p
0 .4 1 r
.018 w
.21972 .37868 m
.18682 .34577 L
s
P
p
0 .4 1 r
.018 w
.21972 .37868 m
.18682 .41158 L
s
P
p
.2 0 1 r
.016 w
.40588 .37868 m
.34835 .55572 L
s
P
p
.2 0 1 r
.016 w
.40588 .37868 m
.51529 .22808 L
s
P
p
.2 0 1 r
.016 w
.40588 .37868 m
.25528 .48809 L
s
P
p
.2 0 1 r
.016 w
.40588 .37868 m
.58292 .32115 L
s
P
p
.2 0 1 r
.016 w
.40588 .37868 m
.21972 .37868 L
s
P
p
.2 0 1 r
.002 w
.50044 .63945 m
.37605 .70283 L
s
P
p
.2 0 1 r
.002 w
.50044 .63945 m
.43706 .76384 L
s
P
p
.2 0 1 r
.002 w
.50044 .63945 m
.52228 .77734 L
s
P
p
.2 0 1 r
.002 w
.56304 .61911 m
.62642 .74351 L
s
P
p
.2 0 1 r
.002 w
.56304 .61911 m
.68743 .68249 L
s
P
p
.2 0 1 r
.002 w
.56304 .61911 m
.70093 .59727 L
s
P
p
0 .4 1 r
.018 w
.52157 .59798 m
.50044 .63945 L
s
P
p
0 .4 1 r
.018 w
.52157 .59798 m
.56304 .61911 L
s
P
p
.2 0 1 r
.002 w
.49695 .20188 m
.63485 .18004 L
s
P
p
.2 0 1 r
.002 w
.49695 .20188 m
.59568 .10316 L
s
P
p
.2 0 1 r
.002 w
.49695 .20188 m
.5188 .06399 L
s
P
p
.2 0 1 r
.002 w
.43114 .20188 m
.4093 .06399 L
s
P
p
.2 0 1 r
.002 w
.43114 .20188 m
.33242 .10316 L
s
P
p
.2 0 1 r
.002 w
.43114 .20188 m
.29325 .18004 L
s
P
p
0 .4 1 r
.018 w
.46405 .23479 m
.49695 .20188 L
s
P
p
0 .4 1 r
.018 w
.46405 .23479 m
.43114 .20188 L
s
P
p
.2 0 1 r
.002 w
.36506 .61911 m
.22716 .59727 L
s
P
p
.2 0 1 r
.002 w
.36506 .61911 m
.24066 .68249 L
s
P
p
.2 0 1 r
.002 w
.36506 .61911 m
.30167 .74351 L
s
P
p
.2 0 1 r
.002 w
.42765 .63945 m
.40581 .77734 L
s
P
p
.2 0 1 r
.002 w
.42765 .63945 m
.49103 .76384 L
s
P
p
.2 0 1 r
.002 w
.42765 .63945 m
.55205 .70283 L
s
P
p
0 .4 1 r
.018 w
.40652 .59798 m
.36506 .61911 L
s
P
p
0 .4 1 r
.018 w
.40652 .59798 m
.42765 .63945 L
s
P
p
.2 0 1 r
.002 w
.61943 .26306 m
.74383 .32644 L
s
P
p
.2 0 1 r
.002 w
.61943 .26306 m
.75732 .24122 L
s
P
p
.2 0 1 r
.002 w
.61943 .26306 m
.71815 .16434 L
s
P
p
.2 0 1 r
.002 w
.56618 .22438 m
.62957 .09998 L
s
P
p
.2 0 1 r
.002 w
.56618 .22438 m
.54434 .08648 L
s
P
p
.2 0 1 r
.002 w
.56618 .22438 m
.46746 .12565 L
s
P
p
0 .4 1 r
.018 w
.57346 .27034 m
.61943 .26306 L
s
P
p
0 .4 1 r
.018 w
.57346 .27034 m
.56618 .22438 L
s
P
p
.2 0 1 r
.002 w
.26748 .52308 m
.16876 .42436 L
s
P
p
.2 0 1 r
.002 w
.26748 .52308 m
.12959 .50124 L
s
P
p
.2 0 1 r
.002 w
.26748 .52308 m
.14309 .58646 L
s
P
p
.2 0 1 r
.002 w
.30617 .57632 m
.20745 .67504 L
s
P
p
.2 0 1 r
.002 w
.30617 .57632 m
.28433 .71422 L
s
P
p
.2 0 1 r
.002 w
.30617 .57632 m
.36955 .70072 L
s
P
p
0 .4 1 r
.018 w
.31345 .53036 m
.26748 .52308 L
s
P
p
0 .4 1 r
.018 w
.31345 .53036 m
.30617 .57632 L
s
P
p
.2 0 1 r
.016 w
.46405 .42094 m
.52157 .59798 L
s
P
p
.2 0 1 r
.016 w
.46405 .42094 m
.46405 .23479 L
s
P
p
.2 0 1 r
.016 w
.46405 .42094 m
.40652 .59798 L
s
P
p
.2 0 1 r
.016 w
.46405 .42094 m
.57346 .27034 L
s
P
p
.2 0 1 r
.016 w
.46405 .42094 m
.31345 .53036 L
s
P
p
.2 0 1 r
.002 w
.69383 .57632 m
.63045 .70072 L
s
P
p
.2 0 1 r
.002 w
.69383 .57632 m
.71567 .71422 L
s
P
p
.2 0 1 r
.002 w
.69383 .57632 m
.79255 .67504 L
s
P
p
.2 0 1 r
.002 w
.73252 .52308 m
.85691 .58646 L
s
P
p
.2 0 1 r
.002 w
.73252 .52308 m
.87041 .50124 L
s
P
p
.2 0 1 r
.002 w
.73252 .52308 m
.83124 .42436 L
s
P
p
0 .4 1 r
.018 w
.68655 .53036 m
.69383 .57632 L
s
P
p
0 .4 1 r
.018 w
.68655 .53036 m
.73252 .52308 L
s
P
p
.2 0 1 r
.002 w
.43382 .22438 m
.53254 .12565 L
s
P
p
.2 0 1 r
.002 w
.43382 .22438 m
.45566 .08648 L
s
P
p
.2 0 1 r
.002 w
.43382 .22438 m
.37043 .09998 L
s
P
p
.2 0 1 r
.002 w
.38057 .26306 m
.28185 .16434 L
s
P
p
.2 0 1 r
.002 w
.38057 .26306 m
.24268 .24122 L
s
P
p
.2 0 1 r
.002 w
.38057 .26306 m
.25617 .32644 L
s
P
p
0 .4 1 r
.018 w
.42654 .27034 m
.43382 .22438 L
s
P
p
0 .4 1 r
.018 w
.42654 .27034 m
.38057 .26306 L
s
P
p
.2 0 1 r
.002 w
.57235 .63945 m
.44795 .70283 L
s
P
p
.2 0 1 r
.002 w
.57235 .63945 m
.50897 .76384 L
s
P
p
.2 0 1 r
.002 w
.57235 .63945 m
.59419 .77734 L
s
P
p
.2 0 1 r
.002 w
.63494 .61911 m
.69833 .74351 L
s
P
p
.2 0 1 r
.002 w
.63494 .61911 m
.75934 .68249 L
s
P
p
.2 0 1 r
.002 w
.63494 .61911 m
.77284 .59727 L
s
P
p
0 .4 1 r
.018 w
.59348 .59798 m
.57235 .63945 L
s
P
p
0 .4 1 r
.018 w
.59348 .59798 m
.63494 .61911 L
s
P
p
.2 0 1 r
.002 w
.56886 .20188 m
.70675 .18004 L
s
P
p
.2 0 1 r
.002 w
.56886 .20188 m
.66758 .10316 L
s
P
p
.2 0 1 r
.002 w
.56886 .20188 m
.5907 .06399 L
s
P
p
.2 0 1 r
.002 w
.50305 .20188 m
.4812 .06399 L
s
P
p
.2 0 1 r
.002 w
.50305 .20188 m
.40432 .10316 L
s
P
p
.2 0 1 r
.002 w
.50305 .20188 m
.36515 .18004 L
s
P
p
0 .4 1 r
.018 w
.53595 .23479 m
.56886 .20188 L
s
P
p
0 .4 1 r
.018 w
.53595 .23479 m
.50305 .20188 L
s
P
p
.2 0 1 r
.002 w
.43696 .61911 m
.29907 .59727 L
s
P
p
.2 0 1 r
.002 w
.43696 .61911 m
.31257 .68249 L
s
P
p
.2 0 1 r
.002 w
.43696 .61911 m
.37358 .74351 L
s
P
p
.2 0 1 r
.002 w
.49956 .63945 m
.47772 .77734 L
s
P
p
.2 0 1 r
.002 w
.49956 .63945 m
.56294 .76384 L
s
P
p
.2 0 1 r
.002 w
.49956 .63945 m
.62395 .70283 L
s
P
p
0 .4 1 r
.018 w
.47843 .59798 m
.43696 .61911 L
s
P
p
0 .4 1 r
.018 w
.47843 .59798 m
.49956 .63945 L
s
P
p
.2 0 1 r
.016 w
.53595 .42094 m
.68655 .53036 L
s
P
p
.2 0 1 r
.016 w
.53595 .42094 m
.42654 .27034 L
s
P
p
.2 0 1 r
.016 w
.53595 .42094 m
.59348 .59798 L
s
P
p
.2 0 1 r
.016 w
.53595 .42094 m
.53595 .23479 L
s
P
p
.2 0 1 r
.016 w
.53595 .42094 m
.47843 .59798 L
s
P
p
.2 0 1 r
.002 w
.81318 .41158 m
.83502 .54948 L
s
P
p
.2 0 1 r
.002 w
.81318 .41158 m
.9119 .5103 L
s
P
p
.2 0 1 r
.002 w
.81318 .41158 m
.95108 .43342 L
s
P
p
.2 0 1 r
.002 w
.81318 .34577 m
.95108 .32393 L
s
P
p
.2 0 1 r
.002 w
.81318 .34577 m
.9119 .24705 L
s
P
p
.2 0 1 r
.002 w
.81318 .34577 m
.83502 .20787 L
s
P
p
0 .4 1 r
.018 w
.78028 .37868 m
.81318 .41158 L
s
P
p
0 .4 1 r
.018 w
.78028 .37868 m
.81318 .34577 L
s
P
p
.2 0 1 r
.002 w
.39596 .27969 m
.4178 .14179 L
s
P
p
.2 0 1 r
.002 w
.39596 .27969 m
.33257 .15529 L
s
P
p
.2 0 1 r
.002 w
.39596 .27969 m
.27156 .2163 L
s
P
p
.2 0 1 r
.002 w
.37562 .34228 m
.23772 .32044 L
s
P
p
.2 0 1 r
.002 w
.37562 .34228 m
.25122 .40566 L
s
P
p
.2 0 1 r
.002 w
.37562 .34228 m
.31224 .46668 L
s
P
p
0 .4 1 r
.018 w
.41708 .32115 m
.39596 .27969 L
s
P
p
0 .4 1 r
.018 w
.41708 .32115 m
.37562 .34228 L
s
P
p
.2 0 1 r
.002 w
.752 .53406 m
.68862 .65845 L
s
P
p
.2 0 1 r
.002 w
.752 .53406 m
.77384 .67195 L
s
P
p
.2 0 1 r
.002 w
.752 .53406 m
.85073 .63278 L
s
P
p
.2 0 1 r
.002 w
.79069 .48081 m
.91509 .5442 L
s
P
p
.2 0 1 r
.002 w
.79069 .48081 m
.92858 .45897 L
s
P
p
.2 0 1 r
.002 w
.79069 .48081 m
.88941 .38209 L
s
P
p
0 .4 1 r
.018 w
.74472 .48809 m
.752 .53406 L
s
P
p
0 .4 1 r
.018 w
.74472 .48809 m
.79069 .48081 L
s
P
p
.2 0 1 r
.002 w
.49199 .18211 m
.59071 .08339 L
s
P
p
.2 0 1 r
.002 w
.49199 .18211 m
.51383 .04422 L
s
P
p
.2 0 1 r
.002 w
.49199 .18211 m
.4286 .05772 L
s
P
p
.2 0 1 r
.002 w
.43874 .2208 m
.34002 .12207 L
s
P
p
.2 0 1 r
.002 w
.43874 .2208 m
.30085 .19896 L
s
P
p
.2 0 1 r
.002 w
.43874 .2208 m
.31435 .28418 L
s
P
p
0 .4 1 r
.018 w
.48471 .22808 m
.49199 .18211 L
s
P
p
0 .4 1 r
.018 w
.48471 .22808 m
.43874 .2208 L
s
P
p
.2 0 1 r
.002 w
.63052 .59718 m
.50612 .66057 L
s
P
p
.2 0 1 r
.002 w
.63052 .59718 m
.56714 .72158 L
s
P
p
.2 0 1 r
.002 w
.63052 .59718 m
.65236 .73508 L
s
P
p
.2 0 1 r
.002 w
.69311 .57684 m
.7565 .70124 L
s
P
p
.2 0 1 r
.002 w
.69311 .57684 m
.81751 .64023 L
s
P
p
.2 0 1 r
.002 w
.69311 .57684 m
.83101 .555 L
s
P
p
0 .4 1 r
.018 w
.65165 .55572 m
.63052 .59718 L
s
P
p
0 .4 1 r
.018 w
.65165 .55572 m
.69311 .57684 L
s
P
p
.2 0 1 r
.016 w
.59412 .37868 m
.78028 .37868 L
s
P
p
.2 0 1 r
.016 w
.59412 .37868 m
.41708 .32115 L
s
P
p
.2 0 1 r
.016 w
.59412 .37868 m
.74472 .48809 L
s
P
p
.2 0 1 r
.016 w
.59412 .37868 m
.48471 .22808 L
s
P
p
.2 0 1 r
.016 w
.59412 .37868 m
.65165 .55572 L
s
P
p
1 .6 0 r
.016 w
.5 .31029 m
.40588 .37868 L
s
P
p
1 .6 0 r
.016 w
.5 .31029 m
.46405 .42094 L
s
P
p
1 .6 0 r
.016 w
.5 .31029 m
.53595 .42094 L
s
P
p
1 .6 0 r
.016 w
.5 .31029 m
.59412 .37868 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0511771 0.952381 [
[ 0 0 0 0 ]
[ 1 .85003 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85003 L
0 .85003 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.2834 .58972 m
.15149 .54686 L
s
P
p
.2 0 1 r
.002 w
.2834 .58972 m
.15149 .63258 L
s
P
p
.2 0 1 r
.002 w
.2834 .58972 m
.20188 .70193 L
s
P
p
.2 0 1 r
.002 w
.39011 .62439 m
.39011 .76309 L
s
P
p
.2 0 1 r
.002 w
.39011 .62439 m
.47163 .7366 L
s
P
p
.2 0 1 r
.002 w
.39011 .62439 m
.52202 .66725 L
s
P
p
0 .4 1 r
.018 w
.34935 .56829 m
.2834 .58972 L
s
P
p
0 .4 1 r
.018 w
.34935 .56829 m
.39011 .62439 L
s
P
p
.2 0 1 r
.002 w
.58454 .24281 m
.69674 .32433 L
s
P
p
.2 0 1 r
.002 w
.58454 .24281 m
.72323 .24281 L
s
P
p
.2 0 1 r
.002 w
.58454 .24281 m
.69674 .16129 L
s
P
p
.2 0 1 r
.002 w
.49376 .17686 m
.53662 .04495 L
s
P
p
.2 0 1 r
.002 w
.49376 .17686 m
.4509 .04495 L
s
P
p
.2 0 1 r
.002 w
.49376 .17686 m
.38156 .09534 L
s
P
p
0 .4 1 r
.018 w
.51519 .24281 m
.58454 .24281 L
s
P
p
0 .4 1 r
.018 w
.51519 .24281 m
.49376 .17686 L
s
P
p
.2 0 1 r
.002 w
.19094 .47968 m
.10941 .36748 L
s
P
p
.2 0 1 r
.002 w
.19094 .47968 m
.05903 .43683 L
s
P
p
.2 0 1 r
.002 w
.19094 .47968 m
.05903 .52254 L
s
P
p
.2 0 1 r
.002 w
.25689 .57046 m
.17537 .68267 L
s
P
p
.2 0 1 r
.002 w
.25689 .57046 m
.25689 .70915 L
s
P
p
.2 0 1 r
.002 w
.25689 .57046 m
.33841 .68267 L
s
P
p
0 .4 1 r
.018 w
.25689 .50111 m
.19094 .47968 L
s
P
p
0 .4 1 r
.018 w
.25689 .50111 m
.25689 .57046 L
s
P
p
.2 0 1 r
.002 w
.63847 .37603 m
.68133 .50794 L
s
P
p
.2 0 1 r
.002 w
.63847 .37603 m
.75068 .45756 L
s
P
p
.2 0 1 r
.002 w
.63847 .37603 m
.77716 .37603 L
s
P
p
.2 0 1 r
.002 w
.6038 .26932 m
.716 .1878 L
s
P
p
.2 0 1 r
.002 w
.6038 .26932 m
.64666 .13742 L
s
P
p
.2 0 1 r
.002 w
.6038 .26932 m
.56094 .13742 L
s
P
p
0 .4 1 r
.018 w
.58237 .33527 m
.63847 .37603 L
s
P
p
0 .4 1 r
.018 w
.58237 .33527 m
.6038 .26932 L
s
P
p
.2 0 1 r
.002 w
.18081 .33632 m
.18081 .19762 L
s
P
p
.2 0 1 r
.002 w
.18081 .33632 m
.09929 .22411 L
s
P
p
.2 0 1 r
.002 w
.18081 .33632 m
.04891 .29346 L
s
P
p
.2 0 1 r
.002 w
.18081 .44852 m
.04891 .49138 L
s
P
p
.2 0 1 r
.002 w
.18081 .44852 m
.09929 .56073 L
s
P
p
.2 0 1 r
.002 w
.18081 .44852 m
.18081 .58721 L
s
P
p
0 .4 1 r
.018 w
.22157 .39242 m
.18081 .33632 L
s
P
p
0 .4 1 r
.018 w
.22157 .39242 m
.18081 .44852 L
s
P
p
.2 0 1 r
.016 w
.4065 .39242 m
.34935 .56829 L
s
P
p
.2 0 1 r
.016 w
.4065 .39242 m
.51519 .24281 L
s
P
p
.2 0 1 r
.016 w
.4065 .39242 m
.25689 .50111 L
s
P
p
.2 0 1 r
.016 w
.4065 .39242 m
.58237 .33527 L
s
P
p
.2 0 1 r
.016 w
.4065 .39242 m
.22157 .39242 L
s
P
p
.2 0 1 r
.002 w
.48067 .66638 m
.34876 .70924 L
s
P
p
.2 0 1 r
.002 w
.48067 .66638 m
.39915 .77858 L
s
P
p
.2 0 1 r
.002 w
.48067 .66638 m
.48067 .80507 L
s
P
p
.2 0 1 r
.002 w
.58738 .63171 m
.6689 .74391 L
s
P
p
.2 0 1 r
.002 w
.58738 .63171 m
.71929 .67457 L
s
P
p
.2 0 1 r
.002 w
.58738 .63171 m
.71929 .58885 L
s
P
p
0 .4 1 r
.018 w
.52143 .61028 m
.48067 .66638 L
s
P
p
0 .4 1 r
.018 w
.52143 .61028 m
.58738 .63171 L
s
P
p
.2 0 1 r
.002 w
.52039 .20872 m
.65908 .20872 L
s
P
p
.2 0 1 r
.002 w
.52039 .20872 m
.63259 .1272 L
s
P
p
.2 0 1 r
.002 w
.52039 .20872 m
.56325 .07681 L
s
P
p
.2 0 1 r
.002 w
.40818 .20872 m
.36532 .07681 L
s
P
p
.2 0 1 r
.002 w
.40818 .20872 m
.29598 .1272 L
s
P
p
.2 0 1 r
.002 w
.40818 .20872 m
.26949 .20872 L
s
P
p
0 .4 1 r
.018 w
.46428 .24948 m
.52039 .20872 L
s
P
p
0 .4 1 r
.018 w
.46428 .24948 m
.40818 .20872 L
s
P
p
.2 0 1 r
.002 w
.34119 .63171 m
.20928 .58885 L
s
P
p
.2 0 1 r
.002 w
.34119 .63171 m
.20928 .67457 L
s
P
p
.2 0 1 r
.002 w
.34119 .63171 m
.25967 .74391 L
s
P
p
.2 0 1 r
.002 w
.4479 .66638 m
.4479 .80507 L
s
P
p
.2 0 1 r
.002 w
.4479 .66638 m
.52942 .77858 L
s
P
p
.2 0 1 r
.002 w
.4479 .66638 m
.57981 .70924 L
s
P
p
0 .4 1 r
.018 w
.40714 .61028 m
.34119 .63171 L
s
P
p
0 .4 1 r
.018 w
.40714 .61028 m
.4479 .66638 L
s
P
p
.2 0 1 r
.002 w
.64233 .2848 m
.75453 .36632 L
s
P
p
.2 0 1 r
.002 w
.64233 .2848 m
.78102 .2848 L
s
P
p
.2 0 1 r
.002 w
.64233 .2848 m
.75453 .20328 L
s
P
p
.2 0 1 r
.002 w
.55155 .21884 m
.59441 .08694 L
s
P
p
.2 0 1 r
.002 w
.55155 .21884 m
.50869 .08694 L
s
P
p
.2 0 1 r
.002 w
.55155 .21884 m
.43935 .13732 L
s
P
p
0 .4 1 r
.018 w
.57298 .2848 m
.64233 .2848 L
s
P
p
0 .4 1 r
.018 w
.57298 .2848 m
.55155 .21884 L
s
P
p
.2 0 1 r
.002 w
.24873 .52167 m
.1672 .40947 L
s
P
p
.2 0 1 r
.002 w
.24873 .52167 m
.11682 .47881 L
s
P
p
.2 0 1 r
.002 w
.24873 .52167 m
.11682 .56453 L
s
P
p
.2 0 1 r
.002 w
.31468 .61245 m
.23316 .72465 L
s
P
p
.2 0 1 r
.002 w
.31468 .61245 m
.31468 .75114 L
s
P
p
.2 0 1 r
.002 w
.31468 .61245 m
.3962 .72465 L
s
P
p
0 .4 1 r
.018 w
.31468 .5431 m
.24873 .52167 L
s
P
p
0 .4 1 r
.018 w
.31468 .5431 m
.31468 .61245 L
s
P
p
.2 0 1 r
.016 w
.46428 .4344 m
.52143 .61028 L
s
P
p
.2 0 1 r
.016 w
.46428 .4344 m
.46428 .24948 L
s
P
p
.2 0 1 r
.016 w
.46428 .4344 m
.40714 .61028 L
s
P
p
.2 0 1 r
.016 w
.46428 .4344 m
.57298 .2848 L
s
P
p
.2 0 1 r
.016 w
.46428 .4344 m
.31468 .5431 L
s
P
p
.2 0 1 r
.002 w
.68532 .61245 m
.6038 .72465 L
s
P
p
.2 0 1 r
.002 w
.68532 .61245 m
.68532 .75114 L
s
P
p
.2 0 1 r
.002 w
.68532 .61245 m
.76684 .72465 L
s
P
p
.2 0 1 r
.002 w
.75127 .52167 m
.88318 .56453 L
s
P
p
.2 0 1 r
.002 w
.75127 .52167 m
.88318 .47881 L
s
P
p
.2 0 1 r
.002 w
.75127 .52167 m
.8328 .40947 L
s
P
p
0 .4 1 r
.018 w
.68532 .5431 m
.68532 .61245 L
s
P
p
0 .4 1 r
.018 w
.68532 .5431 m
.75127 .52167 L
s
P
p
.2 0 1 r
.002 w
.44845 .21884 m
.56065 .13732 L
s
P
p
.2 0 1 r
.002 w
.44845 .21884 m
.49131 .08694 L
s
P
p
.2 0 1 r
.002 w
.44845 .21884 m
.40559 .08694 L
s
P
p
.2 0 1 r
.002 w
.35767 .2848 m
.24547 .20328 L
s
P
p
.2 0 1 r
.002 w
.35767 .2848 m
.21898 .2848 L
s
P
p
.2 0 1 r
.002 w
.35767 .2848 m
.24547 .36632 L
s
P
p
0 .4 1 r
.018 w
.42702 .2848 m
.44845 .21884 L
s
P
p
0 .4 1 r
.018 w
.42702 .2848 m
.35767 .2848 L
s
P
p
.2 0 1 r
.002 w
.5521 .66638 m
.42019 .70924 L
s
P
p
.2 0 1 r
.002 w
.5521 .66638 m
.47058 .77858 L
s
P
p
.2 0 1 r
.002 w
.5521 .66638 m
.5521 .80507 L
s
P
p
.2 0 1 r
.002 w
.65881 .63171 m
.74033 .74391 L
s
P
p
.2 0 1 r
.002 w
.65881 .63171 m
.79072 .67457 L
s
P
p
.2 0 1 r
.002 w
.65881 .63171 m
.79072 .58885 L
s
P
p
0 .4 1 r
.018 w
.59286 .61028 m
.5521 .66638 L
s
P
p
0 .4 1 r
.018 w
.59286 .61028 m
.65881 .63171 L
s
P
p
.2 0 1 r
.002 w
.59182 .20872 m
.73051 .20872 L
s
P
p
.2 0 1 r
.002 w
.59182 .20872 m
.70402 .1272 L
s
P
p
.2 0 1 r
.002 w
.59182 .20872 m
.63468 .07681 L
s
P
p
.2 0 1 r
.002 w
.47961 .20872 m
.43675 .07681 L
s
P
p
.2 0 1 r
.002 w
.47961 .20872 m
.36741 .1272 L
s
P
p
.2 0 1 r
.002 w
.47961 .20872 m
.34092 .20872 L
s
P
p
0 .4 1 r
.018 w
.53572 .24948 m
.59182 .20872 L
s
P
p
0 .4 1 r
.018 w
.53572 .24948 m
.47961 .20872 L
s
P
p
.2 0 1 r
.002 w
.41262 .63171 m
.28071 .58885 L
s
P
p
.2 0 1 r
.002 w
.41262 .63171 m
.28071 .67457 L
s
P
p
.2 0 1 r
.002 w
.41262 .63171 m
.3311 .74391 L
s
P
p
.2 0 1 r
.002 w
.51933 .66638 m
.51933 .80507 L
s
P
p
.2 0 1 r
.002 w
.51933 .66638 m
.60085 .77858 L
s
P
p
.2 0 1 r
.002 w
.51933 .66638 m
.65124 .70924 L
s
P
p
0 .4 1 r
.018 w
.47857 .61028 m
.41262 .63171 L
s
P
p
0 .4 1 r
.018 w
.47857 .61028 m
.51933 .66638 L
s
P
p
.2 0 1 r
.016 w
.53572 .4344 m
.68532 .5431 L
s
P
p
.2 0 1 r
.016 w
.53572 .4344 m
.42702 .2848 L
s
P
p
.2 0 1 r
.016 w
.53572 .4344 m
.59286 .61028 L
s
P
p
.2 0 1 r
.016 w
.53572 .4344 m
.53572 .24948 L
s
P
p
.2 0 1 r
.016 w
.53572 .4344 m
.47857 .61028 L
s
P
p
.2 0 1 r
.002 w
.81919 .44852 m
.81919 .58721 L
s
P
p
.2 0 1 r
.002 w
.81919 .44852 m
.90071 .56073 L
s
P
p
.2 0 1 r
.002 w
.81919 .44852 m
.95109 .49138 L
s
P
p
.2 0 1 r
.002 w
.81919 .33632 m
.95109 .29346 L
s
P
p
.2 0 1 r
.002 w
.81919 .33632 m
.90071 .22411 L
s
P
p
.2 0 1 r
.002 w
.81919 .33632 m
.81919 .19762 L
s
P
p
0 .4 1 r
.018 w
.77843 .39242 m
.81919 .44852 L
s
P
p
0 .4 1 r
.018 w
.77843 .39242 m
.81919 .33632 L
s
P
p
.2 0 1 r
.002 w
.3962 .26932 m
.43906 .13742 L
s
P
p
.2 0 1 r
.002 w
.3962 .26932 m
.35334 .13742 L
s
P
p
.2 0 1 r
.002 w
.3962 .26932 m
.284 .1878 L
s
P
p
.2 0 1 r
.002 w
.36153 .37603 m
.22284 .37603 L
s
P
p
.2 0 1 r
.002 w
.36153 .37603 m
.24932 .45756 L
s
P
p
.2 0 1 r
.002 w
.36153 .37603 m
.31867 .50794 L
s
P
p
0 .4 1 r
.018 w
.41763 .33527 m
.3962 .26932 L
s
P
p
0 .4 1 r
.018 w
.41763 .33527 m
.36153 .37603 L
s
P
p
.2 0 1 r
.002 w
.74311 .57046 m
.66159 .68267 L
s
P
p
.2 0 1 r
.002 w
.74311 .57046 m
.74311 .70915 L
s
P
p
.2 0 1 r
.002 w
.74311 .57046 m
.82463 .68267 L
s
P
p
.2 0 1 r
.002 w
.80906 .47968 m
.94097 .52254 L
s
P
p
.2 0 1 r
.002 w
.80906 .47968 m
.94097 .43683 L
s
P
p
.2 0 1 r
.002 w
.80906 .47968 m
.89059 .36748 L
s
P
p
0 .4 1 r
.018 w
.74311 .50111 m
.74311 .57046 L
s
P
p
0 .4 1 r
.018 w
.74311 .50111 m
.80906 .47968 L
s
P
p
.2 0 1 r
.002 w
.50624 .17686 m
.61844 .09534 L
s
P
p
.2 0 1 r
.002 w
.50624 .17686 m
.5491 .04495 L
s
P
p
.2 0 1 r
.002 w
.50624 .17686 m
.46338 .04495 L
s
P
p
.2 0 1 r
.002 w
.41546 .24281 m
.30326 .16129 L
s
P
p
.2 0 1 r
.002 w
.41546 .24281 m
.27677 .24281 L
s
P
p
.2 0 1 r
.002 w
.41546 .24281 m
.30326 .32433 L
s
P
p
0 .4 1 r
.018 w
.48481 .24281 m
.50624 .17686 L
s
P
p
0 .4 1 r
.018 w
.48481 .24281 m
.41546 .24281 L
s
P
p
.2 0 1 r
.002 w
.60989 .62439 m
.47798 .66725 L
s
P
p
.2 0 1 r
.002 w
.60989 .62439 m
.52837 .7366 L
s
P
p
.2 0 1 r
.002 w
.60989 .62439 m
.60989 .76309 L
s
P
p
.2 0 1 r
.002 w
.7166 .58972 m
.79812 .70193 L
s
P
p
.2 0 1 r
.002 w
.7166 .58972 m
.84851 .63258 L
s
P
p
.2 0 1 r
.002 w
.7166 .58972 m
.84851 .54686 L
s
P
p
0 .4 1 r
.018 w
.65065 .56829 m
.60989 .62439 L
s
P
p
0 .4 1 r
.018 w
.65065 .56829 m
.7166 .58972 L
s
P
p
.2 0 1 r
.016 w
.5935 .39242 m
.77843 .39242 L
s
P
p
.2 0 1 r
.016 w
.5935 .39242 m
.41763 .33527 L
s
P
p
.2 0 1 r
.016 w
.5935 .39242 m
.74311 .50111 L
s
P
p
.2 0 1 r
.016 w
.5935 .39242 m
.48481 .24281 L
s
P
p
.2 0 1 r
.016 w
.5935 .39242 m
.65065 .56829 L
s
P
p
1 .6 0 r
.016 w
.5 .32448 m
.4065 .39242 L
s
P
p
1 .6 0 r
.016 w
.5 .32448 m
.46428 .4344 L
s
P
p
1 .6 0 r
.016 w
.5 .32448 m
.53572 .4344 L
s
P
p
1 .6 0 r
.016 w
.5 .32448 m
.5935 .39242 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.102692 0.952381 [
[ 0 0 0 0 ]
[ 1 .747 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .747 L
0 .747 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.2782 .58703 m
.21346 .60806 L
s
P
p
0 .4 1 r
.018 w
.2782 .58703 m
.31821 .6421 L
s
P
p
0 .4 1 r
.018 w
.52237 .10782 m
.59043 .10782 L
s
P
p
0 .4 1 r
.018 w
.52237 .10782 m
.50133 .04309 L
s
P
p
0 .4 1 r
.018 w
.14207 .48812 m
.07733 .46709 L
s
P
p
0 .4 1 r
.018 w
.14207 .48812 m
.14207 .55619 L
s
P
p
0 .4 1 r
.018 w
.62127 .24395 m
.67634 .28396 L
s
P
p
0 .4 1 r
.018 w
.62127 .24395 m
.64231 .17922 L
s
P
p
0 .4 1 r
.018 w
.09007 .32809 m
.05006 .27302 L
s
P
p
0 .4 1 r
.018 w
.09007 .32809 m
.05006 .38315 L
s
P
p
.2 0 1 r
.016 w
.36233 .32809 m
.2782 .58703 L
s
P
p
.2 0 1 r
.016 w
.36233 .32809 m
.52237 .10782 L
s
P
p
.2 0 1 r
.016 w
.36233 .32809 m
.14207 .48812 L
s
P
p
.2 0 1 r
.016 w
.36233 .32809 m
.62127 .24395 L
s
P
p
.2 0 1 r
.016 w
.36233 .32809 m
.09007 .32809 L
s
P
p
0 .4 1 r
.018 w
.53155 .64884 m
.49154 .70391 L
s
P
p
0 .4 1 r
.018 w
.53155 .64884 m
.59629 .66988 L
s
P
p
0 .4 1 r
.018 w
.44742 .11764 m
.50248 .07763 L
s
P
p
0 .4 1 r
.018 w
.44742 .11764 m
.39235 .07763 L
s
P
p
0 .4 1 r
.018 w
.36328 .64884 m
.29855 .66988 L
s
P
p
0 .4 1 r
.018 w
.36328 .64884 m
.40329 .70391 L
s
P
p
0 .4 1 r
.018 w
.60745 .16964 m
.67552 .16964 L
s
P
p
0 .4 1 r
.018 w
.60745 .16964 m
.58642 .1049 L
s
P
p
0 .4 1 r
.018 w
.22715 .54994 m
.16241 .5289 L
s
P
p
0 .4 1 r
.018 w
.22715 .54994 m
.22715 .618 L
s
P
p
.2 0 1 r
.016 w
.44742 .3899 m
.53155 .64884 L
s
P
p
.2 0 1 r
.016 w
.44742 .3899 m
.44742 .11764 L
s
P
p
.2 0 1 r
.016 w
.44742 .3899 m
.36328 .64884 L
s
P
p
.2 0 1 r
.016 w
.44742 .3899 m
.60745 .16964 L
s
P
p
.2 0 1 r
.016 w
.44742 .3899 m
.22715 .54994 L
s
P
p
0 .4 1 r
.018 w
.77285 .54994 m
.77285 .618 L
s
P
p
0 .4 1 r
.018 w
.77285 .54994 m
.83759 .5289 L
s
P
p
0 .4 1 r
.018 w
.39255 .16964 m
.41358 .1049 L
s
P
p
0 .4 1 r
.018 w
.39255 .16964 m
.32448 .16964 L
s
P
p
0 .4 1 r
.018 w
.63672 .64884 m
.59671 .70391 L
s
P
p
0 .4 1 r
.018 w
.63672 .64884 m
.70145 .66988 L
s
P
p
0 .4 1 r
.018 w
.55258 .11764 m
.60765 .07763 L
s
P
p
0 .4 1 r
.018 w
.55258 .11764 m
.49752 .07763 L
s
P
p
0 .4 1 r
.018 w
.46845 .64884 m
.40371 .66988 L
s
P
p
0 .4 1 r
.018 w
.46845 .64884 m
.50846 .70391 L
s
P
p
.2 0 1 r
.016 w
.55258 .3899 m
.77285 .54994 L
s
P
p
.2 0 1 r
.016 w
.55258 .3899 m
.39255 .16964 L
s
P
p
.2 0 1 r
.016 w
.55258 .3899 m
.63672 .64884 L
s
P
p
.2 0 1 r
.016 w
.55258 .3899 m
.55258 .11764 L
s
P
p
.2 0 1 r
.016 w
.55258 .3899 m
.46845 .64884 L
s
P
p
0 .4 1 r
.018 w
.90993 .32809 m
.94994 .38315 L
s
P
p
0 .4 1 r
.018 w
.90993 .32809 m
.94994 .27302 L
s
P
p
0 .4 1 r
.018 w
.37873 .24395 m
.35769 .17922 L
s
P
p
0 .4 1 r
.018 w
.37873 .24395 m
.32366 .28396 L
s
P
p
0 .4 1 r
.018 w
.85793 .48812 m
.85793 .55619 L
s
P
p
0 .4 1 r
.018 w
.85793 .48812 m
.92267 .46709 L
s
P
p
0 .4 1 r
.018 w
.47763 .10782 m
.49867 .04309 L
s
P
p
0 .4 1 r
.018 w
.47763 .10782 m
.40957 .10782 L
s
P
p
0 .4 1 r
.018 w
.7218 .58703 m
.68179 .6421 L
s
P
p
0 .4 1 r
.018 w
.7218 .58703 m
.78654 .60806 L
s
P
p
.2 0 1 r
.016 w
.63767 .32809 m
.90993 .32809 L
s
P
p
.2 0 1 r
.016 w
.63767 .32809 m
.37873 .24395 L
s
P
p
.2 0 1 r
.016 w
.63767 .32809 m
.85793 .48812 L
s
P
p
.2 0 1 r
.016 w
.63767 .32809 m
.47763 .10782 L
s
P
p
.2 0 1 r
.016 w
.63767 .32809 m
.7218 .58703 L
s
P
p
1 .6 0 r
.016 w
.5 .22807 m
.36233 .32809 L
s
P
p
1 .6 0 r
.016 w
.5 .22807 m
.44742 .3899 L
s
P
p
1 .6 0 r
.016 w
.5 .22807 m
.55258 .3899 L
s
P
p
1 .6 0 r
.016 w
.5 .22807 m
.63767 .32809 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0452321 0.952381 [
[ 0 0 0 0 ]
[ 1 .86192 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .86192 L
0 .86192 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.38688 .65115 m
.23795 .65115 L
s
P
p
.2 0 1 r
.002 w
.38688 .65115 m
.26639 .73869 L
s
P
p
.2 0 1 r
.002 w
.38688 .65115 m
.34086 .79279 L
s
P
p
.2 0 1 r
.002 w
.46721 .65115 m
.51324 .79279 L
s
P
p
.2 0 1 r
.002 w
.46721 .65115 m
.5877 .73869 L
s
P
p
.2 0 1 r
.002 w
.46721 .65115 m
.61615 .65115 L
s
P
p
0 .4 1 r
.018 w
.42705 .62196 m
.38688 .65115 L
s
P
p
0 .4 1 r
.018 w
.42705 .62196 m
.46721 .65115 L
s
P
p
.2 0 1 r
.002 w
.53563 .21918 m
.67728 .2652 L
s
P
p
.2 0 1 r
.002 w
.53563 .21918 m
.67728 .17316 L
s
P
p
.2 0 1 r
.002 w
.53563 .21918 m
.62317 .09869 L
s
P
p
.2 0 1 r
.002 w
.45923 .19436 m
.45923 .04542 L
s
P
p
.2 0 1 r
.002 w
.45923 .19436 m
.37169 .07387 L
s
P
p
.2 0 1 r
.002 w
.45923 .19436 m
.31759 .14833 L
s
P
p
0 .4 1 r
.018 w
.48841 .23452 m
.53563 .21918 L
s
P
p
0 .4 1 r
.018 w
.48841 .23452 m
.45923 .19436 L
s
P
p
.2 0 1 r
.002 w
.26068 .58404 m
.14019 .4965 L
s
P
p
.2 0 1 r
.002 w
.26068 .58404 m
.11174 .58404 L
s
P
p
.2 0 1 r
.002 w
.26068 .58404 m
.14019 .67158 L
s
P
p
.2 0 1 r
.002 w
.32567 .63125 m
.27964 .7729 L
s
P
p
.2 0 1 r
.002 w
.32567 .63125 m
.37169 .7729 L
s
P
p
.2 0 1 r
.002 w
.32567 .63125 m
.44616 .7188 L
s
P
p
0 .4 1 r
.018 w
.31032 .58404 m
.26068 .58404 L
s
P
p
0 .4 1 r
.018 w
.31032 .58404 m
.32567 .63125 L
s
P
p
.2 0 1 r
.002 w
.63492 .322 m
.72246 .44249 L
s
P
p
.2 0 1 r
.002 w
.63492 .322 m
.77657 .36803 L
s
P
p
.2 0 1 r
.002 w
.63492 .322 m
.77657 .27598 L
s
P
p
.2 0 1 r
.002 w
.5877 .25701 m
.67525 .13652 L
s
P
p
.2 0 1 r
.002 w
.5877 .25701 m
.5877 .10808 L
s
P
p
.2 0 1 r
.002 w
.5877 .25701 m
.50016 .13652 L
s
P
p
0 .4 1 r
.018 w
.5877 .30666 m
.63492 .322 L
s
P
p
0 .4 1 r
.018 w
.5877 .30666 m
.5877 .25701 L
s
P
p
.2 0 1 r
.002 w
.19802 .45557 m
.152 .31392 L
s
P
p
.2 0 1 r
.002 w
.19802 .45557 m
.07753 .36803 L
s
P
p
.2 0 1 r
.002 w
.19802 .45557 m
.04909 .45557 L
s
P
p
.2 0 1 r
.002 w
.22284 .53196 m
.10235 .61951 L
s
P
p
.2 0 1 r
.002 w
.22284 .53196 m
.17682 .67361 L
s
P
p
.2 0 1 r
.002 w
.22284 .53196 m
.26887 .67361 L
s
P
p
0 .4 1 r
.018 w
.23819 .48475 m
.19802 .45557 L
s
P
p
0 .4 1 r
.018 w
.23819 .48475 m
.22284 .53196 L
s
P
p
.2 0 1 r
.016 w
.42705 .42338 m
.42705 .62196 L
s
P
p
.2 0 1 r
.016 w
.42705 .42338 m
.48841 .23452 L
s
P
p
.2 0 1 r
.016 w
.42705 .42338 m
.31032 .58404 L
s
P
p
.2 0 1 r
.016 w
.42705 .42338 m
.5877 .30666 L
s
P
p
.2 0 1 r
.016 w
.42705 .42338 m
.23819 .48475 L
s
P
p
.2 0 1 r
.002 w
.60138 .65496 m
.48089 .7425 L
s
P
p
.2 0 1 r
.002 w
.60138 .65496 m
.55536 .7966 L
s
P
p
.2 0 1 r
.002 w
.60138 .65496 m
.64741 .7966 L
s
P
p
.2 0 1 r
.002 w
.66637 .60774 m
.78686 .69528 L
s
P
p
.2 0 1 r
.002 w
.66637 .60774 m
.8153 .60774 L
s
P
p
.2 0 1 r
.002 w
.66637 .60774 m
.78686 .5202 L
s
P
p
0 .4 1 r
.018 w
.61672 .60774 m
.60138 .65496 L
s
P
p
0 .4 1 r
.018 w
.61672 .60774 m
.66637 .60774 L
s
P
p
.2 0 1 r
.002 w
.46782 .21806 m
.60946 .17204 L
s
P
p
.2 0 1 r
.002 w
.46782 .21806 m
.55536 .09757 L
s
P
p
.2 0 1 r
.002 w
.46782 .21806 m
.46782 .06912 L
s
P
p
.2 0 1 r
.002 w
.39142 .24288 m
.30388 .12239 L
s
P
p
.2 0 1 r
.002 w
.39142 .24288 m
.24977 .19686 L
s
P
p
.2 0 1 r
.002 w
.39142 .24288 m
.24977 .28891 L
s
P
p
0 .4 1 r
.018 w
.43863 .25822 m
.46782 .21806 L
s
P
p
0 .4 1 r
.018 w
.43863 .25822 m
.39142 .24288 L
s
P
p
.2 0 1 r
.002 w
.45984 .67485 m
.3109 .67485 L
s
P
p
.2 0 1 r
.002 w
.45984 .67485 m
.33934 .76239 L
s
P
p
.2 0 1 r
.002 w
.45984 .67485 m
.41381 .8165 L
s
P
p
.2 0 1 r
.002 w
.54016 .67485 m
.58619 .8165 L
s
P
p
.2 0 1 r
.002 w
.54016 .67485 m
.66066 .76239 L
s
P
p
.2 0 1 r
.002 w
.54016 .67485 m
.6891 .67485 L
s
P
p
0 .4 1 r
.018 w
.5 .64567 m
.45984 .67485 L
s
P
p
0 .4 1 r
.018 w
.5 .64567 m
.54016 .67485 L
s
P
p
.2 0 1 r
.002 w
.60858 .24288 m
.75023 .28891 L
s
P
p
.2 0 1 r
.002 w
.60858 .24288 m
.75023 .19686 L
s
P
p
.2 0 1 r
.002 w
.60858 .24288 m
.69612 .12239 L
s
P
p
.2 0 1 r
.002 w
.53218 .21806 m
.53218 .06912 L
s
P
p
.2 0 1 r
.002 w
.53218 .21806 m
.44464 .09757 L
s
P
p
.2 0 1 r
.002 w
.53218 .21806 m
.39054 .17204 L
s
P
p
0 .4 1 r
.018 w
.56137 .25822 m
.60858 .24288 L
s
P
p
0 .4 1 r
.018 w
.56137 .25822 m
.53218 .21806 L
s
P
p
.2 0 1 r
.002 w
.33363 .60774 m
.21314 .5202 L
s
P
p
.2 0 1 r
.002 w
.33363 .60774 m
.1847 .60774 L
s
P
p
.2 0 1 r
.002 w
.33363 .60774 m
.21314 .69528 L
s
P
p
.2 0 1 r
.002 w
.39862 .65496 m
.35259 .7966 L
s
P
p
.2 0 1 r
.002 w
.39862 .65496 m
.44464 .7966 L
s
P
p
.2 0 1 r
.002 w
.39862 .65496 m
.51911 .7425 L
s
P
p
0 .4 1 r
.018 w
.38328 .60774 m
.33363 .60774 L
s
P
p
0 .4 1 r
.018 w
.38328 .60774 m
.39862 .65496 L
s
P
p
.2 0 1 r
.016 w
.5 .44709 m
.61672 .60774 L
s
P
p
.2 0 1 r
.016 w
.5 .44709 m
.43863 .25822 L
s
P
p
.2 0 1 r
.016 w
.5 .44709 m
.5 .64567 L
s
P
p
.2 0 1 r
.016 w
.5 .44709 m
.56137 .25822 L
s
P
p
.2 0 1 r
.016 w
.5 .44709 m
.38328 .60774 L
s
P
p
.2 0 1 r
.002 w
.77716 .53196 m
.73113 .67361 L
s
P
p
.2 0 1 r
.002 w
.77716 .53196 m
.82318 .67361 L
s
P
p
.2 0 1 r
.002 w
.77716 .53196 m
.89765 .61951 L
s
P
p
.2 0 1 r
.002 w
.80198 .45557 m
.95091 .45557 L
s
P
p
.2 0 1 r
.002 w
.80198 .45557 m
.92247 .36803 L
s
P
p
.2 0 1 r
.002 w
.80198 .45557 m
.848 .31392 L
s
P
p
0 .4 1 r
.018 w
.76181 .48475 m
.77716 .53196 L
s
P
p
0 .4 1 r
.018 w
.76181 .48475 m
.80198 .45557 L
s
P
p
.2 0 1 r
.002 w
.4123 .25701 m
.49984 .13652 L
s
P
p
.2 0 1 r
.002 w
.4123 .25701 m
.4123 .10808 L
s
P
p
.2 0 1 r
.002 w
.4123 .25701 m
.32475 .13652 L
s
P
p
.2 0 1 r
.002 w
.36508 .322 m
.22343 .27598 L
s
P
p
.2 0 1 r
.002 w
.36508 .322 m
.22343 .36803 L
s
P
p
.2 0 1 r
.002 w
.36508 .322 m
.27754 .44249 L
s
P
p
0 .4 1 r
.018 w
.4123 .30666 m
.4123 .25701 L
s
P
p
0 .4 1 r
.018 w
.4123 .30666 m
.36508 .322 L
s
P
p
.2 0 1 r
.002 w
.67433 .63125 m
.55384 .7188 L
s
P
p
.2 0 1 r
.002 w
.67433 .63125 m
.62831 .7729 L
s
P
p
.2 0 1 r
.002 w
.67433 .63125 m
.72036 .7729 L
s
P
p
.2 0 1 r
.002 w
.73932 .58404 m
.85981 .67158 L
s
P
p
.2 0 1 r
.002 w
.73932 .58404 m
.88826 .58404 L
s
P
p
.2 0 1 r
.002 w
.73932 .58404 m
.85981 .4965 L
s
P
p
0 .4 1 r
.018 w
.68968 .58404 m
.67433 .63125 L
s
P
p
0 .4 1 r
.018 w
.68968 .58404 m
.73932 .58404 L
s
P
p
.2 0 1 r
.002 w
.54077 .19436 m
.68241 .14833 L
s
P
p
.2 0 1 r
.002 w
.54077 .19436 m
.62831 .07387 L
s
P
p
.2 0 1 r
.002 w
.54077 .19436 m
.54077 .04542 L
s
P
p
.2 0 1 r
.002 w
.46437 .21918 m
.37683 .09869 L
s
P
p
.2 0 1 r
.002 w
.46437 .21918 m
.32272 .17316 L
s
P
p
.2 0 1 r
.002 w
.46437 .21918 m
.32272 .2652 L
s
P
p
0 .4 1 r
.018 w
.51159 .23452 m
.54077 .19436 L
s
P
p
0 .4 1 r
.018 w
.51159 .23452 m
.46437 .21918 L
s
P
p
.2 0 1 r
.002 w
.53279 .65115 m
.38385 .65115 L
s
P
p
.2 0 1 r
.002 w
.53279 .65115 m
.4123 .73869 L
s
P
p
.2 0 1 r
.002 w
.53279 .65115 m
.48676 .79279 L
s
P
p
.2 0 1 r
.002 w
.61312 .65115 m
.65914 .79279 L
s
P
p
.2 0 1 r
.002 w
.61312 .65115 m
.73361 .73869 L
s
P
p
.2 0 1 r
.002 w
.61312 .65115 m
.76205 .65115 L
s
P
p
0 .4 1 r
.018 w
.57295 .62196 m
.53279 .65115 L
s
P
p
0 .4 1 r
.018 w
.57295 .62196 m
.61312 .65115 L
s
P
p
.2 0 1 r
.016 w
.57295 .42338 m
.76181 .48475 L
s
P
p
.2 0 1 r
.016 w
.57295 .42338 m
.4123 .30666 L
s
P
p
.2 0 1 r
.016 w
.57295 .42338 m
.68968 .58404 L
s
P
p
.2 0 1 r
.016 w
.57295 .42338 m
.51159 .23452 L
s
P
p
.2 0 1 r
.016 w
.57295 .42338 m
.57295 .62196 L
s
P
p
1 .6 0 r
.016 w
.5 .32297 m
.42705 .42338 L
s
P
p
1 .6 0 r
.016 w
.5 .32297 m
.5 .44709 L
s
P
p
1 .6 0 r
.016 w
.5 .32297 m
.57295 .42338 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0927219 0.952381 [
[ 0 0 0 0 ]
[ 1 .76694 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .76694 L
0 .76694 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.21896 .42083 m
.1241 .32598 L
s
P
p
.2 0 1 r
.002 w
.21896 .42083 m
.08646 .39985 L
s
P
p
.2 0 1 r
.002 w
.21896 .42083 m
.09943 .48173 L
s
P
p
.2 0 1 r
.002 w
.27011 .47199 m
.20921 .59151 L
s
P
p
.2 0 1 r
.002 w
.27011 .47199 m
.2911 .60448 L
s
P
p
.2 0 1 r
.002 w
.27011 .47199 m
.36497 .56684 L
s
P
p
0 .4 1 r
.018 w
.26312 .42782 m
.21896 .42083 L
s
P
p
0 .4 1 r
.018 w
.26312 .42782 m
.27011 .47199 L
s
P
p
.2 0 1 r
.002 w
.58879 .24045 m
.64969 .35998 L
s
P
p
.2 0 1 r
.002 w
.58879 .24045 m
.70832 .30135 L
s
P
p
.2 0 1 r
.002 w
.58879 .24045 m
.72129 .21947 L
s
P
p
.2 0 1 r
.002 w
.55595 .17599 m
.6508 .08114 L
s
P
p
.2 0 1 r
.002 w
.55595 .17599 m
.57693 .0435 L
s
P
p
.2 0 1 r
.002 w
.55595 .17599 m
.49505 .05647 L
s
P
p
0 .4 1 r
.018 w
.54895 .22015 m
.58879 .24045 L
s
P
p
0 .4 1 r
.018 w
.54895 .22015 m
.55595 .17599 L
s
P
p
.2 0 1 r
.002 w
.18132 .29772 m
.16033 .16522 L
s
P
p
.2 0 1 r
.002 w
.18132 .29772 m
.08646 .20286 L
s
P
p
.2 0 1 r
.002 w
.18132 .29772 m
.04883 .27673 L
s
P
p
.2 0 1 r
.002 w
.19264 .36917 m
.07311 .43007 L
s
P
p
.2 0 1 r
.002 w
.19264 .36917 m
.13174 .4887 L
s
P
p
.2 0 1 r
.002 w
.19264 .36917 m
.21362 .50167 L
s
P
p
0 .4 1 r
.018 w
.21294 .32933 m
.18132 .29772 L
s
P
p
0 .4 1 r
.018 w
.21294 .32933 m
.19264 .36917 L
s
P
p
.2 0 1 r
.002 w
.58655 .36917 m
.56556 .50167 L
s
P
p
.2 0 1 r
.002 w
.58655 .36917 m
.64745 .4887 L
s
P
p
.2 0 1 r
.002 w
.58655 .36917 m
.70607 .43007 L
s
P
p
.2 0 1 r
.002 w
.59786 .29772 m
.73035 .27673 L
s
P
p
.2 0 1 r
.002 w
.59786 .29772 m
.69272 .20286 L
s
P
p
.2 0 1 r
.002 w
.59786 .29772 m
.61885 .16522 L
s
P
p
0 .4 1 r
.018 w
.56625 .32933 m
.58655 .36917 L
s
P
p
0 .4 1 r
.018 w
.56625 .32933 m
.59786 .29772 L
s
P
p
.2 0 1 r
.002 w
.22323 .17599 m
.28413 .05647 L
s
P
p
.2 0 1 r
.002 w
.22323 .17599 m
.20225 .0435 L
s
P
p
.2 0 1 r
.002 w
.22323 .17599 m
.12838 .08114 L
s
P
p
.2 0 1 r
.002 w
.19039 .24045 m
.0579 .21947 L
s
P
p
.2 0 1 r
.002 w
.19039 .24045 m
.07086 .30135 L
s
P
p
.2 0 1 r
.002 w
.19039 .24045 m
.12949 .35998 L
s
P
p
0 .4 1 r
.018 w
.23023 .22015 m
.22323 .17599 L
s
P
p
0 .4 1 r
.018 w
.23023 .22015 m
.19039 .24045 L
s
P
p
.2 0 1 r
.016 w
.38959 .30135 m
.26312 .42782 L
s
P
p
.2 0 1 r
.016 w
.38959 .30135 m
.54895 .22015 L
s
P
p
.2 0 1 r
.016 w
.38959 .30135 m
.21294 .32933 L
s
P
p
.2 0 1 r
.016 w
.38959 .30135 m
.56625 .32933 L
s
P
p
.2 0 1 r
.016 w
.38959 .30135 m
.23023 .22015 L
s
P
p
.2 0 1 r
.002 w
.44561 .59174 m
.31312 .61273 L
s
P
p
.2 0 1 r
.002 w
.44561 .59174 m
.35076 .68659 L
s
P
p
.2 0 1 r
.002 w
.44561 .59174 m
.42463 .72423 L
s
P
p
.2 0 1 r
.002 w
.51707 .58042 m
.57797 .69995 L
s
P
p
.2 0 1 r
.002 w
.51707 .58042 m
.63659 .64132 L
s
P
p
.2 0 1 r
.002 w
.51707 .58042 m
.64956 .55944 L
s
P
p
0 .4 1 r
.018 w
.47723 .56012 m
.44561 .59174 L
s
P
p
0 .4 1 r
.018 w
.47723 .56012 m
.51707 .58042 L
s
P
p
.2 0 1 r
.002 w
.51707 .18651 m
.64956 .2075 L
s
P
p
.2 0 1 r
.002 w
.51707 .18651 m
.63659 .12561 L
s
P
p
.2 0 1 r
.002 w
.51707 .18651 m
.57797 .06699 L
s
P
p
.2 0 1 r
.002 w
.44561 .1752 m
.42463 .0427 L
s
P
p
.2 0 1 r
.002 w
.44561 .1752 m
.35076 .08034 L
s
P
p
.2 0 1 r
.002 w
.44561 .1752 m
.31312 .15421 L
s
P
p
0 .4 1 r
.018 w
.47723 .20681 m
.51707 .18651 L
s
P
p
0 .4 1 r
.018 w
.47723 .20681 m
.44561 .1752 L
s
P
p
.2 0 1 r
.002 w
.32389 .54983 m
.20436 .48893 L
s
P
p
.2 0 1 r
.002 w
.32389 .54983 m
.1914 .57081 L
s
P
p
.2 0 1 r
.002 w
.32389 .54983 m
.22903 .64468 L
s
P
p
.2 0 1 r
.002 w
.38835 .58267 m
.36737 .71516 L
s
P
p
.2 0 1 r
.002 w
.38835 .58267 m
.44925 .70219 L
s
P
p
.2 0 1 r
.002 w
.38835 .58267 m
.50787 .64357 L
s
P
p
0 .4 1 r
.018 w
.36805 .54283 m
.32389 .54983 L
s
P
p
0 .4 1 r
.018 w
.36805 .54283 m
.38835 .58267 L
s
P
p
.2 0 1 r
.002 w
.61989 .26399 m
.71474 .35885 L
s
P
p
.2 0 1 r
.002 w
.61989 .26399 m
.75238 .28498 L
s
P
p
.2 0 1 r
.002 w
.61989 .26399 m
.73941 .20309 L
s
P
p
.2 0 1 r
.002 w
.56873 .21283 m
.62963 .09331 L
s
P
p
.2 0 1 r
.002 w
.56873 .21283 m
.54774 .08034 L
s
P
p
.2 0 1 r
.002 w
.56873 .21283 m
.47387 .11798 L
s
P
p
0 .4 1 r
.018 w
.57572 .257 m
.61989 .26399 L
s
P
p
0 .4 1 r
.018 w
.57572 .257 m
.56873 .21283 L
s
P
p
.2 0 1 r
.002 w
.25005 .44437 m
.18915 .32485 L
s
P
p
.2 0 1 r
.002 w
.25005 .44437 m
.13052 .38347 L
s
P
p
.2 0 1 r
.002 w
.25005 .44437 m
.11756 .46535 L
s
P
p
.2 0 1 r
.002 w
.28289 .50883 m
.18804 .60369 L
s
P
p
.2 0 1 r
.002 w
.28289 .50883 m
.26191 .64132 L
s
P
p
.2 0 1 r
.002 w
.28289 .50883 m
.34379 .62835 L
s
P
p
0 .4 1 r
.018 w
.28989 .46467 m
.25005 .44437 L
s
P
p
0 .4 1 r
.018 w
.28989 .46467 m
.28289 .50883 L
s
P
p
.2 0 1 r
.016 w
.44925 .38347 m
.47723 .56012 L
s
P
p
.2 0 1 r
.016 w
.44925 .38347 m
.47723 .20681 L
s
P
p
.2 0 1 r
.016 w
.44925 .38347 m
.36805 .54283 L
s
P
p
.2 0 1 r
.016 w
.44925 .38347 m
.57572 .257 L
s
P
p
.2 0 1 r
.016 w
.44925 .38347 m
.28989 .46467 L
s
P
p
.2 0 1 r
.002 w
.71711 .50883 m
.65621 .62835 L
s
P
p
.2 0 1 r
.002 w
.71711 .50883 m
.73809 .64132 L
s
P
p
.2 0 1 r
.002 w
.71711 .50883 m
.81196 .60369 L
s
P
p
.2 0 1 r
.002 w
.74995 .44437 m
.88244 .46535 L
s
P
p
.2 0 1 r
.002 w
.74995 .44437 m
.86948 .38347 L
s
P
p
.2 0 1 r
.002 w
.74995 .44437 m
.81085 .32485 L
s
P
p
0 .4 1 r
.018 w
.71011 .46467 m
.71711 .50883 L
s
P
p
0 .4 1 r
.018 w
.71011 .46467 m
.74995 .44437 L
s
P
p
.2 0 1 r
.002 w
.43127 .21283 m
.52613 .11798 L
s
P
p
.2 0 1 r
.002 w
.43127 .21283 m
.45226 .08034 L
s
P
p
.2 0 1 r
.002 w
.43127 .21283 m
.37037 .09331 L
s
P
p
.2 0 1 r
.002 w
.38011 .26399 m
.26059 .20309 L
s
P
p
.2 0 1 r
.002 w
.38011 .26399 m
.24762 .28498 L
s
P
p
.2 0 1 r
.002 w
.38011 .26399 m
.28526 .35885 L
s
P
p
0 .4 1 r
.018 w
.42428 .257 m
.43127 .21283 L
s
P
p
0 .4 1 r
.018 w
.42428 .257 m
.38011 .26399 L
s
P
p
.2 0 1 r
.002 w
.61165 .58267 m
.49213 .64357 L
s
P
p
.2 0 1 r
.002 w
.61165 .58267 m
.55075 .70219 L
s
P
p
.2 0 1 r
.002 w
.61165 .58267 m
.63263 .71516 L
s
P
p
.2 0 1 r
.002 w
.67611 .54983 m
.77097 .64468 L
s
P
p
.2 0 1 r
.002 w
.67611 .54983 m
.8086 .57081 L
s
P
p
.2 0 1 r
.002 w
.67611 .54983 m
.79564 .48893 L
s
P
p
0 .4 1 r
.018 w
.63195 .54283 m
.61165 .58267 L
s
P
p
0 .4 1 r
.018 w
.63195 .54283 m
.67611 .54983 L
s
P
p
.2 0 1 r
.002 w
.55439 .1752 m
.68688 .15421 L
s
P
p
.2 0 1 r
.002 w
.55439 .1752 m
.64924 .08034 L
s
P
p
.2 0 1 r
.002 w
.55439 .1752 m
.57537 .0427 L
s
P
p
.2 0 1 r
.002 w
.48293 .18651 m
.42203 .06699 L
s
P
p
.2 0 1 r
.002 w
.48293 .18651 m
.36341 .12561 L
s
P
p
.2 0 1 r
.002 w
.48293 .18651 m
.35044 .2075 L
s
P
p
0 .4 1 r
.018 w
.52277 .20681 m
.55439 .1752 L
s
P
p
0 .4 1 r
.018 w
.52277 .20681 m
.48293 .18651 L
s
P
p
.2 0 1 r
.002 w
.48293 .58042 m
.35044 .55944 L
s
P
p
.2 0 1 r
.002 w
.48293 .58042 m
.36341 .64132 L
s
P
p
.2 0 1 r
.002 w
.48293 .58042 m
.42203 .69995 L
s
P
p
.2 0 1 r
.002 w
.55439 .59174 m
.57537 .72423 L
s
P
p
.2 0 1 r
.002 w
.55439 .59174 m
.64924 .68659 L
s
P
p
.2 0 1 r
.002 w
.55439 .59174 m
.68688 .61273 L
s
P
p
0 .4 1 r
.018 w
.52277 .56012 m
.48293 .58042 L
s
P
p
0 .4 1 r
.018 w
.52277 .56012 m
.55439 .59174 L
s
P
p
.2 0 1 r
.016 w
.55075 .38347 m
.71011 .46467 L
s
P
p
.2 0 1 r
.016 w
.55075 .38347 m
.42428 .257 L
s
P
p
.2 0 1 r
.016 w
.55075 .38347 m
.63195 .54283 L
s
P
p
.2 0 1 r
.016 w
.55075 .38347 m
.52277 .20681 L
s
P
p
.2 0 1 r
.016 w
.55075 .38347 m
.52277 .56012 L
s
P
p
.2 0 1 r
.002 w
.80961 .24045 m
.87051 .35998 L
s
P
p
.2 0 1 r
.002 w
.80961 .24045 m
.92914 .30135 L
s
P
p
.2 0 1 r
.002 w
.80961 .24045 m
.9421 .21947 L
s
P
p
.2 0 1 r
.002 w
.77677 .17599 m
.87162 .08114 L
s
P
p
.2 0 1 r
.002 w
.77677 .17599 m
.79775 .0435 L
s
P
p
.2 0 1 r
.002 w
.77677 .17599 m
.71587 .05647 L
s
P
p
0 .4 1 r
.018 w
.76977 .22015 m
.80961 .24045 L
s
P
p
0 .4 1 r
.018 w
.76977 .22015 m
.77677 .17599 L
s
P
p
.2 0 1 r
.002 w
.40214 .29772 m
.38115 .16522 L
s
P
p
.2 0 1 r
.002 w
.40214 .29772 m
.30728 .20286 L
s
P
p
.2 0 1 r
.002 w
.40214 .29772 m
.26965 .27673 L
s
P
p
.2 0 1 r
.002 w
.41345 .36917 m
.29393 .43007 L
s
P
p
.2 0 1 r
.002 w
.41345 .36917 m
.35255 .4887 L
s
P
p
.2 0 1 r
.002 w
.41345 .36917 m
.43444 .50167 L
s
P
p
0 .4 1 r
.018 w
.43375 .32933 m
.40214 .29772 L
s
P
p
0 .4 1 r
.018 w
.43375 .32933 m
.41345 .36917 L
s
P
p
.2 0 1 r
.002 w
.80736 .36917 m
.78638 .50167 L
s
P
p
.2 0 1 r
.002 w
.80736 .36917 m
.86826 .4887 L
s
P
p
.2 0 1 r
.002 w
.80736 .36917 m
.92689 .43007 L
s
P
p
.2 0 1 r
.002 w
.81868 .29772 m
.95117 .27673 L
s
P
p
.2 0 1 r
.002 w
.81868 .29772 m
.91354 .20286 L
s
P
p
.2 0 1 r
.002 w
.81868 .29772 m
.83967 .16522 L
s
P
p
0 .4 1 r
.018 w
.78706 .32933 m
.80736 .36917 L
s
P
p
0 .4 1 r
.018 w
.78706 .32933 m
.81868 .29772 L
s
P
p
.2 0 1 r
.002 w
.44405 .17599 m
.50495 .05647 L
s
P
p
.2 0 1 r
.002 w
.44405 .17599 m
.42307 .0435 L
s
P
p
.2 0 1 r
.002 w
.44405 .17599 m
.3492 .08114 L
s
P
p
.2 0 1 r
.002 w
.41121 .24045 m
.27871 .21947 L
s
P
p
.2 0 1 r
.002 w
.41121 .24045 m
.29168 .30135 L
s
P
p
.2 0 1 r
.002 w
.41121 .24045 m
.35031 .35998 L
s
P
p
0 .4 1 r
.018 w
.45105 .22015 m
.44405 .17599 L
s
P
p
0 .4 1 r
.018 w
.45105 .22015 m
.41121 .24045 L
s
P
p
.2 0 1 r
.002 w
.72989 .47199 m
.63503 .56684 L
s
P
p
.2 0 1 r
.002 w
.72989 .47199 m
.7089 .60448 L
s
P
p
.2 0 1 r
.002 w
.72989 .47199 m
.79079 .59151 L
s
P
p
.2 0 1 r
.002 w
.78104 .42083 m
.90057 .48173 L
s
P
p
.2 0 1 r
.002 w
.78104 .42083 m
.91354 .39985 L
s
P
p
.2 0 1 r
.002 w
.78104 .42083 m
.8759 .32598 L
s
P
p
0 .4 1 r
.018 w
.73688 .42782 m
.72989 .47199 L
s
P
p
0 .4 1 r
.018 w
.73688 .42782 m
.78104 .42083 L
s
P
p
.2 0 1 r
.016 w
.61041 .30135 m
.76977 .22015 L
s
P
p
.2 0 1 r
.016 w
.61041 .30135 m
.43375 .32933 L
s
P
p
.2 0 1 r
.016 w
.61041 .30135 m
.78706 .32933 L
s
P
p
.2 0 1 r
.016 w
.61041 .30135 m
.45105 .22015 L
s
P
p
.2 0 1 r
.016 w
.61041 .30135 m
.73688 .42782 L
s
P
p
1 .6 0 r
.016 w
.5 .28387 m
.38959 .30135 L
s
P
p
1 .6 0 r
.016 w
.5 .28387 m
.44925 .38347 L
s
P
p
1 .6 0 r
.016 w
.5 .28387 m
.55075 .38347 L
s
P
p
1 .6 0 r
.016 w
.5 .28387 m
.61041 .30135 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.04815 0.952381 [
[ 0 0 0 0 ]
[ 1 .85608 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85608 L
0 .85608 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3106 .60043 m
.16858 .55429 L
s
P
p
.2 0 1 r
.002 w
.3106 .60043 m
.16858 .64658 L
s
P
p
.2 0 1 r
.002 w
.3106 .60043 m
.22283 .72124 L
s
P
p
.2 0 1 r
.002 w
.3872 .62532 m
.3872 .77465 L
s
P
p
.2 0 1 r
.002 w
.3872 .62532 m
.47497 .74613 L
s
P
p
.2 0 1 r
.002 w
.3872 .62532 m
.52921 .67147 L
s
P
p
0 .4 1 r
.018 w
.35794 .58505 m
.3106 .60043 L
s
P
p
0 .4 1 r
.018 w
.35794 .58505 m
.3872 .62532 L
s
P
p
.2 0 1 r
.002 w
.58626 .23463 m
.70707 .3224 L
s
P
p
.2 0 1 r
.002 w
.58626 .23463 m
.73559 .23463 L
s
P
p
.2 0 1 r
.002 w
.58626 .23463 m
.70707 .14686 L
s
P
p
.2 0 1 r
.002 w
.52111 .18729 m
.56725 .04527 L
s
P
p
.2 0 1 r
.002 w
.52111 .18729 m
.47497 .04527 L
s
P
p
.2 0 1 r
.002 w
.52111 .18729 m
.4003 .09952 L
s
P
p
0 .4 1 r
.018 w
.53649 .23463 m
.58626 .23463 L
s
P
p
0 .4 1 r
.018 w
.53649 .23463 m
.52111 .18729 L
s
P
p
.2 0 1 r
.002 w
.21105 .49735 m
.12328 .37654 L
s
P
p
.2 0 1 r
.002 w
.21105 .49735 m
.06904 .4512 L
s
P
p
.2 0 1 r
.002 w
.21105 .49735 m
.06904 .54349 L
s
P
p
.2 0 1 r
.002 w
.25839 .5625 m
.17062 .68331 L
s
P
p
.2 0 1 r
.002 w
.25839 .5625 m
.25839 .71183 L
s
P
p
.2 0 1 r
.002 w
.25839 .5625 m
.34616 .68331 L
s
P
p
0 .4 1 r
.018 w
.25839 .51273 m
.21105 .49735 L
s
P
p
0 .4 1 r
.018 w
.25839 .51273 m
.25839 .5625 L
s
P
p
.2 0 1 r
.002 w
.64909 .36343 m
.69523 .50545 L
s
P
p
.2 0 1 r
.002 w
.64909 .36343 m
.76989 .4512 L
s
P
p
.2 0 1 r
.002 w
.64909 .36343 m
.79841 .36343 L
s
P
p
.2 0 1 r
.002 w
.6242 .28684 m
.745 .19907 L
s
P
p
.2 0 1 r
.002 w
.6242 .28684 m
.67034 .14482 L
s
P
p
.2 0 1 r
.002 w
.6242 .28684 m
.57805 .14482 L
s
P
p
0 .4 1 r
.018 w
.60882 .33417 m
.64909 .36343 L
s
P
p
0 .4 1 r
.018 w
.60882 .33417 m
.6242 .28684 L
s
P
p
.2 0 1 r
.002 w
.19111 .35543 m
.19111 .20611 L
s
P
p
.2 0 1 r
.002 w
.19111 .35543 m
.10334 .23463 L
s
P
p
.2 0 1 r
.002 w
.19111 .35543 m
.04909 .30929 L
s
P
p
.2 0 1 r
.002 w
.19111 .43597 m
.04909 .48211 L
s
P
p
.2 0 1 r
.002 w
.19111 .43597 m
.10334 .55677 L
s
P
p
.2 0 1 r
.002 w
.19111 .43597 m
.19111 .58529 L
s
P
p
0 .4 1 r
.018 w
.22036 .3957 m
.19111 .35543 L
s
P
p
0 .4 1 r
.018 w
.22036 .3957 m
.19111 .43597 L
s
P
p
.2 0 1 r
.016 w
.41946 .3957 m
.35794 .58505 L
s
P
p
.2 0 1 r
.016 w
.41946 .3957 m
.53649 .23463 L
s
P
p
.2 0 1 r
.016 w
.41946 .3957 m
.25839 .51273 L
s
P
p
.2 0 1 r
.016 w
.41946 .3957 m
.60882 .33417 L
s
P
p
.2 0 1 r
.016 w
.41946 .3957 m
.22036 .3957 L
s
P
p
.2 0 1 r
.002 w
.50151 .66149 m
.35949 .70763 L
s
P
p
.2 0 1 r
.002 w
.50151 .66149 m
.41374 .78229 L
s
P
p
.2 0 1 r
.002 w
.50151 .66149 m
.50151 .81081 L
s
P
p
.2 0 1 r
.002 w
.5781 .6366 m
.66587 .7574 L
s
P
p
.2 0 1 r
.002 w
.5781 .6366 m
.72012 .68274 L
s
P
p
.2 0 1 r
.002 w
.5781 .6366 m
.72012 .59045 L
s
P
p
0 .4 1 r
.018 w
.53076 .62122 m
.50151 .66149 L
s
P
p
0 .4 1 r
.018 w
.53076 .62122 m
.5781 .6366 L
s
P
p
.2 0 1 r
.002 w
.50951 .20351 m
.65883 .20351 L
s
P
p
.2 0 1 r
.002 w
.50951 .20351 m
.63031 .11574 L
s
P
p
.2 0 1 r
.002 w
.50951 .20351 m
.55565 .06149 L
s
P
p
.2 0 1 r
.002 w
.42897 .20351 m
.38283 .06149 L
s
P
p
.2 0 1 r
.002 w
.42897 .20351 m
.30816 .11574 L
s
P
p
.2 0 1 r
.002 w
.42897 .20351 m
.27965 .20351 L
s
P
p
0 .4 1 r
.018 w
.46924 .23276 m
.50951 .20351 L
s
P
p
0 .4 1 r
.018 w
.46924 .23276 m
.42897 .20351 L
s
P
p
.2 0 1 r
.002 w
.36037 .6366 m
.21836 .59045 L
s
P
p
.2 0 1 r
.002 w
.36037 .6366 m
.21836 .68274 L
s
P
p
.2 0 1 r
.002 w
.36037 .6366 m
.2726 .7574 L
s
P
p
.2 0 1 r
.002 w
.43697 .66149 m
.43697 .81081 L
s
P
p
.2 0 1 r
.002 w
.43697 .66149 m
.52474 .78229 L
s
P
p
.2 0 1 r
.002 w
.43697 .66149 m
.57898 .70763 L
s
P
p
0 .4 1 r
.018 w
.40771 .62122 m
.36037 .6366 L
s
P
p
0 .4 1 r
.018 w
.40771 .62122 m
.43697 .66149 L
s
P
p
.2 0 1 r
.002 w
.63604 .27079 m
.75684 .35856 L
s
P
p
.2 0 1 r
.002 w
.63604 .27079 m
.78536 .27079 L
s
P
p
.2 0 1 r
.002 w
.63604 .27079 m
.75684 .18302 L
s
P
p
.2 0 1 r
.002 w
.57088 .22345 m
.61703 .08144 L
s
P
p
.2 0 1 r
.002 w
.57088 .22345 m
.52474 .08144 L
s
P
p
.2 0 1 r
.002 w
.57088 .22345 m
.45008 .13568 L
s
P
p
0 .4 1 r
.018 w
.58626 .27079 m
.63604 .27079 L
s
P
p
0 .4 1 r
.018 w
.58626 .27079 m
.57088 .22345 L
s
P
p
.2 0 1 r
.002 w
.26083 .53351 m
.17305 .4127 L
s
P
p
.2 0 1 r
.002 w
.26083 .53351 m
.11881 .48737 L
s
P
p
.2 0 1 r
.002 w
.26083 .53351 m
.11881 .57965 L
s
P
p
.2 0 1 r
.002 w
.30816 .59866 m
.22039 .71947 L
s
P
p
.2 0 1 r
.002 w
.30816 .59866 m
.30816 .74799 L
s
P
p
.2 0 1 r
.002 w
.30816 .59866 m
.39593 .71947 L
s
P
p
0 .4 1 r
.018 w
.30816 .54889 m
.26083 .53351 L
s
P
p
0 .4 1 r
.018 w
.30816 .54889 m
.30816 .59866 L
s
P
p
.2 0 1 r
.016 w
.46924 .43186 m
.53076 .62122 L
s
P
p
.2 0 1 r
.016 w
.46924 .43186 m
.46924 .23276 L
s
P
p
.2 0 1 r
.016 w
.46924 .43186 m
.40771 .62122 L
s
P
p
.2 0 1 r
.016 w
.46924 .43186 m
.58626 .27079 L
s
P
p
.2 0 1 r
.016 w
.46924 .43186 m
.30816 .54889 L
s
P
p
.2 0 1 r
.002 w
.69184 .59866 m
.60407 .71947 L
s
P
p
.2 0 1 r
.002 w
.69184 .59866 m
.69184 .74799 L
s
P
p
.2 0 1 r
.002 w
.69184 .59866 m
.77961 .71947 L
s
P
p
.2 0 1 r
.002 w
.73917 .53351 m
.88119 .57965 L
s
P
p
.2 0 1 r
.002 w
.73917 .53351 m
.88119 .48737 L
s
P
p
.2 0 1 r
.002 w
.73917 .53351 m
.82695 .4127 L
s
P
p
0 .4 1 r
.018 w
.69184 .54889 m
.69184 .59866 L
s
P
p
0 .4 1 r
.018 w
.69184 .54889 m
.73917 .53351 L
s
P
p
.2 0 1 r
.002 w
.42912 .22345 m
.54992 .13568 L
s
P
p
.2 0 1 r
.002 w
.42912 .22345 m
.47526 .08144 L
s
P
p
.2 0 1 r
.002 w
.42912 .22345 m
.38297 .08144 L
s
P
p
.2 0 1 r
.002 w
.36396 .27079 m
.24316 .18302 L
s
P
p
.2 0 1 r
.002 w
.36396 .27079 m
.21464 .27079 L
s
P
p
.2 0 1 r
.002 w
.36396 .27079 m
.24316 .35856 L
s
P
p
0 .4 1 r
.018 w
.41374 .27079 m
.42912 .22345 L
s
P
p
0 .4 1 r
.018 w
.41374 .27079 m
.36396 .27079 L
s
P
p
.2 0 1 r
.002 w
.56303 .66149 m
.42102 .70763 L
s
P
p
.2 0 1 r
.002 w
.56303 .66149 m
.47526 .78229 L
s
P
p
.2 0 1 r
.002 w
.56303 .66149 m
.56303 .81081 L
s
P
p
.2 0 1 r
.002 w
.63963 .6366 m
.7274 .7574 L
s
P
p
.2 0 1 r
.002 w
.63963 .6366 m
.78164 .68274 L
s
P
p
.2 0 1 r
.002 w
.63963 .6366 m
.78164 .59045 L
s
P
p
0 .4 1 r
.018 w
.59229 .62122 m
.56303 .66149 L
s
P
p
0 .4 1 r
.018 w
.59229 .62122 m
.63963 .6366 L
s
P
p
.2 0 1 r
.002 w
.57103 .20351 m
.72035 .20351 L
s
P
p
.2 0 1 r
.002 w
.57103 .20351 m
.69184 .11574 L
s
P
p
.2 0 1 r
.002 w
.57103 .20351 m
.61717 .06149 L
s
P
p
.2 0 1 r
.002 w
.49049 .20351 m
.44435 .06149 L
s
P
p
.2 0 1 r
.002 w
.49049 .20351 m
.36969 .11574 L
s
P
p
.2 0 1 r
.002 w
.49049 .20351 m
.34117 .20351 L
s
P
p
0 .4 1 r
.018 w
.53076 .23276 m
.57103 .20351 L
s
P
p
0 .4 1 r
.018 w
.53076 .23276 m
.49049 .20351 L
s
P
p
.2 0 1 r
.002 w
.4219 .6366 m
.27988 .59045 L
s
P
p
.2 0 1 r
.002 w
.4219 .6366 m
.27988 .68274 L
s
P
p
.2 0 1 r
.002 w
.4219 .6366 m
.33413 .7574 L
s
P
p
.2 0 1 r
.002 w
.49849 .66149 m
.49849 .81081 L
s
P
p
.2 0 1 r
.002 w
.49849 .66149 m
.58626 .78229 L
s
P
p
.2 0 1 r
.002 w
.49849 .66149 m
.64051 .70763 L
s
P
p
0 .4 1 r
.018 w
.46924 .62122 m
.4219 .6366 L
s
P
p
0 .4 1 r
.018 w
.46924 .62122 m
.49849 .66149 L
s
P
p
.2 0 1 r
.016 w
.53076 .43186 m
.69184 .54889 L
s
P
p
.2 0 1 r
.016 w
.53076 .43186 m
.41374 .27079 L
s
P
p
.2 0 1 r
.016 w
.53076 .43186 m
.59229 .62122 L
s
P
p
.2 0 1 r
.016 w
.53076 .43186 m
.53076 .23276 L
s
P
p
.2 0 1 r
.016 w
.53076 .43186 m
.46924 .62122 L
s
P
p
.2 0 1 r
.002 w
.80889 .43597 m
.80889 .58529 L
s
P
p
.2 0 1 r
.002 w
.80889 .43597 m
.89666 .55677 L
s
P
p
.2 0 1 r
.002 w
.80889 .43597 m
.95091 .48211 L
s
P
p
.2 0 1 r
.002 w
.80889 .35543 m
.95091 .30929 L
s
P
p
.2 0 1 r
.002 w
.80889 .35543 m
.89666 .23463 L
s
P
p
.2 0 1 r
.002 w
.80889 .35543 m
.80889 .20611 L
s
P
p
0 .4 1 r
.018 w
.77964 .3957 m
.80889 .43597 L
s
P
p
0 .4 1 r
.018 w
.77964 .3957 m
.80889 .35543 L
s
P
p
.2 0 1 r
.002 w
.3758 .28684 m
.42195 .14482 L
s
P
p
.2 0 1 r
.002 w
.3758 .28684 m
.32966 .14482 L
s
P
p
.2 0 1 r
.002 w
.3758 .28684 m
.255 .19907 L
s
P
p
.2 0 1 r
.002 w
.35091 .36343 m
.20159 .36343 L
s
P
p
.2 0 1 r
.002 w
.35091 .36343 m
.23011 .4512 L
s
P
p
.2 0 1 r
.002 w
.35091 .36343 m
.30477 .50545 L
s
P
p
0 .4 1 r
.018 w
.39118 .33417 m
.3758 .28684 L
s
P
p
0 .4 1 r
.018 w
.39118 .33417 m
.35091 .36343 L
s
P
p
.2 0 1 r
.002 w
.74161 .5625 m
.65384 .68331 L
s
P
p
.2 0 1 r
.002 w
.74161 .5625 m
.74161 .71183 L
s
P
p
.2 0 1 r
.002 w
.74161 .5625 m
.82938 .68331 L
s
P
p
.2 0 1 r
.002 w
.78895 .49735 m
.93096 .54349 L
s
P
p
.2 0 1 r
.002 w
.78895 .49735 m
.93096 .4512 L
s
P
p
.2 0 1 r
.002 w
.78895 .49735 m
.87672 .37654 L
s
P
p
0 .4 1 r
.018 w
.74161 .51273 m
.74161 .5625 L
s
P
p
0 .4 1 r
.018 w
.74161 .51273 m
.78895 .49735 L
s
P
p
.2 0 1 r
.002 w
.47889 .18729 m
.5997 .09952 L
s
P
p
.2 0 1 r
.002 w
.47889 .18729 m
.52503 .04527 L
s
P
p
.2 0 1 r
.002 w
.47889 .18729 m
.43275 .04527 L
s
P
p
.2 0 1 r
.002 w
.41374 .23463 m
.29293 .14686 L
s
P
p
.2 0 1 r
.002 w
.41374 .23463 m
.26441 .23463 L
s
P
p
.2 0 1 r
.002 w
.41374 .23463 m
.29293 .3224 L
s
P
p
0 .4 1 r
.018 w
.46351 .23463 m
.47889 .18729 L
s
P
p
0 .4 1 r
.018 w
.46351 .23463 m
.41374 .23463 L
s
P
p
.2 0 1 r
.002 w
.6128 .62532 m
.47079 .67147 L
s
P
p
.2 0 1 r
.002 w
.6128 .62532 m
.52503 .74613 L
s
P
p
.2 0 1 r
.002 w
.6128 .62532 m
.6128 .77465 L
s
P
p
.2 0 1 r
.002 w
.6894 .60043 m
.77717 .72124 L
s
P
p
.2 0 1 r
.002 w
.6894 .60043 m
.83142 .64658 L
s
P
p
.2 0 1 r
.002 w
.6894 .60043 m
.83142 .55429 L
s
P
p
0 .4 1 r
.018 w
.64206 .58505 m
.6128 .62532 L
s
P
p
0 .4 1 r
.018 w
.64206 .58505 m
.6894 .60043 L
s
P
p
.2 0 1 r
.016 w
.58054 .3957 m
.77964 .3957 L
s
P
p
.2 0 1 r
.016 w
.58054 .3957 m
.39118 .33417 L
s
P
p
.2 0 1 r
.016 w
.58054 .3957 m
.74161 .51273 L
s
P
p
.2 0 1 r
.016 w
.58054 .3957 m
.46351 .23463 L
s
P
p
.2 0 1 r
.016 w
.58054 .3957 m
.64206 .58505 L
s
P
p
1 .6 0 r
.016 w
.5 .33719 m
.41946 .3957 L
s
P
p
1 .6 0 r
.016 w
.5 .33719 m
.46924 .43186 L
s
P
p
1 .6 0 r
.016 w
.5 .33719 m
.53076 .43186 L
s
P
p
1 .6 0 r
.016 w
.5 .33719 m
.58054 .3957 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0608586 0.952381 [
[ 0 0 0 0 ]
[ 1 .83066 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .83066 L
0 .83066 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .53189 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .62025 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.21533 .69174 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.37271 .74288 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.45675 .71557 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.50869 .64408 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.29937 .57607 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.37271 .5999 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .30985 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.7063 .22581 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .14177 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.54512 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.45675 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.38526 .09644 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.56332 .22581 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.50093 .18048 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.12002 .36169 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .43318 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .52154 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.16534 .65542 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.24938 .68273 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.33342 .65542 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.20405 .47736 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.24938 .53975 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.66765 .48512 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.73914 .43318 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.76645 .34914 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.71531 .19176 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.64382 .13982 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.55546 .13982 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.62347 .34914 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.59964 .2758 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.18496 .1985 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.10092 .22581 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.04898 .2973 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.04898 .46278 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.10092 .53426 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.18496 .56157 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .34148 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .41859 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.3447 .56134 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.51566 .22581 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.24938 .49209 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.58491 .32113 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.21297 .38004 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.3581 .68736 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.41004 .75885 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.49408 .78616 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.65146 .73502 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .66353 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .57517 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.49408 .64318 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.56742 .61935 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.64471 .20467 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.61741 .12063 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.54592 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.38044 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.30895 .12063 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.28165 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.50174 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.42462 .20467 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .57517 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .66353 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.27491 .73502 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.43229 .78616 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.51632 .75885 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.56826 .68736 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.35895 .61935 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.43229 .64318 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .35313 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.76587 .26909 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .18505 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.60469 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.51632 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.44484 .13973 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.62289 .26909 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.56051 .22377 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.17959 .40497 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .47646 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .56483 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.22492 .6987 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.30895 .72601 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.39299 .6987 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.26363 .52065 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.30895 .58303 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.52209 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.46318 .23269 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.40427 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.57523 .26909 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.30895 .53537 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.60701 .6987 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.69105 .72601 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.77508 .6987 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .56483 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .47646 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.82041 .40497 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.69105 .58303 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.73637 .52065 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.55516 .13973 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.48368 .08779 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.39531 .08779 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .18505 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.23413 .26909 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .35313 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.43949 .22377 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.37711 .26909 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.43174 .68736 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.48368 .75885 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.56771 .78616 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.72509 .73502 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .66353 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .57517 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.56771 .64318 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.64105 .61935 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.71835 .20467 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.69105 .12063 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.61956 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.45408 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.38259 .12063 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.35529 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.57538 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.49826 .20467 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .57517 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .66353 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.34854 .73502 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.50592 .78616 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.58996 .75885 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.6419 .68736 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.43258 .61935 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.50592 .64318 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.69105 .53537 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.42477 .26909 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.59573 .60462 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.53682 .23269 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.47791 .60462 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.81504 .56157 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.89908 .53426 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.95102 .46278 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.95102 .2973 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.89908 .22581 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.81504 .1985 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .41859 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .34148 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.44454 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.35618 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.28469 .19176 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.23355 .34914 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.26086 .43318 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.33235 .48512 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.40036 .2758 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.37653 .34914 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.66658 .65542 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.75062 .68273 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.83466 .65542 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .52154 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .43318 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.87998 .36169 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.75062 .53975 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.79595 .47736 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.61474 .09644 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.54325 .04451 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.45488 .04451 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .14177 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.2937 .22581 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .30985 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.49907 .18048 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.43668 .22581 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.49131 .64408 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.54325 .71557 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.62729 .74288 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.78467 .69174 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .62025 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .53189 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.62729 .5999 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.70063 .57607 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.78703 .38004 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.41509 .32113 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.75062 .49209 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.48434 .22581 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.6553 .56134 L
s
P
p
1 .6 0 r
.014 w
.5 .31 m
.40361 .38004 L
s
P
p
1 .6 0 r
.014 w
.5 .31 m
.46318 .42332 L
s
P
p
1 .6 0 r
.014 w
.5 .31 m
.53682 .42332 L
s
P
p
1 .6 0 r
.014 w
.5 .31 m
.59639 .38004 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0608586 0.952381 [
[ 0 0 0 0 ]
[ 1 .83066 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .83066 L
0 .83066 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .53189 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .62025 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.21533 .69174 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.37271 .74288 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.45675 .71557 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.50869 .64408 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.29937 .57607 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.37271 .5999 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .30985 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.7063 .22581 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .14177 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.54512 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.45675 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.38526 .09644 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.56332 .22581 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.50093 .18048 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.12002 .36169 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .43318 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .52154 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.16534 .65542 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.24938 .68273 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.33342 .65542 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.20405 .47736 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.24938 .53975 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.66765 .48512 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.73914 .43318 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.76645 .34914 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.71531 .19176 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.64382 .13982 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.55546 .13982 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.62347 .34914 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.59964 .2758 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.18496 .1985 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.10092 .22581 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.04898 .2973 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.04898 .46278 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.10092 .53426 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.18496 .56157 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .34148 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .41859 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.3447 .56134 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.51566 .22581 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.24938 .49209 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.58491 .32113 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.21297 .38004 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.3581 .68736 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.41004 .75885 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.49408 .78616 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.65146 .73502 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .66353 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .57517 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.49408 .64318 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.56742 .61935 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.64471 .20467 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.61741 .12063 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.54592 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.38044 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.30895 .12063 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.28165 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.50174 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.42462 .20467 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .57517 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .66353 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.27491 .73502 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.43229 .78616 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.51632 .75885 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.56826 .68736 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.35895 .61935 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.43229 .64318 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .35313 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.76587 .26909 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .18505 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.60469 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.51632 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.44484 .13973 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.62289 .26909 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.56051 .22377 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.17959 .40497 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .47646 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .56483 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.22492 .6987 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.30895 .72601 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.39299 .6987 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.26363 .52065 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.30895 .58303 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.52209 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.46318 .23269 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.40427 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.57523 .26909 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.30895 .53537 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.60701 .6987 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.69105 .72601 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.77508 .6987 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .56483 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .47646 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.82041 .40497 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.69105 .58303 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.73637 .52065 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.55516 .13973 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.48368 .08779 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.39531 .08779 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .18505 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.23413 .26909 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .35313 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.43949 .22377 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.37711 .26909 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.43174 .68736 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.48368 .75885 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.56771 .78616 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.72509 .73502 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .66353 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .57517 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.56771 .64318 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.64105 .61935 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.71835 .20467 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.69105 .12063 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.61956 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.45408 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.38259 .12063 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.35529 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.57538 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.49826 .20467 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .57517 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .66353 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.34854 .73502 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.50592 .78616 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.58996 .75885 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.6419 .68736 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.43258 .61935 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.50592 .64318 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.69105 .53537 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.42477 .26909 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.59573 .60462 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.53682 .23269 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.47791 .60462 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.81504 .56157 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.89908 .53426 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.95102 .46278 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.95102 .2973 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.89908 .22581 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.81504 .1985 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .41859 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .34148 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.44454 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.35618 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.28469 .19176 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.23355 .34914 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.26086 .43318 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.33235 .48512 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.40036 .2758 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.37653 .34914 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.66658 .65542 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.75062 .68273 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.83466 .65542 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .52154 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .43318 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.87998 .36169 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.75062 .53975 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.79595 .47736 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.61474 .09644 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.54325 .04451 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.45488 .04451 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .14177 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.2937 .22581 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .30985 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.49907 .18048 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.43668 .22581 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.49131 .64408 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.54325 .71557 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.62729 .74288 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.78467 .69174 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .62025 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .53189 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.62729 .5999 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.70063 .57607 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.78703 .38004 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.41509 .32113 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.75062 .49209 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.48434 .22581 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.6553 .56134 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.40361 .38004 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.46318 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.53682 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.59639 .38004 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0455606 0.952381 [
[ 0 0 0 0 ]
[ 1 .86126 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .86126 L
0 .86126 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.58697 .57943 m
.51721 .71634 L
s
P
p
.2 0 1 r
.002 w
.58697 .57943 m
.61101 .7312 L
s
P
p
.2 0 1 r
.002 w
.58697 .57943 m
.69562 .68809 L
s
P
p
.2 0 1 r
.002 w
.62459 .50559 m
.77636 .52962 L
s
P
p
.2 0 1 r
.002 w
.62459 .50559 m
.76151 .43582 L
s
P
p
.2 0 1 r
.002 w
.62459 .50559 m
.69436 .36867 L
s
P
p
0 .4 1 r
.018 w
.57896 .52884 m
.58697 .57943 L
s
P
p
0 .4 1 r
.018 w
.57896 .52884 m
.62459 .50559 L
s
P
p
.2 0 1 r
.002 w
.25954 .24036 m
.3682 .1317 L
s
P
p
.2 0 1 r
.002 w
.25954 .24036 m
.28358 .08859 L
s
P
p
.2 0 1 r
.002 w
.25954 .24036 m
.18978 .10345 L
s
P
p
.2 0 1 r
.002 w
.20094 .29896 m
.06403 .2292 L
s
P
p
.2 0 1 r
.002 w
.20094 .29896 m
.04917 .323 L
s
P
p
.2 0 1 r
.002 w
.20094 .29896 m
.09228 .40762 L
s
P
p
0 .4 1 r
.018 w
.25153 .29095 m
.25954 .24036 L
s
P
p
0 .4 1 r
.018 w
.25153 .29095 m
.20094 .29896 L
s
P
p
.2 0 1 r
.002 w
.46617 .66401 m
.32925 .73378 L
s
P
p
.2 0 1 r
.002 w
.46617 .66401 m
.3964 .80093 L
s
P
p
.2 0 1 r
.002 w
.46617 .66401 m
.4902 .81579 L
s
P
p
.2 0 1 r
.002 w
.54001 .62639 m
.64866 .73504 L
s
P
p
.2 0 1 r
.002 w
.54001 .62639 m
.69178 .65043 L
s
P
p
.2 0 1 r
.002 w
.54001 .62639 m
.67692 .55663 L
s
P
p
0 .4 1 r
.018 w
.48942 .61838 m
.46617 .66401 L
s
P
p
0 .4 1 r
.018 w
.48942 .61838 m
.54001 .62639 L
s
P
p
.2 0 1 r
.002 w
.40057 .19725 m
.55234 .17321 L
s
P
p
.2 0 1 r
.002 w
.40057 .19725 m
.50923 .08859 L
s
P
p
.2 0 1 r
.002 w
.40057 .19725 m
.42461 .04547 L
s
P
p
.2 0 1 r
.002 w
.31871 .21021 m
.24895 .0733 L
s
P
p
.2 0 1 r
.002 w
.31871 .21021 m
.1818 .14045 L
s
P
p
.2 0 1 r
.002 w
.31871 .21021 m
.16694 .23425 L
s
P
p
0 .4 1 r
.018 w
.36435 .23346 m
.40057 .19725 L
s
P
p
0 .4 1 r
.018 w
.36435 .23346 m
.31871 .21021 L
s
P
p
.2 0 1 r
.016 w
.3964 .43582 m
.57896 .52884 L
s
P
p
.2 0 1 r
.016 w
.3964 .43582 m
.25153 .29095 L
s
P
p
.2 0 1 r
.016 w
.3964 .43582 m
.48942 .61838 L
s
P
p
.2 0 1 r
.016 w
.3964 .43582 m
.36435 .23346 L
s
P
p
.2 0 1 r
.002 w
.69901 .48651 m
.72305 .63828 L
s
P
p
.2 0 1 r
.002 w
.69901 .48651 m
.80766 .59517 L
s
P
p
.2 0 1 r
.002 w
.69901 .48651 m
.85078 .51055 L
s
P
p
.2 0 1 r
.002 w
.68604 .40465 m
.82296 .33489 L
s
P
p
.2 0 1 r
.002 w
.68604 .40465 m
.75581 .26774 L
s
P
p
.2 0 1 r
.002 w
.68604 .40465 m
.66201 .25288 L
s
P
p
0 .4 1 r
.018 w
.66279 .45029 m
.69901 .48651 L
s
P
p
0 .4 1 r
.018 w
.66279 .45029 m
.68604 .40465 L
s
P
p
.2 0 1 r
.002 w
.23482 .40465 m
.25885 .25288 L
s
P
p
.2 0 1 r
.002 w
.23482 .40465 m
.16505 .26774 L
s
P
p
.2 0 1 r
.002 w
.23482 .40465 m
.0979 .33489 L
s
P
p
.2 0 1 r
.002 w
.22185 .48651 m
.07008 .51055 L
s
P
p
.2 0 1 r
.002 w
.22185 .48651 m
.11319 .59517 L
s
P
p
.2 0 1 r
.002 w
.22185 .48651 m
.19781 .63828 L
s
P
p
0 .4 1 r
.018 w
.25807 .45029 m
.23482 .40465 L
s
P
p
0 .4 1 r
.018 w
.25807 .45029 m
.22185 .48651 L
s
P
p
.2 0 1 r
.002 w
.65099 .62595 m
.58123 .76286 L
s
P
p
.2 0 1 r
.002 w
.65099 .62595 m
.67503 .77772 L
s
P
p
.2 0 1 r
.002 w
.65099 .62595 m
.75965 .7346 L
s
P
p
.2 0 1 r
.002 w
.68862 .5521 m
.84039 .57614 L
s
P
p
.2 0 1 r
.002 w
.68862 .5521 m
.82553 .48234 L
s
P
p
.2 0 1 r
.002 w
.68862 .5521 m
.75838 .41519 L
s
P
p
0 .4 1 r
.018 w
.64298 .57536 m
.65099 .62595 L
s
P
p
0 .4 1 r
.018 w
.64298 .57536 m
.68862 .5521 L
s
P
p
.2 0 1 r
.002 w
.32357 .28688 m
.43222 .17822 L
s
P
p
.2 0 1 r
.002 w
.32357 .28688 m
.34761 .13511 L
s
P
p
.2 0 1 r
.002 w
.32357 .28688 m
.25381 .14996 L
s
P
p
.2 0 1 r
.002 w
.26497 .34548 m
.12805 .27572 L
s
P
p
.2 0 1 r
.002 w
.26497 .34548 m
.11319 .36952 L
s
P
p
.2 0 1 r
.002 w
.26497 .34548 m
.15631 .45414 L
s
P
p
0 .4 1 r
.018 w
.31556 .33747 m
.32357 .28688 L
s
P
p
0 .4 1 r
.018 w
.31556 .33747 m
.26497 .34548 L
s
P
p
.2 0 1 r
.016 w
.46043 .48234 m
.66279 .45029 L
s
P
p
.2 0 1 r
.016 w
.46043 .48234 m
.25807 .45029 L
s
P
p
.2 0 1 r
.016 w
.46043 .48234 m
.64298 .57536 L
s
P
p
.2 0 1 r
.016 w
.46043 .48234 m
.31556 .33747 L
s
P
p
.2 0 1 r
.002 w
.73503 .34548 m
.84369 .45414 L
s
P
p
.2 0 1 r
.002 w
.73503 .34548 m
.88681 .36952 L
s
P
p
.2 0 1 r
.002 w
.73503 .34548 m
.87195 .27572 L
s
P
p
.2 0 1 r
.002 w
.67643 .28688 m
.74619 .14996 L
s
P
p
.2 0 1 r
.002 w
.67643 .28688 m
.65239 .13511 L
s
P
p
.2 0 1 r
.002 w
.67643 .28688 m
.56778 .17822 L
s
P
p
0 .4 1 r
.018 w
.68444 .33747 m
.73503 .34548 L
s
P
p
0 .4 1 r
.018 w
.68444 .33747 m
.67643 .28688 L
s
P
p
.2 0 1 r
.002 w
.31138 .5521 m
.24162 .41519 L
s
P
p
.2 0 1 r
.002 w
.31138 .5521 m
.17447 .48234 L
s
P
p
.2 0 1 r
.002 w
.31138 .5521 m
.15961 .57614 L
s
P
p
.2 0 1 r
.002 w
.34901 .62595 m
.24035 .7346 L
s
P
p
.2 0 1 r
.002 w
.34901 .62595 m
.32497 .77772 L
s
P
p
.2 0 1 r
.002 w
.34901 .62595 m
.41877 .76286 L
s
P
p
0 .4 1 r
.018 w
.35702 .57536 m
.31138 .5521 L
s
P
p
0 .4 1 r
.018 w
.35702 .57536 m
.34901 .62595 L
s
P
p
.2 0 1 r
.002 w
.77815 .48651 m
.80219 .63828 L
s
P
p
.2 0 1 r
.002 w
.77815 .48651 m
.88681 .59517 L
s
P
p
.2 0 1 r
.002 w
.77815 .48651 m
.92992 .51055 L
s
P
p
.2 0 1 r
.002 w
.76518 .40465 m
.9021 .33489 L
s
P
p
.2 0 1 r
.002 w
.76518 .40465 m
.83495 .26774 L
s
P
p
.2 0 1 r
.002 w
.76518 .40465 m
.74115 .25288 L
s
P
p
0 .4 1 r
.018 w
.74193 .45029 m
.77815 .48651 L
s
P
p
0 .4 1 r
.018 w
.74193 .45029 m
.76518 .40465 L
s
P
p
.2 0 1 r
.002 w
.31396 .40465 m
.33799 .25288 L
s
P
p
.2 0 1 r
.002 w
.31396 .40465 m
.24419 .26774 L
s
P
p
.2 0 1 r
.002 w
.31396 .40465 m
.17704 .33489 L
s
P
p
.2 0 1 r
.002 w
.30099 .48651 m
.14922 .51055 L
s
P
p
.2 0 1 r
.002 w
.30099 .48651 m
.19234 .59517 L
s
P
p
.2 0 1 r
.002 w
.30099 .48651 m
.27695 .63828 L
s
P
p
0 .4 1 r
.018 w
.33721 .45029 m
.31396 .40465 L
s
P
p
0 .4 1 r
.018 w
.33721 .45029 m
.30099 .48651 L
s
P
p
.2 0 1 r
.016 w
.53957 .48234 m
.68444 .33747 L
s
P
p
.2 0 1 r
.016 w
.53957 .48234 m
.35702 .57536 L
s
P
p
.2 0 1 r
.016 w
.53957 .48234 m
.74193 .45029 L
s
P
p
.2 0 1 r
.016 w
.53957 .48234 m
.33721 .45029 L
s
P
p
.2 0 1 r
.002 w
.68129 .21021 m
.83306 .23425 L
s
P
p
.2 0 1 r
.002 w
.68129 .21021 m
.8182 .14045 L
s
P
p
.2 0 1 r
.002 w
.68129 .21021 m
.75105 .0733 L
s
P
p
.2 0 1 r
.002 w
.59943 .19725 m
.57539 .04547 L
s
P
p
.2 0 1 r
.002 w
.59943 .19725 m
.49077 .08859 L
s
P
p
.2 0 1 r
.002 w
.59943 .19725 m
.44766 .17321 L
s
P
p
0 .4 1 r
.018 w
.63565 .23346 m
.68129 .21021 L
s
P
p
0 .4 1 r
.018 w
.63565 .23346 m
.59943 .19725 L
s
P
p
.2 0 1 r
.002 w
.45999 .62639 m
.32308 .55663 L
s
P
p
.2 0 1 r
.002 w
.45999 .62639 m
.30822 .65043 L
s
P
p
.2 0 1 r
.002 w
.45999 .62639 m
.35134 .73504 L
s
P
p
.2 0 1 r
.002 w
.53383 .66401 m
.5098 .81579 L
s
P
p
.2 0 1 r
.002 w
.53383 .66401 m
.6036 .80093 L
s
P
p
.2 0 1 r
.002 w
.53383 .66401 m
.67075 .73378 L
s
P
p
0 .4 1 r
.018 w
.51058 .61838 m
.45999 .62639 L
s
P
p
0 .4 1 r
.018 w
.51058 .61838 m
.53383 .66401 L
s
P
p
.2 0 1 r
.002 w
.79906 .29896 m
.90772 .40762 L
s
P
p
.2 0 1 r
.002 w
.79906 .29896 m
.95083 .323 L
s
P
p
.2 0 1 r
.002 w
.79906 .29896 m
.93597 .2292 L
s
P
p
.2 0 1 r
.002 w
.74046 .24036 m
.81022 .10345 L
s
P
p
.2 0 1 r
.002 w
.74046 .24036 m
.71642 .08859 L
s
P
p
.2 0 1 r
.002 w
.74046 .24036 m
.6318 .1317 L
s
P
p
0 .4 1 r
.018 w
.74847 .29095 m
.79906 .29896 L
s
P
p
0 .4 1 r
.018 w
.74847 .29095 m
.74046 .24036 L
s
P
p
.2 0 1 r
.002 w
.37541 .50559 m
.30564 .36867 L
s
P
p
.2 0 1 r
.002 w
.37541 .50559 m
.23849 .43582 L
s
P
p
.2 0 1 r
.002 w
.37541 .50559 m
.22364 .52962 L
s
P
p
.2 0 1 r
.002 w
.41303 .57943 m
.30438 .68809 L
s
P
p
.2 0 1 r
.002 w
.41303 .57943 m
.38899 .7312 L
s
P
p
.2 0 1 r
.002 w
.41303 .57943 m
.48279 .71634 L
s
P
p
0 .4 1 r
.018 w
.42104 .52884 m
.37541 .50559 L
s
P
p
0 .4 1 r
.018 w
.42104 .52884 m
.41303 .57943 L
s
P
p
.2 0 1 r
.016 w
.6036 .43582 m
.63565 .23346 L
s
P
p
.2 0 1 r
.016 w
.6036 .43582 m
.51058 .61838 L
s
P
p
.2 0 1 r
.016 w
.6036 .43582 m
.74847 .29095 L
s
P
p
.2 0 1 r
.016 w
.6036 .43582 m
.42104 .52884 L
s
P
p
1 .6 0 r
.016 w
.5 .36056 m
.3964 .43582 L
s
P
p
1 .6 0 r
.016 w
.5 .36056 m
.46043 .48234 L
s
P
p
1 .6 0 r
.016 w
.5 .36056 m
.53957 .48234 L
s
P
p
1 .6 0 r
.016 w
.5 .36056 m
.6036 .43582 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`0001D000A=001=7`02C@0304d0020000==00007`000dd0C@0P0003C@1=0200
00==04d080001480@T8F00004`000d`0C0020004C000C1X000I<04a<04`20003C00001T00T`00`1<
0002C1`01d`K0006C000C01<0P000d`0000H0006C000C01<0P000d`0000H0005@P00@P000T800`12
000C00004`06C@0304e=01X01Td00`1=C@0I0003C@1=00I=00<0C@005`000dd0C@07CAX014d00`1=
C@02CAX00Td01@1=CDd0009=6P02@P03049200A2500001403D`F00e<5`000d`0C007C1P01d`00`1<
C003C1H03D`F00e<5P0=@Q80000B00Y=6@0:CAL03ddD0005C@1=C@001dd00`1=000F00E=00?6CDd0
0ddH00]=600;@Q<0000=0003C01<00M<00?6C<H01D`20003C00000`000=<04`01d`00kA<]005C080
00=<00002P000d`0000200M<00?6C<H014`50003C00000d000=<000014`00lI<C002C00304`001@0
1d`01<I<a/H4C14000=<04`01d`00lI<aP06C00304`000d000=204801d800lI2aP06@P03048000d0
000:0004C@00C@801Dd01LI=CDg600A=0`0014d004d80004C@00C@801Dd01KA=CDfd00A=0`0014d0
04d90003C@0000M=00G6CDe=aP06C@<000==00001`001Td0001=00E=00G6CLI=aP06C@<000==0000
1`000dd0C@0400A=00G6C@1=aP04C@@000==04d0200014d004d200E=0/H2C@03aTe=00==0P0014d0
04d80004@P00@P801D82aP9=00?6@T800d820004@P00@P/0000:0003C00000Q<00<0C4`00T`2aPA<
00D0C000C0080003C00000e<0[@4C00504`004`01`02C00304`000801D`00`1<C002C0;60T`40004
C01<C0L000I<0000C009C003aTa<00A<0`000d`000070003C01<00801D`02<H0C01<04c614`20003
C01<00P000E<001<000;C0;614`01@1<001<00P000E200120006@PE<0/H6@P8000=200002@0000T0
0dd00`1=0002009=00<0aP0014d00lH0C@040003C@1=009=1P03C@0304d000800Td00`2dC@04C@03
]01=00@000==04d00Td8009=0P03C@8000?604d00dd00lH00002C@<00Td:0003C@0000E=00?6CDd0
14d2aPE=00<0C@002004C@@00Td02@3604dAC@1=0002C@@014d600==00<0C@000P02C@030<I=00A=
00C604e=0`000dd0C@02C@H00d800`120002009200<0aTd014d01<H0@T830003@P1200922P0000/0
0d`2009<0P02C0<A0T`20004C00000=<2P03C0800T`2009<0a42C08000A<00000d`;0003C01<00D0
0T`34@9<100014`004`<009<00<0C4`01D`34@=<00<0C4`00T`00`1<000:009<0`0014`00002C0<A
0T`30004C000009<2P03C0800T`2009<0a42C0800T`200=<2P03@P800T82009<0a42C0800T8200=2
300000/000==0<H01Dd02LH04DdACA40aP04C@040<H0C@X000==0;@01Dd02K@04DdACA40]004C@04
0;@0C@`000?600000P002dg6015=4DdA0<I=00@000?600002004C@04aP00009=00[6015=4DdA0<I=
10000lI=C@02C@T000?6000014d02LH04DdACA40aP04C@8000?600002@0014d0aP04C@09aP0ACA5=
4@3600E=00?604d02P001480aP04@P09aP0ACA5=4@3600E200?60480300000/000=<00001T`01a5<
4D`A01401T`20003C00000P000=<00001T`01a5<4D`A01401T`20003C00000/01T`01a5<4D`A0140
1T`>0003C01<00E<00LAC15<4@0A00I<00<0C0002P000d`0C006C0074D`AC1404@07C00304`000T0
00=<00001T`01a5<4D`A01401T`20003C00000P000=200000d`02T9<@Q5<4D`A0146C08000=20000
2P0000`00Td200I=00<A01401Dd30003aTd000/00Td200I=00<A01401Td20003]4d000P00Td0101=
aTd30007C@1=CA404@02C@0704d004d0aP03C@L014d01LI=04d000A=00<A01401Dd200I=20000dg6
C@020003C@1=00==00<A014014d01P1=001=aP9=2P02C@801Td00a404@06C@8000?6C@002`02@P80
00A2CDe20Td00a404@02C@04@Te=@P8000?6@P00300000T01D`0101<C003C00504`0C0000d`00`1<
0002C00404a<C0H01D`0101<C003C00504`0C0000d`00`1<C002C00404a<C0P00d`30009C01<C01<
04`0009<00<0C0000P03C0P01D`01@1<04`0009<00D0C01<0002C00704a<C01<0003C0H01D`300A<
00D0C01<0004C0<01D`600Q<00T0C4a<04`0C0000d`01P1<C01<00=<1P07@P03C012009<00D0C01<
0002C007@P1<@P120003@PX000090003C@1=00A=0P02C@0704d0C@1=0002C@8000==aTd00Td00`1=
00050003C@1=00A=0P02C@0704d0C@1=0002C@8000==]4d00Td00`1=000500E=00?604d00P002Dd0
C@1=04d0C@020004C@36aPA=2006C@8000U=04d0C@1=04d00P02C@04aTe=C@X00Td01LI=04d0009=
00L0C@1=04d0009=00<0C@000/H2C@P000==04d014d2009=00L0C@1=04d0009=0P000dg6C@02C@03
04d000D000=204801482000;@Td0C@1=04d0CD800P000dg6@P02@P03048000T0000900=<00<0C4`0
0/H02P1<C01<04`0C002C0030<K6009<00@0C4a<1P03C00304a<00:d00X0C4`0C01<04`00T`00`2d
]002C00404a<C0H000E<001<0002C0800T`01`1<04`0C0000T`2009<00D0C000C00800E<00_604a<
04`0C01<0002C0030<I<00=<2@02C00304a<009<0P02C00704`0C01<0002C08014`00`1<C00600=<
00H0C01<aP02C00704`0C01<0002C0030<K6009<00@0C4a<1P03@P060480@/H00T`01`1<04`0C000
0T`00`36aP02@P040492@PX0000:0003C@1=009=00C604e=0P001Dd0C@1=00800Td00`36C@02C@03
04d000L000==04d00Td01;@0CDd20005C@1=04d00P02C@030;A=009=00<0C@002004C@;60Td20005
C@1=04d00P02C@;614d9009=0P05C@8000E=04d0C@0200E=0P000dd0000900==0/H2C@8000E=04d0
C@02009=0/H3C@X000==04d00Td01<H0CDd20005C@1=04d00P02C@030<I=009=00<0C@001`000d80
@P02@P04aP1=C@8000E=04d0C@02009=00<0aT800T800`12000:00002`000d`0C005C00;04`0C01<
04`0C<H014`00`1<00090003C01<00M<00D0C01<0003C003]4a<009<00<0C0002@05C0;600]<04`0
C01<04`0C002aPE<2@001D`004`0009<00W6C4a<04`0C0000d`00lI<C002C08000=<00001`02C003
04a<00;600]<04`0C01<04`0C002aP9<00<0C4`02P000d`0C007C00904`0C01<04c600A<00<0C000
2@000d80@P05@P0;04`0C01<04`0C<H014800`12000;00003@0:C@0504e=CLH01Td>00E=0[@014fd
C@03C@03]4e=00A=3`02C@0?0<H0aTd0C@1=04g60<H0009=3P04C@0304e=009=00?6CDd00dd01<I=
C@04C@d02Td01`1=CDg6CLH014d>00I=00G6CLI=0003C@;61Dd>00U200==04d00T800lI2@P04@Ph0
000<009<00<0C4`014`01LI<C4c600I<00<0C4`03002C00304a<00=<00<0C4`00T`00k@0C004C003
04a<00h01d`2aP060<I<aTc614`=009<00<0C4`01d`00lI<C007C00304`000/000=<00000d`00lI<
C002aP9<0/H00dc6C002C08000=<00002P02C00304a<00=<00<0C4`00T`00lH0C004C00304a<00`0
0T800`12@P04@P05aT92@/H00T801LI2@T8000923@0000`000==04d03dd01@1=C@1=00`000==04d0
3dd01@1=C@1=00d00Td03P1=C@1=0<I=aTg604d00Td00`1=C@0>00U=00<0C@002Dd?009=00<0CDd0
0Td00lI=aP06C@0304e=00h000E=04e=000@C@0304d000/000=204804T800`12000<00003P02C003
04a<00U<00<0C0000T`@009<00<0C4`02D`00`1<0002C0l000M<001<04`000M<00@0C01<0P000d`0
000>0005C01<C0001d`01@1<C01<014000E<001<0009C00504`004`04002C00304`000]<00<0C4`0
4002@P03048000]200<0@T803`00010014d00`1=C@03C@0304e=009=5004C@0304e=00==00<0CDd0
0TdC0003C@1=00E=00<0CDd014d00`1=000C009=00<0CDd01Dd00`1=C@0E00A=00<0CDd00dd00`1=
C@02CA@014d00`1=C@03C@0304e=009=5004@P03049200=200<0@T800T8A00005004C00304a<01`0
14`00`1<C00L0007C01<04`0C00I0005C01<C0000d`01@1<001<01T00T`00`1<0002C1`00T`00`1<
C002C1`00T800`12@P02@QD0000E0005C@1=04d07P001Dd0C@1=01h00Td00`1=C@0L0008C@00C@1=
04dM0005C@1=04d07P001Dd0C@1=01h000E20480@P0F0000o`030000o`030000o`030000o`030000
o`030000o`030000o`030000o`030000o`0300005@001Dd0001=0>P0000B0004C000C0<000A<001<
6`02C00304a<01l000=<04`080000d`0C0140003C00001h00T`00`1<C00F00003`001Dd004d0009=
0`02C@0504d004d05P001Dd0CDd0009=00<0C@006@001Td0CDd0C@8000==000060001Td004d0C@80
00==00006`000dd0C@0N00M=6`09CA@0000<0007C000C01<0005C00304a<009<00<0C4`00P000d`0
000A00I<00<0C4`06P06C00304a<01X00T`01@1<C4`0009<6P02C00504`0C0000T`I00]<6@09C1@0
000<0003C@0000M=00<0C@001dd20003C@0000h00Td00`1=C@09CAH03DdF00e=5P002Td004d0C@1=
04d20003C@0001D02ddG00i=4@0000d000A<04a<0P06C004aTa<00=<00<0C0004@0<C1P02d`H00]<
5`0=C1D000=<04`02T`00`1<000C00M<00?6C4`01D`A00003P04C@0304d0009=00?6CLH00Td00`1=
C@02C@l000==04d00Td00`1=C@02C@05aTe=C@000dd20003C@0000`000==04d01dd00lI=aP06C@03
04d000d000==04d01dd00lI=aP06C@0304d001001Td00lH0C@06CA@01dd00lI=aP05CA4000==04d0
1Td5aPE=00<0C@003@0000l000?6C4`00d`01/I<04c6C0;60T`00lH0000;0004C000C0801D`2aP03
C<K600E<0P0014`004`80004C000C0801D`01LI<C4c600E<0P0014`004`80004C000C0801D`5aPE<
0P0014`004`;0003C00000Q<00?6C4`014`20003C00000/000A<00001D`2aP9<00?6C4`00d`30003
C00000P000A<001<0P04C0?60T`00lI<C003C08000A<001<2`0000T00dd200==0P03C@<00Td01LH0
04g600<00dd70004C@00C@@02Dd00`1=00030004C@00C@P000==00003Dd2aPA=00D0C@00C@080005
C@00C@001Td7aPA=00D0C@00C@0;0005C@1=C@000Td00lI=C@06C@0504e=04d02`000dd0C@0200I=
00C6CDe=0lH4C@8000==04d02@000dd0C@04009=0/H3C@;600==04d00`000dd0C@0<00003006C004
04a<C0<00T`00lH0C002C0;600=<00001`03C00304a<00A<0/H2C00304a<00;614`00`1<0003C0H0
0d`00`1<0002009<00<0aT`014`01<H0C4`30003C01<009<1P03C00304`000800T`00`36aP05aP03
04a<00<000=<04`00T`6009<0`000d`0C005C003aP1<00I<00<0C0000P02C0P00T`3009<0P000lI<
C003C003aP00009<0`02C0P02T`2aPE<0lH9C0X0000:00a=0a47C@0304d0009=2@03C@<000E=0000
C@034@04C@00C@@00dd:00==0P02C@800Td34@9=0P02C@800dd:00==0P02C@800/H34@;60P02C@80
0dd:0003C@0000Q=0a48C@8000==00001P05C@0404e=C@800Td34@9=0P03C@0304e=00==2@0014g6
0002C@800Td34@9=0P02C@8000?6C@00300000T024`02LI<aT`A01404@02C003aTa<009<00<0C4`0
0T`80004C03600E<00O64D`AC17600E<00@0aP1<2P000d`0aP05C009aP0AC15<4@3600A<00@0aP1<
2P000d`0aP05C009aP0AaQ764@3600A<00@0aP1<2`000d`0C006C0054D`AC1401D`01<I<04`<0003
C<H000<000]<aP0AC15<4@36C0040003aT`000X000=<0<H01D`02LH04D`AC140aP05C004aP00C0/0
000:009=00<0CDd00P0014d0CA42C@094De=4Dd0C@36009=00<0CDd02@000dd0C@06C@074@0ACA40
4@07C@0304d000T000==00001Td01a5=4DdA01401Td20003C@0000P000==00000lH02Tg6CA764LHA
0146aP8000==00001P04C@03aTe=00A=00LACA5=4@0A00]=20000dd00006C@074DdACA404@06C@80
00==000020000dd00006C@074DdACA404@06C@<000==00002@0000X000E<0000aP02C00?04`0aP0A
C140C01<04c600@000=<00001@02C00304a<00<01D`00a404@05C0<000?6C0000T`9009<0P06C003
4@0A00I<0P000lI<000;009<0P0014c6aT`2aP034@0A00;600A<a/I<0P000lI<000:0005C01<C<H0
0d`01P1<C1404@9<00<0C4`014`00`1<0009009<00C604`00T`01P1<C1404@9<00L0C4`0C036009<
2002C00504`0aP000d`01P1<C1404@9<00L0C4a<0<H000A<2P0000T00dd300A=00K6CDdACA47C@<0
0dd700E=00@0C@000Td01@1=04d0009=0P000dd0C@04C@L01Dd0101=C@03C@0504d0C@000dd00`1=
C@02C@0404e=C@H01Dd01@1=aP1=00;600D0aP360002aP03C@3600==00@0CDe=1`0014d00007C@05
04d0C@001Dd00lI=00020003C@0000D00Td00`1=C@020003C@1=009=00D0C@1=0003C@0404d0009=
00<0CDd02003C@0404e=00==00D0C@1=0003C@0504e=0<H00Td<00002`06C00404a<009<00@0C4`0
0T`01@1<aT`0009<20000d`0C004C0<000=<04`00T`0101<04`30003C<I<009<00<0C0001@000d`0
C004C0800T`01`1<04`0C0000T`20003C<I<009<00<0C0001@000d`0C003C00>aP00C<H0aP360<H0
aT`200;60d`00`1<00050003C00000800d`00lI<C00=C0@000=<00001007C00A04`0C01<04`0C01<
04`0C<H01D`600M<0P02C00704`0C01<0002C08000=<a/H014`:00002`07C@0404e=C@<00dd0101=
04d2aP9=2005C@0404g6009=00L0CDe=04d0009=00<0a/H01Td600==00<0CDd00/H02P1=C@1=04d0
C@02C@030<K6009=00@0CDe=1P03C@0304e=00;600X0a/H0aP360<H00/H00`36aP02C@0404e=C@L0
1Dd00`1=aP04C@0304d000I=00<0aTd00dd800I=0P02C@0704d0C@1=0002C@8000?604d00dd700==
00<0CDd00/H3C@0704d0C@1=0003C@;60Td0101=CDd:00002@02C08014`01<I<C002C00604a<04c6
0T`00lI<0002009<1`000d`0C002C004aP1<C08000E<04`0C00200M<00<0C0001`000d`0C002C004
aP1<C08000E<04`0C002009<00<0aT`00T`00`1<00070003C01<009<00C60<K60P001LH0aP360080
0/H00`36C002C00304`000X03D`2aP03C<I<00=<2`000d`0C0020004C<I<C08000E<04`0C002009<
0/H01D`0C01<00P01D`01<H0C4`20005C01<04`00P02C0030<I<00A<2`0000d00Td01<H00004C@05
04e=CLH00`000lI=C@0<0003C@1=00M=00<0CDd00P02C@;614d00`1=00090003C@1=00E=00/0C@1=
04d0C@1=aP04C@0304d000T000==04d01Dd02@360<H0aP360002aPA=00<0C@002P04C@03aTe=009=
00?6CDd014d00lI=C@04C@d014d03LI=04d0C@1=04d0CLH01Dd=00I=00[6C@1=04d0C@1=0/H3C@h0
000<0003C01<009<0P001<I<C4`2aP9<00?600000d`00`1<000;00I<0/H01Dc6C4c6009<00?6C4`0
1D`=00Y<00D0C4a<aP06C0h01D`01`1<C4c60<H00T`00lI<C004C0`000E<04a<0007C003aTa<009<
00C6C4`00T`00`1<000:00U<00L0C01<04c600M<3@04C00;aTa<C<I<04c6C<H01T`>00003@08C@05
aP1=0<H014d0101=04d>0003C@1=015=3P02C@0304e=00A=00G6CDe=aP06C@0304e=00`00Td00`1=
C@04C@05aTe=CLH01Td00`1=C@0=0005C@1=C@000Td00lI=aP06C@0504e=04d03@07C@05aTg6CLH0
2dd<0003C@1=00E=00?604d00dd00lI=aP04C@0304d000`0000<0003C00000I<00?6C00024`20003
C00000X000=<04`04d`=0003C01<00m<00D0C4`0C00<0005C01<C0003D`01@1<C01<00h00T`200E<
00<0C4`00d`2009<40000d`0C00>C00304`000h01T`00`1<aP02C003aTa<00M<3P0000h00Td01@1=
04d000E=00D0C@1=0002CA000Td00`1=0009C@0304d0009=4002C@0304e=00U=00<0C@000Td@009=
00<0CDd02Dd00`1=0002CA4000A=04d00Td01@1=04d0009=00@0C@1=4P0ACA402Dd00`1=C@06C@03
04d000d0000@0003C01<00A<00<0C4`01D`D00A<00L0C4a<04`000A<5004C00304a<00=<00<0C4`0
0T`D00A<00<0C4`00d`00`1<C002C1@014`01`1<04`0C00014`D0004C01<00=<00P0C4a<04`0C1<0
00E<04a<000:C00304a<00l0000?0006C@0004d00dd0101=04d20003C@0001H01ddL00A=00<0CDd0
7004C@0304e=01X000Q=001=04d0C@8000==00005@000dd0C@08C@0304d001P00dd00`1=C@02CA@0
000E00=<00<0C0007@03C00304`001d000E<04`0C00N0005C01<04`0@0001d`0C01<04`07@02C003
04a<01H0000E0005C@0004d0j0000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`0003T000==04d0@0001Dd0CDd0009=00<0C@0070000dd0C@0P0003C@1=01l0
00E=0000C@0F0000=P001D`0C4`0009<00<0C0004`000d`00004009<0`000d`000040003C00001<0
00E<04a<0002C00304`001T000I<001<04`20003C00001P000I<001<04`20003C00001@00T`40005
C01<04`01002C100000G0003aP0001X000==04d00dd00`1=C@02C@0304d000l000==04d00P0014d0
C@02C@0404e=C@8000E=04d0C@020003C@0000h03DdH009=00D0C@1=0002CAX00Td01@1=CDd0009=
500014d0CDd40005C@1=04d01002C@0304d000d0000C00;600H0a/K60<HI009<00<0C0000d`00`1<
0002C1400T`20003C00000=<00H0C4a<04`20005C01<04`0400?C1D03D`F00e<4P04C00904a<C01<
04`000=<00<0C4`00T`>00005002aP05C@1=CLH06@0=CA800dd300A=00<0CDd00Td300==4002C@03
04d0009=00?6CDd00Td00`1=0002CAD02ddH00]=5005C@0304e=00E=00<0CDd00dd?00004`001LH0
C4`0009<00?600005@04C00604a<aTc60d`0101<C4`?0003C036008014`01LH0C4c600A<0P000lH0
C00=0003C01<00I<0/H00dc6C005C00304`000d000=<04`01d`00lI<aP06C00304`000d000=<04`0
1d`00lI<aP06C00304`000h00d`01<I<C<H2C08000=<aT`00/H3C0l0000A00;600I=04d0C@02C@;6
6004C@05aTg6CLH00Td@0005C@1=0<H01Td3aPQ=00G604d0C@080005C@00C@001Dd2aP04C@1=aPE=
0P0014d004d80004C@00C@801Dd2aP9=00?6CDd00dd20004C@00C@P000A=001=0P05C@;60Td00lI=
C@03C@8000A=001=1`02C@0304e=00I=1`04C@05aP1=C@000Td:00004P001<I<04`24@=<00?60000
4`04C08000S6C01<04c600E<2`04C00304a<00A<00<0C4`00T`00lH0C005C00304a<009<1`000d`0
0008C00704`0C01<aP06C08000=<00001P001D`004`000]<0/H4C00504`004`020001D`004`000]<
0/H4C00504`004`02@03C00404`0aP9<1`02C003aP3600800T`<00004P001LI=CA40008A0ddC0003
C@0000A=00D0CDe=0003C@0304e=009=0P000dd00009009=00?6000014d00lI=C@03C@;60dd200==
2003C@0304d0008000E=0<I=0003C@0504g604d00`000dd0C@02C@H00dd00`1=0002009=00<0aTd0
14d01<H0CDd30003C@1=009=1P03C@0304d000800Td00`36C@04C@04aP1=C@<000==04d00Td900E=
00?6CDd01`02C@03aTe=00;60Td<00002@000lH000050007aP004D`AC0024@8000?600001P000lH0
00070003C00000800T`01/H004`AC08000C6C4a<0`000d`0000700E<00<0C4`00T`84@E<00<0aT`0
0d`800=<0P0014`00<H2C0<A0T`01<H004`200=<2P03C0800T`2009<0a42C0800T`200=<2P03C080
0T`2009<0a42C0800T`200=<2009C00304`000H000=<04`00/H6C0X000090003aP0000L000PACDdA
CA5=4@X000?600001002C@0304d000==00<0C@000P000ddAC@030003C@00009=00@0C@1=2@09C@04
04e=4@9=00<0C@001dd:0003C@1=00A=00S6000ACA5=4@8000?6CDd00Td00lH0C@0:0004C@3600A=
00W6015=4DdA0<H014d0103604d:0004C@3600A=00W6015=4DdA0<H01Dd00lH0C@0:00Q=00<0C@00
0a400`1=0008C@`0000:00Q<00XAC01<4D`AC00A2D`90003C01<00<000E<0000C0034@05C00004`0
0`000d`0C00:00=<00?604`00T`20005aQ404D`00P001D`0C03600=<2P000d`00006C0074D`AC140
4@06C08000=<000020000d`00006C0074D`AC1404@06C08000=<000020000d`00006C0074D`AC140
4@06C08000=<00001`002D`0001<aP1<0002C0054@0A01400T`01@36003600<000=<00002@0000T0
00?6000010000dd0C@0200094Dd0CA40C@1=00L000?600001`02C@8000Y=0000CA404@0A0Td20003
C@00009=2`02C@04aTd0C@8000==aQ400`001A5=C@1=008014d;009=00H0C@00C@02C@034@0A009=
00P0C@00C@36C@`00Td20003C@1=00==00<A014014d01P1=0036C@`00Td20003C@1=00==00<A0140
14d01P1=0036C@d0015=04e=aTd04Dd04@1=4@1=aP02C@03aTd000d0000>009<0P0014`0C1430005
4D`0C0000T`<00A<0/H200=<00H0C00A04`200=<00<0a/H014`700I<00<0C4`00d`300I<0/H4C0L0
1T`2000:C01<C01<04`0C08000=<00000T`0101<C4`600E<00<0C00014`01@1<04`000A<00D0C01<
0003C0H01d`00`1<C002C00504`0C00014`01@1<04`000=<2@000d`00007C0034D`A00M<0P000d`0
000;00003@002Dd0001=04d0C@030004C@1=C@<000==00002`02C@800Td3009=00<0C@000Td40004
C@00C@T000==04d00dd01<I=C@03C@<00dd0101=a/H4C@0304d000D000==04d00dd02P1=C@1=04d0
C@03C@0504e=0<H00dd00`1=00050003C@1=00==00<0C@000Td01`1=04d0C@000Td0101=0<H3C@03
04d000D000==04d01Dd02P1=C@1=04d0C@02C@0404d0aP==00<0C@002007C@;600A=4DdA14d01<I=
CLH3C@`0000900;600<0C0000`02C0800T`00`1<C002009<0`0014`0a/H;00=<0`000d`0C004C003
04`0008000=<aT`02`03C00704a<C01<0002C0<00T`0101<0<H2C00404a<C0P01D`2aP=<00L0C01<
04`000=<00?6C4`014`700=<00<0C4`00/H02P1<C01<04`0C002C0030<I<009<00@0C4a<1P03C006
04`0C<H00T`01`1<04`0C0000T`00`36C002C00404a<C0H02D`3009<00@0C4a<0P06C00304a<00X0
000;0003C@0000800Td20007C@1=04d0C@02009=0`000dd0000:0007C@1=04d0C@020005C@1=04d0
0P001dd0C@1=04d03P0014d0aTd200==00@0CDe=0P02C@0304d000X00Td01P1=C@36009=0P0034d0
C@1=04d0C@36009=00<0CDd01`000dd0C@02C@04aP1=C@8000E=04d0C@02009=00<0aTd00Td00`1=
00070003C@1=009=00C604e=0P001Dd0C@1=00800Td00`36C@02C@0304d000T000==04d014d01`1=
aTd0C@000dd01/I=CDd0C@d0000;00?600@0C01<0P001d`0C01<04`00P0014`0C002aP/01D`01<I<
0002C00304`0009<0P000dc6aP04C0h00T`2aP06C000C01<0P02C003aTa<00h000=<04`01D`01`1<
04`0C0000T`2aPA<00<0C0002@000d`0C005C00;04`0C01<04`0C<H014`00`1<00090003C01<00E<
00/0C01<04`0C01<aP04C00304`000T014`01P1<001<aP9<00<0C4`00d`0101<0003C0`0000;0006
aP00C@1=0`0014d004d20004C@00C@8000==0<H02P000dd00005C@0;aTg6C@1=04g6CLH01Dd20003
C@0000T02Dd2aP9=00?6CDd01Dd?00M=00W6C@1=04g6CLH00dd?00Y=00D0CDe=aP06C@h02Td01@1=
CDg600I=3P001Td004d0aP==00?6CLH00dd00lH0C@020003C@0000`0000>00;600E<0000C0020004
C000C0<000=<a/H03P02C00304a<00M<00C6C<K614`00`1<000=00a<00?6C4`01T`=00Q<0/H=C0`0
0T`00`1<C004C005aTa<C<H01T`00`1<C00<009<00<0C4`014`01LI<C4c6009<00G6C4a<0002C0d0
00=<00001T`00lH0aP02C00404a<C08000=<0000300000h000?60<H00P001Dd0001=00<000I=0036
0<H=0005C@1=C@001dd00`1=C@05C@0404e=C@h00Td200A=00<0CDd014d2009=3P000dd0C@0CC@d0
00==04d03dd01@1=C@1=00`000==04d04Td00`1=000@00A=00<0C@001TdB00004@02aP09C036C01<
aP1<00;65@000d`0C009C00304`001L00d`2009<00<0C0005002C00304a<00]<00<0C4`04002C003
04a<00]<00<0C4`04002C00304`000]<00<0C4`04P02C00304a<00E<00<0C4`00T`A00004002aP08
0<K60<H0aP02aP030<H001<00Td00`1=C@0;CAH014d30004C@1=CAL000A=04d01Dd0101=04dE00A=
00<0CDd00dd00`1=C@02CA@014d00`1=C@03C@0304e=009=4`000dd0C@04C@0504d0C@000dd00`1=
000?000050001<H00<H20003aP0001H000]<04a<04`0C01<0002C00304`001H000=<04`00`000d`0
C00G0003C01<00Y<00<0C0005P09C1/00T`00`1<C002C1T000=<00000T`00`1<0002C08000=<0000
400003D000==04d00dd01@1=C@1=03h000E=04d0C@0N0005C@1=04d07P001Dd0C@1=01d000A=001=
0P000dd0000C0000o`030000o`030000o`030000o`030000o`030000o`030000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.10942, 
  0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110617, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.109415, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.74027, -0.110618, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.109417, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277,
   -0.110617, 0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.1939, -0.10942, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.270008, -1.2634, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  69.375, 37.5625}} -> {-1.42777, -1.26686, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26687, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.88594, -1.2634, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277,
   -1.26686, 0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.1939, -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.270008, -2.41738, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.74027, -2.42311, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277,
   -2.42312, 0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1939, -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .78921 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.081587 0.952381 [
[ 0 0 0 0 ]
[ 1 .78921 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .78921 L
0 .78921 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.27517 .37889 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.20765 .42794 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.18186 .50732 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.23015 .65597 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.29768 .70502 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.38114 .70502 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .61316 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.53337 .53378 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .4544 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.3169 .50732 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.33941 .57659 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.39833 .53378 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.54125 .38833 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.62063 .36254 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.66968 .29501 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.66968 .13872 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.62063 .0712 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.54125 .04541 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.3926 .0937 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .16122 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .24469 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .25328 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .18045 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.47198 .20296 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.29111 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.20765 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.14012 .34618 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.09183 .49483 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.11762 .57421 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.18514 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.34144 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.40896 .57421 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.43475 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.24938 .42556 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.22687 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.2997 .49483 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.50083 .46116 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.5802 .48695 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.65958 .46116 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .33471 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .25125 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.70239 .18373 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.55374 .13543 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.47437 .16122 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.42531 .22875 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.5802 .35191 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.62301 .29298 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.55374 .27048 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.35206 .24035 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.28454 .19129 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.20108 .19129 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .28316 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.04884 .36254 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .44191 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.20108 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.28454 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.35206 .48472 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .31972 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.18388 .36254 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .40535 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.35332 .53378 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.51479 .21687 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.26329 .46837 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.5802 .30689 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.2289 .36254 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .49528 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.34081 .57466 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .65404 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.49304 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.57651 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.64403 .69685 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.69233 .5482 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.66653 .46883 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.59901 .41977 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.47585 .57466 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.53478 .61747 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.55728 .5482 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.58741 .34652 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .279 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .19554 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.5446 .06909 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.46522 .0433 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.38585 .06909 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .19554 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .279 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.34304 .34652 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.50804 .23727 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.46522 .17834 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.42241 .23727 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.33144 .41977 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.26391 .46883 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.23812 .5482 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.28642 .69685 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.35394 .74591 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.4374 .74591 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .65404 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.58964 .57466 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .49528 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.37317 .5482 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.39567 .61747 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.4546 .57466 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.59752 .42921 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.67689 .40342 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.72595 .33589 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.72595 .1796 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.67689 .11208 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.59752 .08629 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.44887 .13458 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .20211 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .28557 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .29416 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .22133 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.52825 .24384 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.34738 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.26391 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.19639 .38706 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.14809 .53571 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.17389 .61509 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.24141 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.3977 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.46522 .61509 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.49102 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.30564 .46644 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.28314 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.35597 .53571 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.52087 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.46522 .22336 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.40958 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.57106 .25775 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.31956 .50925 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.50898 .53571 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.53478 .61509 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.6023 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.75859 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.82611 .61509 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.85191 .53571 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.80361 .38706 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.73609 .33801 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.65262 .33801 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.64403 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.71686 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.69436 .46644 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .28557 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .20211 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.55113 .13458 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.40248 .08629 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.32311 .11208 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.27405 .1796 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.27405 .33589 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.32311 .40342 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.40248 .42921 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.47175 .24384 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .22133 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .29416 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .49528 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.41036 .57466 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .65404 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.5626 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.64606 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.71358 .69685 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.76188 .5482 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.73609 .46883 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.66856 .41977 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.5454 .57466 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.60433 .61747 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.62683 .5482 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.65696 .34652 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .279 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .19554 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.61415 .06909 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.53478 .0433 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.4554 .06909 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .19554 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .279 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.41259 .34652 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.57759 .23727 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.53478 .17834 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.49196 .23727 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.40099 .41977 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.33347 .46883 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.30767 .5482 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.35597 .69685 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.42349 .74591 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.50696 .74591 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .65404 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.65919 .57466 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .49528 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.44272 .5482 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.46522 .61747 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.52415 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.68044 .50925 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.42894 .25775 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.59042 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.53478 .22336 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.47913 .57466 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.64794 .48472 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.71546 .53378 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.79892 .53378 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .44191 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.95116 .36254 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .28316 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.79892 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.71546 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.64794 .24035 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .40535 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.81612 .36254 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .31972 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.57469 .22875 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.52563 .16122 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.44626 .13543 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.29761 .18373 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .25125 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .33471 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.34042 .46116 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.4198 .48695 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.49917 .46116 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.44626 .27048 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.37699 .29298 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.4198 .35191 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.56525 .49483 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.59104 .57421 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.65856 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.81486 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.88238 .57421 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.90817 .49483 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.85988 .34618 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.79235 .29713 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.70889 .29713 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.7003 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.77313 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.75062 .42556 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .24469 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .16122 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.6074 .0937 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.45875 .04541 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.37937 .0712 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.33032 .13872 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.33032 .29501 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.37937 .36254 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.45875 .38833 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.52802 .20296 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .18045 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .25328 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .4544 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.46663 .53378 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .61316 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.61886 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.70232 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.76985 .65597 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.81814 .50732 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.79235 .42794 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.72483 .37889 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.60167 .53378 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.66059 .57659 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.6831 .50732 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.7711 .36254 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.4198 .30689 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.73671 .46837 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.48521 .21687 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.64668 .53378 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.40896 .36254 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.46522 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.53478 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.59104 .36254 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{189, 149},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002m0000U@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000;d0002m0000_@000;d0002m0000_@000;d0
002m0000_@0005H00T`<009<E`0005H00Td<009=E`0005H00T`<009<E`0005H00Td<009=E`0004P0
00=<00002P03C0`00d`<0003C00004L00017009=3003C@`00dd<009=B00004L000=<04`03002C0`0
0T`<0003C01<04P000180003C@1=00/00Td<009=2`000dd0C@190000B@000d`0C00:00=<2P03C0X0
00=<04`0BP0004T00dd:00==2P03C@X00de:0000B@04C0T00T`00`1<00070004C01<C0T014a:0000
BP02C@0304d000L00Td20003C@0000@000==00000Td80004C@1=CD/0001;00=<2002C08000=<0000
10000d`00002C0P00da<0000?0000dd0000<00A=1`02C@<000==00000P0014d00002C@L014d>0003
C@0003/0000l0003C00000`00d`00`1<0005009<100014`004`4009<1P000d`0C002C0h000=<0000
>`0003d000==00002`001Td0CDd0C@D00Td5009=1@02C@D000I=04e=04d=0003C@0003`0000n0003
C00000X000=<00000d`5009<1@02C0D00T`500=<0P000d`0000:0003C00003d0000o0003C@0000T0
00E=001=0002C@0404e=009=1@02C@D00Td0101=C@02C@0504d004d02`000dd0000n0000?P03C0X0
00A<00000T`01@1<C4`0009<100014`004`4009<00D0C4a<0002C0<000=<00002003C3l0001000A=
1`000dd0000200A=00@0CDe=100014d004d400==00<0CDd00Td40003C@0000D014e10000@@000d`0
0004C0<000=<00000`03C0800T`30003C000008000A<00000T`200=<1@0014`00004C08000=<0000
@000048000==00000`04C@D000E=04e=0002C@8000==000010000dd00002C@0504e=04d01@04C@D0
00==0000@@0004000d`800=<1002C00604a<C01<20000d`0C002C00304a<00@00d`800=<@@0004<0
0dd50003C@0000A=00<0CDd01Dd800M=00<0CDd00Td20003C@0000@00de30000A0000d`0C002C080
00=<00001003C0C60T`6009<1<H3C0H000A<000014a50000<`03C@l000A=00000dd7009=1<H00`1=
C@04009=00<0a/H00/H2C@L014d20003C@0000h00Tdd0000=P03C0`000=<00000`04C0@000=<0<H0
0lH0101<04`20004C01<00?600=<04`01@03C0D000=<00002P04C3H0000U0003C@0000d000==0000
14d:0003C@00008000A=00000dd00`1=0005aP0304e=00800Td02036a/I=aP1=0P03C@8000==0000
0P000dd0000900==0P000dd0000=0003C@0002@0000U0003C00000d000=<04`00T`200=<1@04C0<0
00=<00001003C0030<K600?600<0C4`00T`00`36aP02aP03C00000=<1@001T`0001<009<1P03C006
04a<C01<3`000d`0000T00009P000dd0000;0003C@0000<00dd200==1@03C@0404e=C@D000==04d0
1/H0101=C@05aPA=1P02C@800dd500==0P03C@@000==00002`000dd0000U00009P000d`0000;0003
C00000<000=<00000d`200=<0`000d`0C002C00404a<C08000=<00003lH014`004`300=<00<0C4`0
0T`400=<0P03C00304`000@000=<00002`000d`0000U00009P000dd0000;0003C@0000@000==0000
0P03C@800dd01@1=04d000==00<0CDd00dd4aP==2LH6C@0304e=009=00@0C@000dd200==0`000dd0
00040003C@0000/000==00009@0002L000=<00002@000d`000060003C00000@00d`2009<0lH200Y<
00C6C4a<1/H3C003aTa<00A<0P03aP=<0P03C0D000=<00001P000d`000090003C00002H0000W0003
C@0000T000==00001`000dd0000600==00@0a/K60Td30003aTe=00A=00?6CDd00dd4aP==1<H300==
0/H200==1`000dd000070003C@0000T000==00009P0002L000=<00002@000d`000070003C00000T0
00=<a/H00/H00`36aP02aP03C<K6009<0/H5C0C60d`4aP=<00<0a/H014`:0003C00000L000=<0000
2@000d`0000V0000:0000dd000070003C@0000T000==00001004C@030<K600O600A=a/I=1<H5C@?6
0dd01<I=CDd4aP==00?604d00dd60003C@0000T000==00001`000dd0000W0000:0000d`000070003
C00000X000=<00000d`600S600=<04`01/H4C003aTc600A<00<0a/H01<H00dc6aP0600=<0P000d`0
000:0003C00000L000=<00009`0002P000==00001`000dd0000:00A=20000dg6aP03aP8000==a/H0
1<H00dg6aP09C@?60P04aP==1`04C@`000==00001`000dd0000W0000:@000d`000050003C00000`0
00=<00001@03C0801/H00dc6aP04aPQ<00C6C4a<1lH00dc6000200=<1P000d`0000<0003C00000D0
00=<0000:00002T000==00000P04C@`00Td00`1=000200==1@02aPI=1<H=C@C60dd00lI=000500==
0P0014d0CDd<00A=10000dd0000X0000:@000d`0000500=<2@0014`00004C0L000=<0<H01T`3aPE<
0P08C0?60d`00lH0C00800=<0`000d`0000700=<1`000d`0000X0000:P000dd000030004C@0000A=
0`02C@8014d900I=0lH7C@@01dd2aPA=00C6CDe=20000dd0C@02C@0304e=00<014d30003C@0000<0
00==0000:@0002X000=<00000`000d`0000500=<00@0C4a<10000d`0000300U<0/H8C0@01T`00`1<
C004C0;61D`40003C00000<01T`70003C00000<000=<0000:@0002X000==00000`000dd0000500I=
1P000dd0C@05C@C600I=a/I=aP05C@H01Dd00`1=C@04C@?600<0CDd01Dd600I=1`000dd000030003
C@0002T0000[0005C00004`01`02C0D014`200I<0P07aP03C<H000A<2004C00304a<009<0/H3C080
00=<04`00d`200A<1P000d`000050005C00004`0;00000h00TdK0005C@0004d01@02C@/014d3aP03
C@3600K600==aTd014d:00M=1/H00dd0C@04aP==2`02C@D000E=0000C@0K009=3`00010000=<0000
60001D`0001<00@000=<00002@03C0803<H00dc6C005C0<01A4200M<2LH01Dc6a/I<00800d`:0003
C000008000E<0000C00J0003C00000l0000A009=50000dd000020003C@1=00<00Td20003C@0000D0
0Td200==2lH00dg60006C@801a400`1=C@04C@030<K600K600==aTd00/H0101=CDd20003C@0000D0
00==00000Td30003C@1=00@000==00004P02CA80000C0003C000014000=<00000P000d`0C0020003
C000008000=<00001P03C0@000=<a/H01<H5C00304a<00A<2a45C00304a<00=<1<H3C0D00d`70003
C000008000I<001<04`40003C000014000=<00004P0001@000==00004@001Td0001=00==1@000dd0
000300==0`05C@<00lH;C@dA2Td00lI=C@0300E=1003C@D000==00000P03C@0304d000<000==0000
40000dd0000C00005@02C14000A<00000lH60004C00000=<0`03C0<000Q<0000C01<00U<4149C004
04`0C0<000A<00000d`400=<0P000d`0000400?60`000d`0000?009<5P0001L000==00003P0014d0
0003aPH014d300==1@001Dd0001=008000==04d00/H5C@`A00==4A401144C@?600D0C@00C@030003
C@0000<00dd400==1P03aP<000==00003P000dd0000F00006002C0l000=<00000lH400=<0P04C0L0
00=<00000P001T`004`0C0;60d`74@03C14A00DA00=<4A401143C0?600D0C000C0040003C00000D0
14`300=<0`03aP<000=<00003002C1T0000J0003C@0000`000==0<H00lH01@1=CDd000A=2`001Dd0
001=00<00Td3aP9=1Q43C@LA0Td74@9=0/H2C@<000E=0000C@0;00A=0P03C@C600<0C@003@000dd0
000I00006`02C0`000=<0<H00/H2C0<00T`=0005C00004`010000d`0aP02aPLA0d`44@04C14A4@A<
1Q42C003aP1<00@000E<0000C00=009<1004aP0304`000/00T`L00007@000dd0000:0004CLK6aP<0
00A=001=30001Dd0001=00@00Td00`36aP064@E=11400ddA4@024@A=1Q400dg60002C@@000E=0000
C@0=0003C@1=00<00lH00`1=000:0003C@0001`0000J009<0P000d`000090004C<K6aP<000A<001<
2`02C0<000=<00000P02C003014A00DA1T`34@9<1146C0HA00<0C4`0100014`00002C0`000=<04`0
0`03aP0304`000T000=<00000T`K000070000dd00002C@T01<H4009=30001Dd0001=00@000==04d0
1Q47C@@A0dd34@M=1Q400dd0C@040005C@0004d03002C@@00lH00dd00007009=0P000dd0000K0000
7@02C0802LHQC0HA14`0101<C4`44@=<0a43C00304a<009<1Q4QC0W60`000d`0000L00002@0HC@W6
8Dd44@==1003C@<A14d44@9=1003C@@A8Dd9aQQ=2P00020000=<a/H01lHQC0<A00=<04`01@02C0@A
14`44@9<1@000d`0C0034B5<2LH00d`0000O00007`0014d0CDd700C61002C@/000==04d01009C@80
00==00000P02C@@A1Dd34@9=10000dd00009C@@000==04d02`000dd0C@0300;600==aP001`000dd0
C@0P00007@02C0@000=<00001004aP@00T`;009<100:C08000=<00000P02C0<A1T`44@03C0000080
00=<00002T`4009<2`000d`0C00300;600=<aP001@02C0<00T`N000070000dd00005009=1@03aP<0
00A=04e=2@02C@@02Dd00`1=00020005C@0004d01142C@800Td44@05C@0004d00`000dd0C@08C@@0
0Td9009=00<0C@000P000lI=aP060003C@0000D000==00006`0001/000=<00001`02C0@00lH30004
C01<C0T00T`200I<00<0C4`00T`00`1<00030004C000C0@A00=<00000P02C0<A00A<001<10000d`0
C003C00304a<00A<0P02C0T00T`20006C000aTc61002C0T000=<00006P0001T00Td<0004C@0000?6
0`0014d004d90003C@0000I=0P04C@0304d000<000A=001=0a42C@@00Td44@8000==00000P000dd0
C@03C@801Td20003C@0000L000E=0000C@020003aTg600<00Td;009=6P0001P000=<00003@02C003
0<K600;60P000d`00002C0L000=<00001T`200A<0P000d`00003009<11400d`000040003C14A008A
0T`50003C00000A<0P06C08000=<00001@02C0<000I<0<K6C<H20003C00000d000=<00005`0001L0
00==00003`02C@C600<0C@000P02C@H024d400A=0P000dd00003009=11480004CA4A4@9=1@000dd0
0004C@@024d6009=10000dg6C@02aP9=4@000dd0000F00005@02C1@000I<a/K604`40003C00000D0
1T`400E<0P000d`0000200=<0a4:00<A0d`40003C00000E<1006C0L000=<00000`0014c6C<H2C1<0
0T`F000050000dd0000E0003CLK6009=1002C@@01dd40003C@1=00==0P000dd00009C@P02Dd20003
C@0000A=00<0C@000`07C@@00Td50004CLI=CAL000==00004`0001<000=<00005P03C003aTa<00<0
0T`300I<1P000d`0C003C08000=<04`02D`800Y<00@0C00014`00`1<000500I<0`02C0<00T`3aP03
C00001H000=<00004P0001400TdI0007C@1=CLH0C@030003C@0000I=1P000dd0C@04C@8034d800a=
0P05C@0304d000D01Td20005C@0004d00P03aP03C@0001L00TdB000040000d`0000D009<0`001D`0
C<I<00800T`00`1<C005C08000=<00000P000d`0000<C00304a<00E<1P07C00304a<00Y<0P000d`0
00020003C00000M<00<0C4`00P04aP04C000009<5P000d`0000?00003`000dd0000G0003C@1=0080
00?6CLH00Td200M=0`000dd000020003C@0000==0P06C@801dd600M=0P06C@800dd20003C@000080
00A=00001dd2009=1<H0101=04dI0003C@0000h0000>0003C00001T00T`20007aTc6aP1<0007C0<0
00E<0000C00200A<00<0C4`014`300=<00@0C4a<1P03C00404a<C0<01T`00`1<C002C08000E<0000
C00300M<00@0C0000lH2009<6`000d`0000=0000:`02C@8000A=a/H01Td00`1=00040003C@1=00<0
2Dd400A=00<0CDd00Td400A=00<0CDd00Td400U=0`000dd0C@050003C@1=00E=00<0a/H00/H00`1=
C@0/0000:P0024`004`0aTc62D`50003C01<00<02D`400A<00<0C4`00T`400A<00<0C4`00T`400U<
0`000d`0C00500U<1<H014`004`[0000:P001Td0001=aPU=00<0CDd01002C@<02Td400==0`0:C@<0
0dd400Y=0`02C@@00Td00`1=C@06C@;600E=0000C@0[0000:P000d`000020003aTa<00=<0`03aP03
04a<00800T`300I<0`0014`00004C0<02T`300A<0`0014`00006C0<00T`2009<00@0a/I<0`06C0@0
00=<0000:@0002T000==00000P02aPA=00C600000lH3009=00@0C@001Td40004C@0000A=0`04C@80
14d300A=0`000dd0000200I=0P0014d0CDd300;600E=0000aP04C@;610000dd0000X0000:@000d`0
0004aPA<0lH00`36aP02aP<02D`60004C00000=<1@03C0800d`500=<0`000d`0000400U<0`02aP03
C<H000C60d`4aP8000=<0000:00002T000==0<H01LH00dg6aP02C@K61@07C@H00Td00`1=C@02C@@0
2Td400A=00<0CDd01P07C@D00/H00dg6aP02aP9=00?6CLH01LH00`1=000Y0000:0000d`0aP05aP80
00E<a/K6C005aP@01d`7009<00<0C4`00T`2009<00<0C4`01T`00`1<C00200A<00<0C4`01`07C0@0
0/H01Dc6a/I<00;600=<00001/H00`1<000X0000:0000dg6aP03aP@000==00000/H00dg6aP03aP03
04e=00M=1`02C@0404e=C@8000==00000P06C@@000==00000dd00`1=C@0700U=00@0a/I=0lH01Dg6
001=00@01LH00dd0000W00004@0HC0C61@0014`00002aP03C<K600;66D`500I<1@0LC004aTa<aP<0
00=<00000`04aQQ<4P0002L00Td3aPL000A=00001LH6C@0304e=00==2005C@H01Td600E=2005C@03
04e=00A=00?6CDd00/H30003C@0000D00lH2CBP0000W0003C01<00T000=<00000`000dc6C004C0<0
0d`0101<C4`600A<00<0C0001006C0D000=<04`00d`600=<00@0C4a<0`02C0C600=<00000`000d`0
00070003C01<02P0000R01M=0/H4C@03aP0000A=0`02C@D00dd3009=1004C@@00Td300==1@02C@<0
14d200K664dS000090000d`0C0020003C00000P000=<00001<H3C0?600<0C4`00T`4009<0`04C0D0
00A<000014`30003C00000<014`3009<1004C0030<K600G600=<a/H00P000d`000080006C000C01<
9@0002<000I=001=04d;0003C@3600_60dd600Q=1P000dd00004C@8000==00001008C@H00dd7aP03
CLK600;600<0C@002P000dd0C@020003C@000280000Q009<0`000d`0C00;0003C<K600C60P06aP=<
1P07C0L024`700M<1P05C0C60P000dc6aP03aP03C00000T000=<04`00`02C280000P0003C@000080
00A=001=2`05aP0304d000<01LH2C@K60P05C@P01Td800E=0P07aPA=0/H40003C@3600;600==aP00
2P0014d004d40003C@0001l0000L01Q<1<H30003C00000801<H/C0S60d`00lH000020004C00000;6
00=<aT`05d`M00007@02C@P000==00002@0014g6a/H40003C@0000801<H00dg6aP05aP03C@1=00==
1<H500I=1@04aPA=00<0CLH01lH3C@03aP00008000==00000P03aP03C@0000T000==00001P02CAh0
000L0003C00000P000=<00000P0VC0G60`08C0<00lH:C0?600=<aT`01<HDC0@000=<000020000d`0
000K00006`000dd000080003C@0000L000E=0000C@070004C@0000?600E=0<K6C@04aP0304e=009=
00<0a/H01LH00`1=C@06C@030<K600;600A=a/H014d00`36aP02aP05CLK604d00lH30003C@0000D0
00E=0000C@090003C@0000P000==00006P0001T00T`;0003C00000H000=<00000P000d`000050003
C00000C600I<0000aT`4aPE<0P06aP=<0P05C004aTa<aP801D`3aP9<00G60000C004aP8000=<0000
1@000d`000020003C00000H000=<00002@02C1X0000H0003C@0000/000==00001002C@@000==0000
1P000dd00004aP0304d0008000C6CDg614d20003C@0000C614d200A=00C6CLK60P000dd00004C@04
aTg6aP<000==0<H00lH20003C@0000H000==00000P02C@H000==00002`000dd0000G00005`000d`0
000;0003C00000@000=<000010000d`000070003C03600;60P000d`000030003aTa<00=<2LH4C0[6
0T`3aPE<00?600000`000d`00003aP0304`000P000=<000010000d`000040003C00000/000=<0000
5P0001H000==000030000dd00002009=1`000dd000070003CLK600]=00?6CDd02Td01<I=CDd8aQI=
1<H00dd000070003C@0000D00Td40003C@0000`000==00005@0002D000E<0000C0080003C00000P0
00=<a/H00/H30003C00000<000C6C4a<2<H00dc6C002C0S60T`7aP=<00?600000`0014`00004aP03
C00000P000=<00001P001D`0001<02H0000T0005C@0004d02@000dd00008009=0/H40003C@0000<0
1<H00dd00003009=00<0a/H00/H400?600A=04e=1@000dg6aP02aPD000==00000P03aP03C@0000P0
00==00001`001Dd0001=02D0000T0004C01<C0X000=<00001`000d`0C002C0@000=<00000`03aP80
0T`20004C00000?61P02C005aP0004`00P02C0800lH50003C00000800d`00`1<00080003C00000P0
0T`00`1<000T00009002C@/000==00001P02C@8000==04d01@0014d00004aP@00Td300C600==0000
0P000dg6aP02aP<00Td400C60`000dd000030003C@1=00800Td80003C@0000T00TdU00008`02C0`0
00=<00001@000d`0000200=<1@0014`00004aP<014`200C600<0C4`00T`00`36aP02aP8014`300C6
0`000d`0000300=<10000d`000050003C00000X00T`T00008P02C@d000==000010000dd00003009=
00<0C@000`0014d00003aP<000==00000P000dd0aP02aP<00Td300?600<0C@000`0014d00003aP<0
00==00000P0014d0CDd50003C@0000@000==00002`02CB<0000Q0003C01<00`000=<00000`02C0D0
00E<04`0C0050003C03600?600<0C4`01P04aP8000A<001<0P03aP03C00000@00T`00`36aP02aP03
04`000@000E<04`0C005009<1@000d`0000:0003C01<0280000P0003C@1=00d000==00000P000dd0
00050003C@00009=1@000dd0aP03aP03C@0000H01<H00`1=00030006C@36aTg620000dg6aP02aP03
04d000@00Td20003C@0000D000==00000P000dd0000;0003C@1=0240000R0003C00000/000E<0000
C0080006C000C01<1002C0?600=<00001P0014c6a/H2C0H00T`3aP03C00000H000A<a/K60T`40003
C01<008000=<00001P001D`0001<00d000=<00008@0002l000==00000Td90003C@00008000A=0000
1Td7009=00@0C@1=2P0014d0C@02C@L01Td30003C@00008000==00001`02C@8000==0000;P0002l0
00=<04`02P000d`000030004C000C0800T`00`1<00050004C00000=<2P03C0<000=<0000100014`0
C4`20004C000C0D000=<000020000d`0C00`0000;`02C@/000==00001002C@800dd00`1=00040004
C@00009=00<0C@002@0014d0CDd30003C@0000<000==04d00Td2009=1P000dd00009009=<00002h0
0T`<0003C00000<00T`20004C01<C08000=<00000T`3009<0`000d`000060004C000009<0`02C080
00=<00000T`0101<0002C0D000=<00002P02C2l0000]009=30000dd000030005C@1=04d00P02C@80
00==04d010000dd0C@030003C@0000H000M=0000C@1=00@000==04d00P02C@8000E=04d0C@050003
C@0000X00Td^0000;0000d`0C00<0004C000009<0`0014`00002C0800T`40004C000C0<000=<0000
1P001D`0001<008000=<00000P02C0800T`30004C000009<0`000d`0000:0003C01<02d0000[0003
C@1=00d000A=001=1@0014d004d2009=00<0C@001@000dd000030003C@0000@000==00000`000dd0
00040004C@1=C@8000A=001=1@0014d004d=0003C@1=02`0000]0003C00000X000A<001<1P0014`0
04`20004C000C0H000=<00000`000d`000040003C00000<000=<0000100014`004`20004C000C0H0
00A<001<30000d`0000/0000>P03C@P000==04d00Td30003C@0000@000==00000`000dd000040003
C@0000<000==0000100014d00003C@0304d000L00ddk0000>P000d`0000800=<1P000d`000020003
C00000D000=<00000P000d`000050003C000008000=<00001003C0X000=<0000>@0003P00dd:009=
1`000dd000020003C@0000D000==00000P000dd000050003C@00008000==00001@02C@X00ddi0000
=`000d`0C00:0003C01<00L000=<00000P000d`000050003C000008000=<00001@000d`000020003
C00000D000=<04`02P000d`0C00h0000=P0014d004d90004C@1=C@P000A=001=2@0014d004d90004
C@00C@P00Td00`1=00080004C@00CCL0000e0005C00004`020000d`00002C0P000A<001<2@0014`0
04`90004C000C0P00T`20003C00000H000E<0000C00f0000>0000dd0000:0003C@1=00L000A=001=
2@0014d004d90004C@00C@L000==04d030000dd0000g0000>0000d`000090004C000C0P00T`;009<
2`02C0P000A<001<2`000d`0000g0000A0000dd00009009=2`02C@/00Td;0003C@0004<000140003
C00000T00T`;009<2`02C0/000=<0000@`0004<000==00002P02C@/00Td;009=30000dd000120000
@`000d`0000:009<2`02C0/00T`<0003C000048000130003C@0000X00Td;009=2`02C@`000==0000
@P00048000=<00002P0014`004`90004C000C0T000A<001<30000d`000110000@P000dd0000:0004
C@00C@T000A=001=2@0014d004d<0003C@000440002m0000_@000;d0002m0000_@000;d0002m0000
_@000001\
\>"],
  ImageRangeCache->{{{0, 188}, {148, 0}} -> {-0.026323, 0.0856622, 0.00559918,
   0.00559918}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.081587 0.952381 [
[ 0 0 0 0 ]
[ 1 .78921 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78921 L
0 .78921 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.27517 .37889 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.20765 .42794 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.18186 .50732 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.23015 .65597 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.29768 .70502 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.38114 .70502 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .61316 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.53337 .53378 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .4544 L
s
P
p
0 .4 1 r
.016 w
.35332 .53378 m
.3169 .50732 L
s
P
p
0 .4 1 r
.016 w
.35332 .53378 m
.33941 .57659 L
s
P
p
0 .4 1 r
.016 w
.35332 .53378 m
.39833 .53378 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.54125 .38833 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.62063 .36254 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.66968 .29501 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.66968 .13872 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.62063 .0712 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.54125 .04541 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.3926 .0937 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .16122 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .24469 L
s
P
p
0 .4 1 r
.016 w
.51479 .21687 m
.54125 .25328 L
s
P
p
0 .4 1 r
.016 w
.51479 .21687 m
.54125 .18045 L
s
P
p
0 .4 1 r
.016 w
.51479 .21687 m
.47198 .20296 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.29111 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.20765 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.14012 .34618 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.09183 .49483 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.11762 .57421 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.18514 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.34144 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.40896 .57421 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.43475 .49483 L
s
P
p
0 .4 1 r
.016 w
.26329 .46837 m
.24938 .42556 L
s
P
p
0 .4 1 r
.016 w
.26329 .46837 m
.22687 .49483 L
s
P
p
0 .4 1 r
.016 w
.26329 .46837 m
.2997 .49483 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.50083 .46116 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.5802 .48695 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.65958 .46116 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .33471 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .25125 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.70239 .18373 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.55374 .13543 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.47437 .16122 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.42531 .22875 L
s
P
p
0 .4 1 r
.016 w
.5802 .30689 m
.5802 .35191 L
s
P
p
0 .4 1 r
.016 w
.5802 .30689 m
.62301 .29298 L
s
P
p
0 .4 1 r
.016 w
.5802 .30689 m
.55374 .27048 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.35206 .24035 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.28454 .19129 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.20108 .19129 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .28316 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.04884 .36254 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .44191 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.20108 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.28454 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.35206 .48472 L
s
P
p
0 .4 1 r
.016 w
.2289 .36254 m
.24281 .31972 L
s
P
p
0 .4 1 r
.016 w
.2289 .36254 m
.18388 .36254 L
s
P
p
0 .4 1 r
.016 w
.2289 .36254 m
.24281 .40535 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.35332 .53378 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.51479 .21687 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.26329 .46837 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.5802 .30689 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.2289 .36254 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .49528 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.34081 .57466 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .65404 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.49304 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.57651 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.64403 .69685 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.69233 .5482 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.66653 .46883 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.59901 .41977 L
s
P
p
0 .4 1 r
.016 w
.52087 .57466 m
.47585 .57466 L
s
P
p
0 .4 1 r
.016 w
.52087 .57466 m
.53478 .61747 L
s
P
p
0 .4 1 r
.016 w
.52087 .57466 m
.55728 .5482 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.58741 .34652 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .279 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .19554 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.5446 .06909 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.46522 .0433 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.38585 .06909 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .19554 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .279 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.34304 .34652 L
s
P
p
0 .4 1 r
.016 w
.46522 .22336 m
.50804 .23727 L
s
P
p
0 .4 1 r
.016 w
.46522 .22336 m
.46522 .17834 L
s
P
p
0 .4 1 r
.016 w
.46522 .22336 m
.42241 .23727 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.33144 .41977 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.26391 .46883 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.23812 .5482 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.28642 .69685 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.35394 .74591 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.4374 .74591 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .65404 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.58964 .57466 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .49528 L
s
P
p
0 .4 1 r
.016 w
.40958 .57466 m
.37317 .5482 L
s
P
p
0 .4 1 r
.016 w
.40958 .57466 m
.39567 .61747 L
s
P
p
0 .4 1 r
.016 w
.40958 .57466 m
.4546 .57466 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.59752 .42921 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.67689 .40342 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.72595 .33589 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.72595 .1796 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.67689 .11208 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.59752 .08629 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.44887 .13458 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .20211 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .28557 L
s
P
p
0 .4 1 r
.016 w
.57106 .25775 m
.59752 .29416 L
s
P
p
0 .4 1 r
.016 w
.57106 .25775 m
.59752 .22133 L
s
P
p
0 .4 1 r
.016 w
.57106 .25775 m
.52825 .24384 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.34738 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.26391 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.19639 .38706 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.14809 .53571 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.17389 .61509 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.24141 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.3977 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.46522 .61509 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.49102 .53571 L
s
P
p
0 .4 1 r
.016 w
.31956 .50925 m
.30564 .46644 L
s
P
p
0 .4 1 r
.016 w
.31956 .50925 m
.28314 .53571 L
s
P
p
0 .4 1 r
.016 w
.31956 .50925 m
.35597 .53571 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.52087 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.46522 .22336 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.40958 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.57106 .25775 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.31956 .50925 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.50898 .53571 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.53478 .61509 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.6023 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.75859 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.82611 .61509 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.85191 .53571 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.80361 .38706 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.73609 .33801 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.65262 .33801 L
s
P
p
0 .4 1 r
.016 w
.68044 .50925 m
.64403 .53571 L
s
P
p
0 .4 1 r
.016 w
.68044 .50925 m
.71686 .53571 L
s
P
p
0 .4 1 r
.016 w
.68044 .50925 m
.69436 .46644 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .28557 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .20211 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.55113 .13458 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.40248 .08629 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.32311 .11208 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.27405 .1796 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.27405 .33589 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.32311 .40342 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.40248 .42921 L
s
P
p
0 .4 1 r
.016 w
.42894 .25775 m
.47175 .24384 L
s
P
p
0 .4 1 r
.016 w
.42894 .25775 m
.40248 .22133 L
s
P
p
0 .4 1 r
.016 w
.42894 .25775 m
.40248 .29416 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .49528 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.41036 .57466 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .65404 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.5626 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.64606 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.71358 .69685 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.76188 .5482 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.73609 .46883 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.66856 .41977 L
s
P
p
0 .4 1 r
.016 w
.59042 .57466 m
.5454 .57466 L
s
P
p
0 .4 1 r
.016 w
.59042 .57466 m
.60433 .61747 L
s
P
p
0 .4 1 r
.016 w
.59042 .57466 m
.62683 .5482 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.65696 .34652 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .279 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .19554 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.61415 .06909 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.53478 .0433 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.4554 .06909 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .19554 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .279 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.41259 .34652 L
s
P
p
0 .4 1 r
.016 w
.53478 .22336 m
.57759 .23727 L
s
P
p
0 .4 1 r
.016 w
.53478 .22336 m
.53478 .17834 L
s
P
p
0 .4 1 r
.016 w
.53478 .22336 m
.49196 .23727 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.40099 .41977 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.33347 .46883 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.30767 .5482 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.35597 .69685 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.42349 .74591 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.50696 .74591 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .65404 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.65919 .57466 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .49528 L
s
P
p
0 .4 1 r
.016 w
.47913 .57466 m
.44272 .5482 L
s
P
p
0 .4 1 r
.016 w
.47913 .57466 m
.46522 .61747 L
s
P
p
0 .4 1 r
.016 w
.47913 .57466 m
.52415 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.68044 .50925 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.42894 .25775 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.59042 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.53478 .22336 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.47913 .57466 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.64794 .48472 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.71546 .53378 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.79892 .53378 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .44191 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.95116 .36254 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .28316 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.79892 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.71546 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.64794 .24035 L
s
P
p
0 .4 1 r
.016 w
.7711 .36254 m
.75719 .40535 L
s
P
p
0 .4 1 r
.016 w
.7711 .36254 m
.81612 .36254 L
s
P
p
0 .4 1 r
.016 w
.7711 .36254 m
.75719 .31972 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.57469 .22875 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.52563 .16122 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.44626 .13543 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.29761 .18373 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .25125 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .33471 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.34042 .46116 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.4198 .48695 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.49917 .46116 L
s
P
p
0 .4 1 r
.016 w
.4198 .30689 m
.44626 .27048 L
s
P
p
0 .4 1 r
.016 w
.4198 .30689 m
.37699 .29298 L
s
P
p
0 .4 1 r
.016 w
.4198 .30689 m
.4198 .35191 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.56525 .49483 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.59104 .57421 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.65856 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.81486 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.88238 .57421 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.90817 .49483 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.85988 .34618 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.79235 .29713 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.70889 .29713 L
s
P
p
0 .4 1 r
.016 w
.73671 .46837 m
.7003 .49483 L
s
P
p
0 .4 1 r
.016 w
.73671 .46837 m
.77313 .49483 L
s
P
p
0 .4 1 r
.016 w
.73671 .46837 m
.75062 .42556 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .24469 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .16122 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.6074 .0937 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.45875 .04541 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.37937 .0712 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.33032 .13872 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.33032 .29501 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.37937 .36254 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.45875 .38833 L
s
P
p
0 .4 1 r
.016 w
.48521 .21687 m
.52802 .20296 L
s
P
p
0 .4 1 r
.016 w
.48521 .21687 m
.45875 .18045 L
s
P
p
0 .4 1 r
.016 w
.48521 .21687 m
.45875 .25328 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .4544 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.46663 .53378 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .61316 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.61886 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.70232 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.76985 .65597 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.81814 .50732 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.79235 .42794 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.72483 .37889 L
s
P
p
0 .4 1 r
.016 w
.64668 .53378 m
.60167 .53378 L
s
P
p
0 .4 1 r
.016 w
.64668 .53378 m
.66059 .57659 L
s
P
p
0 .4 1 r
.016 w
.64668 .53378 m
.6831 .50732 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.7711 .36254 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.4198 .30689 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.73671 .46837 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.48521 .21687 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.64668 .53378 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.40896 .36254 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.46522 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.53478 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.59104 .36254 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.081587 0.952381 [
[ 0 0 0 0 ]
[ 1 .78921 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78921 L
0 .78921 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.27517 .37889 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.20765 .42794 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.18186 .50732 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.23015 .65597 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.29768 .70502 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.38114 .70502 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .61316 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.53337 .53378 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .4544 L
s
P
p
.2 0 1 r
.018 w
.35332 .53378 m
.3169 .50732 L
s
P
p
.2 0 1 r
.018 w
.35332 .53378 m
.33941 .57659 L
s
P
p
.2 0 1 r
.018 w
.35332 .53378 m
.39833 .53378 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.54125 .38833 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.62063 .36254 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.66968 .29501 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.66968 .13872 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.62063 .0712 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.54125 .04541 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.3926 .0937 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .16122 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .24469 L
s
P
p
.2 0 1 r
.018 w
.51479 .21687 m
.54125 .25328 L
s
P
p
.2 0 1 r
.018 w
.51479 .21687 m
.54125 .18045 L
s
P
p
.2 0 1 r
.018 w
.51479 .21687 m
.47198 .20296 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.29111 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.20765 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.14012 .34618 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.09183 .49483 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.11762 .57421 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.18514 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.34144 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.40896 .57421 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.43475 .49483 L
s
P
p
.2 0 1 r
.018 w
.26329 .46837 m
.24938 .42556 L
s
P
p
.2 0 1 r
.018 w
.26329 .46837 m
.22687 .49483 L
s
P
p
.2 0 1 r
.018 w
.26329 .46837 m
.2997 .49483 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.50083 .46116 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.5802 .48695 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.65958 .46116 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .33471 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .25125 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.70239 .18373 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.55374 .13543 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.47437 .16122 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.42531 .22875 L
s
P
p
.2 0 1 r
.018 w
.5802 .30689 m
.5802 .35191 L
s
P
p
.2 0 1 r
.018 w
.5802 .30689 m
.62301 .29298 L
s
P
p
.2 0 1 r
.018 w
.5802 .30689 m
.55374 .27048 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.35206 .24035 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.28454 .19129 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.20108 .19129 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .28316 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.04884 .36254 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .44191 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.20108 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.28454 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.35206 .48472 L
s
P
p
.2 0 1 r
.018 w
.2289 .36254 m
.24281 .31972 L
s
P
p
.2 0 1 r
.018 w
.2289 .36254 m
.18388 .36254 L
s
P
p
.2 0 1 r
.018 w
.2289 .36254 m
.24281 .40535 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.35332 .53378 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.51479 .21687 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.26329 .46837 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.5802 .30689 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.2289 .36254 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .49528 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.34081 .57466 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .65404 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.49304 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.57651 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.64403 .69685 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.69233 .5482 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.66653 .46883 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.59901 .41977 L
s
P
p
.2 0 1 r
.018 w
.52087 .57466 m
.47585 .57466 L
s
P
p
.2 0 1 r
.018 w
.52087 .57466 m
.53478 .61747 L
s
P
p
.2 0 1 r
.018 w
.52087 .57466 m
.55728 .5482 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.58741 .34652 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .279 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .19554 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.5446 .06909 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.46522 .0433 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.38585 .06909 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .19554 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .279 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.34304 .34652 L
s
P
p
.2 0 1 r
.018 w
.46522 .22336 m
.50804 .23727 L
s
P
p
.2 0 1 r
.018 w
.46522 .22336 m
.46522 .17834 L
s
P
p
.2 0 1 r
.018 w
.46522 .22336 m
.42241 .23727 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.33144 .41977 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.26391 .46883 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.23812 .5482 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.28642 .69685 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.35394 .74591 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.4374 .74591 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .65404 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.58964 .57466 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .49528 L
s
P
p
.2 0 1 r
.018 w
.40958 .57466 m
.37317 .5482 L
s
P
p
.2 0 1 r
.018 w
.40958 .57466 m
.39567 .61747 L
s
P
p
.2 0 1 r
.018 w
.40958 .57466 m
.4546 .57466 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.59752 .42921 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.67689 .40342 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.72595 .33589 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.72595 .1796 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.67689 .11208 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.59752 .08629 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.44887 .13458 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .20211 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .28557 L
s
P
p
.2 0 1 r
.018 w
.57106 .25775 m
.59752 .29416 L
s
P
p
.2 0 1 r
.018 w
.57106 .25775 m
.59752 .22133 L
s
P
p
.2 0 1 r
.018 w
.57106 .25775 m
.52825 .24384 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.34738 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.26391 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.19639 .38706 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.14809 .53571 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.17389 .61509 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.24141 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.3977 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.46522 .61509 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.49102 .53571 L
s
P
p
.2 0 1 r
.018 w
.31956 .50925 m
.30564 .46644 L
s
P
p
.2 0 1 r
.018 w
.31956 .50925 m
.28314 .53571 L
s
P
p
.2 0 1 r
.018 w
.31956 .50925 m
.35597 .53571 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.52087 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.46522 .22336 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.40958 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.57106 .25775 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.31956 .50925 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.50898 .53571 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.53478 .61509 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.6023 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.75859 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.82611 .61509 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.85191 .53571 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.80361 .38706 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.73609 .33801 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.65262 .33801 L
s
P
p
.2 0 1 r
.018 w
.68044 .50925 m
.64403 .53571 L
s
P
p
.2 0 1 r
.018 w
.68044 .50925 m
.71686 .53571 L
s
P
p
.2 0 1 r
.018 w
.68044 .50925 m
.69436 .46644 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .28557 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .20211 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.55113 .13458 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.40248 .08629 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.32311 .11208 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.27405 .1796 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.27405 .33589 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.32311 .40342 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.40248 .42921 L
s
P
p
.2 0 1 r
.018 w
.42894 .25775 m
.47175 .24384 L
s
P
p
.2 0 1 r
.018 w
.42894 .25775 m
.40248 .22133 L
s
P
p
.2 0 1 r
.018 w
.42894 .25775 m
.40248 .29416 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .49528 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.41036 .57466 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .65404 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.5626 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.64606 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.71358 .69685 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.76188 .5482 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.73609 .46883 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.66856 .41977 L
s
P
p
.2 0 1 r
.018 w
.59042 .57466 m
.5454 .57466 L
s
P
p
.2 0 1 r
.018 w
.59042 .57466 m
.60433 .61747 L
s
P
p
.2 0 1 r
.018 w
.59042 .57466 m
.62683 .5482 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.65696 .34652 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .279 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .19554 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.61415 .06909 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.53478 .0433 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.4554 .06909 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .19554 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .279 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.41259 .34652 L
s
P
p
.2 0 1 r
.018 w
.53478 .22336 m
.57759 .23727 L
s
P
p
.2 0 1 r
.018 w
.53478 .22336 m
.53478 .17834 L
s
P
p
.2 0 1 r
.018 w
.53478 .22336 m
.49196 .23727 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.40099 .41977 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.33347 .46883 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.30767 .5482 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.35597 .69685 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.42349 .74591 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.50696 .74591 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .65404 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.65919 .57466 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .49528 L
s
P
p
.2 0 1 r
.018 w
.47913 .57466 m
.44272 .5482 L
s
P
p
.2 0 1 r
.018 w
.47913 .57466 m
.46522 .61747 L
s
P
p
.2 0 1 r
.018 w
.47913 .57466 m
.52415 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.68044 .50925 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.42894 .25775 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.59042 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.53478 .22336 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.47913 .57466 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.64794 .48472 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.71546 .53378 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.79892 .53378 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .44191 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.95116 .36254 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .28316 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.79892 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.71546 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.64794 .24035 L
s
P
p
.2 0 1 r
.018 w
.7711 .36254 m
.75719 .40535 L
s
P
p
.2 0 1 r
.018 w
.7711 .36254 m
.81612 .36254 L
s
P
p
.2 0 1 r
.018 w
.7711 .36254 m
.75719 .31972 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.57469 .22875 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.52563 .16122 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.44626 .13543 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.29761 .18373 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .25125 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .33471 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.34042 .46116 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.4198 .48695 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.49917 .46116 L
s
P
p
.2 0 1 r
.018 w
.4198 .30689 m
.44626 .27048 L
s
P
p
.2 0 1 r
.018 w
.4198 .30689 m
.37699 .29298 L
s
P
p
.2 0 1 r
.018 w
.4198 .30689 m
.4198 .35191 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.56525 .49483 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.59104 .57421 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.65856 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.81486 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.88238 .57421 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.90817 .49483 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.85988 .34618 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.79235 .29713 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.70889 .29713 L
s
P
p
.2 0 1 r
.018 w
.73671 .46837 m
.7003 .49483 L
s
P
p
.2 0 1 r
.018 w
.73671 .46837 m
.77313 .49483 L
s
P
p
.2 0 1 r
.018 w
.73671 .46837 m
.75062 .42556 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .24469 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .16122 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.6074 .0937 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.45875 .04541 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.37937 .0712 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.33032 .13872 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.33032 .29501 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.37937 .36254 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.45875 .38833 L
s
P
p
.2 0 1 r
.018 w
.48521 .21687 m
.52802 .20296 L
s
P
p
.2 0 1 r
.018 w
.48521 .21687 m
.45875 .18045 L
s
P
p
.2 0 1 r
.018 w
.48521 .21687 m
.45875 .25328 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .4544 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.46663 .53378 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .61316 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.61886 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.70232 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.76985 .65597 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.81814 .50732 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.79235 .42794 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.72483 .37889 L
s
P
p
.2 0 1 r
.018 w
.64668 .53378 m
.60167 .53378 L
s
P
p
.2 0 1 r
.018 w
.64668 .53378 m
.66059 .57659 L
s
P
p
.2 0 1 r
.018 w
.64668 .53378 m
.6831 .50732 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.7711 .36254 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.4198 .30689 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.73671 .46837 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.48521 .21687 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.64668 .53378 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.40896 .36254 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.46522 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.53478 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.59104 .36254 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0760741 0.952381 [
[ 0 0 0 0 ]
[ 1 .80023 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .80023 L
0 .80023 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.31419 .50779 m
.31419 .37075 L
s
P
p
.2 0 1 r
.002 w
.31419 .50779 m
.23364 .39693 L
s
P
p
.2 0 1 r
.002 w
.31419 .50779 m
.18386 .46545 L
s
P
p
.2 0 1 r
.002 w
.31419 .50779 m
.18386 .55014 L
s
P
p
.2 0 1 r
.002 w
.33703 .57809 m
.2067 .62044 L
s
P
p
.2 0 1 r
.002 w
.33703 .57809 m
.25648 .68896 L
s
P
p
.2 0 1 r
.002 w
.33703 .57809 m
.33703 .71513 L
s
P
p
.2 0 1 r
.002 w
.33703 .57809 m
.41758 .68896 L
s
P
p
.2 0 1 r
.002 w
.39683 .53464 m
.47738 .64551 L
s
P
p
.2 0 1 r
.002 w
.39683 .53464 m
.52716 .57699 L
s
P
p
.2 0 1 r
.002 w
.39683 .53464 m
.52716 .4923 L
s
P
p
.2 0 1 r
.002 w
.39683 .53464 m
.47738 .42378 L
s
P
p
0 .4 1 r
.018 w
.35115 .53464 m
.31419 .50779 L
s
P
p
0 .4 1 r
.018 w
.35115 .53464 m
.33703 .57809 L
s
P
p
0 .4 1 r
.018 w
.35115 .53464 m
.39683 .53464 L
s
P
p
.2 0 1 r
.002 w
.54186 .25 m
.49951 .38033 L
s
P
p
.2 0 1 r
.002 w
.54186 .25 m
.58421 .38033 L
s
P
p
.2 0 1 r
.002 w
.54186 .25 m
.65273 .33055 L
s
P
p
.2 0 1 r
.002 w
.54186 .25 m
.6789 .25 L
s
P
p
.2 0 1 r
.002 w
.54186 .17609 m
.6789 .17609 L
s
P
p
.2 0 1 r
.002 w
.54186 .17609 m
.65273 .09554 L
s
P
p
.2 0 1 r
.002 w
.54186 .17609 m
.58421 .04575 L
s
P
p
.2 0 1 r
.002 w
.54186 .17609 m
.49951 .04575 L
s
P
p
.2 0 1 r
.002 w
.47157 .19893 m
.42922 .06859 L
s
P
p
.2 0 1 r
.002 w
.47157 .19893 m
.3607 .11838 L
s
P
p
.2 0 1 r
.002 w
.47157 .19893 m
.33453 .19893 L
s
P
p
.2 0 1 r
.002 w
.47157 .19893 m
.3607 .27948 L
s
P
p
0 .4 1 r
.018 w
.51501 .21304 m
.54186 .25 L
s
P
p
0 .4 1 r
.018 w
.51501 .21304 m
.54186 .17609 L
s
P
p
0 .4 1 r
.018 w
.51501 .21304 m
.47157 .19893 L
s
P
p
.2 0 1 r
.002 w
.24567 .42482 m
.32622 .31395 L
s
P
p
.2 0 1 r
.002 w
.24567 .42482 m
.24567 .28778 L
s
P
p
.2 0 1 r
.002 w
.24567 .42482 m
.16512 .31395 L
s
P
p
.2 0 1 r
.002 w
.24567 .42482 m
.11534 .38247 L
s
P
p
.2 0 1 r
.002 w
.22283 .49512 m
.0925 .45277 L
s
P
p
.2 0 1 r
.002 w
.22283 .49512 m
.0925 .53746 L
s
P
p
.2 0 1 r
.002 w
.22283 .49512 m
.14228 .60598 L
s
P
p
.2 0 1 r
.002 w
.22283 .49512 m
.22283 .63216 L
s
P
p
.2 0 1 r
.002 w
.29674 .49512 m
.29674 .63216 L
s
P
p
.2 0 1 r
.002 w
.29674 .49512 m
.37729 .60598 L
s
P
p
.2 0 1 r
.002 w
.29674 .49512 m
.42708 .53746 L
s
P
p
.2 0 1 r
.002 w
.29674 .49512 m
.42708 .45277 L
s
P
p
0 .4 1 r
.018 w
.25979 .46827 m
.24567 .42482 L
s
P
p
0 .4 1 r
.018 w
.25979 .46827 m
.22283 .49512 L
s
P
p
0 .4 1 r
.018 w
.25979 .46827 m
.29674 .49512 L
s
P
p
.2 0 1 r
.002 w
.58139 .35008 m
.47052 .43063 L
s
P
p
.2 0 1 r
.002 w
.58139 .35008 m
.53904 .48042 L
s
P
p
.2 0 1 r
.002 w
.58139 .35008 m
.62374 .48042 L
s
P
p
.2 0 1 r
.002 w
.58139 .35008 m
.69226 .43063 L
s
P
p
.2 0 1 r
.002 w
.62483 .29029 m
.7357 .37084 L
s
P
p
.2 0 1 r
.002 w
.62483 .29029 m
.76187 .29029 L
s
P
p
.2 0 1 r
.002 w
.62483 .29029 m
.7357 .20974 L
s
P
p
.2 0 1 r
.002 w
.62483 .29029 m
.66718 .15995 L
s
P
p
.2 0 1 r
.002 w
.55454 .26745 m
.59689 .13711 L
s
P
p
.2 0 1 r
.002 w
.55454 .26745 m
.51219 .13711 L
s
P
p
.2 0 1 r
.002 w
.55454 .26745 m
.44367 .1869 L
s
P
p
.2 0 1 r
.002 w
.55454 .26745 m
.4175 .26745 L
s
P
p
0 .4 1 r
.018 w
.58139 .3044 m
.58139 .35008 L
s
P
p
0 .4 1 r
.018 w
.58139 .3044 m
.62483 .29029 L
s
P
p
0 .4 1 r
.018 w
.58139 .3044 m
.55454 .26745 L
s
P
p
.2 0 1 r
.002 w
.23901 .31742 m
.36934 .27507 L
s
P
p
.2 0 1 r
.002 w
.23901 .31742 m
.31956 .20655 L
s
P
p
.2 0 1 r
.002 w
.23901 .31742 m
.23901 .18038 L
s
P
p
.2 0 1 r
.002 w
.23901 .31742 m
.15846 .20655 L
s
P
p
.2 0 1 r
.002 w
.17921 .36087 m
.09866 .25 L
s
P
p
.2 0 1 r
.002 w
.17921 .36087 m
.04888 .31852 L
s
P
p
.2 0 1 r
.002 w
.17921 .36087 m
.04888 .40321 L
s
P
p
.2 0 1 r
.002 w
.17921 .36087 m
.09866 .47173 L
s
P
p
.2 0 1 r
.002 w
.23901 .40431 m
.15846 .51518 L
s
P
p
.2 0 1 r
.002 w
.23901 .40431 m
.23901 .54135 L
s
P
p
.2 0 1 r
.002 w
.23901 .40431 m
.31956 .51518 L
s
P
p
.2 0 1 r
.002 w
.23901 .40431 m
.36934 .44666 L
s
P
p
0 .4 1 r
.018 w
.22489 .36087 m
.23901 .31742 L
s
P
p
0 .4 1 r
.018 w
.22489 .36087 m
.17921 .36087 L
s
P
p
0 .4 1 r
.018 w
.22489 .36087 m
.23901 .40431 L
s
P
p
.2 0 1 r
.016 w
.40761 .36087 m
.35115 .53464 L
s
P
p
.2 0 1 r
.016 w
.40761 .36087 m
.51501 .21304 L
s
P
p
.2 0 1 r
.016 w
.40761 .36087 m
.25979 .46827 L
s
P
p
.2 0 1 r
.016 w
.40761 .36087 m
.58139 .3044 L
s
P
p
.2 0 1 r
.016 w
.40761 .36087 m
.22489 .36087 L
s
P
p
.2 0 1 r
.002 w
.47549 .57613 m
.39494 .46526 L
s
P
p
.2 0 1 r
.002 w
.47549 .57613 m
.34516 .53378 L
s
P
p
.2 0 1 r
.002 w
.47549 .57613 m
.34516 .61848 L
s
P
p
.2 0 1 r
.002 w
.47549 .57613 m
.39494 .687 L
s
P
p
.2 0 1 r
.002 w
.53529 .61957 m
.45474 .73044 L
s
P
p
.2 0 1 r
.002 w
.53529 .61957 m
.53529 .75661 L
s
P
p
.2 0 1 r
.002 w
.53529 .61957 m
.61584 .73044 L
s
P
p
.2 0 1 r
.002 w
.53529 .61957 m
.66562 .66192 L
s
P
p
.2 0 1 r
.002 w
.55813 .54928 m
.68846 .59163 L
s
P
p
.2 0 1 r
.002 w
.55813 .54928 m
.68846 .50693 L
s
P
p
.2 0 1 r
.002 w
.55813 .54928 m
.63868 .43841 L
s
P
p
.2 0 1 r
.002 w
.55813 .54928 m
.55813 .41224 L
s
P
p
0 .4 1 r
.018 w
.52117 .57613 m
.47549 .57613 L
s
P
p
0 .4 1 r
.018 w
.52117 .57613 m
.53529 .61957 L
s
P
p
0 .4 1 r
.018 w
.52117 .57613 m
.55813 .54928 L
s
P
p
.2 0 1 r
.002 w
.50815 .23375 m
.5505 .36408 L
s
P
p
.2 0 1 r
.002 w
.50815 .23375 m
.61902 .3143 L
s
P
p
.2 0 1 r
.002 w
.50815 .23375 m
.64519 .23375 L
s
P
p
.2 0 1 r
.002 w
.50815 .23375 m
.61902 .1532 L
s
P
p
.2 0 1 r
.002 w
.46471 .17395 m
.57558 .0934 L
s
P
p
.2 0 1 r
.002 w
.46471 .17395 m
.50706 .04362 L
s
P
p
.2 0 1 r
.002 w
.46471 .17395 m
.42236 .04362 L
s
P
p
.2 0 1 r
.002 w
.46471 .17395 m
.35384 .0934 L
s
P
p
.2 0 1 r
.002 w
.42127 .23375 m
.3104 .1532 L
s
P
p
.2 0 1 r
.002 w
.42127 .23375 m
.28423 .23375 L
s
P
p
.2 0 1 r
.002 w
.42127 .23375 m
.3104 .3143 L
s
P
p
.2 0 1 r
.002 w
.42127 .23375 m
.37892 .36408 L
s
P
p
0 .4 1 r
.018 w
.46471 .21963 m
.50815 .23375 L
s
P
p
0 .4 1 r
.018 w
.46471 .21963 m
.46471 .17395 L
s
P
p
0 .4 1 r
.018 w
.46471 .21963 m
.42127 .23375 L
s
P
p
.2 0 1 r
.002 w
.37129 .54928 m
.37129 .41224 L
s
P
p
.2 0 1 r
.002 w
.37129 .54928 m
.29074 .43841 L
s
P
p
.2 0 1 r
.002 w
.37129 .54928 m
.24096 .50693 L
s
P
p
.2 0 1 r
.002 w
.37129 .54928 m
.24096 .59163 L
s
P
p
.2 0 1 r
.002 w
.39413 .61957 m
.2638 .66192 L
s
P
p
.2 0 1 r
.002 w
.39413 .61957 m
.31358 .73044 L
s
P
p
.2 0 1 r
.002 w
.39413 .61957 m
.39413 .75661 L
s
P
p
.2 0 1 r
.002 w
.39413 .61957 m
.47468 .73044 L
s
P
p
.2 0 1 r
.002 w
.45393 .57613 m
.53448 .687 L
s
P
p
.2 0 1 r
.002 w
.45393 .57613 m
.58426 .61848 L
s
P
p
.2 0 1 r
.002 w
.45393 .57613 m
.58426 .53378 L
s
P
p
.2 0 1 r
.002 w
.45393 .57613 m
.53448 .46526 L
s
P
p
0 .4 1 r
.018 w
.40825 .57613 m
.37129 .54928 L
s
P
p
0 .4 1 r
.018 w
.40825 .57613 m
.39413 .61957 L
s
P
p
0 .4 1 r
.018 w
.40825 .57613 m
.45393 .57613 L
s
P
p
.2 0 1 r
.002 w
.59896 .29148 m
.55661 .42182 L
s
P
p
.2 0 1 r
.002 w
.59896 .29148 m
.64131 .42182 L
s
P
p
.2 0 1 r
.002 w
.59896 .29148 m
.70983 .37203 L
s
P
p
.2 0 1 r
.002 w
.59896 .29148 m
.736 .29148 L
s
P
p
.2 0 1 r
.002 w
.59896 .21757 m
.736 .21757 L
s
P
p
.2 0 1 r
.002 w
.59896 .21757 m
.70983 .13702 L
s
P
p
.2 0 1 r
.002 w
.59896 .21757 m
.64131 .08724 L
s
P
p
.2 0 1 r
.002 w
.59896 .21757 m
.55661 .08724 L
s
P
p
.2 0 1 r
.002 w
.52867 .24041 m
.48632 .11008 L
s
P
p
.2 0 1 r
.002 w
.52867 .24041 m
.4178 .15986 L
s
P
p
.2 0 1 r
.002 w
.52867 .24041 m
.39163 .24041 L
s
P
p
.2 0 1 r
.002 w
.52867 .24041 m
.4178 .32096 L
s
P
p
0 .4 1 r
.018 w
.57211 .25453 m
.59896 .29148 L
s
P
p
0 .4 1 r
.018 w
.57211 .25453 m
.59896 .21757 L
s
P
p
0 .4 1 r
.018 w
.57211 .25453 m
.52867 .24041 L
s
P
p
.2 0 1 r
.002 w
.30277 .46631 m
.38332 .35544 L
s
P
p
.2 0 1 r
.002 w
.30277 .46631 m
.30277 .32927 L
s
P
p
.2 0 1 r
.002 w
.30277 .46631 m
.22222 .35544 L
s
P
p
.2 0 1 r
.002 w
.30277 .46631 m
.17244 .42396 L
s
P
p
.2 0 1 r
.002 w
.27993 .5366 m
.1496 .49425 L
s
P
p
.2 0 1 r
.002 w
.27993 .5366 m
.1496 .57895 L
s
P
p
.2 0 1 r
.002 w
.27993 .5366 m
.19938 .64747 L
s
P
p
.2 0 1 r
.002 w
.27993 .5366 m
.27993 .67364 L
s
P
p
.2 0 1 r
.002 w
.35384 .5366 m
.35384 .67364 L
s
P
p
.2 0 1 r
.002 w
.35384 .5366 m
.43439 .64747 L
s
P
p
.2 0 1 r
.002 w
.35384 .5366 m
.48418 .57895 L
s
P
p
.2 0 1 r
.002 w
.35384 .5366 m
.48418 .49425 L
s
P
p
0 .4 1 r
.018 w
.31689 .50975 m
.30277 .46631 L
s
P
p
0 .4 1 r
.018 w
.31689 .50975 m
.27993 .5366 L
s
P
p
0 .4 1 r
.018 w
.31689 .50975 m
.35384 .5366 L
s
P
p
.2 0 1 r
.016 w
.46471 .40235 m
.52117 .57613 L
s
P
p
.2 0 1 r
.016 w
.46471 .40235 m
.46471 .21963 L
s
P
p
.2 0 1 r
.016 w
.46471 .40235 m
.40825 .57613 L
s
P
p
.2 0 1 r
.016 w
.46471 .40235 m
.57211 .25453 L
s
P
p
.2 0 1 r
.016 w
.46471 .40235 m
.31689 .50975 L
s
P
p
.2 0 1 r
.002 w
.64616 .5366 m
.51582 .49425 L
s
P
p
.2 0 1 r
.002 w
.64616 .5366 m
.51582 .57895 L
s
P
p
.2 0 1 r
.002 w
.64616 .5366 m
.56561 .64747 L
s
P
p
.2 0 1 r
.002 w
.64616 .5366 m
.64616 .67364 L
s
P
p
.2 0 1 r
.002 w
.72007 .5366 m
.72007 .67364 L
s
P
p
.2 0 1 r
.002 w
.72007 .5366 m
.80062 .64747 L
s
P
p
.2 0 1 r
.002 w
.72007 .5366 m
.8504 .57895 L
s
P
p
.2 0 1 r
.002 w
.72007 .5366 m
.8504 .49425 L
s
P
p
.2 0 1 r
.002 w
.69723 .46631 m
.82756 .42396 L
s
P
p
.2 0 1 r
.002 w
.69723 .46631 m
.77778 .35544 L
s
P
p
.2 0 1 r
.002 w
.69723 .46631 m
.69723 .32927 L
s
P
p
.2 0 1 r
.002 w
.69723 .46631 m
.61668 .35544 L
s
P
p
0 .4 1 r
.018 w
.68311 .50975 m
.64616 .5366 L
s
P
p
0 .4 1 r
.018 w
.68311 .50975 m
.72007 .5366 L
s
P
p
0 .4 1 r
.018 w
.68311 .50975 m
.69723 .46631 L
s
P
p
.2 0 1 r
.002 w
.47133 .24041 m
.5822 .32096 L
s
P
p
.2 0 1 r
.002 w
.47133 .24041 m
.60837 .24041 L
s
P
p
.2 0 1 r
.002 w
.47133 .24041 m
.5822 .15986 L
s
P
p
.2 0 1 r
.002 w
.47133 .24041 m
.51368 .11008 L
s
P
p
.2 0 1 r
.002 w
.40104 .21757 m
.44339 .08724 L
s
P
p
.2 0 1 r
.002 w
.40104 .21757 m
.35869 .08724 L
s
P
p
.2 0 1 r
.002 w
.40104 .21757 m
.29017 .13702 L
s
P
p
.2 0 1 r
.002 w
.40104 .21757 m
.264 .21757 L
s
P
p
.2 0 1 r
.002 w
.40104 .29148 m
.264 .29148 L
s
P
p
.2 0 1 r
.002 w
.40104 .29148 m
.29017 .37203 L
s
P
p
.2 0 1 r
.002 w
.40104 .29148 m
.35869 .42182 L
s
P
p
.2 0 1 r
.002 w
.40104 .29148 m
.44339 .42182 L
s
P
p
0 .4 1 r
.018 w
.42789 .25453 m
.47133 .24041 L
s
P
p
0 .4 1 r
.018 w
.42789 .25453 m
.40104 .21757 L
s
P
p
0 .4 1 r
.018 w
.42789 .25453 m
.40104 .29148 L
s
P
p
.2 0 1 r
.002 w
.54607 .57613 m
.46552 .46526 L
s
P
p
.2 0 1 r
.002 w
.54607 .57613 m
.41574 .53378 L
s
P
p
.2 0 1 r
.002 w
.54607 .57613 m
.41574 .61848 L
s
P
p
.2 0 1 r
.002 w
.54607 .57613 m
.46552 .687 L
s
P
p
.2 0 1 r
.002 w
.60587 .61957 m
.52532 .73044 L
s
P
p
.2 0 1 r
.002 w
.60587 .61957 m
.60587 .75661 L
s
P
p
.2 0 1 r
.002 w
.60587 .61957 m
.68642 .73044 L
s
P
p
.2 0 1 r
.002 w
.60587 .61957 m
.7362 .66192 L
s
P
p
.2 0 1 r
.002 w
.62871 .54928 m
.75904 .59163 L
s
P
p
.2 0 1 r
.002 w
.62871 .54928 m
.75904 .50693 L
s
P
p
.2 0 1 r
.002 w
.62871 .54928 m
.70926 .43841 L
s
P
p
.2 0 1 r
.002 w
.62871 .54928 m
.62871 .41224 L
s
P
p
0 .4 1 r
.018 w
.59175 .57613 m
.54607 .57613 L
s
P
p
0 .4 1 r
.018 w
.59175 .57613 m
.60587 .61957 L
s
P
p
0 .4 1 r
.018 w
.59175 .57613 m
.62871 .54928 L
s
P
p
.2 0 1 r
.002 w
.57873 .23375 m
.62108 .36408 L
s
P
p
.2 0 1 r
.002 w
.57873 .23375 m
.6896 .3143 L
s
P
p
.2 0 1 r
.002 w
.57873 .23375 m
.71577 .23375 L
s
P
p
.2 0 1 r
.002 w
.57873 .23375 m
.6896 .1532 L
s
P
p
.2 0 1 r
.002 w
.53529 .17395 m
.64616 .0934 L
s
P
p
.2 0 1 r
.002 w
.53529 .17395 m
.57764 .04362 L
s
P
p
.2 0 1 r
.002 w
.53529 .17395 m
.49294 .04362 L
s
P
p
.2 0 1 r
.002 w
.53529 .17395 m
.42442 .0934 L
s
P
p
.2 0 1 r
.002 w
.49185 .23375 m
.38098 .1532 L
s
P
p
.2 0 1 r
.002 w
.49185 .23375 m
.35481 .23375 L
s
P
p
.2 0 1 r
.002 w
.49185 .23375 m
.38098 .3143 L
s
P
p
.2 0 1 r
.002 w
.49185 .23375 m
.4495 .36408 L
s
P
p
0 .4 1 r
.018 w
.53529 .21963 m
.57873 .23375 L
s
P
p
0 .4 1 r
.018 w
.53529 .21963 m
.53529 .17395 L
s
P
p
0 .4 1 r
.018 w
.53529 .21963 m
.49185 .23375 L
s
P
p
.2 0 1 r
.002 w
.44187 .54928 m
.44187 .41224 L
s
P
p
.2 0 1 r
.002 w
.44187 .54928 m
.36132 .43841 L
s
P
p
.2 0 1 r
.002 w
.44187 .54928 m
.31154 .50693 L
s
P
p
.2 0 1 r
.002 w
.44187 .54928 m
.31154 .59163 L
s
P
p
.2 0 1 r
.002 w
.46471 .61957 m
.33438 .66192 L
s
P
p
.2 0 1 r
.002 w
.46471 .61957 m
.38416 .73044 L
s
P
p
.2 0 1 r
.002 w
.46471 .61957 m
.46471 .75661 L
s
P
p
.2 0 1 r
.002 w
.46471 .61957 m
.54526 .73044 L
s
P
p
.2 0 1 r
.002 w
.52451 .57613 m
.60506 .687 L
s
P
p
.2 0 1 r
.002 w
.52451 .57613 m
.65484 .61848 L
s
P
p
.2 0 1 r
.002 w
.52451 .57613 m
.65484 .53378 L
s
P
p
.2 0 1 r
.002 w
.52451 .57613 m
.60506 .46526 L
s
P
p
0 .4 1 r
.018 w
.47883 .57613 m
.44187 .54928 L
s
P
p
0 .4 1 r
.018 w
.47883 .57613 m
.46471 .61957 L
s
P
p
0 .4 1 r
.018 w
.47883 .57613 m
.52451 .57613 L
s
P
p
.2 0 1 r
.016 w
.53529 .40235 m
.68311 .50975 L
s
P
p
.2 0 1 r
.016 w
.53529 .40235 m
.42789 .25453 L
s
P
p
.2 0 1 r
.016 w
.53529 .40235 m
.59175 .57613 L
s
P
p
.2 0 1 r
.016 w
.53529 .40235 m
.53529 .21963 L
s
P
p
.2 0 1 r
.016 w
.53529 .40235 m
.47883 .57613 L
s
P
p
.2 0 1 r
.002 w
.76099 .40431 m
.63066 .44666 L
s
P
p
.2 0 1 r
.002 w
.76099 .40431 m
.68044 .51518 L
s
P
p
.2 0 1 r
.002 w
.76099 .40431 m
.76099 .54135 L
s
P
p
.2 0 1 r
.002 w
.76099 .40431 m
.84154 .51518 L
s
P
p
.2 0 1 r
.002 w
.82079 .36087 m
.90134 .47173 L
s
P
p
.2 0 1 r
.002 w
.82079 .36087 m
.95112 .40321 L
s
P
p
.2 0 1 r
.002 w
.82079 .36087 m
.95112 .31852 L
s
P
p
.2 0 1 r
.002 w
.82079 .36087 m
.90134 .25 L
s
P
p
.2 0 1 r
.002 w
.76099 .31742 m
.84154 .20655 L
s
P
p
.2 0 1 r
.002 w
.76099 .31742 m
.76099 .18038 L
s
P
p
.2 0 1 r
.002 w
.76099 .31742 m
.68044 .20655 L
s
P
p
.2 0 1 r
.002 w
.76099 .31742 m
.63066 .27507 L
s
P
p
0 .4 1 r
.018 w
.77511 .36087 m
.76099 .40431 L
s
P
p
0 .4 1 r
.018 w
.77511 .36087 m
.82079 .36087 L
s
P
p
0 .4 1 r
.018 w
.77511 .36087 m
.76099 .31742 L
s
P
p
.2 0 1 r
.002 w
.44546 .26745 m
.5825 .26745 L
s
P
p
.2 0 1 r
.002 w
.44546 .26745 m
.55633 .1869 L
s
P
p
.2 0 1 r
.002 w
.44546 .26745 m
.48781 .13711 L
s
P
p
.2 0 1 r
.002 w
.44546 .26745 m
.40311 .13711 L
s
P
p
.2 0 1 r
.002 w
.37517 .29029 m
.33282 .15995 L
s
P
p
.2 0 1 r
.002 w
.37517 .29029 m
.2643 .20974 L
s
P
p
.2 0 1 r
.002 w
.37517 .29029 m
.23813 .29029 L
s
P
p
.2 0 1 r
.002 w
.37517 .29029 m
.2643 .37084 L
s
P
p
.2 0 1 r
.002 w
.41861 .35008 m
.30774 .43063 L
s
P
p
.2 0 1 r
.002 w
.41861 .35008 m
.37626 .48042 L
s
P
p
.2 0 1 r
.002 w
.41861 .35008 m
.46096 .48042 L
s
P
p
.2 0 1 r
.002 w
.41861 .35008 m
.52948 .43063 L
s
P
p
0 .4 1 r
.018 w
.41861 .3044 m
.44546 .26745 L
s
P
p
0 .4 1 r
.018 w
.41861 .3044 m
.37517 .29029 L
s
P
p
0 .4 1 r
.018 w
.41861 .3044 m
.41861 .35008 L
s
P
p
.2 0 1 r
.002 w
.70326 .49512 m
.57292 .45277 L
s
P
p
.2 0 1 r
.002 w
.70326 .49512 m
.57292 .53746 L
s
P
p
.2 0 1 r
.002 w
.70326 .49512 m
.62271 .60598 L
s
P
p
.2 0 1 r
.002 w
.70326 .49512 m
.70326 .63216 L
s
P
p
.2 0 1 r
.002 w
.77717 .49512 m
.77717 .63216 L
s
P
p
.2 0 1 r
.002 w
.77717 .49512 m
.85772 .60598 L
s
P
p
.2 0 1 r
.002 w
.77717 .49512 m
.9075 .53746 L
s
P
p
.2 0 1 r
.002 w
.77717 .49512 m
.9075 .45277 L
s
P
p
.2 0 1 r
.002 w
.75433 .42482 m
.88466 .38247 L
s
P
p
.2 0 1 r
.002 w
.75433 .42482 m
.83488 .31395 L
s
P
p
.2 0 1 r
.002 w
.75433 .42482 m
.75433 .28778 L
s
P
p
.2 0 1 r
.002 w
.75433 .42482 m
.67378 .31395 L
s
P
p
0 .4 1 r
.018 w
.74021 .46827 m
.70326 .49512 L
s
P
p
0 .4 1 r
.018 w
.74021 .46827 m
.77717 .49512 L
s
P
p
0 .4 1 r
.018 w
.74021 .46827 m
.75433 .42482 L
s
P
p
.2 0 1 r
.002 w
.52843 .19893 m
.6393 .27948 L
s
P
p
.2 0 1 r
.002 w
.52843 .19893 m
.66547 .19893 L
s
P
p
.2 0 1 r
.002 w
.52843 .19893 m
.6393 .11838 L
s
P
p
.2 0 1 r
.002 w
.52843 .19893 m
.57078 .06859 L
s
P
p
.2 0 1 r
.002 w
.45814 .17609 m
.50049 .04575 L
s
P
p
.2 0 1 r
.002 w
.45814 .17609 m
.41579 .04575 L
s
P
p
.2 0 1 r
.002 w
.45814 .17609 m
.34727 .09554 L
s
P
p
.2 0 1 r
.002 w
.45814 .17609 m
.3211 .17609 L
s
P
p
.2 0 1 r
.002 w
.45814 .25 m
.3211 .25 L
s
P
p
.2 0 1 r
.002 w
.45814 .25 m
.34727 .33055 L
s
P
p
.2 0 1 r
.002 w
.45814 .25 m
.41579 .38033 L
s
P
p
.2 0 1 r
.002 w
.45814 .25 m
.50049 .38033 L
s
P
p
0 .4 1 r
.018 w
.48499 .21304 m
.52843 .19893 L
s
P
p
0 .4 1 r
.018 w
.48499 .21304 m
.45814 .17609 L
s
P
p
0 .4 1 r
.018 w
.48499 .21304 m
.45814 .25 L
s
P
p
.2 0 1 r
.002 w
.60317 .53464 m
.52262 .42378 L
s
P
p
.2 0 1 r
.002 w
.60317 .53464 m
.47284 .4923 L
s
P
p
.2 0 1 r
.002 w
.60317 .53464 m
.47284 .57699 L
s
P
p
.2 0 1 r
.002 w
.60317 .53464 m
.52262 .64551 L
s
P
p
.2 0 1 r
.002 w
.66297 .57809 m
.58242 .68896 L
s
P
p
.2 0 1 r
.002 w
.66297 .57809 m
.66297 .71513 L
s
P
p
.2 0 1 r
.002 w
.66297 .57809 m
.74352 .68896 L
s
P
p
.2 0 1 r
.002 w
.66297 .57809 m
.7933 .62044 L
s
P
p
.2 0 1 r
.002 w
.68581 .50779 m
.81614 .55014 L
s
P
p
.2 0 1 r
.002 w
.68581 .50779 m
.81614 .46545 L
s
P
p
.2 0 1 r
.002 w
.68581 .50779 m
.76636 .39693 L
s
P
p
.2 0 1 r
.002 w
.68581 .50779 m
.68581 .37075 L
s
P
p
0 .4 1 r
.018 w
.64885 .53464 m
.60317 .53464 L
s
P
p
0 .4 1 r
.018 w
.64885 .53464 m
.66297 .57809 L
s
P
p
0 .4 1 r
.018 w
.64885 .53464 m
.68581 .50779 L
s
P
p
.2 0 1 r
.016 w
.59239 .36087 m
.77511 .36087 L
s
P
p
.2 0 1 r
.016 w
.59239 .36087 m
.41861 .3044 L
s
P
p
.2 0 1 r
.016 w
.59239 .36087 m
.74021 .46827 L
s
P
p
.2 0 1 r
.016 w
.59239 .36087 m
.48499 .21304 L
s
P
p
.2 0 1 r
.016 w
.59239 .36087 m
.64885 .53464 L
s
P
p
1 .6 0 r
.016 w
.5 .29374 m
.40761 .36087 L
s
P
p
1 .6 0 r
.016 w
.5 .29374 m
.46471 .40235 L
s
P
p
1 .6 0 r
.016 w
.5 .29374 m
.53529 .40235 L
s
P
p
1 .6 0 r
.016 w
.5 .29374 m
.59239 .36087 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0780989 0.952381 [
[ 0 0 0 0 ]
[ 1 .79618 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79618 L
0 .79618 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.23752 .39825 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.20765 .42813 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.18846 .46577 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.26003 .68603 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.29768 .70521 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.33941 .71182 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .57569 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.53337 .53396 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .49223 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.3169 .5075 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.33941 .57677 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.39833 .53396 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.58298 .3819 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.62063 .36272 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.6505 .33284 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.6505 .10126 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.62063 .07138 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.58298 .0522 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.36273 .12376 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.34355 .16141 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.33694 .20314 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .25347 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .18063 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.47198 .20314 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.24938 .2907 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.20765 .29731 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.17 .31649 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.09844 .53674 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.11762 .57439 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.14749 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.37908 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.40896 .57439 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.42814 .53674 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.24938 .42574 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.22687 .49501 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.2997 .49501 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.53847 .48053 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.5802 .48713 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.62193 .48053 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75806 .29317 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75145 .25144 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.73226 .21379 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.51201 .14223 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.47437 .16141 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.44449 .19128 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.5802 .35209 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.62301 .29317 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.55374 .27066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.32219 .21066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.28454 .19147 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.24281 .18486 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .32099 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.04884 .36272 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .40445 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.24281 .54057 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.28454 .53396 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.32219 .51478 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .31991 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.18388 .36272 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .40553 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.35332 .53396 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.51479 .21705 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.26329 .46855 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.5802 .30708 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.2289 .36272 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .53311 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34081 .57484 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .61657 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.53478 .7527 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.57651 .74609 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.61415 .72691 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.68572 .50665 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.66653 .46901 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.63666 .43913 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.47585 .57484 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.53478 .61766 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.55728 .54839 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.61729 .31683 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.63647 .27918 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.64308 .23745 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.50696 .05009 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.46522 .04348 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.42349 .05009 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.28737 .23745 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.29398 .27918 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.31316 .31683 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.50804 .23745 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.46522 .17853 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.42241 .23745 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.29379 .43913 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.26391 .46901 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.24473 .50665 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.3163 .72691 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.35394 .74609 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.39567 .7527 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .61657 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58964 .57484 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .53311 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.37317 .54839 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.39567 .61766 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.4546 .57484 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.63925 .42278 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.67689 .4036 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.70677 .37372 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.70677 .14214 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.67689 .11226 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.63925 .09308 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.419 .16464 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39981 .20229 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39321 .24402 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .29435 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .22151 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.52825 .24402 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.30564 .33158 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.26391 .33819 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.22627 .35737 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.1547 .57762 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.17389 .61527 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.20376 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.43535 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.46522 .61527 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.48441 .57762 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.30564 .46662 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.28314 .53589 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.35597 .53589 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.52087 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.46522 .22354 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.40958 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.57106 .25793 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.31956 .50943 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.51559 .57762 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.53478 .61527 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.56465 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.79624 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.82611 .61527 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.8453 .57762 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.77373 .35737 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.73609 .33819 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.69436 .33158 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.64403 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.71686 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.69436 .46662 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60679 .24402 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60019 .20229 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.581 .16464 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.36075 .09308 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.32311 .11226 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.29323 .14214 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.29323 .37372 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.32311 .4036 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.36075 .42278 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.47175 .24402 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .22151 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .29435 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .53311 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41036 .57484 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .61657 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.60433 .7527 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.64606 .74609 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.6837 .72691 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.75527 .50665 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.73609 .46901 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.70621 .43913 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.5454 .57484 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.60433 .61766 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.62683 .54839 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.68684 .31683 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.70602 .27918 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.71263 .23745 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.57651 .05009 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.53478 .04348 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.49304 .05009 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.35692 .23745 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.36353 .27918 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.38271 .31683 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.57759 .23745 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.53478 .17853 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.49196 .23745 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.36334 .43913 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.33347 .46901 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.31428 .50665 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.38585 .72691 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.42349 .74609 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.46522 .7527 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .61657 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65919 .57484 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .53311 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.44272 .54839 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.46522 .61766 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.52415 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.68044 .50943 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.42894 .25793 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.59042 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.53478 .22354 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.47913 .57484 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.67781 .51478 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.71546 .53396 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.75719 .54057 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .40445 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.95116 .36272 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .32099 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.75719 .18486 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.71546 .19147 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.67781 .21066 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .40553 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.81612 .36272 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .31991 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.55551 .19128 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.52563 .16141 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.48799 .14223 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.26774 .21379 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24855 .25144 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24194 .29317 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.37807 .48053 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.4198 .48713 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.46153 .48053 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.44626 .27066 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.37699 .29317 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.4198 .35209 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.57186 .53674 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.59104 .57439 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.62092 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.85251 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.88238 .57439 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.90156 .53674 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.83 .31649 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.79235 .29731 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.75062 .2907 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.7003 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.77313 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.75062 .42574 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.66306 .20314 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.65645 .16141 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.63727 .12376 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.41702 .0522 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.37937 .07138 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.3495 .10126 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.3495 .33284 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.37937 .36272 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.41702 .3819 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.52802 .20314 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .18063 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .25347 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .49223 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.46663 .53396 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .57569 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.66059 .71182 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.70232 .70521 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.73997 .68603 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.81154 .46577 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.79235 .42813 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.76248 .39825 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.60167 .53396 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.66059 .57677 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.6831 .5075 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.7711 .36272 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.4198 .30708 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.73671 .46855 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.48521 .21705 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.64668 .53396 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.40896 .36272 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.46522 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.53478 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.59104 .36272 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0771326 0.952381 [
[ 0 0 0 0 ]
[ 1 .79812 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79812 L
0 .79812 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.32556 .50697 m
.27917 .36422 L
s
P
p
.2 0 1 r
.002 w
.32556 .50697 m
.20412 .41874 L
s
P
p
.2 0 1 r
.002 w
.32556 .50697 m
.17545 .50697 L
s
P
p
.2 0 1 r
.002 w
.347 .57297 m
.22556 .66119 L
s
P
p
.2 0 1 r
.002 w
.347 .57297 m
.30061 .71572 L
s
P
p
.2 0 1 r
.002 w
.347 .57297 m
.39338 .71572 L
s
P
p
.2 0 1 r
.002 w
.40314 .53218 m
.52457 .62041 L
s
P
p
.2 0 1 r
.002 w
.40314 .53218 m
.55324 .53218 L
s
P
p
.2 0 1 r
.002 w
.40314 .53218 m
.52457 .44395 L
s
P
p
0 .4 1 r
.018 w
.36025 .53218 m
.32556 .50697 L
s
P
p
0 .4 1 r
.018 w
.36025 .53218 m
.347 .57297 L
s
P
p
0 .4 1 r
.018 w
.36025 .53218 m
.40314 .53218 L
s
P
p
.2 0 1 r
.002 w
.5393 .26494 m
.5393 .41504 L
s
P
p
.2 0 1 r
.002 w
.5393 .26494 m
.62753 .38638 L
s
P
p
.2 0 1 r
.002 w
.5393 .26494 m
.68205 .31133 L
s
P
p
.2 0 1 r
.002 w
.5393 .19555 m
.68205 .14917 L
s
P
p
.2 0 1 r
.002 w
.5393 .19555 m
.62753 .07412 L
s
P
p
.2 0 1 r
.002 w
.5393 .19555 m
.5393 .04545 L
s
P
p
.2 0 1 r
.002 w
.47331 .217 m
.38508 .09556 L
s
P
p
.2 0 1 r
.002 w
.47331 .217 m
.33055 .17061 L
s
P
p
.2 0 1 r
.002 w
.47331 .217 m
.33055 .26338 L
s
P
p
0 .4 1 r
.018 w
.51409 .23025 m
.5393 .26494 L
s
P
p
0 .4 1 r
.018 w
.51409 .23025 m
.5393 .19555 L
s
P
p
0 .4 1 r
.018 w
.51409 .23025 m
.47331 .217 L
s
P
p
.2 0 1 r
.002 w
.26123 .42907 m
.30761 .28632 L
s
P
p
.2 0 1 r
.002 w
.26123 .42907 m
.21484 .28632 L
s
P
p
.2 0 1 r
.002 w
.26123 .42907 m
.13979 .34085 L
s
P
p
.2 0 1 r
.002 w
.23978 .49507 m
.08968 .49507 L
s
P
p
.2 0 1 r
.002 w
.23978 .49507 m
.11835 .5833 L
s
P
p
.2 0 1 r
.002 w
.23978 .49507 m
.1934 .63782 L
s
P
p
.2 0 1 r
.002 w
.30917 .49507 m
.35556 .63782 L
s
P
p
.2 0 1 r
.002 w
.30917 .49507 m
.43061 .5833 L
s
P
p
.2 0 1 r
.002 w
.30917 .49507 m
.45928 .49507 L
s
P
p
0 .4 1 r
.018 w
.27448 .46986 m
.26123 .42907 L
s
P
p
0 .4 1 r
.018 w
.27448 .46986 m
.23978 .49507 L
s
P
p
0 .4 1 r
.018 w
.27448 .46986 m
.30917 .49507 L
s
P
p
.2 0 1 r
.002 w
.57641 .35891 m
.48818 .48034 L
s
P
p
.2 0 1 r
.002 w
.57641 .35891 m
.57641 .50901 L
s
P
p
.2 0 1 r
.002 w
.57641 .35891 m
.66464 .48034 L
s
P
p
.2 0 1 r
.002 w
.6172 .30277 m
.75995 .34915 L
s
P
p
.2 0 1 r
.002 w
.6172 .30277 m
.75995 .25638 L
s
P
p
.2 0 1 r
.002 w
.6172 .30277 m
.70542 .18133 L
s
P
p
.2 0 1 r
.002 w
.5512 .28132 m
.5512 .13122 L
s
P
p
.2 0 1 r
.002 w
.5512 .28132 m
.46297 .15989 L
s
P
p
.2 0 1 r
.002 w
.5512 .28132 m
.40845 .23494 L
s
P
p
0 .4 1 r
.018 w
.57641 .31602 m
.57641 .35891 L
s
P
p
0 .4 1 r
.018 w
.57641 .31602 m
.6172 .30277 L
s
P
p
0 .4 1 r
.018 w
.57641 .31602 m
.5512 .28132 L
s
P
p
.2 0 1 r
.002 w
.25497 .32824 m
.3764 .24002 L
s
P
p
.2 0 1 r
.002 w
.25497 .32824 m
.30135 .18549 L
s
P
p
.2 0 1 r
.002 w
.25497 .32824 m
.20859 .18549 L
s
P
p
.2 0 1 r
.002 w
.19883 .36903 m
.0774 .2808 L
s
P
p
.2 0 1 r
.002 w
.19883 .36903 m
.04873 .36903 L
s
P
p
.2 0 1 r
.002 w
.19883 .36903 m
.0774 .45726 L
s
P
p
.2 0 1 r
.002 w
.25497 .40982 m
.20859 .55257 L
s
P
p
.2 0 1 r
.002 w
.25497 .40982 m
.30135 .55257 L
s
P
p
.2 0 1 r
.002 w
.25497 .40982 m
.3764 .49804 L
s
P
p
0 .4 1 r
.018 w
.24172 .36903 m
.25497 .32824 L
s
P
p
0 .4 1 r
.018 w
.24172 .36903 m
.19883 .36903 L
s
P
p
0 .4 1 r
.018 w
.24172 .36903 m
.25497 .40982 L
s
P
p
.2 0 1 r
.016 w
.41326 .36903 m
.36025 .53218 L
s
P
p
.2 0 1 r
.016 w
.41326 .36903 m
.51409 .23025 L
s
P
p
.2 0 1 r
.016 w
.41326 .36903 m
.27448 .46986 L
s
P
p
.2 0 1 r
.016 w
.41326 .36903 m
.57641 .31602 L
s
P
p
.2 0 1 r
.016 w
.41326 .36903 m
.24172 .36903 L
s
P
p
.2 0 1 r
.002 w
.47699 .57113 m
.35556 .4829 L
s
P
p
.2 0 1 r
.002 w
.47699 .57113 m
.32689 .57113 L
s
P
p
.2 0 1 r
.002 w
.47699 .57113 m
.35556 .65935 L
s
P
p
.2 0 1 r
.002 w
.53313 .61191 m
.48675 .75467 L
s
P
p
.2 0 1 r
.002 w
.53313 .61191 m
.57952 .75467 L
s
P
p
.2 0 1 r
.002 w
.53313 .61191 m
.65457 .70014 L
s
P
p
.2 0 1 r
.002 w
.55457 .54592 m
.70468 .54592 L
s
P
p
.2 0 1 r
.002 w
.55457 .54592 m
.67601 .45769 L
s
P
p
.2 0 1 r
.002 w
.55457 .54592 m
.60096 .40316 L
s
P
p
0 .4 1 r
.018 w
.51988 .57113 m
.47699 .57113 L
s
P
p
0 .4 1 r
.018 w
.51988 .57113 m
.53313 .61191 L
s
P
p
0 .4 1 r
.018 w
.51988 .57113 m
.55457 .54592 L
s
P
p
.2 0 1 r
.002 w
.50766 .24969 m
.59588 .37112 L
s
P
p
.2 0 1 r
.002 w
.50766 .24969 m
.65041 .29607 L
s
P
p
.2 0 1 r
.002 w
.50766 .24969 m
.65041 .2033 L
s
P
p
.2 0 1 r
.002 w
.46687 .19355 m
.5551 .07211 L
s
P
p
.2 0 1 r
.002 w
.46687 .19355 m
.46687 .04345 L
s
P
p
.2 0 1 r
.002 w
.46687 .19355 m
.37864 .07211 L
s
P
p
.2 0 1 r
.002 w
.42608 .24969 m
.28333 .2033 L
s
P
p
.2 0 1 r
.002 w
.42608 .24969 m
.28333 .29607 L
s
P
p
.2 0 1 r
.002 w
.42608 .24969 m
.33785 .37112 L
s
P
p
0 .4 1 r
.018 w
.46687 .23643 m
.50766 .24969 L
s
P
p
0 .4 1 r
.018 w
.46687 .23643 m
.46687 .19355 L
s
P
p
0 .4 1 r
.018 w
.46687 .23643 m
.42608 .24969 L
s
P
p
.2 0 1 r
.002 w
.37916 .54592 m
.33278 .40316 L
s
P
p
.2 0 1 r
.002 w
.37916 .54592 m
.25773 .45769 L
s
P
p
.2 0 1 r
.002 w
.37916 .54592 m
.22906 .54592 L
s
P
p
.2 0 1 r
.002 w
.40061 .61191 m
.27917 .70014 L
s
P
p
.2 0 1 r
.002 w
.40061 .61191 m
.35422 .75467 L
s
P
p
.2 0 1 r
.002 w
.40061 .61191 m
.44699 .75467 L
s
P
p
.2 0 1 r
.002 w
.45674 .57113 m
.57818 .65935 L
s
P
p
.2 0 1 r
.002 w
.45674 .57113 m
.60685 .57113 L
s
P
p
.2 0 1 r
.002 w
.45674 .57113 m
.57818 .4829 L
s
P
p
0 .4 1 r
.018 w
.41386 .57113 m
.37916 .54592 L
s
P
p
0 .4 1 r
.018 w
.41386 .57113 m
.40061 .61191 L
s
P
p
0 .4 1 r
.018 w
.41386 .57113 m
.45674 .57113 L
s
P
p
.2 0 1 r
.002 w
.59291 .30389 m
.59291 .45399 L
s
P
p
.2 0 1 r
.002 w
.59291 .30389 m
.68113 .42533 L
s
P
p
.2 0 1 r
.002 w
.59291 .30389 m
.73566 .35028 L
s
P
p
.2 0 1 r
.002 w
.59291 .2345 m
.73566 .18812 L
s
P
p
.2 0 1 r
.002 w
.59291 .2345 m
.68113 .11307 L
s
P
p
.2 0 1 r
.002 w
.59291 .2345 m
.59291 .0844 L
s
P
p
.2 0 1 r
.002 w
.52691 .25594 m
.43869 .13451 L
s
P
p
.2 0 1 r
.002 w
.52691 .25594 m
.38416 .20956 L
s
P
p
.2 0 1 r
.002 w
.52691 .25594 m
.38416 .30233 L
s
P
p
0 .4 1 r
.018 w
.5677 .2692 m
.59291 .30389 L
s
P
p
0 .4 1 r
.018 w
.5677 .2692 m
.59291 .2345 L
s
P
p
0 .4 1 r
.018 w
.5677 .2692 m
.52691 .25594 L
s
P
p
.2 0 1 r
.002 w
.31483 .46802 m
.36122 .32527 L
s
P
p
.2 0 1 r
.002 w
.31483 .46802 m
.26845 .32527 L
s
P
p
.2 0 1 r
.002 w
.31483 .46802 m
.1934 .3798 L
s
P
p
.2 0 1 r
.002 w
.29339 .53402 m
.14329 .53402 L
s
P
p
.2 0 1 r
.002 w
.29339 .53402 m
.17196 .62224 L
s
P
p
.2 0 1 r
.002 w
.29339 .53402 m
.24701 .67677 L
s
P
p
.2 0 1 r
.002 w
.36278 .53402 m
.40917 .67677 L
s
P
p
.2 0 1 r
.002 w
.36278 .53402 m
.48422 .62224 L
s
P
p
.2 0 1 r
.002 w
.36278 .53402 m
.51288 .53402 L
s
P
p
0 .4 1 r
.018 w
.32809 .50881 m
.31483 .46802 L
s
P
p
0 .4 1 r
.018 w
.32809 .50881 m
.29339 .53402 L
s
P
p
0 .4 1 r
.018 w
.32809 .50881 m
.36278 .53402 L
s
P
p
.2 0 1 r
.016 w
.46687 .40798 m
.51988 .57113 L
s
P
p
.2 0 1 r
.016 w
.46687 .40798 m
.46687 .23643 L
s
P
p
.2 0 1 r
.016 w
.46687 .40798 m
.41386 .57113 L
s
P
p
.2 0 1 r
.016 w
.46687 .40798 m
.5677 .2692 L
s
P
p
.2 0 1 r
.016 w
.46687 .40798 m
.32809 .50881 L
s
P
p
.2 0 1 r
.002 w
.63722 .53402 m
.48712 .53402 L
s
P
p
.2 0 1 r
.002 w
.63722 .53402 m
.51578 .62224 L
s
P
p
.2 0 1 r
.002 w
.63722 .53402 m
.59083 .67677 L
s
P
p
.2 0 1 r
.002 w
.70661 .53402 m
.75299 .67677 L
s
P
p
.2 0 1 r
.002 w
.70661 .53402 m
.82804 .62224 L
s
P
p
.2 0 1 r
.002 w
.70661 .53402 m
.85671 .53402 L
s
P
p
.2 0 1 r
.002 w
.68517 .46802 m
.8066 .3798 L
s
P
p
.2 0 1 r
.002 w
.68517 .46802 m
.73155 .32527 L
s
P
p
.2 0 1 r
.002 w
.68517 .46802 m
.63878 .32527 L
s
P
p
0 .4 1 r
.018 w
.67191 .50881 m
.63722 .53402 L
s
P
p
0 .4 1 r
.018 w
.67191 .50881 m
.70661 .53402 L
s
P
p
0 .4 1 r
.018 w
.67191 .50881 m
.68517 .46802 L
s
P
p
.2 0 1 r
.002 w
.47309 .25594 m
.61584 .30233 L
s
P
p
.2 0 1 r
.002 w
.47309 .25594 m
.61584 .20956 L
s
P
p
.2 0 1 r
.002 w
.47309 .25594 m
.56131 .13451 L
s
P
p
.2 0 1 r
.002 w
.40709 .2345 m
.40709 .0844 L
s
P
p
.2 0 1 r
.002 w
.40709 .2345 m
.31887 .11307 L
s
P
p
.2 0 1 r
.002 w
.40709 .2345 m
.26434 .18812 L
s
P
p
.2 0 1 r
.002 w
.40709 .30389 m
.26434 .35028 L
s
P
p
.2 0 1 r
.002 w
.40709 .30389 m
.31887 .42533 L
s
P
p
.2 0 1 r
.002 w
.40709 .30389 m
.40709 .45399 L
s
P
p
0 .4 1 r
.018 w
.4323 .2692 m
.47309 .25594 L
s
P
p
0 .4 1 r
.018 w
.4323 .2692 m
.40709 .2345 L
s
P
p
0 .4 1 r
.018 w
.4323 .2692 m
.40709 .30389 L
s
P
p
.2 0 1 r
.002 w
.54326 .57113 m
.42182 .4829 L
s
P
p
.2 0 1 r
.002 w
.54326 .57113 m
.39315 .57113 L
s
P
p
.2 0 1 r
.002 w
.54326 .57113 m
.42182 .65935 L
s
P
p
.2 0 1 r
.002 w
.59939 .61191 m
.55301 .75467 L
s
P
p
.2 0 1 r
.002 w
.59939 .61191 m
.64578 .75467 L
s
P
p
.2 0 1 r
.002 w
.59939 .61191 m
.72083 .70014 L
s
P
p
.2 0 1 r
.002 w
.62084 .54592 m
.77094 .54592 L
s
P
p
.2 0 1 r
.002 w
.62084 .54592 m
.74227 .45769 L
s
P
p
.2 0 1 r
.002 w
.62084 .54592 m
.66722 .40316 L
s
P
p
0 .4 1 r
.018 w
.58614 .57113 m
.54326 .57113 L
s
P
p
0 .4 1 r
.018 w
.58614 .57113 m
.59939 .61191 L
s
P
p
0 .4 1 r
.018 w
.58614 .57113 m
.62084 .54592 L
s
P
p
.2 0 1 r
.002 w
.57392 .24969 m
.66215 .37112 L
s
P
p
.2 0 1 r
.002 w
.57392 .24969 m
.71667 .29607 L
s
P
p
.2 0 1 r
.002 w
.57392 .24969 m
.71667 .2033 L
s
P
p
.2 0 1 r
.002 w
.53313 .19355 m
.62136 .07211 L
s
P
p
.2 0 1 r
.002 w
.53313 .19355 m
.53313 .04345 L
s
P
p
.2 0 1 r
.002 w
.53313 .19355 m
.4449 .07211 L
s
P
p
.2 0 1 r
.002 w
.49234 .24969 m
.34959 .2033 L
s
P
p
.2 0 1 r
.002 w
.49234 .24969 m
.34959 .29607 L
s
P
p
.2 0 1 r
.002 w
.49234 .24969 m
.40412 .37112 L
s
P
p
0 .4 1 r
.018 w
.53313 .23643 m
.57392 .24969 L
s
P
p
0 .4 1 r
.018 w
.53313 .23643 m
.53313 .19355 L
s
P
p
0 .4 1 r
.018 w
.53313 .23643 m
.49234 .24969 L
s
P
p
.2 0 1 r
.002 w
.44543 .54592 m
.39904 .40316 L
s
P
p
.2 0 1 r
.002 w
.44543 .54592 m
.32399 .45769 L
s
P
p
.2 0 1 r
.002 w
.44543 .54592 m
.29532 .54592 L
s
P
p
.2 0 1 r
.002 w
.46687 .61191 m
.34543 .70014 L
s
P
p
.2 0 1 r
.002 w
.46687 .61191 m
.42048 .75467 L
s
P
p
.2 0 1 r
.002 w
.46687 .61191 m
.51325 .75467 L
s
P
p
.2 0 1 r
.002 w
.52301 .57113 m
.64444 .65935 L
s
P
p
.2 0 1 r
.002 w
.52301 .57113 m
.67311 .57113 L
s
P
p
.2 0 1 r
.002 w
.52301 .57113 m
.64444 .4829 L
s
P
p
0 .4 1 r
.018 w
.48012 .57113 m
.44543 .54592 L
s
P
p
0 .4 1 r
.018 w
.48012 .57113 m
.46687 .61191 L
s
P
p
0 .4 1 r
.018 w
.48012 .57113 m
.52301 .57113 L
s
P
p
.2 0 1 r
.016 w
.53313 .40798 m
.67191 .50881 L
s
P
p
.2 0 1 r
.016 w
.53313 .40798 m
.4323 .2692 L
s
P
p
.2 0 1 r
.016 w
.53313 .40798 m
.58614 .57113 L
s
P
p
.2 0 1 r
.016 w
.53313 .40798 m
.53313 .23643 L
s
P
p
.2 0 1 r
.016 w
.53313 .40798 m
.48012 .57113 L
s
P
p
.2 0 1 r
.002 w
.74503 .40982 m
.6236 .49804 L
s
P
p
.2 0 1 r
.002 w
.74503 .40982 m
.69865 .55257 L
s
P
p
.2 0 1 r
.002 w
.74503 .40982 m
.79141 .55257 L
s
P
p
.2 0 1 r
.002 w
.80117 .36903 m
.9226 .45726 L
s
P
p
.2 0 1 r
.002 w
.80117 .36903 m
.95127 .36903 L
s
P
p
.2 0 1 r
.002 w
.80117 .36903 m
.9226 .2808 L
s
P
p
.2 0 1 r
.002 w
.74503 .32824 m
.79141 .18549 L
s
P
p
.2 0 1 r
.002 w
.74503 .32824 m
.69865 .18549 L
s
P
p
.2 0 1 r
.002 w
.74503 .32824 m
.6236 .24002 L
s
P
p
0 .4 1 r
.018 w
.75828 .36903 m
.74503 .40982 L
s
P
p
0 .4 1 r
.018 w
.75828 .36903 m
.80117 .36903 L
s
P
p
0 .4 1 r
.018 w
.75828 .36903 m
.74503 .32824 L
s
P
p
.2 0 1 r
.002 w
.4488 .28132 m
.59155 .23494 L
s
P
p
.2 0 1 r
.002 w
.4488 .28132 m
.53703 .15989 L
s
P
p
.2 0 1 r
.002 w
.4488 .28132 m
.4488 .13122 L
s
P
p
.2 0 1 r
.002 w
.3828 .30277 m
.29458 .18133 L
s
P
p
.2 0 1 r
.002 w
.3828 .30277 m
.24005 .25638 L
s
P
p
.2 0 1 r
.002 w
.3828 .30277 m
.24005 .34915 L
s
P
p
.2 0 1 r
.002 w
.42359 .35891 m
.33536 .48034 L
s
P
p
.2 0 1 r
.002 w
.42359 .35891 m
.42359 .50901 L
s
P
p
.2 0 1 r
.002 w
.42359 .35891 m
.51182 .48034 L
s
P
p
0 .4 1 r
.018 w
.42359 .31602 m
.4488 .28132 L
s
P
p
0 .4 1 r
.018 w
.42359 .31602 m
.3828 .30277 L
s
P
p
0 .4 1 r
.018 w
.42359 .31602 m
.42359 .35891 L
s
P
p
.2 0 1 r
.002 w
.69083 .49507 m
.54072 .49507 L
s
P
p
.2 0 1 r
.002 w
.69083 .49507 m
.56939 .5833 L
s
P
p
.2 0 1 r
.002 w
.69083 .49507 m
.64444 .63782 L
s
P
p
.2 0 1 r
.002 w
.76022 .49507 m
.8066 .63782 L
s
P
p
.2 0 1 r
.002 w
.76022 .49507 m
.88165 .5833 L
s
P
p
.2 0 1 r
.002 w
.76022 .49507 m
.91032 .49507 L
s
P
p
.2 0 1 r
.002 w
.73877 .42907 m
.86021 .34085 L
s
P
p
.2 0 1 r
.002 w
.73877 .42907 m
.78516 .28632 L
s
P
p
.2 0 1 r
.002 w
.73877 .42907 m
.69239 .28632 L
s
P
p
0 .4 1 r
.018 w
.72552 .46986 m
.69083 .49507 L
s
P
p
0 .4 1 r
.018 w
.72552 .46986 m
.76022 .49507 L
s
P
p
0 .4 1 r
.018 w
.72552 .46986 m
.73877 .42907 L
s
P
p
.2 0 1 r
.002 w
.52669 .217 m
.66945 .26338 L
s
P
p
.2 0 1 r
.002 w
.52669 .217 m
.66945 .17061 L
s
P
p
.2 0 1 r
.002 w
.52669 .217 m
.61492 .09556 L
s
P
p
.2 0 1 r
.002 w
.4607 .19555 m
.4607 .04545 L
s
P
p
.2 0 1 r
.002 w
.4607 .19555 m
.37247 .07412 L
s
P
p
.2 0 1 r
.002 w
.4607 .19555 m
.31795 .14917 L
s
P
p
.2 0 1 r
.002 w
.4607 .26494 m
.31795 .31133 L
s
P
p
.2 0 1 r
.002 w
.4607 .26494 m
.37247 .38638 L
s
P
p
.2 0 1 r
.002 w
.4607 .26494 m
.4607 .41504 L
s
P
p
0 .4 1 r
.018 w
.48591 .23025 m
.52669 .217 L
s
P
p
0 .4 1 r
.018 w
.48591 .23025 m
.4607 .19555 L
s
P
p
0 .4 1 r
.018 w
.48591 .23025 m
.4607 .26494 L
s
P
p
.2 0 1 r
.002 w
.59686 .53218 m
.47543 .44395 L
s
P
p
.2 0 1 r
.002 w
.59686 .53218 m
.44676 .53218 L
s
P
p
.2 0 1 r
.002 w
.59686 .53218 m
.47543 .62041 L
s
P
p
.2 0 1 r
.002 w
.653 .57297 m
.60662 .71572 L
s
P
p
.2 0 1 r
.002 w
.653 .57297 m
.69939 .71572 L
s
P
p
.2 0 1 r
.002 w
.653 .57297 m
.77444 .66119 L
s
P
p
.2 0 1 r
.002 w
.67444 .50697 m
.82455 .50697 L
s
P
p
.2 0 1 r
.002 w
.67444 .50697 m
.79588 .41874 L
s
P
p
.2 0 1 r
.002 w
.67444 .50697 m
.72083 .36422 L
s
P
p
0 .4 1 r
.018 w
.63975 .53218 m
.59686 .53218 L
s
P
p
0 .4 1 r
.018 w
.63975 .53218 m
.653 .57297 L
s
P
p
0 .4 1 r
.018 w
.63975 .53218 m
.67444 .50697 L
s
P
p
.2 0 1 r
.016 w
.58674 .36903 m
.75828 .36903 L
s
P
p
.2 0 1 r
.016 w
.58674 .36903 m
.42359 .31602 L
s
P
p
.2 0 1 r
.016 w
.58674 .36903 m
.72552 .46986 L
s
P
p
.2 0 1 r
.016 w
.58674 .36903 m
.48591 .23025 L
s
P
p
.2 0 1 r
.016 w
.58674 .36903 m
.63975 .53218 L
s
P
p
1 .6 0 r
.016 w
.5 .30601 m
.41326 .36903 L
s
P
p
1 .6 0 r
.016 w
.5 .30601 m
.46687 .40798 L
s
P
p
1 .6 0 r
.016 w
.5 .30601 m
.53313 .40798 L
s
P
p
1 .6 0 r
.016 w
.5 .30601 m
.58674 .36903 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.081587 0.952381 [
[ 0 0 0 0 ]
[ 1 .78921 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78921 L
0 .78921 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.004 w
.3169 .50732 m
.27517 .37889 L
s
P
p
.2 0 1 r
.004 w
.3169 .50732 m
.20765 .42794 L
s
P
p
.2 0 1 r
.004 w
.3169 .50732 m
.18186 .50732 L
s
P
p
.2 0 1 r
.004 w
.33941 .57659 m
.23015 .65597 L
s
P
p
.2 0 1 r
.004 w
.33941 .57659 m
.29768 .70502 L
s
P
p
.2 0 1 r
.004 w
.33941 .57659 m
.38114 .70502 L
s
P
p
.2 0 1 r
.004 w
.39833 .53378 m
.50758 .61316 L
s
P
p
.2 0 1 r
.004 w
.39833 .53378 m
.53337 .53378 L
s
P
p
.2 0 1 r
.004 w
.39833 .53378 m
.50758 .4544 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.3169 .50732 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.33941 .57659 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.39833 .53378 L
s
P
p
.2 0 1 r
.004 w
.54125 .25328 m
.54125 .38833 L
s
P
p
.2 0 1 r
.004 w
.54125 .25328 m
.62063 .36254 L
s
P
p
.2 0 1 r
.004 w
.54125 .25328 m
.66968 .29501 L
s
P
p
.2 0 1 r
.004 w
.54125 .18045 m
.66968 .13872 L
s
P
p
.2 0 1 r
.004 w
.54125 .18045 m
.62063 .0712 L
s
P
p
.2 0 1 r
.004 w
.54125 .18045 m
.54125 .04541 L
s
P
p
.2 0 1 r
.004 w
.47198 .20296 m
.3926 .0937 L
s
P
p
.2 0 1 r
.004 w
.47198 .20296 m
.34355 .16122 L
s
P
p
.2 0 1 r
.004 w
.47198 .20296 m
.34355 .24469 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .25328 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .18045 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.47198 .20296 L
s
P
p
.2 0 1 r
.004 w
.24938 .42556 m
.29111 .29713 L
s
P
p
.2 0 1 r
.004 w
.24938 .42556 m
.20765 .29713 L
s
P
p
.2 0 1 r
.004 w
.24938 .42556 m
.14012 .34618 L
s
P
p
.2 0 1 r
.004 w
.22687 .49483 m
.09183 .49483 L
s
P
p
.2 0 1 r
.004 w
.22687 .49483 m
.11762 .57421 L
s
P
p
.2 0 1 r
.004 w
.22687 .49483 m
.18514 .62326 L
s
P
p
.2 0 1 r
.004 w
.2997 .49483 m
.34144 .62326 L
s
P
p
.2 0 1 r
.004 w
.2997 .49483 m
.40896 .57421 L
s
P
p
.2 0 1 r
.004 w
.2997 .49483 m
.43475 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.24938 .42556 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.22687 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.2997 .49483 L
s
P
p
.2 0 1 r
.004 w
.5802 .35191 m
.50083 .46116 L
s
P
p
.2 0 1 r
.004 w
.5802 .35191 m
.5802 .48695 L
s
P
p
.2 0 1 r
.004 w
.5802 .35191 m
.65958 .46116 L
s
P
p
.2 0 1 r
.004 w
.62301 .29298 m
.75145 .33471 L
s
P
p
.2 0 1 r
.004 w
.62301 .29298 m
.75145 .25125 L
s
P
p
.2 0 1 r
.004 w
.62301 .29298 m
.70239 .18373 L
s
P
p
.2 0 1 r
.004 w
.55374 .27048 m
.55374 .13543 L
s
P
p
.2 0 1 r
.004 w
.55374 .27048 m
.47437 .16122 L
s
P
p
.2 0 1 r
.004 w
.55374 .27048 m
.42531 .22875 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.5802 .35191 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.62301 .29298 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.55374 .27048 L
s
P
p
.2 0 1 r
.004 w
.24281 .31972 m
.35206 .24035 L
s
P
p
.2 0 1 r
.004 w
.24281 .31972 m
.28454 .19129 L
s
P
p
.2 0 1 r
.004 w
.24281 .31972 m
.20108 .19129 L
s
P
p
.2 0 1 r
.004 w
.18388 .36254 m
.07463 .28316 L
s
P
p
.2 0 1 r
.004 w
.18388 .36254 m
.04884 .36254 L
s
P
p
.2 0 1 r
.004 w
.18388 .36254 m
.07463 .44191 L
s
P
p
.2 0 1 r
.004 w
.24281 .40535 m
.20108 .53378 L
s
P
p
.2 0 1 r
.004 w
.24281 .40535 m
.28454 .53378 L
s
P
p
.2 0 1 r
.004 w
.24281 .40535 m
.35206 .48472 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .31972 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.18388 .36254 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .40535 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.35332 .53378 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.51479 .21687 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.26329 .46837 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.5802 .30689 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.2289 .36254 L
s
P
p
.2 0 1 r
.004 w
.47585 .57466 m
.3666 .49528 L
s
P
p
.2 0 1 r
.004 w
.47585 .57466 m
.34081 .57466 L
s
P
p
.2 0 1 r
.004 w
.47585 .57466 m
.3666 .65404 L
s
P
p
.2 0 1 r
.004 w
.53478 .61747 m
.49304 .74591 L
s
P
p
.2 0 1 r
.004 w
.53478 .61747 m
.57651 .74591 L
s
P
p
.2 0 1 r
.004 w
.53478 .61747 m
.64403 .69685 L
s
P
p
.2 0 1 r
.004 w
.55728 .5482 m
.69233 .5482 L
s
P
p
.2 0 1 r
.004 w
.55728 .5482 m
.66653 .46883 L
s
P
p
.2 0 1 r
.004 w
.55728 .5482 m
.59901 .41977 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.47585 .57466 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.53478 .61747 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.55728 .5482 L
s
P
p
.2 0 1 r
.004 w
.50804 .23727 m
.58741 .34652 L
s
P
p
.2 0 1 r
.004 w
.50804 .23727 m
.63647 .279 L
s
P
p
.2 0 1 r
.004 w
.50804 .23727 m
.63647 .19554 L
s
P
p
.2 0 1 r
.004 w
.46522 .17834 m
.5446 .06909 L
s
P
p
.2 0 1 r
.004 w
.46522 .17834 m
.46522 .0433 L
s
P
p
.2 0 1 r
.004 w
.46522 .17834 m
.38585 .06909 L
s
P
p
.2 0 1 r
.004 w
.42241 .23727 m
.29398 .19554 L
s
P
p
.2 0 1 r
.004 w
.42241 .23727 m
.29398 .279 L
s
P
p
.2 0 1 r
.004 w
.42241 .23727 m
.34304 .34652 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.50804 .23727 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.46522 .17834 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.42241 .23727 L
s
P
p
.2 0 1 r
.004 w
.37317 .5482 m
.33144 .41977 L
s
P
p
.2 0 1 r
.004 w
.37317 .5482 m
.26391 .46883 L
s
P
p
.2 0 1 r
.004 w
.37317 .5482 m
.23812 .5482 L
s
P
p
.2 0 1 r
.004 w
.39567 .61747 m
.28642 .69685 L
s
P
p
.2 0 1 r
.004 w
.39567 .61747 m
.35394 .74591 L
s
P
p
.2 0 1 r
.004 w
.39567 .61747 m
.4374 .74591 L
s
P
p
.2 0 1 r
.004 w
.4546 .57466 m
.56385 .65404 L
s
P
p
.2 0 1 r
.004 w
.4546 .57466 m
.58964 .57466 L
s
P
p
.2 0 1 r
.004 w
.4546 .57466 m
.56385 .49528 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.37317 .5482 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.39567 .61747 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.4546 .57466 L
s
P
p
.2 0 1 r
.004 w
.59752 .29416 m
.59752 .42921 L
s
P
p
.2 0 1 r
.004 w
.59752 .29416 m
.67689 .40342 L
s
P
p
.2 0 1 r
.004 w
.59752 .29416 m
.72595 .33589 L
s
P
p
.2 0 1 r
.004 w
.59752 .22133 m
.72595 .1796 L
s
P
p
.2 0 1 r
.004 w
.59752 .22133 m
.67689 .11208 L
s
P
p
.2 0 1 r
.004 w
.59752 .22133 m
.59752 .08629 L
s
P
p
.2 0 1 r
.004 w
.52825 .24384 m
.44887 .13458 L
s
P
p
.2 0 1 r
.004 w
.52825 .24384 m
.39981 .20211 L
s
P
p
.2 0 1 r
.004 w
.52825 .24384 m
.39981 .28557 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .29416 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .22133 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.52825 .24384 L
s
P
p
.2 0 1 r
.004 w
.30564 .46644 m
.34738 .33801 L
s
P
p
.2 0 1 r
.004 w
.30564 .46644 m
.26391 .33801 L
s
P
p
.2 0 1 r
.004 w
.30564 .46644 m
.19639 .38706 L
s
P
p
.2 0 1 r
.004 w
.28314 .53571 m
.14809 .53571 L
s
P
p
.2 0 1 r
.004 w
.28314 .53571 m
.17389 .61509 L
s
P
p
.2 0 1 r
.004 w
.28314 .53571 m
.24141 .66414 L
s
P
p
.2 0 1 r
.004 w
.35597 .53571 m
.3977 .66414 L
s
P
p
.2 0 1 r
.004 w
.35597 .53571 m
.46522 .61509 L
s
P
p
.2 0 1 r
.004 w
.35597 .53571 m
.49102 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.30564 .46644 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.28314 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.35597 .53571 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.52087 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.46522 .22336 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.40958 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.57106 .25775 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.31956 .50925 L
s
P
p
.2 0 1 r
.004 w
.64403 .53571 m
.50898 .53571 L
s
P
p
.2 0 1 r
.004 w
.64403 .53571 m
.53478 .61509 L
s
P
p
.2 0 1 r
.004 w
.64403 .53571 m
.6023 .66414 L
s
P
p
.2 0 1 r
.004 w
.71686 .53571 m
.75859 .66414 L
s
P
p
.2 0 1 r
.004 w
.71686 .53571 m
.82611 .61509 L
s
P
p
.2 0 1 r
.004 w
.71686 .53571 m
.85191 .53571 L
s
P
p
.2 0 1 r
.004 w
.69436 .46644 m
.80361 .38706 L
s
P
p
.2 0 1 r
.004 w
.69436 .46644 m
.73609 .33801 L
s
P
p
.2 0 1 r
.004 w
.69436 .46644 m
.65262 .33801 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.64403 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.71686 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.69436 .46644 L
s
P
p
.2 0 1 r
.004 w
.47175 .24384 m
.60019 .28557 L
s
P
p
.2 0 1 r
.004 w
.47175 .24384 m
.60019 .20211 L
s
P
p
.2 0 1 r
.004 w
.47175 .24384 m
.55113 .13458 L
s
P
p
.2 0 1 r
.004 w
.40248 .22133 m
.40248 .08629 L
s
P
p
.2 0 1 r
.004 w
.40248 .22133 m
.32311 .11208 L
s
P
p
.2 0 1 r
.004 w
.40248 .22133 m
.27405 .1796 L
s
P
p
.2 0 1 r
.004 w
.40248 .29416 m
.27405 .33589 L
s
P
p
.2 0 1 r
.004 w
.40248 .29416 m
.32311 .40342 L
s
P
p
.2 0 1 r
.004 w
.40248 .29416 m
.40248 .42921 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.47175 .24384 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .22133 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .29416 L
s
P
p
.2 0 1 r
.004 w
.5454 .57466 m
.43615 .49528 L
s
P
p
.2 0 1 r
.004 w
.5454 .57466 m
.41036 .57466 L
s
P
p
.2 0 1 r
.004 w
.5454 .57466 m
.43615 .65404 L
s
P
p
.2 0 1 r
.004 w
.60433 .61747 m
.5626 .74591 L
s
P
p
.2 0 1 r
.004 w
.60433 .61747 m
.64606 .74591 L
s
P
p
.2 0 1 r
.004 w
.60433 .61747 m
.71358 .69685 L
s
P
p
.2 0 1 r
.004 w
.62683 .5482 m
.76188 .5482 L
s
P
p
.2 0 1 r
.004 w
.62683 .5482 m
.73609 .46883 L
s
P
p
.2 0 1 r
.004 w
.62683 .5482 m
.66856 .41977 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.5454 .57466 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.60433 .61747 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.62683 .5482 L
s
P
p
.2 0 1 r
.004 w
.57759 .23727 m
.65696 .34652 L
s
P
p
.2 0 1 r
.004 w
.57759 .23727 m
.70602 .279 L
s
P
p
.2 0 1 r
.004 w
.57759 .23727 m
.70602 .19554 L
s
P
p
.2 0 1 r
.004 w
.53478 .17834 m
.61415 .06909 L
s
P
p
.2 0 1 r
.004 w
.53478 .17834 m
.53478 .0433 L
s
P
p
.2 0 1 r
.004 w
.53478 .17834 m
.4554 .06909 L
s
P
p
.2 0 1 r
.004 w
.49196 .23727 m
.36353 .19554 L
s
P
p
.2 0 1 r
.004 w
.49196 .23727 m
.36353 .279 L
s
P
p
.2 0 1 r
.004 w
.49196 .23727 m
.41259 .34652 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.57759 .23727 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.53478 .17834 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.49196 .23727 L
s
P
p
.2 0 1 r
.004 w
.44272 .5482 m
.40099 .41977 L
s
P
p
.2 0 1 r
.004 w
.44272 .5482 m
.33347 .46883 L
s
P
p
.2 0 1 r
.004 w
.44272 .5482 m
.30767 .5482 L
s
P
p
.2 0 1 r
.004 w
.46522 .61747 m
.35597 .69685 L
s
P
p
.2 0 1 r
.004 w
.46522 .61747 m
.42349 .74591 L
s
P
p
.2 0 1 r
.004 w
.46522 .61747 m
.50696 .74591 L
s
P
p
.2 0 1 r
.004 w
.52415 .57466 m
.6334 .65404 L
s
P
p
.2 0 1 r
.004 w
.52415 .57466 m
.65919 .57466 L
s
P
p
.2 0 1 r
.004 w
.52415 .57466 m
.6334 .49528 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.44272 .5482 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.46522 .61747 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.52415 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.68044 .50925 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.42894 .25775 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.59042 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.53478 .22336 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.47913 .57466 L
s
P
p
.2 0 1 r
.004 w
.75719 .40535 m
.64794 .48472 L
s
P
p
.2 0 1 r
.004 w
.75719 .40535 m
.71546 .53378 L
s
P
p
.2 0 1 r
.004 w
.75719 .40535 m
.79892 .53378 L
s
P
p
.2 0 1 r
.004 w
.81612 .36254 m
.92537 .44191 L
s
P
p
.2 0 1 r
.004 w
.81612 .36254 m
.95116 .36254 L
s
P
p
.2 0 1 r
.004 w
.81612 .36254 m
.92537 .28316 L
s
P
p
.2 0 1 r
.004 w
.75719 .31972 m
.79892 .19129 L
s
P
p
.2 0 1 r
.004 w
.75719 .31972 m
.71546 .19129 L
s
P
p
.2 0 1 r
.004 w
.75719 .31972 m
.64794 .24035 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .40535 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.81612 .36254 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .31972 L
s
P
p
.2 0 1 r
.004 w
.44626 .27048 m
.57469 .22875 L
s
P
p
.2 0 1 r
.004 w
.44626 .27048 m
.52563 .16122 L
s
P
p
.2 0 1 r
.004 w
.44626 .27048 m
.44626 .13543 L
s
P
p
.2 0 1 r
.004 w
.37699 .29298 m
.29761 .18373 L
s
P
p
.2 0 1 r
.004 w
.37699 .29298 m
.24855 .25125 L
s
P
p
.2 0 1 r
.004 w
.37699 .29298 m
.24855 .33471 L
s
P
p
.2 0 1 r
.004 w
.4198 .35191 m
.34042 .46116 L
s
P
p
.2 0 1 r
.004 w
.4198 .35191 m
.4198 .48695 L
s
P
p
.2 0 1 r
.004 w
.4198 .35191 m
.49917 .46116 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.44626 .27048 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.37699 .29298 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.4198 .35191 L
s
P
p
.2 0 1 r
.004 w
.7003 .49483 m
.56525 .49483 L
s
P
p
.2 0 1 r
.004 w
.7003 .49483 m
.59104 .57421 L
s
P
p
.2 0 1 r
.004 w
.7003 .49483 m
.65856 .62326 L
s
P
p
.2 0 1 r
.004 w
.77313 .49483 m
.81486 .62326 L
s
P
p
.2 0 1 r
.004 w
.77313 .49483 m
.88238 .57421 L
s
P
p
.2 0 1 r
.004 w
.77313 .49483 m
.90817 .49483 L
s
P
p
.2 0 1 r
.004 w
.75062 .42556 m
.85988 .34618 L
s
P
p
.2 0 1 r
.004 w
.75062 .42556 m
.79235 .29713 L
s
P
p
.2 0 1 r
.004 w
.75062 .42556 m
.70889 .29713 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.7003 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.77313 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.75062 .42556 L
s
P
p
.2 0 1 r
.004 w
.52802 .20296 m
.65645 .24469 L
s
P
p
.2 0 1 r
.004 w
.52802 .20296 m
.65645 .16122 L
s
P
p
.2 0 1 r
.004 w
.52802 .20296 m
.6074 .0937 L
s
P
p
.2 0 1 r
.004 w
.45875 .18045 m
.45875 .04541 L
s
P
p
.2 0 1 r
.004 w
.45875 .18045 m
.37937 .0712 L
s
P
p
.2 0 1 r
.004 w
.45875 .18045 m
.33032 .13872 L
s
P
p
.2 0 1 r
.004 w
.45875 .25328 m
.33032 .29501 L
s
P
p
.2 0 1 r
.004 w
.45875 .25328 m
.37937 .36254 L
s
P
p
.2 0 1 r
.004 w
.45875 .25328 m
.45875 .38833 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.52802 .20296 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .18045 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .25328 L
s
P
p
.2 0 1 r
.004 w
.60167 .53378 m
.49242 .4544 L
s
P
p
.2 0 1 r
.004 w
.60167 .53378 m
.46663 .53378 L
s
P
p
.2 0 1 r
.004 w
.60167 .53378 m
.49242 .61316 L
s
P
p
.2 0 1 r
.004 w
.66059 .57659 m
.61886 .70502 L
s
P
p
.2 0 1 r
.004 w
.66059 .57659 m
.70232 .70502 L
s
P
p
.2 0 1 r
.004 w
.66059 .57659 m
.76985 .65597 L
s
P
p
.2 0 1 r
.004 w
.6831 .50732 m
.81814 .50732 L
s
P
p
.2 0 1 r
.004 w
.6831 .50732 m
.79235 .42794 L
s
P
p
.2 0 1 r
.004 w
.6831 .50732 m
.72483 .37889 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.60167 .53378 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.66059 .57659 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.6831 .50732 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.7711 .36254 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.4198 .30689 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.73671 .46837 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.48521 .21687 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.64668 .53378 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.40896 .36254 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.46522 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.53478 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.59104 .36254 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.081587 0.952381 [
[ 0 0 0 0 ]
[ 1 .78921 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78921 L
0 .78921 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.002 w
.3169 .50732 m
.27517 .37889 L
s
P
p
0 .4 1 r
.002 w
.3169 .50732 m
.20765 .42794 L
s
P
p
0 .4 1 r
.002 w
.3169 .50732 m
.18186 .50732 L
s
P
p
0 .4 1 r
.002 w
.33941 .57659 m
.23015 .65597 L
s
P
p
0 .4 1 r
.002 w
.33941 .57659 m
.29768 .70502 L
s
P
p
0 .4 1 r
.002 w
.33941 .57659 m
.38114 .70502 L
s
P
p
0 .4 1 r
.002 w
.39833 .53378 m
.50758 .61316 L
s
P
p
0 .4 1 r
.002 w
.39833 .53378 m
.53337 .53378 L
s
P
p
0 .4 1 r
.002 w
.39833 .53378 m
.50758 .4544 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.3169 .50732 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.33941 .57659 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.39833 .53378 L
s
P
p
0 .4 1 r
.002 w
.54125 .25328 m
.54125 .38833 L
s
P
p
0 .4 1 r
.002 w
.54125 .25328 m
.62063 .36254 L
s
P
p
0 .4 1 r
.002 w
.54125 .25328 m
.66968 .29501 L
s
P
p
0 .4 1 r
.002 w
.54125 .18045 m
.66968 .13872 L
s
P
p
0 .4 1 r
.002 w
.54125 .18045 m
.62063 .0712 L
s
P
p
0 .4 1 r
.002 w
.54125 .18045 m
.54125 .04541 L
s
P
p
0 .4 1 r
.002 w
.47198 .20296 m
.3926 .0937 L
s
P
p
0 .4 1 r
.002 w
.47198 .20296 m
.34355 .16122 L
s
P
p
0 .4 1 r
.002 w
.47198 .20296 m
.34355 .24469 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .25328 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .18045 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.47198 .20296 L
s
P
p
0 .4 1 r
.002 w
.24938 .42556 m
.29111 .29713 L
s
P
p
0 .4 1 r
.002 w
.24938 .42556 m
.20765 .29713 L
s
P
p
0 .4 1 r
.002 w
.24938 .42556 m
.14012 .34618 L
s
P
p
0 .4 1 r
.002 w
.22687 .49483 m
.09183 .49483 L
s
P
p
0 .4 1 r
.002 w
.22687 .49483 m
.11762 .57421 L
s
P
p
0 .4 1 r
.002 w
.22687 .49483 m
.18514 .62326 L
s
P
p
0 .4 1 r
.002 w
.2997 .49483 m
.34144 .62326 L
s
P
p
0 .4 1 r
.002 w
.2997 .49483 m
.40896 .57421 L
s
P
p
0 .4 1 r
.002 w
.2997 .49483 m
.43475 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.24938 .42556 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.22687 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.2997 .49483 L
s
P
p
0 .4 1 r
.002 w
.5802 .35191 m
.50083 .46116 L
s
P
p
0 .4 1 r
.002 w
.5802 .35191 m
.5802 .48695 L
s
P
p
0 .4 1 r
.002 w
.5802 .35191 m
.65958 .46116 L
s
P
p
0 .4 1 r
.002 w
.62301 .29298 m
.75145 .33471 L
s
P
p
0 .4 1 r
.002 w
.62301 .29298 m
.75145 .25125 L
s
P
p
0 .4 1 r
.002 w
.62301 .29298 m
.70239 .18373 L
s
P
p
0 .4 1 r
.002 w
.55374 .27048 m
.55374 .13543 L
s
P
p
0 .4 1 r
.002 w
.55374 .27048 m
.47437 .16122 L
s
P
p
0 .4 1 r
.002 w
.55374 .27048 m
.42531 .22875 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.5802 .35191 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.62301 .29298 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.55374 .27048 L
s
P
p
0 .4 1 r
.002 w
.24281 .31972 m
.35206 .24035 L
s
P
p
0 .4 1 r
.002 w
.24281 .31972 m
.28454 .19129 L
s
P
p
0 .4 1 r
.002 w
.24281 .31972 m
.20108 .19129 L
s
P
p
0 .4 1 r
.002 w
.18388 .36254 m
.07463 .28316 L
s
P
p
0 .4 1 r
.002 w
.18388 .36254 m
.04884 .36254 L
s
P
p
0 .4 1 r
.002 w
.18388 .36254 m
.07463 .44191 L
s
P
p
0 .4 1 r
.002 w
.24281 .40535 m
.20108 .53378 L
s
P
p
0 .4 1 r
.002 w
.24281 .40535 m
.28454 .53378 L
s
P
p
0 .4 1 r
.002 w
.24281 .40535 m
.35206 .48472 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .31972 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.18388 .36254 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .40535 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.35332 .53378 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.51479 .21687 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.26329 .46837 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.5802 .30689 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.2289 .36254 L
s
P
p
0 .4 1 r
.002 w
.47585 .57466 m
.3666 .49528 L
s
P
p
0 .4 1 r
.002 w
.47585 .57466 m
.34081 .57466 L
s
P
p
0 .4 1 r
.002 w
.47585 .57466 m
.3666 .65404 L
s
P
p
0 .4 1 r
.002 w
.53478 .61747 m
.49304 .74591 L
s
P
p
0 .4 1 r
.002 w
.53478 .61747 m
.57651 .74591 L
s
P
p
0 .4 1 r
.002 w
.53478 .61747 m
.64403 .69685 L
s
P
p
0 .4 1 r
.002 w
.55728 .5482 m
.69233 .5482 L
s
P
p
0 .4 1 r
.002 w
.55728 .5482 m
.66653 .46883 L
s
P
p
0 .4 1 r
.002 w
.55728 .5482 m
.59901 .41977 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.47585 .57466 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.53478 .61747 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.55728 .5482 L
s
P
p
0 .4 1 r
.002 w
.50804 .23727 m
.58741 .34652 L
s
P
p
0 .4 1 r
.002 w
.50804 .23727 m
.63647 .279 L
s
P
p
0 .4 1 r
.002 w
.50804 .23727 m
.63647 .19554 L
s
P
p
0 .4 1 r
.002 w
.46522 .17834 m
.5446 .06909 L
s
P
p
0 .4 1 r
.002 w
.46522 .17834 m
.46522 .0433 L
s
P
p
0 .4 1 r
.002 w
.46522 .17834 m
.38585 .06909 L
s
P
p
0 .4 1 r
.002 w
.42241 .23727 m
.29398 .19554 L
s
P
p
0 .4 1 r
.002 w
.42241 .23727 m
.29398 .279 L
s
P
p
0 .4 1 r
.002 w
.42241 .23727 m
.34304 .34652 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.50804 .23727 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.46522 .17834 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.42241 .23727 L
s
P
p
0 .4 1 r
.002 w
.37317 .5482 m
.33144 .41977 L
s
P
p
0 .4 1 r
.002 w
.37317 .5482 m
.26391 .46883 L
s
P
p
0 .4 1 r
.002 w
.37317 .5482 m
.23812 .5482 L
s
P
p
0 .4 1 r
.002 w
.39567 .61747 m
.28642 .69685 L
s
P
p
0 .4 1 r
.002 w
.39567 .61747 m
.35394 .74591 L
s
P
p
0 .4 1 r
.002 w
.39567 .61747 m
.4374 .74591 L
s
P
p
0 .4 1 r
.002 w
.4546 .57466 m
.56385 .65404 L
s
P
p
0 .4 1 r
.002 w
.4546 .57466 m
.58964 .57466 L
s
P
p
0 .4 1 r
.002 w
.4546 .57466 m
.56385 .49528 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.37317 .5482 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.39567 .61747 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.4546 .57466 L
s
P
p
0 .4 1 r
.002 w
.59752 .29416 m
.59752 .42921 L
s
P
p
0 .4 1 r
.002 w
.59752 .29416 m
.67689 .40342 L
s
P
p
0 .4 1 r
.002 w
.59752 .29416 m
.72595 .33589 L
s
P
p
0 .4 1 r
.002 w
.59752 .22133 m
.72595 .1796 L
s
P
p
0 .4 1 r
.002 w
.59752 .22133 m
.67689 .11208 L
s
P
p
0 .4 1 r
.002 w
.59752 .22133 m
.59752 .08629 L
s
P
p
0 .4 1 r
.002 w
.52825 .24384 m
.44887 .13458 L
s
P
p
0 .4 1 r
.002 w
.52825 .24384 m
.39981 .20211 L
s
P
p
0 .4 1 r
.002 w
.52825 .24384 m
.39981 .28557 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .29416 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .22133 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.52825 .24384 L
s
P
p
0 .4 1 r
.002 w
.30564 .46644 m
.34738 .33801 L
s
P
p
0 .4 1 r
.002 w
.30564 .46644 m
.26391 .33801 L
s
P
p
0 .4 1 r
.002 w
.30564 .46644 m
.19639 .38706 L
s
P
p
0 .4 1 r
.002 w
.28314 .53571 m
.14809 .53571 L
s
P
p
0 .4 1 r
.002 w
.28314 .53571 m
.17389 .61509 L
s
P
p
0 .4 1 r
.002 w
.28314 .53571 m
.24141 .66414 L
s
P
p
0 .4 1 r
.002 w
.35597 .53571 m
.3977 .66414 L
s
P
p
0 .4 1 r
.002 w
.35597 .53571 m
.46522 .61509 L
s
P
p
0 .4 1 r
.002 w
.35597 .53571 m
.49102 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.30564 .46644 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.28314 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.35597 .53571 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.52087 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.46522 .22336 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.40958 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.57106 .25775 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.31956 .50925 L
s
P
p
0 .4 1 r
.002 w
.64403 .53571 m
.50898 .53571 L
s
P
p
0 .4 1 r
.002 w
.64403 .53571 m
.53478 .61509 L
s
P
p
0 .4 1 r
.002 w
.64403 .53571 m
.6023 .66414 L
s
P
p
0 .4 1 r
.002 w
.71686 .53571 m
.75859 .66414 L
s
P
p
0 .4 1 r
.002 w
.71686 .53571 m
.82611 .61509 L
s
P
p
0 .4 1 r
.002 w
.71686 .53571 m
.85191 .53571 L
s
P
p
0 .4 1 r
.002 w
.69436 .46644 m
.80361 .38706 L
s
P
p
0 .4 1 r
.002 w
.69436 .46644 m
.73609 .33801 L
s
P
p
0 .4 1 r
.002 w
.69436 .46644 m
.65262 .33801 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.64403 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.71686 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.69436 .46644 L
s
P
p
0 .4 1 r
.002 w
.47175 .24384 m
.60019 .28557 L
s
P
p
0 .4 1 r
.002 w
.47175 .24384 m
.60019 .20211 L
s
P
p
0 .4 1 r
.002 w
.47175 .24384 m
.55113 .13458 L
s
P
p
0 .4 1 r
.002 w
.40248 .22133 m
.40248 .08629 L
s
P
p
0 .4 1 r
.002 w
.40248 .22133 m
.32311 .11208 L
s
P
p
0 .4 1 r
.002 w
.40248 .22133 m
.27405 .1796 L
s
P
p
0 .4 1 r
.002 w
.40248 .29416 m
.27405 .33589 L
s
P
p
0 .4 1 r
.002 w
.40248 .29416 m
.32311 .40342 L
s
P
p
0 .4 1 r
.002 w
.40248 .29416 m
.40248 .42921 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.47175 .24384 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .22133 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .29416 L
s
P
p
0 .4 1 r
.002 w
.5454 .57466 m
.43615 .49528 L
s
P
p
0 .4 1 r
.002 w
.5454 .57466 m
.41036 .57466 L
s
P
p
0 .4 1 r
.002 w
.5454 .57466 m
.43615 .65404 L
s
P
p
0 .4 1 r
.002 w
.60433 .61747 m
.5626 .74591 L
s
P
p
0 .4 1 r
.002 w
.60433 .61747 m
.64606 .74591 L
s
P
p
0 .4 1 r
.002 w
.60433 .61747 m
.71358 .69685 L
s
P
p
0 .4 1 r
.002 w
.62683 .5482 m
.76188 .5482 L
s
P
p
0 .4 1 r
.002 w
.62683 .5482 m
.73609 .46883 L
s
P
p
0 .4 1 r
.002 w
.62683 .5482 m
.66856 .41977 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.5454 .57466 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.60433 .61747 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.62683 .5482 L
s
P
p
0 .4 1 r
.002 w
.57759 .23727 m
.65696 .34652 L
s
P
p
0 .4 1 r
.002 w
.57759 .23727 m
.70602 .279 L
s
P
p
0 .4 1 r
.002 w
.57759 .23727 m
.70602 .19554 L
s
P
p
0 .4 1 r
.002 w
.53478 .17834 m
.61415 .06909 L
s
P
p
0 .4 1 r
.002 w
.53478 .17834 m
.53478 .0433 L
s
P
p
0 .4 1 r
.002 w
.53478 .17834 m
.4554 .06909 L
s
P
p
0 .4 1 r
.002 w
.49196 .23727 m
.36353 .19554 L
s
P
p
0 .4 1 r
.002 w
.49196 .23727 m
.36353 .279 L
s
P
p
0 .4 1 r
.002 w
.49196 .23727 m
.41259 .34652 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.57759 .23727 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.53478 .17834 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.49196 .23727 L
s
P
p
0 .4 1 r
.002 w
.44272 .5482 m
.40099 .41977 L
s
P
p
0 .4 1 r
.002 w
.44272 .5482 m
.33347 .46883 L
s
P
p
0 .4 1 r
.002 w
.44272 .5482 m
.30767 .5482 L
s
P
p
0 .4 1 r
.002 w
.46522 .61747 m
.35597 .69685 L
s
P
p
0 .4 1 r
.002 w
.46522 .61747 m
.42349 .74591 L
s
P
p
0 .4 1 r
.002 w
.46522 .61747 m
.50696 .74591 L
s
P
p
0 .4 1 r
.002 w
.52415 .57466 m
.6334 .65404 L
s
P
p
0 .4 1 r
.002 w
.52415 .57466 m
.65919 .57466 L
s
P
p
0 .4 1 r
.002 w
.52415 .57466 m
.6334 .49528 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.44272 .5482 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.46522 .61747 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.52415 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.68044 .50925 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.42894 .25775 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.59042 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.53478 .22336 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.47913 .57466 L
s
P
p
0 .4 1 r
.002 w
.75719 .40535 m
.64794 .48472 L
s
P
p
0 .4 1 r
.002 w
.75719 .40535 m
.71546 .53378 L
s
P
p
0 .4 1 r
.002 w
.75719 .40535 m
.79892 .53378 L
s
P
p
0 .4 1 r
.002 w
.81612 .36254 m
.92537 .44191 L
s
P
p
0 .4 1 r
.002 w
.81612 .36254 m
.95116 .36254 L
s
P
p
0 .4 1 r
.002 w
.81612 .36254 m
.92537 .28316 L
s
P
p
0 .4 1 r
.002 w
.75719 .31972 m
.79892 .19129 L
s
P
p
0 .4 1 r
.002 w
.75719 .31972 m
.71546 .19129 L
s
P
p
0 .4 1 r
.002 w
.75719 .31972 m
.64794 .24035 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .40535 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.81612 .36254 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .31972 L
s
P
p
0 .4 1 r
.002 w
.44626 .27048 m
.57469 .22875 L
s
P
p
0 .4 1 r
.002 w
.44626 .27048 m
.52563 .16122 L
s
P
p
0 .4 1 r
.002 w
.44626 .27048 m
.44626 .13543 L
s
P
p
0 .4 1 r
.002 w
.37699 .29298 m
.29761 .18373 L
s
P
p
0 .4 1 r
.002 w
.37699 .29298 m
.24855 .25125 L
s
P
p
0 .4 1 r
.002 w
.37699 .29298 m
.24855 .33471 L
s
P
p
0 .4 1 r
.002 w
.4198 .35191 m
.34042 .46116 L
s
P
p
0 .4 1 r
.002 w
.4198 .35191 m
.4198 .48695 L
s
P
p
0 .4 1 r
.002 w
.4198 .35191 m
.49917 .46116 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.44626 .27048 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.37699 .29298 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.4198 .35191 L
s
P
p
0 .4 1 r
.002 w
.7003 .49483 m
.56525 .49483 L
s
P
p
0 .4 1 r
.002 w
.7003 .49483 m
.59104 .57421 L
s
P
p
0 .4 1 r
.002 w
.7003 .49483 m
.65856 .62326 L
s
P
p
0 .4 1 r
.002 w
.77313 .49483 m
.81486 .62326 L
s
P
p
0 .4 1 r
.002 w
.77313 .49483 m
.88238 .57421 L
s
P
p
0 .4 1 r
.002 w
.77313 .49483 m
.90817 .49483 L
s
P
p
0 .4 1 r
.002 w
.75062 .42556 m
.85988 .34618 L
s
P
p
0 .4 1 r
.002 w
.75062 .42556 m
.79235 .29713 L
s
P
p
0 .4 1 r
.002 w
.75062 .42556 m
.70889 .29713 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.7003 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.77313 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.75062 .42556 L
s
P
p
0 .4 1 r
.002 w
.52802 .20296 m
.65645 .24469 L
s
P
p
0 .4 1 r
.002 w
.52802 .20296 m
.65645 .16122 L
s
P
p
0 .4 1 r
.002 w
.52802 .20296 m
.6074 .0937 L
s
P
p
0 .4 1 r
.002 w
.45875 .18045 m
.45875 .04541 L
s
P
p
0 .4 1 r
.002 w
.45875 .18045 m
.37937 .0712 L
s
P
p
0 .4 1 r
.002 w
.45875 .18045 m
.33032 .13872 L
s
P
p
0 .4 1 r
.002 w
.45875 .25328 m
.33032 .29501 L
s
P
p
0 .4 1 r
.002 w
.45875 .25328 m
.37937 .36254 L
s
P
p
0 .4 1 r
.002 w
.45875 .25328 m
.45875 .38833 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.52802 .20296 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .18045 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .25328 L
s
P
p
0 .4 1 r
.002 w
.60167 .53378 m
.49242 .4544 L
s
P
p
0 .4 1 r
.002 w
.60167 .53378 m
.46663 .53378 L
s
P
p
0 .4 1 r
.002 w
.60167 .53378 m
.49242 .61316 L
s
P
p
0 .4 1 r
.002 w
.66059 .57659 m
.61886 .70502 L
s
P
p
0 .4 1 r
.002 w
.66059 .57659 m
.70232 .70502 L
s
P
p
0 .4 1 r
.002 w
.66059 .57659 m
.76985 .65597 L
s
P
p
0 .4 1 r
.002 w
.6831 .50732 m
.81814 .50732 L
s
P
p
0 .4 1 r
.002 w
.6831 .50732 m
.79235 .42794 L
s
P
p
0 .4 1 r
.002 w
.6831 .50732 m
.72483 .37889 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.60167 .53378 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.66059 .57659 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.6831 .50732 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.7711 .36254 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.4198 .30689 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.73671 .46837 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.48521 .21687 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.64668 .53378 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.40896 .36254 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.46522 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.53478 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.59104 .36254 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.028973 0.952381 [
[ 0 0 0 0 ]
[ 1 .89443 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .89443 L
0 .89443 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.41116 .61381 m
.29047 .52612 L
s
P
p
.2 0 1 r
.002 w
.41116 .61381 m
.26198 .61381 L
s
P
p
.2 0 1 r
.002 w
.41116 .61381 m
.29047 .7015 L
s
P
p
.2 0 1 r
.002 w
.47626 .6611 m
.43016 .80299 L
s
P
p
.2 0 1 r
.002 w
.47626 .6611 m
.52236 .80299 L
s
P
p
.2 0 1 r
.002 w
.47626 .6611 m
.59695 .74879 L
s
P
p
.2 0 1 r
.002 w
.50112 .58458 m
.6503 .58458 L
s
P
p
.2 0 1 r
.002 w
.50112 .58458 m
.62181 .49689 L
s
P
p
.2 0 1 r
.002 w
.50112 .58458 m
.54722 .4427 L
s
P
p
0 .4 1 r
.018 w
.46089 .61381 m
.41116 .61381 L
s
P
p
0 .4 1 r
.018 w
.46089 .61381 m
.47626 .6611 L
s
P
p
0 .4 1 r
.018 w
.46089 .61381 m
.50112 .58458 L
s
P
p
.2 0 1 r
.002 w
.50112 .26469 m
.54722 .40657 L
s
P
p
.2 0 1 r
.002 w
.50112 .26469 m
.62181 .35238 L
s
P
p
.2 0 1 r
.002 w
.50112 .26469 m
.6503 .26469 L
s
P
p
.2 0 1 r
.002 w
.47626 .18817 m
.59695 .10048 L
s
P
p
.2 0 1 r
.002 w
.47626 .18817 m
.52236 .04629 L
s
P
p
.2 0 1 r
.002 w
.47626 .18817 m
.43016 .04629 L
s
P
p
.2 0 1 r
.002 w
.41116 .23546 m
.29047 .14778 L
s
P
p
.2 0 1 r
.002 w
.41116 .23546 m
.26198 .23546 L
s
P
p
.2 0 1 r
.002 w
.41116 .23546 m
.29047 .32315 L
s
P
p
0 .4 1 r
.018 w
.46089 .23546 m
.50112 .26469 L
s
P
p
0 .4 1 r
.018 w
.46089 .23546 m
.47626 .18817 L
s
P
p
0 .4 1 r
.018 w
.46089 .23546 m
.41116 .23546 L
s
P
p
.2 0 1 r
.002 w
.22314 .49426 m
.26924 .35238 L
s
P
p
.2 0 1 r
.002 w
.22314 .49426 m
.17704 .35238 L
s
P
p
.2 0 1 r
.002 w
.22314 .49426 m
.10245 .40657 L
s
P
p
.2 0 1 r
.002 w
.19827 .57078 m
.04909 .57078 L
s
P
p
.2 0 1 r
.002 w
.19827 .57078 m
.07758 .65847 L
s
P
p
.2 0 1 r
.002 w
.19827 .57078 m
.15217 .71266 L
s
P
p
.2 0 1 r
.002 w
.27873 .57078 m
.32483 .71266 L
s
P
p
.2 0 1 r
.002 w
.27873 .57078 m
.39942 .65847 L
s
P
p
.2 0 1 r
.002 w
.27873 .57078 m
.42792 .57078 L
s
P
p
0 .4 1 r
.018 w
.2385 .54155 m
.22314 .49426 L
s
P
p
0 .4 1 r
.018 w
.2385 .54155 m
.19827 .57078 L
s
P
p
0 .4 1 r
.018 w
.2385 .54155 m
.27873 .57078 L
s
P
p
.2 0 1 r
.002 w
.58297 .47193 m
.46228 .55962 L
s
P
p
.2 0 1 r
.002 w
.58297 .47193 m
.53687 .61381 L
s
P
p
.2 0 1 r
.002 w
.58297 .47193 m
.62907 .61381 L
s
P
p
.2 0 1 r
.002 w
.64806 .42464 m
.76875 .51232 L
s
P
p
.2 0 1 r
.002 w
.64806 .42464 m
.79724 .42464 L
s
P
p
.2 0 1 r
.002 w
.64806 .42464 m
.76875 .33695 L
s
P
p
.2 0 1 r
.002 w
.58297 .37734 m
.62907 .23546 L
s
P
p
.2 0 1 r
.002 w
.58297 .37734 m
.53687 .23546 L
s
P
p
.2 0 1 r
.002 w
.58297 .37734 m
.46228 .28966 L
s
P
p
0 .4 1 r
.018 w
.59833 .42464 m
.58297 .47193 L
s
P
p
0 .4 1 r
.018 w
.59833 .42464 m
.64806 .42464 L
s
P
p
0 .4 1 r
.018 w
.59833 .42464 m
.58297 .37734 L
s
P
p
.2 0 1 r
.002 w
.27873 .27849 m
.42792 .27849 L
s
P
p
.2 0 1 r
.002 w
.27873 .27849 m
.39942 .1908 L
s
P
p
.2 0 1 r
.002 w
.27873 .27849 m
.32483 .13661 L
s
P
p
.2 0 1 r
.002 w
.19827 .27849 m
.15217 .13661 L
s
P
p
.2 0 1 r
.002 w
.19827 .27849 m
.07758 .1908 L
s
P
p
.2 0 1 r
.002 w
.19827 .27849 m
.04909 .27849 L
s
P
p
.2 0 1 r
.002 w
.22314 .35501 m
.10245 .4427 L
s
P
p
.2 0 1 r
.002 w
.22314 .35501 m
.17704 .49689 L
s
P
p
.2 0 1 r
.002 w
.22314 .35501 m
.26924 .49689 L
s
P
p
0 .4 1 r
.018 w
.2385 .30772 m
.27873 .27849 L
s
P
p
0 .4 1 r
.018 w
.2385 .30772 m
.19827 .27849 L
s
P
p
0 .4 1 r
.018 w
.2385 .30772 m
.22314 .35501 L
s
P
p
.2 0 1 r
.016 w
.39942 .42464 m
.46089 .61381 L
s
P
p
.2 0 1 r
.016 w
.39942 .42464 m
.46089 .23546 L
s
P
p
.2 0 1 r
.016 w
.39942 .42464 m
.2385 .54155 L
s
P
p
.2 0 1 r
.016 w
.39942 .42464 m
.59833 .42464 L
s
P
p
.2 0 1 r
.016 w
.39942 .42464 m
.2385 .30772 L
s
P
p
.2 0 1 r
.002 w
.58227 .61594 m
.43309 .61594 L
s
P
p
.2 0 1 r
.002 w
.58227 .61594 m
.46158 .70363 L
s
P
p
.2 0 1 r
.002 w
.58227 .61594 m
.53617 .75782 L
s
P
p
.2 0 1 r
.002 w
.66274 .61594 m
.70883 .75782 L
s
P
p
.2 0 1 r
.002 w
.66274 .61594 m
.78343 .70363 L
s
P
p
.2 0 1 r
.002 w
.66274 .61594 m
.81192 .61594 L
s
P
p
.2 0 1 r
.002 w
.63787 .53942 m
.75856 .45173 L
s
P
p
.2 0 1 r
.002 w
.63787 .53942 m
.68397 .39754 L
s
P
p
.2 0 1 r
.002 w
.63787 .53942 m
.59177 .39754 L
s
P
p
0 .4 1 r
.018 w
.6225 .58671 m
.58227 .61594 L
s
P
p
0 .4 1 r
.018 w
.6225 .58671 m
.66274 .61594 L
s
P
p
0 .4 1 r
.018 w
.6225 .58671 m
.63787 .53942 L
s
P
p
.2 0 1 r
.002 w
.44984 .28062 m
.57054 .36831 L
s
P
p
.2 0 1 r
.002 w
.44984 .28062 m
.59903 .28062 L
s
P
p
.2 0 1 r
.002 w
.44984 .28062 m
.57054 .19294 L
s
P
p
.2 0 1 r
.002 w
.38475 .23333 m
.43085 .09145 L
s
P
p
.2 0 1 r
.002 w
.38475 .23333 m
.33865 .09145 L
s
P
p
.2 0 1 r
.002 w
.38475 .23333 m
.26406 .14564 L
s
P
p
.2 0 1 r
.002 w
.35989 .30985 m
.2107 .30985 L
s
P
p
.2 0 1 r
.002 w
.35989 .30985 m
.2392 .39754 L
s
P
p
.2 0 1 r
.002 w
.35989 .30985 m
.31379 .45173 L
s
P
p
0 .4 1 r
.018 w
.40012 .28062 m
.44984 .28062 L
s
P
p
0 .4 1 r
.018 w
.40012 .28062 m
.38475 .23333 L
s
P
p
0 .4 1 r
.018 w
.40012 .28062 m
.35989 .30985 L
s
P
p
.2 0 1 r
.002 w
.35989 .62974 m
.31379 .48786 L
s
P
p
.2 0 1 r
.002 w
.35989 .62974 m
.2392 .54206 L
s
P
p
.2 0 1 r
.002 w
.35989 .62974 m
.2107 .62974 L
s
P
p
.2 0 1 r
.002 w
.38475 .70627 m
.26406 .79395 L
s
P
p
.2 0 1 r
.002 w
.38475 .70627 m
.33865 .84815 L
s
P
p
.2 0 1 r
.002 w
.38475 .70627 m
.43085 .84815 L
s
P
p
.2 0 1 r
.002 w
.44984 .65897 m
.57054 .74666 L
s
P
p
.2 0 1 r
.002 w
.44984 .65897 m
.59903 .65897 L
s
P
p
.2 0 1 r
.002 w
.44984 .65897 m
.57054 .57129 L
s
P
p
0 .4 1 r
.018 w
.40012 .65897 m
.35989 .62974 L
s
P
p
0 .4 1 r
.018 w
.40012 .65897 m
.38475 .70627 L
s
P
p
0 .4 1 r
.018 w
.40012 .65897 m
.44984 .65897 L
s
P
p
.2 0 1 r
.002 w
.63787 .40018 m
.59177 .54206 L
s
P
p
.2 0 1 r
.002 w
.63787 .40018 m
.68397 .54206 L
s
P
p
.2 0 1 r
.002 w
.63787 .40018 m
.75856 .48786 L
s
P
p
.2 0 1 r
.002 w
.66274 .32365 m
.81192 .32365 L
s
P
p
.2 0 1 r
.002 w
.66274 .32365 m
.78343 .23597 L
s
P
p
.2 0 1 r
.002 w
.66274 .32365 m
.70883 .18177 L
s
P
p
.2 0 1 r
.002 w
.58227 .32365 m
.53617 .18177 L
s
P
p
.2 0 1 r
.002 w
.58227 .32365 m
.46158 .23597 L
s
P
p
.2 0 1 r
.002 w
.58227 .32365 m
.43309 .32365 L
s
P
p
0 .4 1 r
.018 w
.6225 .35288 m
.63787 .40018 L
s
P
p
0 .4 1 r
.018 w
.6225 .35288 m
.66274 .32365 L
s
P
p
0 .4 1 r
.018 w
.6225 .35288 m
.58227 .32365 L
s
P
p
.2 0 1 r
.002 w
.27804 .4225 m
.39873 .33482 L
s
P
p
.2 0 1 r
.002 w
.27804 .4225 m
.32414 .28062 L
s
P
p
.2 0 1 r
.002 w
.27804 .4225 m
.23194 .28062 L
s
P
p
.2 0 1 r
.002 w
.21295 .4698 m
.09226 .38211 L
s
P
p
.2 0 1 r
.002 w
.21295 .4698 m
.06376 .4698 L
s
P
p
.2 0 1 r
.002 w
.21295 .4698 m
.09226 .55749 L
s
P
p
.2 0 1 r
.002 w
.27804 .51709 m
.23194 .65897 L
s
P
p
.2 0 1 r
.002 w
.27804 .51709 m
.32414 .65897 L
s
P
p
.2 0 1 r
.002 w
.27804 .51709 m
.39873 .60478 L
s
P
p
0 .4 1 r
.018 w
.26267 .4698 m
.27804 .4225 L
s
P
p
0 .4 1 r
.018 w
.26267 .4698 m
.21295 .4698 L
s
P
p
0 .4 1 r
.018 w
.26267 .4698 m
.27804 .51709 L
s
P
p
.2 0 1 r
.016 w
.46158 .4698 m
.6225 .58671 L
s
P
p
.2 0 1 r
.016 w
.46158 .4698 m
.40012 .28062 L
s
P
p
.2 0 1 r
.016 w
.46158 .4698 m
.40012 .65897 L
s
P
p
.2 0 1 r
.016 w
.46158 .4698 m
.6225 .35288 L
s
P
p
.2 0 1 r
.016 w
.46158 .4698 m
.26267 .4698 L
s
P
p
.2 0 1 r
.002 w
.72196 .51709 m
.60127 .60478 L
s
P
p
.2 0 1 r
.002 w
.72196 .51709 m
.67586 .65897 L
s
P
p
.2 0 1 r
.002 w
.72196 .51709 m
.76806 .65897 L
s
P
p
.2 0 1 r
.002 w
.78705 .4698 m
.90774 .55749 L
s
P
p
.2 0 1 r
.002 w
.78705 .4698 m
.93624 .4698 L
s
P
p
.2 0 1 r
.002 w
.78705 .4698 m
.90774 .38211 L
s
P
p
.2 0 1 r
.002 w
.72196 .4225 m
.76806 .28062 L
s
P
p
.2 0 1 r
.002 w
.72196 .4225 m
.67586 .28062 L
s
P
p
.2 0 1 r
.002 w
.72196 .4225 m
.60127 .33482 L
s
P
p
0 .4 1 r
.018 w
.73733 .4698 m
.72196 .51709 L
s
P
p
0 .4 1 r
.018 w
.73733 .4698 m
.78705 .4698 L
s
P
p
0 .4 1 r
.018 w
.73733 .4698 m
.72196 .4225 L
s
P
p
.2 0 1 r
.002 w
.41773 .32365 m
.56691 .32365 L
s
P
p
.2 0 1 r
.002 w
.41773 .32365 m
.53842 .23597 L
s
P
p
.2 0 1 r
.002 w
.41773 .32365 m
.46383 .18177 L
s
P
p
.2 0 1 r
.002 w
.33726 .32365 m
.29117 .18177 L
s
P
p
.2 0 1 r
.002 w
.33726 .32365 m
.21657 .23597 L
s
P
p
.2 0 1 r
.002 w
.33726 .32365 m
.18808 .32365 L
s
P
p
.2 0 1 r
.002 w
.36213 .40018 m
.24144 .48786 L
s
P
p
.2 0 1 r
.002 w
.36213 .40018 m
.31603 .54206 L
s
P
p
.2 0 1 r
.002 w
.36213 .40018 m
.40823 .54206 L
s
P
p
0 .4 1 r
.018 w
.3775 .35288 m
.41773 .32365 L
s
P
p
0 .4 1 r
.018 w
.3775 .35288 m
.33726 .32365 L
s
P
p
0 .4 1 r
.018 w
.3775 .35288 m
.36213 .40018 L
s
P
p
.2 0 1 r
.002 w
.55016 .65897 m
.42946 .57129 L
s
P
p
.2 0 1 r
.002 w
.55016 .65897 m
.40097 .65897 L
s
P
p
.2 0 1 r
.002 w
.55016 .65897 m
.42946 .74666 L
s
P
p
.2 0 1 r
.002 w
.61525 .70627 m
.56915 .84815 L
s
P
p
.2 0 1 r
.002 w
.61525 .70627 m
.66135 .84815 L
s
P
p
.2 0 1 r
.002 w
.61525 .70627 m
.73594 .79395 L
s
P
p
.2 0 1 r
.002 w
.64011 .62974 m
.7893 .62974 L
s
P
p
.2 0 1 r
.002 w
.64011 .62974 m
.7608 .54206 L
s
P
p
.2 0 1 r
.002 w
.64011 .62974 m
.68621 .48786 L
s
P
p
0 .4 1 r
.018 w
.59988 .65897 m
.55016 .65897 L
s
P
p
0 .4 1 r
.018 w
.59988 .65897 m
.61525 .70627 L
s
P
p
0 .4 1 r
.018 w
.59988 .65897 m
.64011 .62974 L
s
P
p
.2 0 1 r
.002 w
.64011 .30985 m
.68621 .45173 L
s
P
p
.2 0 1 r
.002 w
.64011 .30985 m
.7608 .39754 L
s
P
p
.2 0 1 r
.002 w
.64011 .30985 m
.7893 .30985 L
s
P
p
.2 0 1 r
.002 w
.61525 .23333 m
.73594 .14564 L
s
P
p
.2 0 1 r
.002 w
.61525 .23333 m
.66135 .09145 L
s
P
p
.2 0 1 r
.002 w
.61525 .23333 m
.56915 .09145 L
s
P
p
.2 0 1 r
.002 w
.55016 .28062 m
.42946 .19294 L
s
P
p
.2 0 1 r
.002 w
.55016 .28062 m
.40097 .28062 L
s
P
p
.2 0 1 r
.002 w
.55016 .28062 m
.42946 .36831 L
s
P
p
0 .4 1 r
.018 w
.59988 .28062 m
.64011 .30985 L
s
P
p
0 .4 1 r
.018 w
.59988 .28062 m
.61525 .23333 L
s
P
p
0 .4 1 r
.018 w
.59988 .28062 m
.55016 .28062 L
s
P
p
.2 0 1 r
.002 w
.36213 .53942 m
.40823 .39754 L
s
P
p
.2 0 1 r
.002 w
.36213 .53942 m
.31603 .39754 L
s
P
p
.2 0 1 r
.002 w
.36213 .53942 m
.24144 .45173 L
s
P
p
.2 0 1 r
.002 w
.33726 .61594 m
.18808 .61594 L
s
P
p
.2 0 1 r
.002 w
.33726 .61594 m
.21657 .70363 L
s
P
p
.2 0 1 r
.002 w
.33726 .61594 m
.29117 .75782 L
s
P
p
.2 0 1 r
.002 w
.41773 .61594 m
.46383 .75782 L
s
P
p
.2 0 1 r
.002 w
.41773 .61594 m
.53842 .70363 L
s
P
p
.2 0 1 r
.002 w
.41773 .61594 m
.56691 .61594 L
s
P
p
0 .4 1 r
.018 w
.3775 .58671 m
.36213 .53942 L
s
P
p
0 .4 1 r
.018 w
.3775 .58671 m
.33726 .61594 L
s
P
p
0 .4 1 r
.018 w
.3775 .58671 m
.41773 .61594 L
s
P
p
.2 0 1 r
.016 w
.53842 .4698 m
.73733 .4698 L
s
P
p
.2 0 1 r
.016 w
.53842 .4698 m
.3775 .35288 L
s
P
p
.2 0 1 r
.016 w
.53842 .4698 m
.59988 .65897 L
s
P
p
.2 0 1 r
.016 w
.53842 .4698 m
.59988 .28062 L
s
P
p
.2 0 1 r
.016 w
.53842 .4698 m
.3775 .58671 L
s
P
p
.2 0 1 r
.002 w
.77686 .35501 m
.73076 .49689 L
s
P
p
.2 0 1 r
.002 w
.77686 .35501 m
.82296 .49689 L
s
P
p
.2 0 1 r
.002 w
.77686 .35501 m
.89755 .4427 L
s
P
p
.2 0 1 r
.002 w
.80173 .27849 m
.95091 .27849 L
s
P
p
.2 0 1 r
.002 w
.80173 .27849 m
.92242 .1908 L
s
P
p
.2 0 1 r
.002 w
.80173 .27849 m
.84783 .13661 L
s
P
p
.2 0 1 r
.002 w
.72127 .27849 m
.67517 .13661 L
s
P
p
.2 0 1 r
.002 w
.72127 .27849 m
.60058 .1908 L
s
P
p
.2 0 1 r
.002 w
.72127 .27849 m
.57208 .27849 L
s
P
p
0 .4 1 r
.018 w
.7615 .30772 m
.77686 .35501 L
s
P
p
0 .4 1 r
.018 w
.7615 .30772 m
.80173 .27849 L
s
P
p
0 .4 1 r
.018 w
.7615 .30772 m
.72127 .27849 L
s
P
p
.2 0 1 r
.002 w
.41703 .37734 m
.53772 .28966 L
s
P
p
.2 0 1 r
.002 w
.41703 .37734 m
.46313 .23546 L
s
P
p
.2 0 1 r
.002 w
.41703 .37734 m
.37093 .23546 L
s
P
p
.2 0 1 r
.002 w
.35194 .42464 m
.23125 .33695 L
s
P
p
.2 0 1 r
.002 w
.35194 .42464 m
.20276 .42464 L
s
P
p
.2 0 1 r
.002 w
.35194 .42464 m
.23125 .51232 L
s
P
p
.2 0 1 r
.002 w
.41703 .47193 m
.37093 .61381 L
s
P
p
.2 0 1 r
.002 w
.41703 .47193 m
.46313 .61381 L
s
P
p
.2 0 1 r
.002 w
.41703 .47193 m
.53772 .55962 L
s
P
p
0 .4 1 r
.018 w
.40167 .42464 m
.41703 .37734 L
s
P
p
0 .4 1 r
.018 w
.40167 .42464 m
.35194 .42464 L
s
P
p
0 .4 1 r
.018 w
.40167 .42464 m
.41703 .47193 L
s
P
p
.2 0 1 r
.002 w
.72127 .57078 m
.57208 .57078 L
s
P
p
.2 0 1 r
.002 w
.72127 .57078 m
.60058 .65847 L
s
P
p
.2 0 1 r
.002 w
.72127 .57078 m
.67517 .71266 L
s
P
p
.2 0 1 r
.002 w
.80173 .57078 m
.84783 .71266 L
s
P
p
.2 0 1 r
.002 w
.80173 .57078 m
.92242 .65847 L
s
P
p
.2 0 1 r
.002 w
.80173 .57078 m
.95091 .57078 L
s
P
p
.2 0 1 r
.002 w
.77686 .49426 m
.89755 .40657 L
s
P
p
.2 0 1 r
.002 w
.77686 .49426 m
.82296 .35238 L
s
P
p
.2 0 1 r
.002 w
.77686 .49426 m
.73076 .35238 L
s
P
p
0 .4 1 r
.018 w
.7615 .54155 m
.72127 .57078 L
s
P
p
0 .4 1 r
.018 w
.7615 .54155 m
.80173 .57078 L
s
P
p
0 .4 1 r
.018 w
.7615 .54155 m
.77686 .49426 L
s
P
p
.2 0 1 r
.002 w
.58884 .23546 m
.70953 .32315 L
s
P
p
.2 0 1 r
.002 w
.58884 .23546 m
.73802 .23546 L
s
P
p
.2 0 1 r
.002 w
.58884 .23546 m
.70953 .14778 L
s
P
p
.2 0 1 r
.002 w
.52374 .18817 m
.56984 .04629 L
s
P
p
.2 0 1 r
.002 w
.52374 .18817 m
.47764 .04629 L
s
P
p
.2 0 1 r
.002 w
.52374 .18817 m
.40305 .10048 L
s
P
p
.2 0 1 r
.002 w
.49888 .26469 m
.3497 .26469 L
s
P
p
.2 0 1 r
.002 w
.49888 .26469 m
.37819 .35238 L
s
P
p
.2 0 1 r
.002 w
.49888 .26469 m
.45278 .40657 L
s
P
p
0 .4 1 r
.018 w
.53911 .23546 m
.58884 .23546 L
s
P
p
0 .4 1 r
.018 w
.53911 .23546 m
.52374 .18817 L
s
P
p
0 .4 1 r
.018 w
.53911 .23546 m
.49888 .26469 L
s
P
p
.2 0 1 r
.002 w
.49888 .58458 m
.45278 .4427 L
s
P
p
.2 0 1 r
.002 w
.49888 .58458 m
.37819 .49689 L
s
P
p
.2 0 1 r
.002 w
.49888 .58458 m
.3497 .58458 L
s
P
p
.2 0 1 r
.002 w
.52374 .6611 m
.40305 .74879 L
s
P
p
.2 0 1 r
.002 w
.52374 .6611 m
.47764 .80299 L
s
P
p
.2 0 1 r
.002 w
.52374 .6611 m
.56984 .80299 L
s
P
p
.2 0 1 r
.002 w
.58884 .61381 m
.70953 .7015 L
s
P
p
.2 0 1 r
.002 w
.58884 .61381 m
.73802 .61381 L
s
P
p
.2 0 1 r
.002 w
.58884 .61381 m
.70953 .52612 L
s
P
p
0 .4 1 r
.018 w
.53911 .61381 m
.49888 .58458 L
s
P
p
0 .4 1 r
.018 w
.53911 .61381 m
.52374 .6611 L
s
P
p
0 .4 1 r
.018 w
.53911 .61381 m
.58884 .61381 L
s
P
p
.2 0 1 r
.016 w
.60058 .42464 m
.7615 .30772 L
s
P
p
.2 0 1 r
.016 w
.60058 .42464 m
.40167 .42464 L
s
P
p
.2 0 1 r
.016 w
.60058 .42464 m
.7615 .54155 L
s
P
p
.2 0 1 r
.016 w
.60058 .42464 m
.53911 .23546 L
s
P
p
.2 0 1 r
.016 w
.60058 .42464 m
.53911 .61381 L
s
P
p
1 .6 0 r
.016 w
.5 .35156 m
.39942 .42464 L
s
P
p
1 .6 0 r
.016 w
.5 .35156 m
.46158 .4698 L
s
P
p
1 .6 0 r
.016 w
.5 .35156 m
.53842 .4698 L
s
P
p
1 .6 0 r
.016 w
.5 .35156 m
.60058 .42464 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0771326 0.952381 [
[ 0 0 0 0 ]
[ 1 .79812 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79812 L
0 .79812 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.31893 .52736 m
.27917 .405 L
s
P
p
.2 0 1 r
.002 w
.31893 .52736 m
.21484 .45174 L
s
P
p
.2 0 1 r
.002 w
.31893 .52736 m
.19027 .52736 L
s
P
p
.2 0 1 r
.002 w
.34037 .59336 m
.23629 .66898 L
s
P
p
.2 0 1 r
.002 w
.34037 .59336 m
.30061 .71572 L
s
P
p
.2 0 1 r
.002 w
.34037 .59336 m
.38013 .71572 L
s
P
p
.2 0 1 r
.002 w
.39651 .55257 m
.5006 .6282 L
s
P
p
.2 0 1 r
.002 w
.39651 .55257 m
.52517 .55257 L
s
P
p
.2 0 1 r
.002 w
.39651 .55257 m
.5006 .47695 L
s
P
p
0 .4 1 r
.018 w
.35362 .55257 m
.31893 .52736 L
s
P
p
0 .4 1 r
.018 w
.35362 .55257 m
.34037 .59336 L
s
P
p
0 .4 1 r
.018 w
.35362 .55257 m
.39651 .55257 L
s
P
p
.2 0 1 r
.002 w
.5519 .2476 m
.5519 .37625 L
s
P
p
.2 0 1 r
.002 w
.5519 .2476 m
.62753 .35168 L
s
P
p
.2 0 1 r
.002 w
.5519 .2476 m
.67427 .28735 L
s
P
p
.2 0 1 r
.002 w
.5519 .17821 m
.67427 .13845 L
s
P
p
.2 0 1 r
.002 w
.5519 .17821 m
.62753 .07412 L
s
P
p
.2 0 1 r
.002 w
.5519 .17821 m
.5519 .04955 L
s
P
p
.2 0 1 r
.002 w
.48591 .19965 m
.41029 .09556 L
s
P
p
.2 0 1 r
.002 w
.48591 .19965 m
.36355 .15989 L
s
P
p
.2 0 1 r
.002 w
.48591 .19965 m
.36355 .23941 L
s
P
p
0 .4 1 r
.018 w
.5267 .2129 m
.5519 .2476 L
s
P
p
0 .4 1 r
.018 w
.5267 .2129 m
.5519 .17821 L
s
P
p
0 .4 1 r
.018 w
.5267 .2129 m
.48591 .19965 L
s
P
p
.2 0 1 r
.002 w
.24388 .44168 m
.28364 .31932 L
s
P
p
.2 0 1 r
.002 w
.24388 .44168 m
.20412 .31932 L
s
P
p
.2 0 1 r
.002 w
.24388 .44168 m
.13979 .36606 L
s
P
p
.2 0 1 r
.002 w
.22244 .50767 m
.09378 .50767 L
s
P
p
.2 0 1 r
.002 w
.22244 .50767 m
.11835 .5833 L
s
P
p
.2 0 1 r
.002 w
.22244 .50767 m
.18268 .63003 L
s
P
p
.2 0 1 r
.002 w
.29183 .50767 m
.33158 .63003 L
s
P
p
.2 0 1 r
.002 w
.29183 .50767 m
.39591 .5833 L
s
P
p
.2 0 1 r
.002 w
.29183 .50767 m
.42048 .50767 L
s
P
p
0 .4 1 r
.018 w
.25713 .48247 m
.24388 .44168 L
s
P
p
0 .4 1 r
.018 w
.25713 .48247 m
.22244 .50767 L
s
P
p
0 .4 1 r
.018 w
.25713 .48247 m
.29183 .50767 L
s
P
p
.2 0 1 r
.002 w
.5968 .35228 m
.52118 .45637 L
s
P
p
.2 0 1 r
.002 w
.5968 .35228 m
.5968 .48094 L
s
P
p
.2 0 1 r
.002 w
.5968 .35228 m
.67243 .45637 L
s
P
p
.2 0 1 r
.002 w
.63759 .29614 m
.75995 .3359 L
s
P
p
.2 0 1 r
.002 w
.63759 .29614 m
.75995 .25638 L
s
P
p
.2 0 1 r
.002 w
.63759 .29614 m
.71321 .19206 L
s
P
p
.2 0 1 r
.002 w
.5716 .2747 m
.5716 .14604 L
s
P
p
.2 0 1 r
.002 w
.5716 .2747 m
.49597 .17061 L
s
P
p
.2 0 1 r
.002 w
.5716 .2747 m
.44923 .23494 L
s
P
p
0 .4 1 r
.018 w
.5968 .30939 m
.5968 .35228 L
s
P
p
0 .4 1 r
.018 w
.5968 .30939 m
.63759 .29614 L
s
P
p
0 .4 1 r
.018 w
.5968 .30939 m
.5716 .2747 L
s
P
p
.2 0 1 r
.002 w
.23353 .32824 m
.33761 .25262 L
s
P
p
.2 0 1 r
.002 w
.23353 .32824 m
.27328 .20588 L
s
P
p
.2 0 1 r
.002 w
.23353 .32824 m
.19377 .20588 L
s
P
p
.2 0 1 r
.002 w
.17739 .36903 m
.0733 .29341 L
s
P
p
.2 0 1 r
.002 w
.17739 .36903 m
.04873 .36903 L
s
P
p
.2 0 1 r
.002 w
.17739 .36903 m
.0733 .44465 L
s
P
p
.2 0 1 r
.002 w
.23353 .40982 m
.19377 .53218 L
s
P
p
.2 0 1 r
.002 w
.23353 .40982 m
.27328 .53218 L
s
P
p
.2 0 1 r
.002 w
.23353 .40982 m
.33761 .48544 L
s
P
p
0 .4 1 r
.018 w
.22027 .36903 m
.23353 .32824 L
s
P
p
0 .4 1 r
.018 w
.22027 .36903 m
.17739 .36903 L
s
P
p
0 .4 1 r
.018 w
.22027 .36903 m
.23353 .40982 L
s
P
p
.2 0 1 r
.016 w
.41326 .36903 m
.35362 .55257 L
s
P
p
.2 0 1 r
.016 w
.41326 .36903 m
.5267 .2129 L
s
P
p
.2 0 1 r
.016 w
.41326 .36903 m
.25713 .48247 L
s
P
p
.2 0 1 r
.016 w
.41326 .36903 m
.5968 .30939 L
s
P
p
.2 0 1 r
.016 w
.41326 .36903 m
.22027 .36903 L
s
P
p
.2 0 1 r
.002 w
.48362 .59152 m
.37953 .5159 L
s
P
p
.2 0 1 r
.002 w
.48362 .59152 m
.35496 .59152 L
s
P
p
.2 0 1 r
.002 w
.48362 .59152 m
.37953 .66714 L
s
P
p
.2 0 1 r
.002 w
.53976 .63231 m
.5 .75467 L
s
P
p
.2 0 1 r
.002 w
.53976 .63231 m
.57952 .75467 L
s
P
p
.2 0 1 r
.002 w
.53976 .63231 m
.64384 .70793 L
s
P
p
.2 0 1 r
.002 w
.5612 .56631 m
.68986 .56631 L
s
P
p
.2 0 1 r
.002 w
.5612 .56631 m
.66529 .49069 L
s
P
p
.2 0 1 r
.002 w
.5612 .56631 m
.60096 .44395 L
s
P
p
0 .4 1 r
.018 w
.52651 .59152 m
.48362 .59152 L
s
P
p
0 .4 1 r
.018 w
.52651 .59152 m
.53976 .63231 L
s
P
p
0 .4 1 r
.018 w
.52651 .59152 m
.5612 .56631 L
s
P
p
.2 0 1 r
.002 w
.50766 .22824 m
.58328 .33233 L
s
P
p
.2 0 1 r
.002 w
.50766 .22824 m
.63002 .268 L
s
P
p
.2 0 1 r
.002 w
.50766 .22824 m
.63002 .18849 L
s
P
p
.2 0 1 r
.002 w
.46687 .17211 m
.54249 .06802 L
s
P
p
.2 0 1 r
.002 w
.46687 .17211 m
.46687 .04345 L
s
P
p
.2 0 1 r
.002 w
.46687 .17211 m
.39125 .06802 L
s
P
p
.2 0 1 r
.002 w
.42608 .22824 m
.30372 .18849 L
s
P
p
.2 0 1 r
.002 w
.42608 .22824 m
.30372 .268 L
s
P
p
.2 0 1 r
.002 w
.42608 .22824 m
.35046 .33233 L
s
P
p
0 .4 1 r
.018 w
.46687 .21499 m
.50766 .22824 L
s
P
p
0 .4 1 r
.018 w
.46687 .21499 m
.46687 .17211 L
s
P
p
0 .4 1 r
.018 w
.46687 .21499 m
.42608 .22824 L
s
P
p
.2 0 1 r
.002 w
.37254 .56631 m
.33278 .44395 L
s
P
p
.2 0 1 r
.002 w
.37254 .56631 m
.26845 .49069 L
s
P
p
.2 0 1 r
.002 w
.37254 .56631 m
.24388 .56631 L
s
P
p
.2 0 1 r
.002 w
.39398 .63231 m
.28989 .70793 L
s
P
p
.2 0 1 r
.002 w
.39398 .63231 m
.35422 .75467 L
s
P
p
.2 0 1 r
.002 w
.39398 .63231 m
.43374 .75467 L
s
P
p
.2 0 1 r
.002 w
.45012 .59152 m
.55421 .66714 L
s
P
p
.2 0 1 r
.002 w
.45012 .59152 m
.57878 .59152 L
s
P
p
.2 0 1 r
.002 w
.45012 .59152 m
.55421 .5159 L
s
P
p
0 .4 1 r
.018 w
.40723 .59152 m
.37254 .56631 L
s
P
p
0 .4 1 r
.018 w
.40723 .59152 m
.39398 .63231 L
s
P
p
0 .4 1 r
.018 w
.40723 .59152 m
.45012 .59152 L
s
P
p
.2 0 1 r
.002 w
.60551 .28654 m
.60551 .4152 L
s
P
p
.2 0 1 r
.002 w
.60551 .28654 m
.68113 .39063 L
s
P
p
.2 0 1 r
.002 w
.60551 .28654 m
.72787 .3263 L
s
P
p
.2 0 1 r
.002 w
.60551 .21715 m
.72787 .1774 L
s
P
p
.2 0 1 r
.002 w
.60551 .21715 m
.68113 .11307 L
s
P
p
.2 0 1 r
.002 w
.60551 .21715 m
.60551 .0885 L
s
P
p
.2 0 1 r
.002 w
.53952 .2386 m
.46389 .13451 L
s
P
p
.2 0 1 r
.002 w
.53952 .2386 m
.41716 .19884 L
s
P
p
.2 0 1 r
.002 w
.53952 .2386 m
.41716 .27835 L
s
P
p
0 .4 1 r
.018 w
.5803 .25185 m
.60551 .28654 L
s
P
p
0 .4 1 r
.018 w
.5803 .25185 m
.60551 .21715 L
s
P
p
0 .4 1 r
.018 w
.5803 .25185 m
.53952 .2386 L
s
P
p
.2 0 1 r
.002 w
.29749 .48063 m
.33724 .35827 L
s
P
p
.2 0 1 r
.002 w
.29749 .48063 m
.25773 .35827 L
s
P
p
.2 0 1 r
.002 w
.29749 .48063 m
.1934 .405 L
s
P
p
.2 0 1 r
.002 w
.27604 .54662 m
.14739 .54662 L
s
P
p
.2 0 1 r
.002 w
.27604 .54662 m
.17196 .62224 L
s
P
p
.2 0 1 r
.002 w
.27604 .54662 m
.23629 .66898 L
s
P
p
.2 0 1 r
.002 w
.34543 .54662 m
.38519 .66898 L
s
P
p
.2 0 1 r
.002 w
.34543 .54662 m
.44952 .62224 L
s
P
p
.2 0 1 r
.002 w
.34543 .54662 m
.47409 .54662 L
s
P
p
0 .4 1 r
.018 w
.31074 .52141 m
.29749 .48063 L
s
P
p
0 .4 1 r
.018 w
.31074 .52141 m
.27604 .54662 L
s
P
p
0 .4 1 r
.018 w
.31074 .52141 m
.34543 .54662 L
s
P
p
.2 0 1 r
.016 w
.46687 .40798 m
.52651 .59152 L
s
P
p
.2 0 1 r
.016 w
.46687 .40798 m
.46687 .21499 L
s
P
p
.2 0 1 r
.016 w
.46687 .40798 m
.40723 .59152 L
s
P
p
.2 0 1 r
.016 w
.46687 .40798 m
.5803 .25185 L
s
P
p
.2 0 1 r
.016 w
.46687 .40798 m
.31074 .52141 L
s
P
p
.2 0 1 r
.002 w
.65457 .54662 m
.52591 .54662 L
s
P
p
.2 0 1 r
.002 w
.65457 .54662 m
.55048 .62224 L
s
P
p
.2 0 1 r
.002 w
.65457 .54662 m
.61481 .66898 L
s
P
p
.2 0 1 r
.002 w
.72396 .54662 m
.76371 .66898 L
s
P
p
.2 0 1 r
.002 w
.72396 .54662 m
.82804 .62224 L
s
P
p
.2 0 1 r
.002 w
.72396 .54662 m
.85261 .54662 L
s
P
p
.2 0 1 r
.002 w
.70251 .48063 m
.8066 .405 L
s
P
p
.2 0 1 r
.002 w
.70251 .48063 m
.74227 .35827 L
s
P
p
.2 0 1 r
.002 w
.70251 .48063 m
.66276 .35827 L
s
P
p
0 .4 1 r
.018 w
.68926 .52141 m
.65457 .54662 L
s
P
p
0 .4 1 r
.018 w
.68926 .52141 m
.72396 .54662 L
s
P
p
0 .4 1 r
.018 w
.68926 .52141 m
.70251 .48063 L
s
P
p
.2 0 1 r
.002 w
.46048 .2386 m
.58284 .27835 L
s
P
p
.2 0 1 r
.002 w
.46048 .2386 m
.58284 .19884 L
s
P
p
.2 0 1 r
.002 w
.46048 .2386 m
.53611 .13451 L
s
P
p
.2 0 1 r
.002 w
.39449 .21715 m
.39449 .0885 L
s
P
p
.2 0 1 r
.002 w
.39449 .21715 m
.31887 .11307 L
s
P
p
.2 0 1 r
.002 w
.39449 .21715 m
.27213 .1774 L
s
P
p
.2 0 1 r
.002 w
.39449 .28654 m
.27213 .3263 L
s
P
p
.2 0 1 r
.002 w
.39449 .28654 m
.31887 .39063 L
s
P
p
.2 0 1 r
.002 w
.39449 .28654 m
.39449 .4152 L
s
P
p
0 .4 1 r
.018 w
.4197 .25185 m
.46048 .2386 L
s
P
p
0 .4 1 r
.018 w
.4197 .25185 m
.39449 .21715 L
s
P
p
0 .4 1 r
.018 w
.4197 .25185 m
.39449 .28654 L
s
P
p
.2 0 1 r
.002 w
.54988 .59152 m
.44579 .5159 L
s
P
p
.2 0 1 r
.002 w
.54988 .59152 m
.42122 .59152 L
s
P
p
.2 0 1 r
.002 w
.54988 .59152 m
.44579 .66714 L
s
P
p
.2 0 1 r
.002 w
.60602 .63231 m
.56626 .75467 L
s
P
p
.2 0 1 r
.002 w
.60602 .63231 m
.64578 .75467 L
s
P
p
.2 0 1 r
.002 w
.60602 .63231 m
.71011 .70793 L
s
P
p
.2 0 1 r
.002 w
.62746 .56631 m
.75612 .56631 L
s
P
p
.2 0 1 r
.002 w
.62746 .56631 m
.73155 .49069 L
s
P
p
.2 0 1 r
.002 w
.62746 .56631 m
.66722 .44395 L
s
P
p
0 .4 1 r
.018 w
.59277 .59152 m
.54988 .59152 L
s
P
p
0 .4 1 r
.018 w
.59277 .59152 m
.60602 .63231 L
s
P
p
0 .4 1 r
.018 w
.59277 .59152 m
.62746 .56631 L
s
P
p
.2 0 1 r
.002 w
.57392 .22824 m
.64954 .33233 L
s
P
p
.2 0 1 r
.002 w
.57392 .22824 m
.69628 .268 L
s
P
p
.2 0 1 r
.002 w
.57392 .22824 m
.69628 .18849 L
s
P
p
.2 0 1 r
.002 w
.53313 .17211 m
.60875 .06802 L
s
P
p
.2 0 1 r
.002 w
.53313 .17211 m
.53313 .04345 L
s
P
p
.2 0 1 r
.002 w
.53313 .17211 m
.45751 .06802 L
s
P
p
.2 0 1 r
.002 w
.49234 .22824 m
.36998 .18849 L
s
P
p
.2 0 1 r
.002 w
.49234 .22824 m
.36998 .268 L
s
P
p
.2 0 1 r
.002 w
.49234 .22824 m
.41672 .33233 L
s
P
p
0 .4 1 r
.018 w
.53313 .21499 m
.57392 .22824 L
s
P
p
0 .4 1 r
.018 w
.53313 .21499 m
.53313 .17211 L
s
P
p
0 .4 1 r
.018 w
.53313 .21499 m
.49234 .22824 L
s
P
p
.2 0 1 r
.002 w
.4388 .56631 m
.39904 .44395 L
s
P
p
.2 0 1 r
.002 w
.4388 .56631 m
.33471 .49069 L
s
P
p
.2 0 1 r
.002 w
.4388 .56631 m
.31014 .56631 L
s
P
p
.2 0 1 r
.002 w
.46024 .63231 m
.35616 .70793 L
s
P
p
.2 0 1 r
.002 w
.46024 .63231 m
.42048 .75467 L
s
P
p
.2 0 1 r
.002 w
.46024 .63231 m
.5 .75467 L
s
P
p
.2 0 1 r
.002 w
.51638 .59152 m
.62047 .66714 L
s
P
p
.2 0 1 r
.002 w
.51638 .59152 m
.64504 .59152 L
s
P
p
.2 0 1 r
.002 w
.51638 .59152 m
.62047 .5159 L
s
P
p
0 .4 1 r
.018 w
.47349 .59152 m
.4388 .56631 L
s
P
p
0 .4 1 r
.018 w
.47349 .59152 m
.46024 .63231 L
s
P
p
0 .4 1 r
.018 w
.47349 .59152 m
.51638 .59152 L
s
P
p
.2 0 1 r
.016 w
.53313 .40798 m
.68926 .52141 L
s
P
p
.2 0 1 r
.016 w
.53313 .40798 m
.4197 .25185 L
s
P
p
.2 0 1 r
.016 w
.53313 .40798 m
.59277 .59152 L
s
P
p
.2 0 1 r
.016 w
.53313 .40798 m
.53313 .21499 L
s
P
p
.2 0 1 r
.016 w
.53313 .40798 m
.47349 .59152 L
s
P
p
.2 0 1 r
.002 w
.76647 .40982 m
.66239 .48544 L
s
P
p
.2 0 1 r
.002 w
.76647 .40982 m
.72672 .53218 L
s
P
p
.2 0 1 r
.002 w
.76647 .40982 m
.80623 .53218 L
s
P
p
.2 0 1 r
.002 w
.82261 .36903 m
.9267 .44465 L
s
P
p
.2 0 1 r
.002 w
.82261 .36903 m
.95127 .36903 L
s
P
p
.2 0 1 r
.002 w
.82261 .36903 m
.9267 .29341 L
s
P
p
.2 0 1 r
.002 w
.76647 .32824 m
.80623 .20588 L
s
P
p
.2 0 1 r
.002 w
.76647 .32824 m
.72672 .20588 L
s
P
p
.2 0 1 r
.002 w
.76647 .32824 m
.66239 .25262 L
s
P
p
0 .4 1 r
.018 w
.77973 .36903 m
.76647 .40982 L
s
P
p
0 .4 1 r
.018 w
.77973 .36903 m
.82261 .36903 L
s
P
p
0 .4 1 r
.018 w
.77973 .36903 m
.76647 .32824 L
s
P
p
.2 0 1 r
.002 w
.4284 .2747 m
.55077 .23494 L
s
P
p
.2 0 1 r
.002 w
.4284 .2747 m
.50403 .17061 L
s
P
p
.2 0 1 r
.002 w
.4284 .2747 m
.4284 .14604 L
s
P
p
.2 0 1 r
.002 w
.36241 .29614 m
.28679 .19206 L
s
P
p
.2 0 1 r
.002 w
.36241 .29614 m
.24005 .25638 L
s
P
p
.2 0 1 r
.002 w
.36241 .29614 m
.24005 .3359 L
s
P
p
.2 0 1 r
.002 w
.4032 .35228 m
.32757 .45637 L
s
P
p
.2 0 1 r
.002 w
.4032 .35228 m
.4032 .48094 L
s
P
p
.2 0 1 r
.002 w
.4032 .35228 m
.47882 .45637 L
s
P
p
0 .4 1 r
.018 w
.4032 .30939 m
.4284 .2747 L
s
P
p
0 .4 1 r
.018 w
.4032 .30939 m
.36241 .29614 L
s
P
p
0 .4 1 r
.018 w
.4032 .30939 m
.4032 .35228 L
s
P
p
.2 0 1 r
.002 w
.70817 .50767 m
.57952 .50767 L
s
P
p
.2 0 1 r
.002 w
.70817 .50767 m
.60409 .5833 L
s
P
p
.2 0 1 r
.002 w
.70817 .50767 m
.66842 .63003 L
s
P
p
.2 0 1 r
.002 w
.77756 .50767 m
.81732 .63003 L
s
P
p
.2 0 1 r
.002 w
.77756 .50767 m
.88165 .5833 L
s
P
p
.2 0 1 r
.002 w
.77756 .50767 m
.90622 .50767 L
s
P
p
.2 0 1 r
.002 w
.75612 .44168 m
.86021 .36606 L
s
P
p
.2 0 1 r
.002 w
.75612 .44168 m
.79588 .31932 L
s
P
p
.2 0 1 r
.002 w
.75612 .44168 m
.71636 .31932 L
s
P
p
0 .4 1 r
.018 w
.74287 .48247 m
.70817 .50767 L
s
P
p
0 .4 1 r
.018 w
.74287 .48247 m
.77756 .50767 L
s
P
p
0 .4 1 r
.018 w
.74287 .48247 m
.75612 .44168 L
s
P
p
.2 0 1 r
.002 w
.51409 .19965 m
.63645 .23941 L
s
P
p
.2 0 1 r
.002 w
.51409 .19965 m
.63645 .15989 L
s
P
p
.2 0 1 r
.002 w
.51409 .19965 m
.58971 .09556 L
s
P
p
.2 0 1 r
.002 w
.4481 .17821 m
.4481 .04955 L
s
P
p
.2 0 1 r
.002 w
.4481 .17821 m
.37247 .07412 L
s
P
p
.2 0 1 r
.002 w
.4481 .17821 m
.32573 .13845 L
s
P
p
.2 0 1 r
.002 w
.4481 .2476 m
.32573 .28735 L
s
P
p
.2 0 1 r
.002 w
.4481 .2476 m
.37247 .35168 L
s
P
p
.2 0 1 r
.002 w
.4481 .2476 m
.4481 .37625 L
s
P
p
0 .4 1 r
.018 w
.4733 .2129 m
.51409 .19965 L
s
P
p
0 .4 1 r
.018 w
.4733 .2129 m
.4481 .17821 L
s
P
p
0 .4 1 r
.018 w
.4733 .2129 m
.4481 .2476 L
s
P
p
.2 0 1 r
.002 w
.60349 .55257 m
.4994 .47695 L
s
P
p
.2 0 1 r
.002 w
.60349 .55257 m
.47483 .55257 L
s
P
p
.2 0 1 r
.002 w
.60349 .55257 m
.4994 .6282 L
s
P
p
.2 0 1 r
.002 w
.65963 .59336 m
.61987 .71572 L
s
P
p
.2 0 1 r
.002 w
.65963 .59336 m
.69939 .71572 L
s
P
p
.2 0 1 r
.002 w
.65963 .59336 m
.76371 .66898 L
s
P
p
.2 0 1 r
.002 w
.68107 .52736 m
.80973 .52736 L
s
P
p
.2 0 1 r
.002 w
.68107 .52736 m
.78516 .45174 L
s
P
p
.2 0 1 r
.002 w
.68107 .52736 m
.72083 .405 L
s
P
p
0 .4 1 r
.018 w
.64638 .55257 m
.60349 .55257 L
s
P
p
0 .4 1 r
.018 w
.64638 .55257 m
.65963 .59336 L
s
P
p
0 .4 1 r
.018 w
.64638 .55257 m
.68107 .52736 L
s
P
p
.2 0 1 r
.016 w
.58674 .36903 m
.77973 .36903 L
s
P
p
.2 0 1 r
.016 w
.58674 .36903 m
.4032 .30939 L
s
P
p
.2 0 1 r
.016 w
.58674 .36903 m
.74287 .48247 L
s
P
p
.2 0 1 r
.016 w
.58674 .36903 m
.4733 .2129 L
s
P
p
.2 0 1 r
.016 w
.58674 .36903 m
.64638 .55257 L
s
P
p
1 .6 0 r
.016 w
.5 .30601 m
.41326 .36903 L
s
P
p
1 .6 0 r
.016 w
.5 .30601 m
.46687 .40798 L
s
P
p
1 .6 0 r
.016 w
.5 .30601 m
.53313 .40798 L
s
P
p
1 .6 0 r
.016 w
.5 .30601 m
.58674 .36903 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.081587 0.952381 [
[ 0 0 0 0 ]
[ 1 .78921 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78921 L
0 .78921 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.27517 .37889 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.20765 .42794 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.18186 .50732 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.23015 .65597 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.29768 .70502 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.38114 .70502 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .61316 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.53337 .53378 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .4544 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.3169 .50732 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.33941 .57659 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.39833 .53378 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.54125 .38833 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.62063 .36254 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.66968 .29501 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.66968 .13872 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.62063 .0712 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.54125 .04541 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.3926 .0937 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .16122 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .24469 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .25328 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .18045 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.47198 .20296 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.29111 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.20765 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.14012 .34618 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.09183 .49483 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.11762 .57421 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.18514 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.34144 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.40896 .57421 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.43475 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.24938 .42556 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.22687 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.2997 .49483 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.50083 .46116 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.5802 .48695 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.65958 .46116 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .33471 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .25125 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.70239 .18373 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.55374 .13543 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.47437 .16122 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.42531 .22875 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.5802 .35191 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.62301 .29298 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.55374 .27048 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.35206 .24035 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.28454 .19129 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.20108 .19129 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .28316 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.04884 .36254 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .44191 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.20108 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.28454 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.35206 .48472 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .31972 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.18388 .36254 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .40535 L
s
P
p
.2 0 1 r
.018 w
.40896 .36254 m
.35332 .53378 L
s
P
p
.2 0 1 r
.018 w
.40896 .36254 m
.51479 .21687 L
s
P
p
.2 0 1 r
.018 w
.40896 .36254 m
.26329 .46837 L
s
P
p
.2 0 1 r
.018 w
.40896 .36254 m
.5802 .30689 L
s
P
p
.2 0 1 r
.018 w
.40896 .36254 m
.2289 .36254 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .49528 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.34081 .57466 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .65404 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.49304 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.57651 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.64403 .69685 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.69233 .5482 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.66653 .46883 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.59901 .41977 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.47585 .57466 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.53478 .61747 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.55728 .5482 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.58741 .34652 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .279 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .19554 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.5446 .06909 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.46522 .0433 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.38585 .06909 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .19554 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .279 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.34304 .34652 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.50804 .23727 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.46522 .17834 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.42241 .23727 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.33144 .41977 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.26391 .46883 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.23812 .5482 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.28642 .69685 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.35394 .74591 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.4374 .74591 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .65404 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.58964 .57466 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .49528 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.37317 .5482 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.39567 .61747 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.4546 .57466 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.59752 .42921 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.67689 .40342 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.72595 .33589 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.72595 .1796 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.67689 .11208 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.59752 .08629 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.44887 .13458 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .20211 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .28557 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .29416 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .22133 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.52825 .24384 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.34738 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.26391 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.19639 .38706 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.14809 .53571 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.17389 .61509 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.24141 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.3977 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.46522 .61509 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.49102 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.30564 .46644 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.28314 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.35597 .53571 L
s
P
p
.2 0 1 r
.018 w
.46522 .40342 m
.52087 .57466 L
s
P
p
.2 0 1 r
.018 w
.46522 .40342 m
.46522 .22336 L
s
P
p
.2 0 1 r
.018 w
.46522 .40342 m
.40958 .57466 L
s
P
p
.2 0 1 r
.018 w
.46522 .40342 m
.57106 .25775 L
s
P
p
.2 0 1 r
.018 w
.46522 .40342 m
.31956 .50925 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.50898 .53571 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.53478 .61509 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.6023 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.75859 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.82611 .61509 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.85191 .53571 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.80361 .38706 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.73609 .33801 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.65262 .33801 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.64403 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.71686 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.69436 .46644 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .28557 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .20211 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.55113 .13458 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.40248 .08629 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.32311 .11208 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.27405 .1796 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.27405 .33589 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.32311 .40342 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.40248 .42921 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.47175 .24384 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .22133 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .29416 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .49528 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.41036 .57466 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .65404 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.5626 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.64606 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.71358 .69685 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.76188 .5482 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.73609 .46883 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.66856 .41977 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.5454 .57466 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.60433 .61747 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.62683 .5482 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.65696 .34652 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .279 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .19554 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.61415 .06909 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.53478 .0433 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.4554 .06909 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .19554 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .279 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.41259 .34652 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.57759 .23727 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.53478 .17834 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.49196 .23727 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.40099 .41977 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.33347 .46883 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.30767 .5482 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.35597 .69685 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.42349 .74591 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.50696 .74591 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .65404 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.65919 .57466 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .49528 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.44272 .5482 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.46522 .61747 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.52415 .57466 L
s
P
p
.2 0 1 r
.018 w
.53478 .40342 m
.68044 .50925 L
s
P
p
.2 0 1 r
.018 w
.53478 .40342 m
.42894 .25775 L
s
P
p
.2 0 1 r
.018 w
.53478 .40342 m
.59042 .57466 L
s
P
p
.2 0 1 r
.018 w
.53478 .40342 m
.53478 .22336 L
s
P
p
.2 0 1 r
.018 w
.53478 .40342 m
.47913 .57466 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.64794 .48472 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.71546 .53378 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.79892 .53378 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .44191 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.95116 .36254 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .28316 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.79892 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.71546 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.64794 .24035 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .40535 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.81612 .36254 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .31972 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.57469 .22875 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.52563 .16122 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.44626 .13543 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.29761 .18373 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .25125 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .33471 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.34042 .46116 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.4198 .48695 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.49917 .46116 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.44626 .27048 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.37699 .29298 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.4198 .35191 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.56525 .49483 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.59104 .57421 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.65856 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.81486 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.88238 .57421 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.90817 .49483 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.85988 .34618 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.79235 .29713 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.70889 .29713 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.7003 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.77313 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.75062 .42556 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .24469 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .16122 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.6074 .0937 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.45875 .04541 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.37937 .0712 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.33032 .13872 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.33032 .29501 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.37937 .36254 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.45875 .38833 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.52802 .20296 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .18045 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .25328 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .4544 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.46663 .53378 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .61316 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.61886 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.70232 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.76985 .65597 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.81814 .50732 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.79235 .42794 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.72483 .37889 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.60167 .53378 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.66059 .57659 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.6831 .50732 L
s
P
p
.2 0 1 r
.018 w
.59104 .36254 m
.7711 .36254 L
s
P
p
.2 0 1 r
.018 w
.59104 .36254 m
.4198 .30689 L
s
P
p
.2 0 1 r
.018 w
.59104 .36254 m
.73671 .46837 L
s
P
p
.2 0 1 r
.018 w
.59104 .36254 m
.48521 .21687 L
s
P
p
.2 0 1 r
.018 w
.59104 .36254 m
.64668 .53378 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.40896 .36254 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.46522 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.53478 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.59104 .36254 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.081587 0.952381 [
[ 0 0 0 0 ]
[ 1 .78921 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78921 L
0 .78921 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.27517 .37889 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.20765 .42794 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.18186 .50732 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.23015 .65597 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.29768 .70502 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.38114 .70502 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .61316 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.53337 .53378 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .4544 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.3169 .50732 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.33941 .57659 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.39833 .53378 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.54125 .38833 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.62063 .36254 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.66968 .29501 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.66968 .13872 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.62063 .0712 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.54125 .04541 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.3926 .0937 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .16122 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .24469 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .25328 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .18045 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.47198 .20296 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.29111 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.20765 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.14012 .34618 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.09183 .49483 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.11762 .57421 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.18514 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.34144 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.40896 .57421 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.43475 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.24938 .42556 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.22687 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.2997 .49483 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.50083 .46116 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.5802 .48695 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.65958 .46116 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .33471 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .25125 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.70239 .18373 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.55374 .13543 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.47437 .16122 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.42531 .22875 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.5802 .35191 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.62301 .29298 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.55374 .27048 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.35206 .24035 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.28454 .19129 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.20108 .19129 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .28316 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.04884 .36254 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .44191 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.20108 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.28454 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.35206 .48472 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .31972 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.18388 .36254 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .40535 L
s
P
p
.8 0 1 r
.016 w
.40896 .36254 m
.35332 .53378 L
s
P
p
.8 0 1 r
.016 w
.40896 .36254 m
.51479 .21687 L
s
P
p
.8 0 1 r
.016 w
.40896 .36254 m
.26329 .46837 L
s
P
p
.8 0 1 r
.016 w
.40896 .36254 m
.5802 .30689 L
s
P
p
.8 0 1 r
.016 w
.40896 .36254 m
.2289 .36254 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .49528 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.34081 .57466 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .65404 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.49304 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.57651 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.64403 .69685 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.69233 .5482 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.66653 .46883 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.59901 .41977 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.47585 .57466 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.53478 .61747 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.55728 .5482 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.58741 .34652 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .279 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .19554 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.5446 .06909 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.46522 .0433 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.38585 .06909 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .19554 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .279 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.34304 .34652 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.50804 .23727 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.46522 .17834 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.42241 .23727 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.33144 .41977 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.26391 .46883 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.23812 .5482 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.28642 .69685 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.35394 .74591 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.4374 .74591 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .65404 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.58964 .57466 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .49528 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.37317 .5482 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.39567 .61747 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.4546 .57466 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.59752 .42921 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.67689 .40342 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.72595 .33589 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.72595 .1796 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.67689 .11208 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.59752 .08629 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.44887 .13458 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .20211 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .28557 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .29416 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .22133 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.52825 .24384 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.34738 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.26391 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.19639 .38706 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.14809 .53571 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.17389 .61509 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.24141 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.3977 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.46522 .61509 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.49102 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.30564 .46644 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.28314 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.35597 .53571 L
s
P
p
.8 0 1 r
.016 w
.46522 .40342 m
.52087 .57466 L
s
P
p
.8 0 1 r
.016 w
.46522 .40342 m
.46522 .22336 L
s
P
p
.8 0 1 r
.016 w
.46522 .40342 m
.40958 .57466 L
s
P
p
.8 0 1 r
.016 w
.46522 .40342 m
.57106 .25775 L
s
P
p
.8 0 1 r
.016 w
.46522 .40342 m
.31956 .50925 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.50898 .53571 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.53478 .61509 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.6023 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.75859 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.82611 .61509 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.85191 .53571 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.80361 .38706 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.73609 .33801 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.65262 .33801 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.64403 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.71686 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.69436 .46644 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .28557 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .20211 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.55113 .13458 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.40248 .08629 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.32311 .11208 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.27405 .1796 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.27405 .33589 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.32311 .40342 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.40248 .42921 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.47175 .24384 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .22133 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .29416 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .49528 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.41036 .57466 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .65404 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.5626 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.64606 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.71358 .69685 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.76188 .5482 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.73609 .46883 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.66856 .41977 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.5454 .57466 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.60433 .61747 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.62683 .5482 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.65696 .34652 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .279 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .19554 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.61415 .06909 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.53478 .0433 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.4554 .06909 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .19554 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .279 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.41259 .34652 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.57759 .23727 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.53478 .17834 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.49196 .23727 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.40099 .41977 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.33347 .46883 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.30767 .5482 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.35597 .69685 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.42349 .74591 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.50696 .74591 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .65404 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.65919 .57466 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .49528 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.44272 .5482 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.46522 .61747 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.52415 .57466 L
s
P
p
.8 0 1 r
.016 w
.53478 .40342 m
.68044 .50925 L
s
P
p
.8 0 1 r
.016 w
.53478 .40342 m
.42894 .25775 L
s
P
p
.8 0 1 r
.016 w
.53478 .40342 m
.59042 .57466 L
s
P
p
.8 0 1 r
.016 w
.53478 .40342 m
.53478 .22336 L
s
P
p
.8 0 1 r
.016 w
.53478 .40342 m
.47913 .57466 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.64794 .48472 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.71546 .53378 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.79892 .53378 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .44191 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.95116 .36254 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .28316 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.79892 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.71546 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.64794 .24035 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .40535 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.81612 .36254 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .31972 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.57469 .22875 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.52563 .16122 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.44626 .13543 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.29761 .18373 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .25125 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .33471 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.34042 .46116 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.4198 .48695 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.49917 .46116 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.44626 .27048 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.37699 .29298 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.4198 .35191 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.56525 .49483 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.59104 .57421 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.65856 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.81486 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.88238 .57421 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.90817 .49483 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.85988 .34618 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.79235 .29713 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.70889 .29713 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.7003 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.77313 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.75062 .42556 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .24469 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .16122 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.6074 .0937 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.45875 .04541 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.37937 .0712 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.33032 .13872 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.33032 .29501 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.37937 .36254 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.45875 .38833 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.52802 .20296 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .18045 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .25328 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .4544 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.46663 .53378 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .61316 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.61886 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.70232 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.76985 .65597 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.81814 .50732 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.79235 .42794 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.72483 .37889 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.60167 .53378 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.66059 .57659 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.6831 .50732 L
s
P
p
.8 0 1 r
.016 w
.59104 .36254 m
.7711 .36254 L
s
P
p
.8 0 1 r
.016 w
.59104 .36254 m
.4198 .30689 L
s
P
p
.8 0 1 r
.016 w
.59104 .36254 m
.73671 .46837 L
s
P
p
.8 0 1 r
.016 w
.59104 .36254 m
.48521 .21687 L
s
P
p
.8 0 1 r
.016 w
.59104 .36254 m
.64668 .53378 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.40896 .36254 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.46522 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.53478 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.59104 .36254 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0608586 0.952381 [
[ 0 0 0 0 ]
[ 1 .83066 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .83066 L
0 .83066 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .53189 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.16339 .62025 L
s
P
p
.2 0 1 r
.002 w
.29937 .57607 m
.21533 .69174 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.37271 .74288 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.45675 .71557 L
s
P
p
.2 0 1 r
.002 w
.37271 .5999 m
.50869 .64408 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.29937 .57607 L
s
P
p
0 .4 1 r
.018 w
.3447 .56134 m
.37271 .5999 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .30985 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.7063 .22581 L
s
P
p
.2 0 1 r
.002 w
.56332 .22581 m
.67899 .14177 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.54512 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.45675 .04451 L
s
P
p
.2 0 1 r
.002 w
.50093 .18048 m
.38526 .09644 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.56332 .22581 L
s
P
p
0 .4 1 r
.018 w
.51566 .22581 m
.50093 .18048 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.12002 .36169 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .43318 L
s
P
p
.2 0 1 r
.002 w
.20405 .47736 m
.06808 .52154 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.16534 .65542 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.24938 .68273 L
s
P
p
.2 0 1 r
.002 w
.24938 .53975 m
.33342 .65542 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.20405 .47736 L
s
P
p
0 .4 1 r
.018 w
.24938 .49209 m
.24938 .53975 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.66765 .48512 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.73914 .43318 L
s
P
p
.2 0 1 r
.002 w
.62347 .34914 m
.76645 .34914 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.71531 .19176 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.64382 .13982 L
s
P
p
.2 0 1 r
.002 w
.59964 .2758 m
.55546 .13982 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.62347 .34914 L
s
P
p
0 .4 1 r
.018 w
.58491 .32113 m
.59964 .2758 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.18496 .1985 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.10092 .22581 L
s
P
p
.2 0 1 r
.002 w
.18496 .34148 m
.04898 .2973 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.04898 .46278 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.10092 .53426 L
s
P
p
.2 0 1 r
.002 w
.18496 .41859 m
.18496 .56157 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .34148 L
s
P
p
0 .4 1 r
.018 w
.21297 .38004 m
.18496 .41859 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.3447 .56134 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.51566 .22581 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.24938 .49209 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.58491 .32113 L
s
P
p
.2 0 1 r
.016 w
.40361 .38004 m
.21297 .38004 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.3581 .68736 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.41004 .75885 L
s
P
p
.2 0 1 r
.002 w
.49408 .64318 m
.49408 .78616 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.65146 .73502 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .66353 L
s
P
p
.2 0 1 r
.002 w
.56742 .61935 m
.7034 .57517 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.49408 .64318 L
s
P
p
0 .4 1 r
.018 w
.52209 .60462 m
.56742 .61935 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.64471 .20467 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.61741 .12063 L
s
P
p
.2 0 1 r
.002 w
.50174 .20467 m
.54592 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.38044 .06869 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.30895 .12063 L
s
P
p
.2 0 1 r
.002 w
.42462 .20467 m
.28165 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.50174 .20467 L
s
P
p
0 .4 1 r
.018 w
.46318 .23269 m
.42462 .20467 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .57517 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.22297 .66353 L
s
P
p
.2 0 1 r
.002 w
.35895 .61935 m
.27491 .73502 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.43229 .78616 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.51632 .75885 L
s
P
p
.2 0 1 r
.002 w
.43229 .64318 m
.56826 .68736 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.35895 .61935 L
s
P
p
0 .4 1 r
.018 w
.40427 .60462 m
.43229 .64318 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .35313 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.76587 .26909 L
s
P
p
.2 0 1 r
.002 w
.62289 .26909 m
.73856 .18505 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.60469 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.51632 .08779 L
s
P
p
.2 0 1 r
.002 w
.56051 .22377 m
.44484 .13973 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.62289 .26909 L
s
P
p
0 .4 1 r
.018 w
.57523 .26909 m
.56051 .22377 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.17959 .40497 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .47646 L
s
P
p
.2 0 1 r
.002 w
.26363 .52065 m
.12765 .56483 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.22492 .6987 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.30895 .72601 L
s
P
p
.2 0 1 r
.002 w
.30895 .58303 m
.39299 .6987 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.26363 .52065 L
s
P
p
0 .4 1 r
.018 w
.30895 .53537 m
.30895 .58303 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.52209 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.46318 .23269 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.40427 .60462 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.57523 .26909 L
s
P
p
.2 0 1 r
.016 w
.46318 .42332 m
.30895 .53537 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.60701 .6987 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.69105 .72601 L
s
P
p
.2 0 1 r
.002 w
.69105 .58303 m
.77508 .6987 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .56483 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.87235 .47646 L
s
P
p
.2 0 1 r
.002 w
.73637 .52065 m
.82041 .40497 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.69105 .58303 L
s
P
p
0 .4 1 r
.018 w
.69105 .53537 m
.73637 .52065 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.55516 .13973 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.48368 .08779 L
s
P
p
.2 0 1 r
.002 w
.43949 .22377 m
.39531 .08779 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .18505 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.23413 .26909 L
s
P
p
.2 0 1 r
.002 w
.37711 .26909 m
.26144 .35313 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.43949 .22377 L
s
P
p
0 .4 1 r
.018 w
.42477 .26909 m
.37711 .26909 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.43174 .68736 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.48368 .75885 L
s
P
p
.2 0 1 r
.002 w
.56771 .64318 m
.56771 .78616 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.72509 .73502 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .66353 L
s
P
p
.2 0 1 r
.002 w
.64105 .61935 m
.77703 .57517 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.56771 .64318 L
s
P
p
0 .4 1 r
.018 w
.59573 .60462 m
.64105 .61935 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.71835 .20467 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.69105 .12063 L
s
P
p
.2 0 1 r
.002 w
.57538 .20467 m
.61956 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.45408 .06869 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.38259 .12063 L
s
P
p
.2 0 1 r
.002 w
.49826 .20467 m
.35529 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.57538 .20467 L
s
P
p
0 .4 1 r
.018 w
.53682 .23269 m
.49826 .20467 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .57517 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.2966 .66353 L
s
P
p
.2 0 1 r
.002 w
.43258 .61935 m
.34854 .73502 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.50592 .78616 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.58996 .75885 L
s
P
p
.2 0 1 r
.002 w
.50592 .64318 m
.6419 .68736 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.43258 .61935 L
s
P
p
0 .4 1 r
.018 w
.47791 .60462 m
.50592 .64318 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.69105 .53537 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.42477 .26909 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.59573 .60462 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.53682 .23269 L
s
P
p
.2 0 1 r
.016 w
.53682 .42332 m
.47791 .60462 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.81504 .56157 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.89908 .53426 L
s
P
p
.2 0 1 r
.002 w
.81504 .41859 m
.95102 .46278 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.95102 .2973 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.89908 .22581 L
s
P
p
.2 0 1 r
.002 w
.81504 .34148 m
.81504 .1985 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .41859 L
s
P
p
0 .4 1 r
.018 w
.78703 .38004 m
.81504 .34148 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.44454 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.35618 .13982 L
s
P
p
.2 0 1 r
.002 w
.40036 .2758 m
.28469 .19176 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.23355 .34914 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.26086 .43318 L
s
P
p
.2 0 1 r
.002 w
.37653 .34914 m
.33235 .48512 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.40036 .2758 L
s
P
p
0 .4 1 r
.018 w
.41509 .32113 m
.37653 .34914 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.66658 .65542 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.75062 .68273 L
s
P
p
.2 0 1 r
.002 w
.75062 .53975 m
.83466 .65542 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .52154 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.93192 .43318 L
s
P
p
.2 0 1 r
.002 w
.79595 .47736 m
.87998 .36169 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.75062 .53975 L
s
P
p
0 .4 1 r
.018 w
.75062 .49209 m
.79595 .47736 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.61474 .09644 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.54325 .04451 L
s
P
p
.2 0 1 r
.002 w
.49907 .18048 m
.45488 .04451 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .14177 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.2937 .22581 L
s
P
p
.2 0 1 r
.002 w
.43668 .22581 m
.32101 .30985 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.49907 .18048 L
s
P
p
0 .4 1 r
.018 w
.48434 .22581 m
.43668 .22581 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.49131 .64408 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.54325 .71557 L
s
P
p
.2 0 1 r
.002 w
.62729 .5999 m
.62729 .74288 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.78467 .69174 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .62025 L
s
P
p
.2 0 1 r
.002 w
.70063 .57607 m
.83661 .53189 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.62729 .5999 L
s
P
p
0 .4 1 r
.018 w
.6553 .56134 m
.70063 .57607 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.78703 .38004 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.41509 .32113 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.75062 .49209 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.48434 .22581 L
s
P
p
.2 0 1 r
.016 w
.59639 .38004 m
.6553 .56134 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.40361 .38004 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.46318 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.53682 .42332 L
s
P
p
1 .6 0 r
.016 w
.5 .31 m
.59639 .38004 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.081587 0.952381 [
[ 0 0 0 0 ]
[ 1 .78921 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78921 L
0 .78921 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3105 .51987 m
.23113 .41062 L
s
P
p
.2 0 1 r
.002 w
.3105 .51987 m
.18207 .47814 L
s
P
p
.2 0 1 r
.002 w
.3105 .51987 m
.18207 .5616 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.23015 .65597 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.29768 .70502 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.38114 .70502 L
s
P
p
.2 0 1 r
.002 w
.39613 .54769 m
.4755 .65694 L
s
P
p
.2 0 1 r
.002 w
.39613 .54769 m
.52456 .58942 L
s
P
p
.2 0 1 r
.002 w
.39613 .54769 m
.52456 .50596 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.3105 .51987 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.33941 .57659 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.39613 .54769 L
s
P
p
.2 0 1 r
.002 w
.55121 .24332 m
.59294 .37176 L
s
P
p
.2 0 1 r
.002 w
.55121 .24332 m
.66046 .3227 L
s
P
p
.2 0 1 r
.002 w
.55121 .24332 m
.68625 .24332 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.66968 .13872 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.62063 .0712 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.54125 .04541 L
s
P
p
.2 0 1 r
.002 w
.47837 .19041 m
.43664 .06197 L
s
P
p
.2 0 1 r
.002 w
.47837 .19041 m
.36912 .11103 L
s
P
p
.2 0 1 r
.002 w
.47837 .19041 m
.34333 .19041 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.55121 .24332 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .18045 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.47837 .19041 L
s
P
p
.2 0 1 r
.002 w
.23683 .43195 m
.23683 .29691 L
s
P
p
.2 0 1 r
.002 w
.23683 .43195 m
.15745 .3227 L
s
P
p
.2 0 1 r
.002 w
.23683 .43195 m
.10839 .39022 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.09183 .49483 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.11762 .57421 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.18514 .62326 L
s
P
p
.2 0 1 r
.002 w
.28975 .50479 m
.28975 .63983 L
s
P
p
.2 0 1 r
.002 w
.28975 .50479 m
.36912 .61404 L
s
P
p
.2 0 1 r
.002 w
.28975 .50479 m
.41818 .54652 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.23683 .43195 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.22687 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.28975 .50479 L
s
P
p
.2 0 1 r
.002 w
.59411 .34971 m
.55238 .47814 L
s
P
p
.2 0 1 r
.002 w
.59411 .34971 m
.63584 .47814 L
s
P
p
.2 0 1 r
.002 w
.59411 .34971 m
.70336 .42908 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .33471 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .25125 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.70239 .18373 L
s
P
p
.2 0 1 r
.002 w
.56629 .26408 m
.60802 .13565 L
s
P
p
.2 0 1 r
.002 w
.56629 .26408 m
.52456 .13565 L
s
P
p
.2 0 1 r
.002 w
.56629 .26408 m
.45704 .18471 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.59411 .34971 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.62301 .29298 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.56629 .26408 L
s
P
p
.2 0 1 r
.002 w
.2289 .31752 m
.30828 .20827 L
s
P
p
.2 0 1 r
.002 w
.2289 .31752 m
.2289 .18248 L
s
P
p
.2 0 1 r
.002 w
.2289 .31752 m
.14952 .20827 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .28316 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.04884 .36254 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .44191 L
s
P
p
.2 0 1 r
.002 w
.2289 .40755 m
.14952 .5168 L
s
P
p
.2 0 1 r
.002 w
.2289 .40755 m
.2289 .54259 L
s
P
p
.2 0 1 r
.002 w
.2289 .40755 m
.30828 .5168 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.2289 .31752 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.18388 .36254 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.2289 .40755 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.35332 .53378 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.51479 .21687 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.26329 .46837 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.5802 .30689 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.2289 .36254 L
s
P
p
.2 0 1 r
.002 w
.47805 .58857 m
.34962 .54684 L
s
P
p
.2 0 1 r
.002 w
.47805 .58857 m
.34962 .6303 L
s
P
p
.2 0 1 r
.002 w
.47805 .58857 m
.39868 .69782 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.49304 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.57651 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.64403 .69685 L
s
P
p
.2 0 1 r
.002 w
.56368 .56075 m
.69211 .60248 L
s
P
p
.2 0 1 r
.002 w
.56368 .56075 m
.69211 .51902 L
s
P
p
.2 0 1 r
.002 w
.56368 .56075 m
.64305 .4515 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.47805 .58857 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.53478 .61747 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.56368 .56075 L
s
P
p
.2 0 1 r
.002 w
.51024 .22336 m
.61949 .30274 L
s
P
p
.2 0 1 r
.002 w
.51024 .22336 m
.64528 .22336 L
s
P
p
.2 0 1 r
.002 w
.51024 .22336 m
.61949 .14398 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.5446 .06909 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.46522 .0433 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.38585 .06909 L
s
P
p
.2 0 1 r
.002 w
.42021 .22336 m
.31096 .14398 L
s
P
p
.2 0 1 r
.002 w
.42021 .22336 m
.28517 .22336 L
s
P
p
.2 0 1 r
.002 w
.42021 .22336 m
.31096 .30274 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.51024 .22336 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.46522 .17834 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.42021 .22336 L
s
P
p
.2 0 1 r
.002 w
.36677 .56075 m
.2874 .4515 L
s
P
p
.2 0 1 r
.002 w
.36677 .56075 m
.23834 .51902 L
s
P
p
.2 0 1 r
.002 w
.36677 .56075 m
.23834 .60248 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.28642 .69685 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.35394 .74591 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.4374 .74591 L
s
P
p
.2 0 1 r
.002 w
.45239 .58857 m
.53177 .69782 L
s
P
p
.2 0 1 r
.002 w
.45239 .58857 m
.58083 .6303 L
s
P
p
.2 0 1 r
.002 w
.45239 .58857 m
.58083 .54684 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.36677 .56075 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.39567 .61747 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.45239 .58857 L
s
P
p
.2 0 1 r
.002 w
.60748 .28421 m
.64921 .41264 L
s
P
p
.2 0 1 r
.002 w
.60748 .28421 m
.71673 .36358 L
s
P
p
.2 0 1 r
.002 w
.60748 .28421 m
.74252 .28421 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.72595 .1796 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.67689 .11208 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.59752 .08629 L
s
P
p
.2 0 1 r
.002 w
.53464 .23129 m
.49291 .10285 L
s
P
p
.2 0 1 r
.002 w
.53464 .23129 m
.42539 .15191 L
s
P
p
.2 0 1 r
.002 w
.53464 .23129 m
.3996 .23129 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.60748 .28421 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .22133 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.53464 .23129 L
s
P
p
.2 0 1 r
.002 w
.2931 .47283 m
.2931 .33779 L
s
P
p
.2 0 1 r
.002 w
.2931 .47283 m
.21372 .36358 L
s
P
p
.2 0 1 r
.002 w
.2931 .47283 m
.16466 .4311 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.14809 .53571 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.17389 .61509 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.24141 .66414 L
s
P
p
.2 0 1 r
.002 w
.34601 .54567 m
.34601 .68071 L
s
P
p
.2 0 1 r
.002 w
.34601 .54567 m
.42539 .65492 L
s
P
p
.2 0 1 r
.002 w
.34601 .54567 m
.47445 .5874 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.2931 .47283 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.28314 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.34601 .54567 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.52087 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.46522 .22336 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.40958 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.57106 .25775 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.31956 .50925 L
s
P
p
.2 0 1 r
.002 w
.65399 .54567 m
.52555 .5874 L
s
P
p
.2 0 1 r
.002 w
.65399 .54567 m
.57461 .65492 L
s
P
p
.2 0 1 r
.002 w
.65399 .54567 m
.65399 .68071 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.75859 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.82611 .61509 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.85191 .53571 L
s
P
p
.2 0 1 r
.002 w
.7069 .47283 m
.83534 .4311 L
s
P
p
.2 0 1 r
.002 w
.7069 .47283 m
.78628 .36358 L
s
P
p
.2 0 1 r
.002 w
.7069 .47283 m
.7069 .33779 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.65399 .54567 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.71686 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.7069 .47283 L
s
P
p
.2 0 1 r
.002 w
.46536 .23129 m
.6004 .23129 L
s
P
p
.2 0 1 r
.002 w
.46536 .23129 m
.57461 .15191 L
s
P
p
.2 0 1 r
.002 w
.46536 .23129 m
.50709 .10285 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.40248 .08629 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.32311 .11208 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.27405 .1796 L
s
P
p
.2 0 1 r
.002 w
.39252 .28421 m
.25748 .28421 L
s
P
p
.2 0 1 r
.002 w
.39252 .28421 m
.28327 .36358 L
s
P
p
.2 0 1 r
.002 w
.39252 .28421 m
.35079 .41264 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.46536 .23129 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .22133 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.39252 .28421 L
s
P
p
.2 0 1 r
.002 w
.54761 .58857 m
.41917 .54684 L
s
P
p
.2 0 1 r
.002 w
.54761 .58857 m
.41917 .6303 L
s
P
p
.2 0 1 r
.002 w
.54761 .58857 m
.46823 .69782 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.5626 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.64606 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.71358 .69685 L
s
P
p
.2 0 1 r
.002 w
.63323 .56075 m
.76166 .60248 L
s
P
p
.2 0 1 r
.002 w
.63323 .56075 m
.76166 .51902 L
s
P
p
.2 0 1 r
.002 w
.63323 .56075 m
.7126 .4515 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.54761 .58857 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.60433 .61747 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.63323 .56075 L
s
P
p
.2 0 1 r
.002 w
.57979 .22336 m
.68904 .30274 L
s
P
p
.2 0 1 r
.002 w
.57979 .22336 m
.71483 .22336 L
s
P
p
.2 0 1 r
.002 w
.57979 .22336 m
.68904 .14398 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.61415 .06909 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.53478 .0433 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.4554 .06909 L
s
P
p
.2 0 1 r
.002 w
.48976 .22336 m
.38051 .14398 L
s
P
p
.2 0 1 r
.002 w
.48976 .22336 m
.35472 .22336 L
s
P
p
.2 0 1 r
.002 w
.48976 .22336 m
.38051 .30274 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.57979 .22336 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.53478 .17834 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.48976 .22336 L
s
P
p
.2 0 1 r
.002 w
.43632 .56075 m
.35695 .4515 L
s
P
p
.2 0 1 r
.002 w
.43632 .56075 m
.30789 .51902 L
s
P
p
.2 0 1 r
.002 w
.43632 .56075 m
.30789 .60248 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.35597 .69685 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.42349 .74591 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.50696 .74591 L
s
P
p
.2 0 1 r
.002 w
.52195 .58857 m
.60132 .69782 L
s
P
p
.2 0 1 r
.002 w
.52195 .58857 m
.65038 .6303 L
s
P
p
.2 0 1 r
.002 w
.52195 .58857 m
.65038 .54684 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.43632 .56075 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.46522 .61747 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.52195 .58857 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.68044 .50925 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.42894 .25775 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.59042 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.53478 .22336 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.47913 .57466 L
s
P
p
.2 0 1 r
.002 w
.7711 .40755 m
.69172 .5168 L
s
P
p
.2 0 1 r
.002 w
.7711 .40755 m
.7711 .54259 L
s
P
p
.2 0 1 r
.002 w
.7711 .40755 m
.85048 .5168 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .44191 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.95116 .36254 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .28316 L
s
P
p
.2 0 1 r
.002 w
.7711 .31752 m
.85048 .20827 L
s
P
p
.2 0 1 r
.002 w
.7711 .31752 m
.7711 .18248 L
s
P
p
.2 0 1 r
.002 w
.7711 .31752 m
.69172 .20827 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.7711 .40755 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.81612 .36254 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.7711 .31752 L
s
P
p
.2 0 1 r
.002 w
.43371 .26408 m
.54296 .18471 L
s
P
p
.2 0 1 r
.002 w
.43371 .26408 m
.47544 .13565 L
s
P
p
.2 0 1 r
.002 w
.43371 .26408 m
.39198 .13565 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.29761 .18373 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .25125 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .33471 L
s
P
p
.2 0 1 r
.002 w
.40589 .34971 m
.29664 .42908 L
s
P
p
.2 0 1 r
.002 w
.40589 .34971 m
.36416 .47814 L
s
P
p
.2 0 1 r
.002 w
.40589 .34971 m
.44762 .47814 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.43371 .26408 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.37699 .29298 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.40589 .34971 L
s
P
p
.2 0 1 r
.002 w
.71025 .50479 m
.58182 .54652 L
s
P
p
.2 0 1 r
.002 w
.71025 .50479 m
.63088 .61404 L
s
P
p
.2 0 1 r
.002 w
.71025 .50479 m
.71025 .63983 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.81486 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.88238 .57421 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.90817 .49483 L
s
P
p
.2 0 1 r
.002 w
.76317 .43195 m
.89161 .39022 L
s
P
p
.2 0 1 r
.002 w
.76317 .43195 m
.84255 .3227 L
s
P
p
.2 0 1 r
.002 w
.76317 .43195 m
.76317 .29691 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.71025 .50479 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.77313 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.76317 .43195 L
s
P
p
.2 0 1 r
.002 w
.52163 .19041 m
.65667 .19041 L
s
P
p
.2 0 1 r
.002 w
.52163 .19041 m
.63088 .11103 L
s
P
p
.2 0 1 r
.002 w
.52163 .19041 m
.56336 .06197 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.45875 .04541 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.37937 .0712 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.33032 .13872 L
s
P
p
.2 0 1 r
.002 w
.44879 .24332 m
.31375 .24332 L
s
P
p
.2 0 1 r
.002 w
.44879 .24332 m
.33954 .3227 L
s
P
p
.2 0 1 r
.002 w
.44879 .24332 m
.40706 .37176 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.52163 .19041 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .18045 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.44879 .24332 L
s
P
p
.2 0 1 r
.002 w
.60387 .54769 m
.47544 .50596 L
s
P
p
.2 0 1 r
.002 w
.60387 .54769 m
.47544 .58942 L
s
P
p
.2 0 1 r
.002 w
.60387 .54769 m
.5245 .65694 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.61886 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.70232 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.76985 .65597 L
s
P
p
.2 0 1 r
.002 w
.6895 .51987 m
.81793 .5616 L
s
P
p
.2 0 1 r
.002 w
.6895 .51987 m
.81793 .47814 L
s
P
p
.2 0 1 r
.002 w
.6895 .51987 m
.76887 .41062 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.60387 .54769 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.66059 .57659 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.6895 .51987 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.7711 .36254 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.4198 .30689 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.73671 .46837 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.48521 .21687 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.64668 .53378 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.40896 .36254 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.46522 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.53478 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.59104 .36254 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0852902 0.952381 [
[ 0 0 0 0 ]
[ 1 .7818 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .7818 L
0 .7818 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3265 .524 m
.28259 .38886 L
s
P
p
.2 0 1 r
.002 w
.3265 .524 m
.21154 .44048 L
s
P
p
.2 0 1 r
.002 w
.3265 .524 m
.1844 .524 L
s
P
p
.2 0 1 r
.002 w
.33834 .56044 m
.22338 .64396 L
s
P
p
.2 0 1 r
.002 w
.33834 .56044 m
.29443 .69558 L
s
P
p
.2 0 1 r
.002 w
.33834 .56044 m
.38225 .69558 L
s
P
p
.2 0 1 r
.002 w
.36934 .53792 m
.4843 .62144 L
s
P
p
.2 0 1 r
.002 w
.36934 .53792 m
.51143 .53792 L
s
P
p
.2 0 1 r
.002 w
.36934 .53792 m
.4843 .4544 L
s
P
p
0 .4 1 r
.018 w
.34566 .53792 m
.3265 .524 L
s
P
p
0 .4 1 r
.018 w
.34566 .53792 m
.33834 .56044 L
s
P
p
0 .4 1 r
.018 w
.34566 .53792 m
.36934 .53792 L
s
P
p
.2 0 1 r
.002 w
.52948 .22362 m
.52948 .36571 L
s
P
p
.2 0 1 r
.002 w
.52948 .22362 m
.61301 .33857 L
s
P
p
.2 0 1 r
.002 w
.52948 .22362 m
.66462 .26753 L
s
P
p
.2 0 1 r
.002 w
.52948 .1853 m
.66462 .14139 L
s
P
p
.2 0 1 r
.002 w
.52948 .1853 m
.61301 .07034 L
s
P
p
.2 0 1 r
.002 w
.52948 .1853 m
.52948 .0432 L
s
P
p
.2 0 1 r
.002 w
.49304 .19714 m
.40952 .08218 L
s
P
p
.2 0 1 r
.002 w
.49304 .19714 m
.3579 .15323 L
s
P
p
.2 0 1 r
.002 w
.49304 .19714 m
.3579 .24105 L
s
P
p
0 .4 1 r
.018 w
.51556 .20446 m
.52948 .22362 L
s
P
p
0 .4 1 r
.018 w
.51556 .20446 m
.52948 .1853 L
s
P
p
0 .4 1 r
.018 w
.51556 .20446 m
.49304 .19714 L
s
P
p
.2 0 1 r
.002 w
.24361 .44657 m
.28752 .31143 L
s
P
p
.2 0 1 r
.002 w
.24361 .44657 m
.1997 .31143 L
s
P
p
.2 0 1 r
.002 w
.24361 .44657 m
.12865 .36305 L
s
P
p
.2 0 1 r
.002 w
.23177 .48301 m
.08967 .48301 L
s
P
p
.2 0 1 r
.002 w
.23177 .48301 m
.11681 .56654 L
s
P
p
.2 0 1 r
.002 w
.23177 .48301 m
.18786 .61815 L
s
P
p
.2 0 1 r
.002 w
.27009 .48301 m
.314 .61815 L
s
P
p
.2 0 1 r
.002 w
.27009 .48301 m
.38504 .56654 L
s
P
p
.2 0 1 r
.002 w
.27009 .48301 m
.41218 .48301 L
s
P
p
0 .4 1 r
.018 w
.25093 .46909 m
.24361 .44657 L
s
P
p
0 .4 1 r
.018 w
.25093 .46909 m
.23177 .48301 L
s
P
p
0 .4 1 r
.018 w
.25093 .46909 m
.27009 .48301 L
s
P
p
.2 0 1 r
.002 w
.58439 .32287 m
.50087 .43783 L
s
P
p
.2 0 1 r
.002 w
.58439 .32287 m
.58439 .46496 L
s
P
p
.2 0 1 r
.002 w
.58439 .32287 m
.66791 .43783 L
s
P
p
.2 0 1 r
.002 w
.60691 .29187 m
.74205 .33578 L
s
P
p
.2 0 1 r
.002 w
.60691 .29187 m
.74205 .24796 L
s
P
p
.2 0 1 r
.002 w
.60691 .29187 m
.69043 .17691 L
s
P
p
.2 0 1 r
.002 w
.57047 .28003 m
.57047 .13793 L
s
P
p
.2 0 1 r
.002 w
.57047 .28003 m
.48695 .16507 L
s
P
p
.2 0 1 r
.002 w
.57047 .28003 m
.43533 .23612 L
s
P
p
0 .4 1 r
.018 w
.58439 .29919 m
.58439 .32287 L
s
P
p
0 .4 1 r
.018 w
.58439 .29919 m
.60691 .29187 L
s
P
p
0 .4 1 r
.018 w
.58439 .29919 m
.57047 .28003 L
s
P
p
.2 0 1 r
.002 w
.22206 .33521 m
.33702 .25169 L
s
P
p
.2 0 1 r
.002 w
.22206 .33521 m
.26597 .20007 L
s
P
p
.2 0 1 r
.002 w
.22206 .33521 m
.17815 .20007 L
s
P
p
.2 0 1 r
.002 w
.19106 .35773 m
.0761 .27421 L
s
P
p
.2 0 1 r
.002 w
.19106 .35773 m
.04897 .35773 L
s
P
p
.2 0 1 r
.002 w
.19106 .35773 m
.0761 .44125 L
s
P
p
.2 0 1 r
.002 w
.22206 .38026 m
.17815 .5154 L
s
P
p
.2 0 1 r
.002 w
.22206 .38026 m
.26597 .5154 L
s
P
p
.2 0 1 r
.002 w
.22206 .38026 m
.33702 .46378 L
s
P
p
0 .4 1 r
.018 w
.21474 .35773 m
.22206 .33521 L
s
P
p
0 .4 1 r
.018 w
.21474 .35773 m
.19106 .35773 L
s
P
p
0 .4 1 r
.018 w
.21474 .35773 m
.22206 .38026 L
s
P
p
.2 0 1 r
.016 w
.4042 .35773 m
.34566 .53792 L
s
P
p
.2 0 1 r
.016 w
.4042 .35773 m
.51556 .20446 L
s
P
p
.2 0 1 r
.016 w
.4042 .35773 m
.25093 .46909 L
s
P
p
.2 0 1 r
.016 w
.4042 .35773 m
.58439 .29919 L
s
P
p
.2 0 1 r
.016 w
.4042 .35773 m
.21474 .35773 L
s
P
p
.2 0 1 r
.002 w
.49827 .58093 m
.38332 .49741 L
s
P
p
.2 0 1 r
.002 w
.49827 .58093 m
.35618 .58093 L
s
P
p
.2 0 1 r
.002 w
.49827 .58093 m
.38332 .66446 L
s
P
p
.2 0 1 r
.002 w
.52927 .60346 m
.48536 .7386 L
s
P
p
.2 0 1 r
.002 w
.52927 .60346 m
.57318 .7386 L
s
P
p
.2 0 1 r
.002 w
.52927 .60346 m
.64423 .68698 L
s
P
p
.2 0 1 r
.002 w
.54111 .56701 m
.68321 .56701 L
s
P
p
.2 0 1 r
.002 w
.54111 .56701 m
.65607 .48349 L
s
P
p
.2 0 1 r
.002 w
.54111 .56701 m
.58502 .43187 L
s
P
p
0 .4 1 r
.018 w
.52195 .58093 m
.49827 .58093 L
s
P
p
0 .4 1 r
.018 w
.52195 .58093 m
.52927 .60346 L
s
P
p
0 .4 1 r
.018 w
.52195 .58093 m
.54111 .56701 L
s
P
p
.2 0 1 r
.002 w
.48593 .21861 m
.56945 .33356 L
s
P
p
.2 0 1 r
.002 w
.48593 .21861 m
.62107 .26252 L
s
P
p
.2 0 1 r
.002 w
.48593 .21861 m
.62107 .1747 L
s
P
p
.2 0 1 r
.002 w
.46341 .18761 m
.54693 .07265 L
s
P
p
.2 0 1 r
.002 w
.46341 .18761 m
.46341 .04551 L
s
P
p
.2 0 1 r
.002 w
.46341 .18761 m
.37989 .07265 L
s
P
p
.2 0 1 r
.002 w
.44089 .21861 m
.30575 .1747 L
s
P
p
.2 0 1 r
.002 w
.44089 .21861 m
.30575 .26252 L
s
P
p
.2 0 1 r
.002 w
.44089 .21861 m
.35736 .33356 L
s
P
p
0 .4 1 r
.018 w
.46341 .21129 m
.48593 .21861 L
s
P
p
0 .4 1 r
.018 w
.46341 .21129 m
.46341 .18761 L
s
P
p
0 .4 1 r
.018 w
.46341 .21129 m
.44089 .21861 L
s
P
p
.2 0 1 r
.002 w
.3857 .56701 m
.34179 .43187 L
s
P
p
.2 0 1 r
.002 w
.3857 .56701 m
.27075 .48349 L
s
P
p
.2 0 1 r
.002 w
.3857 .56701 m
.24361 .56701 L
s
P
p
.2 0 1 r
.002 w
.39754 .60346 m
.28259 .68698 L
s
P
p
.2 0 1 r
.002 w
.39754 .60346 m
.35363 .7386 L
s
P
p
.2 0 1 r
.002 w
.39754 .60346 m
.44145 .7386 L
s
P
p
.2 0 1 r
.002 w
.42854 .58093 m
.5435 .66446 L
s
P
p
.2 0 1 r
.002 w
.42854 .58093 m
.57064 .58093 L
s
P
p
.2 0 1 r
.002 w
.42854 .58093 m
.5435 .49741 L
s
P
p
0 .4 1 r
.018 w
.40486 .58093 m
.3857 .56701 L
s
P
p
0 .4 1 r
.018 w
.40486 .58093 m
.39754 .60346 L
s
P
p
0 .4 1 r
.018 w
.40486 .58093 m
.42854 .58093 L
s
P
p
.2 0 1 r
.002 w
.58869 .26663 m
.58869 .40873 L
s
P
p
.2 0 1 r
.002 w
.58869 .26663 m
.67221 .38159 L
s
P
p
.2 0 1 r
.002 w
.58869 .26663 m
.72383 .31054 L
s
P
p
.2 0 1 r
.002 w
.58869 .22831 m
.72383 .1844 L
s
P
p
.2 0 1 r
.002 w
.58869 .22831 m
.67221 .11336 L
s
P
p
.2 0 1 r
.002 w
.58869 .22831 m
.58869 .08622 L
s
P
p
.2 0 1 r
.002 w
.55225 .24015 m
.46873 .1252 L
s
P
p
.2 0 1 r
.002 w
.55225 .24015 m
.41711 .19624 L
s
P
p
.2 0 1 r
.002 w
.55225 .24015 m
.41711 .28406 L
s
P
p
0 .4 1 r
.018 w
.57477 .24747 m
.58869 .26663 L
s
P
p
0 .4 1 r
.018 w
.57477 .24747 m
.58869 .22831 L
s
P
p
0 .4 1 r
.018 w
.57477 .24747 m
.55225 .24015 L
s
P
p
.2 0 1 r
.002 w
.30281 .48959 m
.34672 .35445 L
s
P
p
.2 0 1 r
.002 w
.30281 .48959 m
.2589 .35445 L
s
P
p
.2 0 1 r
.002 w
.30281 .48959 m
.18786 .40607 L
s
P
p
.2 0 1 r
.002 w
.29097 .52603 m
.14888 .52603 L
s
P
p
.2 0 1 r
.002 w
.29097 .52603 m
.17602 .60955 L
s
P
p
.2 0 1 r
.002 w
.29097 .52603 m
.24706 .66117 L
s
P
p
.2 0 1 r
.002 w
.32929 .52603 m
.3732 .66117 L
s
P
p
.2 0 1 r
.002 w
.32929 .52603 m
.44425 .60955 L
s
P
p
.2 0 1 r
.002 w
.32929 .52603 m
.47139 .52603 L
s
P
p
0 .4 1 r
.018 w
.31013 .51211 m
.30281 .48959 L
s
P
p
0 .4 1 r
.018 w
.31013 .51211 m
.29097 .52603 L
s
P
p
0 .4 1 r
.018 w
.31013 .51211 m
.32929 .52603 L
s
P
p
.2 0 1 r
.016 w
.46341 .40075 m
.52195 .58093 L
s
P
p
.2 0 1 r
.016 w
.46341 .40075 m
.46341 .21129 L
s
P
p
.2 0 1 r
.016 w
.46341 .40075 m
.40486 .58093 L
s
P
p
.2 0 1 r
.016 w
.46341 .40075 m
.57477 .24747 L
s
P
p
.2 0 1 r
.016 w
.46341 .40075 m
.31013 .51211 L
s
P
p
.2 0 1 r
.002 w
.67071 .52603 m
.52861 .52603 L
s
P
p
.2 0 1 r
.002 w
.67071 .52603 m
.55575 .60955 L
s
P
p
.2 0 1 r
.002 w
.67071 .52603 m
.6268 .66117 L
s
P
p
.2 0 1 r
.002 w
.70903 .52603 m
.75294 .66117 L
s
P
p
.2 0 1 r
.002 w
.70903 .52603 m
.82398 .60955 L
s
P
p
.2 0 1 r
.002 w
.70903 .52603 m
.85112 .52603 L
s
P
p
.2 0 1 r
.002 w
.69719 .48959 m
.81214 .40607 L
s
P
p
.2 0 1 r
.002 w
.69719 .48959 m
.7411 .35445 L
s
P
p
.2 0 1 r
.002 w
.69719 .48959 m
.65328 .35445 L
s
P
p
0 .4 1 r
.018 w
.68987 .51211 m
.67071 .52603 L
s
P
p
0 .4 1 r
.018 w
.68987 .51211 m
.70903 .52603 L
s
P
p
0 .4 1 r
.018 w
.68987 .51211 m
.69719 .48959 L
s
P
p
.2 0 1 r
.002 w
.44775 .24015 m
.58289 .28406 L
s
P
p
.2 0 1 r
.002 w
.44775 .24015 m
.58289 .19624 L
s
P
p
.2 0 1 r
.002 w
.44775 .24015 m
.53127 .1252 L
s
P
p
.2 0 1 r
.002 w
.41131 .22831 m
.41131 .08622 L
s
P
p
.2 0 1 r
.002 w
.41131 .22831 m
.32779 .11336 L
s
P
p
.2 0 1 r
.002 w
.41131 .22831 m
.27617 .1844 L
s
P
p
.2 0 1 r
.002 w
.41131 .26663 m
.27617 .31054 L
s
P
p
.2 0 1 r
.002 w
.41131 .26663 m
.32779 .38159 L
s
P
p
.2 0 1 r
.002 w
.41131 .26663 m
.41131 .40873 L
s
P
p
0 .4 1 r
.018 w
.42523 .24747 m
.44775 .24015 L
s
P
p
0 .4 1 r
.018 w
.42523 .24747 m
.41131 .22831 L
s
P
p
0 .4 1 r
.018 w
.42523 .24747 m
.41131 .26663 L
s
P
p
.2 0 1 r
.002 w
.57146 .58093 m
.4565 .49741 L
s
P
p
.2 0 1 r
.002 w
.57146 .58093 m
.42936 .58093 L
s
P
p
.2 0 1 r
.002 w
.57146 .58093 m
.4565 .66446 L
s
P
p
.2 0 1 r
.002 w
.60246 .60346 m
.55855 .7386 L
s
P
p
.2 0 1 r
.002 w
.60246 .60346 m
.64637 .7386 L
s
P
p
.2 0 1 r
.002 w
.60246 .60346 m
.71741 .68698 L
s
P
p
.2 0 1 r
.002 w
.6143 .56701 m
.75639 .56701 L
s
P
p
.2 0 1 r
.002 w
.6143 .56701 m
.72925 .48349 L
s
P
p
.2 0 1 r
.002 w
.6143 .56701 m
.65821 .43187 L
s
P
p
0 .4 1 r
.018 w
.59514 .58093 m
.57146 .58093 L
s
P
p
0 .4 1 r
.018 w
.59514 .58093 m
.60246 .60346 L
s
P
p
0 .4 1 r
.018 w
.59514 .58093 m
.6143 .56701 L
s
P
p
.2 0 1 r
.002 w
.55911 .21861 m
.64264 .33356 L
s
P
p
.2 0 1 r
.002 w
.55911 .21861 m
.69425 .26252 L
s
P
p
.2 0 1 r
.002 w
.55911 .21861 m
.69425 .1747 L
s
P
p
.2 0 1 r
.002 w
.53659 .18761 m
.62011 .07265 L
s
P
p
.2 0 1 r
.002 w
.53659 .18761 m
.53659 .04551 L
s
P
p
.2 0 1 r
.002 w
.53659 .18761 m
.45307 .07265 L
s
P
p
.2 0 1 r
.002 w
.51407 .21861 m
.37893 .1747 L
s
P
p
.2 0 1 r
.002 w
.51407 .21861 m
.37893 .26252 L
s
P
p
.2 0 1 r
.002 w
.51407 .21861 m
.43055 .33356 L
s
P
p
0 .4 1 r
.018 w
.53659 .21129 m
.55911 .21861 L
s
P
p
0 .4 1 r
.018 w
.53659 .21129 m
.53659 .18761 L
s
P
p
0 .4 1 r
.018 w
.53659 .21129 m
.51407 .21861 L
s
P
p
.2 0 1 r
.002 w
.45889 .56701 m
.41498 .43187 L
s
P
p
.2 0 1 r
.002 w
.45889 .56701 m
.34393 .48349 L
s
P
p
.2 0 1 r
.002 w
.45889 .56701 m
.31679 .56701 L
s
P
p
.2 0 1 r
.002 w
.47073 .60346 m
.35577 .68698 L
s
P
p
.2 0 1 r
.002 w
.47073 .60346 m
.42682 .7386 L
s
P
p
.2 0 1 r
.002 w
.47073 .60346 m
.51464 .7386 L
s
P
p
.2 0 1 r
.002 w
.50173 .58093 m
.61668 .66446 L
s
P
p
.2 0 1 r
.002 w
.50173 .58093 m
.64382 .58093 L
s
P
p
.2 0 1 r
.002 w
.50173 .58093 m
.61668 .49741 L
s
P
p
0 .4 1 r
.018 w
.47805 .58093 m
.45889 .56701 L
s
P
p
0 .4 1 r
.018 w
.47805 .58093 m
.47073 .60346 L
s
P
p
0 .4 1 r
.018 w
.47805 .58093 m
.50173 .58093 L
s
P
p
.2 0 1 r
.016 w
.53659 .40075 m
.68987 .51211 L
s
P
p
.2 0 1 r
.016 w
.53659 .40075 m
.42523 .24747 L
s
P
p
.2 0 1 r
.016 w
.53659 .40075 m
.59514 .58093 L
s
P
p
.2 0 1 r
.016 w
.53659 .40075 m
.53659 .21129 L
s
P
p
.2 0 1 r
.016 w
.53659 .40075 m
.47805 .58093 L
s
P
p
.2 0 1 r
.002 w
.77794 .38026 m
.66298 .46378 L
s
P
p
.2 0 1 r
.002 w
.77794 .38026 m
.73403 .5154 L
s
P
p
.2 0 1 r
.002 w
.77794 .38026 m
.82185 .5154 L
s
P
p
.2 0 1 r
.002 w
.80894 .35773 m
.9239 .44125 L
s
P
p
.2 0 1 r
.002 w
.80894 .35773 m
.95103 .35773 L
s
P
p
.2 0 1 r
.002 w
.80894 .35773 m
.9239 .27421 L
s
P
p
.2 0 1 r
.002 w
.77794 .33521 m
.82185 .20007 L
s
P
p
.2 0 1 r
.002 w
.77794 .33521 m
.73403 .20007 L
s
P
p
.2 0 1 r
.002 w
.77794 .33521 m
.66298 .25169 L
s
P
p
0 .4 1 r
.018 w
.78526 .35773 m
.77794 .38026 L
s
P
p
0 .4 1 r
.018 w
.78526 .35773 m
.80894 .35773 L
s
P
p
0 .4 1 r
.018 w
.78526 .35773 m
.77794 .33521 L
s
P
p
.2 0 1 r
.002 w
.42953 .28003 m
.56467 .23612 L
s
P
p
.2 0 1 r
.002 w
.42953 .28003 m
.51305 .16507 L
s
P
p
.2 0 1 r
.002 w
.42953 .28003 m
.42953 .13793 L
s
P
p
.2 0 1 r
.002 w
.39309 .29187 m
.30957 .17691 L
s
P
p
.2 0 1 r
.002 w
.39309 .29187 m
.25795 .24796 L
s
P
p
.2 0 1 r
.002 w
.39309 .29187 m
.25795 .33578 L
s
P
p
.2 0 1 r
.002 w
.41561 .32287 m
.33209 .43783 L
s
P
p
.2 0 1 r
.002 w
.41561 .32287 m
.41561 .46496 L
s
P
p
.2 0 1 r
.002 w
.41561 .32287 m
.49913 .43783 L
s
P
p
0 .4 1 r
.018 w
.41561 .29919 m
.42953 .28003 L
s
P
p
0 .4 1 r
.018 w
.41561 .29919 m
.39309 .29187 L
s
P
p
0 .4 1 r
.018 w
.41561 .29919 m
.41561 .32287 L
s
P
p
.2 0 1 r
.002 w
.72991 .48301 m
.58782 .48301 L
s
P
p
.2 0 1 r
.002 w
.72991 .48301 m
.61496 .56654 L
s
P
p
.2 0 1 r
.002 w
.72991 .48301 m
.686 .61815 L
s
P
p
.2 0 1 r
.002 w
.76823 .48301 m
.81214 .61815 L
s
P
p
.2 0 1 r
.002 w
.76823 .48301 m
.88319 .56654 L
s
P
p
.2 0 1 r
.002 w
.76823 .48301 m
.91033 .48301 L
s
P
p
.2 0 1 r
.002 w
.75639 .44657 m
.87135 .36305 L
s
P
p
.2 0 1 r
.002 w
.75639 .44657 m
.8003 .31143 L
s
P
p
.2 0 1 r
.002 w
.75639 .44657 m
.71248 .31143 L
s
P
p
0 .4 1 r
.018 w
.74907 .46909 m
.72991 .48301 L
s
P
p
0 .4 1 r
.018 w
.74907 .46909 m
.76823 .48301 L
s
P
p
0 .4 1 r
.018 w
.74907 .46909 m
.75639 .44657 L
s
P
p
.2 0 1 r
.002 w
.50696 .19714 m
.6421 .24105 L
s
P
p
.2 0 1 r
.002 w
.50696 .19714 m
.6421 .15323 L
s
P
p
.2 0 1 r
.002 w
.50696 .19714 m
.59048 .08218 L
s
P
p
.2 0 1 r
.002 w
.47052 .1853 m
.47052 .0432 L
s
P
p
.2 0 1 r
.002 w
.47052 .1853 m
.38699 .07034 L
s
P
p
.2 0 1 r
.002 w
.47052 .1853 m
.33538 .14139 L
s
P
p
.2 0 1 r
.002 w
.47052 .22362 m
.33538 .26753 L
s
P
p
.2 0 1 r
.002 w
.47052 .22362 m
.38699 .33857 L
s
P
p
.2 0 1 r
.002 w
.47052 .22362 m
.47052 .36571 L
s
P
p
0 .4 1 r
.018 w
.48444 .20446 m
.50696 .19714 L
s
P
p
0 .4 1 r
.018 w
.48444 .20446 m
.47052 .1853 L
s
P
p
0 .4 1 r
.018 w
.48444 .20446 m
.47052 .22362 L
s
P
p
.2 0 1 r
.002 w
.63066 .53792 m
.5157 .4544 L
s
P
p
.2 0 1 r
.002 w
.63066 .53792 m
.48857 .53792 L
s
P
p
.2 0 1 r
.002 w
.63066 .53792 m
.5157 .62144 L
s
P
p
.2 0 1 r
.002 w
.66166 .56044 m
.61775 .69558 L
s
P
p
.2 0 1 r
.002 w
.66166 .56044 m
.70557 .69558 L
s
P
p
.2 0 1 r
.002 w
.66166 .56044 m
.77662 .64396 L
s
P
p
.2 0 1 r
.002 w
.6735 .524 m
.8156 .524 L
s
P
p
.2 0 1 r
.002 w
.6735 .524 m
.78846 .44048 L
s
P
p
.2 0 1 r
.002 w
.6735 .524 m
.71741 .38886 L
s
P
p
0 .4 1 r
.018 w
.65434 .53792 m
.63066 .53792 L
s
P
p
0 .4 1 r
.018 w
.65434 .53792 m
.66166 .56044 L
s
P
p
0 .4 1 r
.018 w
.65434 .53792 m
.6735 .524 L
s
P
p
.2 0 1 r
.016 w
.5958 .35773 m
.78526 .35773 L
s
P
p
.2 0 1 r
.016 w
.5958 .35773 m
.41561 .29919 L
s
P
p
.2 0 1 r
.016 w
.5958 .35773 m
.74907 .46909 L
s
P
p
.2 0 1 r
.016 w
.5958 .35773 m
.48444 .20446 L
s
P
p
.2 0 1 r
.016 w
.5958 .35773 m
.65434 .53792 L
s
P
p
1 .6 0 r
.016 w
.5 .28813 m
.4042 .35773 L
s
P
p
1 .6 0 r
.016 w
.5 .28813 m
.46341 .40075 L
s
P
p
1 .6 0 r
.016 w
.5 .28813 m
.53659 .40075 L
s
P
p
1 .6 0 r
.016 w
.5 .28813 m
.5958 .35773 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.121634 0.952381 [
[ 0 0 0 0 ]
[ 1 .70911 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .70911 L
0 .70911 L
closepath
clip
newpath
p
P
p
0 .4 1 r
.018 w
.29112 .54804 m
.23926 .51036 L
s
P
p
0 .4 1 r
.018 w
.29112 .54804 m
.27131 .609 L
s
P
p
0 .4 1 r
.018 w
.29112 .54804 m
.35522 .54804 L
s
P
p
0 .4 1 r
.018 w
.52106 .09675 m
.55874 .14861 L
s
P
p
0 .4 1 r
.018 w
.52106 .09675 m
.55874 .04489 L
s
P
p
0 .4 1 r
.018 w
.52106 .09675 m
.4601 .07694 L
s
P
p
0 .4 1 r
.018 w
.16292 .4549 m
.14311 .39393 L
s
P
p
0 .4 1 r
.018 w
.16292 .4549 m
.11106 .49257 L
s
P
p
0 .4 1 r
.018 w
.16292 .4549 m
.21478 .49257 L
s
P
p
0 .4 1 r
.018 w
.61421 .22495 m
.61421 .28905 L
s
P
p
0 .4 1 r
.018 w
.61421 .22495 m
.67517 .20514 L
s
P
p
0 .4 1 r
.018 w
.61421 .22495 m
.57653 .17309 L
s
P
p
0 .4 1 r
.018 w
.11395 .30419 m
.13376 .24322 L
s
P
p
0 .4 1 r
.018 w
.11395 .30419 m
.04985 .30419 L
s
P
p
0 .4 1 r
.018 w
.11395 .30419 m
.13376 .36515 L
s
P
p
.2 0 1 r
.016 w
.37035 .30419 m
.29112 .54804 L
s
P
p
.2 0 1 r
.016 w
.37035 .30419 m
.52106 .09675 L
s
P
p
.2 0 1 r
.016 w
.37035 .30419 m
.16292 .4549 L
s
P
p
.2 0 1 r
.016 w
.37035 .30419 m
.61421 .22495 L
s
P
p
.2 0 1 r
.016 w
.37035 .30419 m
.11395 .30419 L
s
P
p
0 .4 1 r
.018 w
.52971 .60625 m
.46561 .60625 L
s
P
p
0 .4 1 r
.018 w
.52971 .60625 m
.54952 .66722 L
s
P
p
0 .4 1 r
.018 w
.52971 .60625 m
.58157 .56858 L
s
P
p
0 .4 1 r
.018 w
.45048 .106 m
.51144 .1258 L
s
P
p
0 .4 1 r
.018 w
.45048 .106 m
.45048 .0419 L
s
P
p
0 .4 1 r
.018 w
.45048 .106 m
.38952 .1258 L
s
P
p
0 .4 1 r
.018 w
.37125 .60625 m
.31939 .56858 L
s
P
p
0 .4 1 r
.018 w
.37125 .60625 m
.35144 .66722 L
s
P
p
0 .4 1 r
.018 w
.37125 .60625 m
.43535 .60625 L
s
P
p
0 .4 1 r
.018 w
.60119 .15497 m
.63887 .20682 L
s
P
p
0 .4 1 r
.018 w
.60119 .15497 m
.63887 .10311 L
s
P
p
0 .4 1 r
.018 w
.60119 .15497 m
.54023 .13516 L
s
P
p
0 .4 1 r
.018 w
.24304 .51311 m
.22324 .45215 L
s
P
p
0 .4 1 r
.018 w
.24304 .51311 m
.19119 .55079 L
s
P
p
0 .4 1 r
.018 w
.24304 .51311 m
.2949 .55079 L
s
P
p
.2 0 1 r
.016 w
.45048 .3624 m
.52971 .60625 L
s
P
p
.2 0 1 r
.016 w
.45048 .3624 m
.45048 .106 L
s
P
p
.2 0 1 r
.016 w
.45048 .3624 m
.37125 .60625 L
s
P
p
.2 0 1 r
.016 w
.45048 .3624 m
.60119 .15497 L
s
P
p
.2 0 1 r
.016 w
.45048 .3624 m
.24304 .51311 L
s
P
p
0 .4 1 r
.018 w
.75696 .51311 m
.7051 .55079 L
s
P
p
0 .4 1 r
.018 w
.75696 .51311 m
.80881 .55079 L
s
P
p
0 .4 1 r
.018 w
.75696 .51311 m
.77676 .45215 L
s
P
p
0 .4 1 r
.018 w
.39881 .15497 m
.45977 .13516 L
s
P
p
0 .4 1 r
.018 w
.39881 .15497 m
.36113 .10311 L
s
P
p
0 .4 1 r
.018 w
.39881 .15497 m
.36113 .20682 L
s
P
p
0 .4 1 r
.018 w
.62875 .60625 m
.56465 .60625 L
s
P
p
0 .4 1 r
.018 w
.62875 .60625 m
.64856 .66722 L
s
P
p
0 .4 1 r
.018 w
.62875 .60625 m
.68061 .56858 L
s
P
p
0 .4 1 r
.018 w
.54952 .106 m
.61048 .1258 L
s
P
p
0 .4 1 r
.018 w
.54952 .106 m
.54952 .0419 L
s
P
p
0 .4 1 r
.018 w
.54952 .106 m
.48856 .1258 L
s
P
p
0 .4 1 r
.018 w
.47029 .60625 m
.41843 .56858 L
s
P
p
0 .4 1 r
.018 w
.47029 .60625 m
.45048 .66722 L
s
P
p
0 .4 1 r
.018 w
.47029 .60625 m
.53439 .60625 L
s
P
p
.2 0 1 r
.016 w
.54952 .3624 m
.75696 .51311 L
s
P
p
.2 0 1 r
.016 w
.54952 .3624 m
.39881 .15497 L
s
P
p
.2 0 1 r
.016 w
.54952 .3624 m
.62875 .60625 L
s
P
p
.2 0 1 r
.016 w
.54952 .3624 m
.54952 .106 L
s
P
p
.2 0 1 r
.016 w
.54952 .3624 m
.47029 .60625 L
s
P
p
0 .4 1 r
.018 w
.88605 .30419 m
.86624 .36515 L
s
P
p
0 .4 1 r
.018 w
.88605 .30419 m
.95015 .30419 L
s
P
p
0 .4 1 r
.018 w
.88605 .30419 m
.86624 .24322 L
s
P
p
0 .4 1 r
.018 w
.38579 .22495 m
.42347 .17309 L
s
P
p
0 .4 1 r
.018 w
.38579 .22495 m
.32483 .20514 L
s
P
p
0 .4 1 r
.018 w
.38579 .22495 m
.38579 .28905 L
s
P
p
0 .4 1 r
.018 w
.83708 .4549 m
.78522 .49257 L
s
P
p
0 .4 1 r
.018 w
.83708 .4549 m
.88894 .49257 L
s
P
p
0 .4 1 r
.018 w
.83708 .4549 m
.85689 .39393 L
s
P
p
0 .4 1 r
.018 w
.47894 .09675 m
.5399 .07694 L
s
P
p
0 .4 1 r
.018 w
.47894 .09675 m
.44126 .04489 L
s
P
p
0 .4 1 r
.018 w
.47894 .09675 m
.44126 .14861 L
s
P
p
0 .4 1 r
.018 w
.70888 .54804 m
.64478 .54804 L
s
P
p
0 .4 1 r
.018 w
.70888 .54804 m
.72869 .609 L
s
P
p
0 .4 1 r
.018 w
.70888 .54804 m
.76074 .51036 L
s
P
p
.2 0 1 r
.016 w
.62965 .30419 m
.88605 .30419 L
s
P
p
.2 0 1 r
.016 w
.62965 .30419 m
.38579 .22495 L
s
P
p
.2 0 1 r
.016 w
.62965 .30419 m
.83708 .4549 L
s
P
p
.2 0 1 r
.016 w
.62965 .30419 m
.47894 .09675 L
s
P
p
.2 0 1 r
.016 w
.62965 .30419 m
.70888 .54804 L
s
P
p
1 .6 0 r
.016 w
.5 .20999 m
.37035 .30419 L
s
P
p
1 .6 0 r
.016 w
.5 .20999 m
.45048 .3624 L
s
P
p
1 .6 0 r
.016 w
.5 .20999 m
.54952 .3624 L
s
P
p
1 .6 0 r
.016 w
.5 .20999 m
.62965 .30419 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0304803 0.952381 [
[ 0 0 0 0 ]
[ 1 .89142 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .89142 L
0 .89142 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.37977 .60746 m
.29218 .48691 L
s
P
p
.2 0 1 r
.002 w
.37977 .60746 m
.23805 .56142 L
s
P
p
.2 0 1 r
.002 w
.37977 .60746 m
.23805 .65351 L
s
P
p
.2 0 1 r
.002 w
.42701 .67248 m
.33942 .79304 L
s
P
p
.2 0 1 r
.002 w
.42701 .67248 m
.42701 .8215 L
s
P
p
.2 0 1 r
.002 w
.42701 .67248 m
.5146 .79304 L
s
P
p
.2 0 1 r
.002 w
.47425 .60746 m
.61597 .65351 L
s
P
p
.2 0 1 r
.002 w
.47425 .60746 m
.61597 .56142 L
s
P
p
.2 0 1 r
.002 w
.47425 .60746 m
.56184 .48691 L
s
P
p
0 .4 1 r
.018 w
.42701 .62281 m
.37977 .60746 L
s
P
p
0 .4 1 r
.018 w
.42701 .62281 m
.42701 .67248 L
s
P
p
0 .4 1 r
.018 w
.42701 .62281 m
.47425 .60746 L
s
P
p
.2 0 1 r
.002 w
.52859 .26436 m
.57464 .40608 L
s
P
p
.2 0 1 r
.002 w
.52859 .26436 m
.64915 .35195 L
s
P
p
.2 0 1 r
.002 w
.52859 .26436 m
.67761 .26436 L
s
P
p
.2 0 1 r
.002 w
.50376 .18793 m
.62431 .10034 L
s
P
p
.2 0 1 r
.002 w
.50376 .18793 m
.5498 .04621 L
s
P
p
.2 0 1 r
.002 w
.50376 .18793 m
.45771 .04621 L
s
P
p
.2 0 1 r
.002 w
.43874 .23517 m
.31818 .14758 L
s
P
p
.2 0 1 r
.002 w
.43874 .23517 m
.28972 .23517 L
s
P
p
.2 0 1 r
.002 w
.43874 .23517 m
.31818 .32275 L
s
P
p
0 .4 1 r
.018 w
.48841 .23517 m
.52859 .26436 L
s
P
p
0 .4 1 r
.018 w
.48841 .23517 m
.50376 .18793 L
s
P
p
0 .4 1 r
.018 w
.48841 .23517 m
.43874 .23517 L
s
P
p
.2 0 1 r
.002 w
.28103 .54468 m
.28103 .39567 L
s
P
p
.2 0 1 r
.002 w
.28103 .54468 m
.19344 .42413 L
s
P
p
.2 0 1 r
.002 w
.28103 .54468 m
.13931 .49863 L
s
P
p
.2 0 1 r
.002 w
.28103 .62505 m
.13931 .6711 L
s
P
p
.2 0 1 r
.002 w
.28103 .62505 m
.19344 .74561 L
s
P
p
.2 0 1 r
.002 w
.28103 .62505 m
.28103 .77407 L
s
P
p
.2 0 1 r
.002 w
.35747 .60022 m
.44505 .72077 L
s
P
p
.2 0 1 r
.002 w
.35747 .60022 m
.49919 .64627 L
s
P
p
.2 0 1 r
.002 w
.35747 .60022 m
.49919 .55417 L
s
P
p
0 .4 1 r
.018 w
.31023 .58487 m
.28103 .54468 L
s
P
p
0 .4 1 r
.018 w
.31023 .58487 m
.28103 .62505 L
s
P
p
0 .4 1 r
.018 w
.31023 .58487 m
.35747 .60022 L
s
P
p
.2 0 1 r
.002 w
.6031 .35458 m
.55705 .4963 L
s
P
p
.2 0 1 r
.002 w
.6031 .35458 m
.64915 .4963 L
s
P
p
.2 0 1 r
.002 w
.6031 .35458 m
.72365 .44217 L
s
P
p
.2 0 1 r
.002 w
.62793 .27815 m
.77695 .27815 L
s
P
p
.2 0 1 r
.002 w
.62793 .27815 m
.74849 .19056 L
s
P
p
.2 0 1 r
.002 w
.62793 .27815 m
.67398 .13643 L
s
P
p
.2 0 1 r
.002 w
.54756 .27815 m
.50152 .13643 L
s
P
p
.2 0 1 r
.002 w
.54756 .27815 m
.42701 .19056 L
s
P
p
.2 0 1 r
.002 w
.54756 .27815 m
.39855 .27815 L
s
P
p
0 .4 1 r
.018 w
.58775 .30734 m
.6031 .35458 L
s
P
p
0 .4 1 r
.018 w
.58775 .30734 m
.62793 .27815 L
s
P
p
0 .4 1 r
.018 w
.58775 .30734 m
.54756 .27815 L
s
P
p
.2 0 1 r
.002 w
.23805 .43585 m
.32564 .3153 L
s
P
p
.2 0 1 r
.002 w
.23805 .43585 m
.23805 .28684 L
s
P
p
.2 0 1 r
.002 w
.23805 .43585 m
.15046 .3153 L
s
P
p
.2 0 1 r
.002 w
.19081 .50087 m
.04909 .45483 L
s
P
p
.2 0 1 r
.002 w
.19081 .50087 m
.04909 .54692 L
s
P
p
.2 0 1 r
.002 w
.19081 .50087 m
.10322 .62143 L
s
P
p
.2 0 1 r
.002 w
.26724 .52571 m
.26724 .67472 L
s
P
p
.2 0 1 r
.002 w
.26724 .52571 m
.35483 .64627 L
s
P
p
.2 0 1 r
.002 w
.26724 .52571 m
.40897 .57176 L
s
P
p
0 .4 1 r
.018 w
.23805 .48553 m
.23805 .43585 L
s
P
p
0 .4 1 r
.018 w
.23805 .48553 m
.19081 .50087 L
s
P
p
0 .4 1 r
.018 w
.23805 .48553 m
.26724 .52571 L
s
P
p
.2 0 1 r
.016 w
.42701 .42413 m
.42701 .62281 L
s
P
p
.2 0 1 r
.016 w
.42701 .42413 m
.48841 .23517 L
s
P
p
.2 0 1 r
.016 w
.42701 .42413 m
.31023 .58487 L
s
P
p
.2 0 1 r
.016 w
.42701 .42413 m
.58775 .30734 L
s
P
p
.2 0 1 r
.016 w
.42701 .42413 m
.23805 .48553 L
s
P
p
.2 0 1 r
.002 w
.56954 .62393 m
.42782 .57789 L
s
P
p
.2 0 1 r
.002 w
.56954 .62393 m
.42782 .66998 L
s
P
p
.2 0 1 r
.002 w
.56954 .62393 m
.48196 .74449 L
s
P
p
.2 0 1 r
.002 w
.64598 .64877 m
.64598 .79778 L
s
P
p
.2 0 1 r
.002 w
.64598 .64877 m
.73357 .76932 L
s
P
p
.2 0 1 r
.002 w
.64598 .64877 m
.7877 .69482 L
s
P
p
.2 0 1 r
.002 w
.64598 .5684 m
.7877 .52235 L
s
P
p
.2 0 1 r
.002 w
.64598 .5684 m
.73357 .44784 L
s
P
p
.2 0 1 r
.002 w
.64598 .5684 m
.64598 .41938 L
s
P
p
0 .4 1 r
.018 w
.61678 .60858 m
.56954 .62393 L
s
P
p
0 .4 1 r
.018 w
.61678 .60858 m
.64598 .64877 L
s
P
p
0 .4 1 r
.018 w
.61678 .60858 m
.64598 .5684 L
s
P
p
.2 0 1 r
.002 w
.48827 .25888 m
.60883 .34647 L
s
P
p
.2 0 1 r
.002 w
.48827 .25888 m
.63729 .25888 L
s
P
p
.2 0 1 r
.002 w
.48827 .25888 m
.60883 .17129 L
s
P
p
.2 0 1 r
.002 w
.42325 .21164 m
.4693 .06992 L
s
P
p
.2 0 1 r
.002 w
.42325 .21164 m
.37721 .06992 L
s
P
p
.2 0 1 r
.002 w
.42325 .21164 m
.3027 .12405 L
s
P
p
.2 0 1 r
.002 w
.39842 .28808 m
.2494 .28808 L
s
P
p
.2 0 1 r
.002 w
.39842 .28808 m
.27786 .37567 L
s
P
p
.2 0 1 r
.002 w
.39842 .28808 m
.35237 .4298 L
s
P
p
0 .4 1 r
.018 w
.4386 .25888 m
.48827 .25888 L
s
P
p
0 .4 1 r
.018 w
.4386 .25888 m
.42325 .21164 L
s
P
p
0 .4 1 r
.018 w
.4386 .25888 m
.39842 .28808 L
s
P
p
.2 0 1 r
.002 w
.45276 .63118 m
.36517 .51063 L
s
P
p
.2 0 1 r
.002 w
.45276 .63118 m
.31104 .58513 L
s
P
p
.2 0 1 r
.002 w
.45276 .63118 m
.31104 .67723 L
s
P
p
.2 0 1 r
.002 w
.5 .6962 m
.41241 .81676 L
s
P
p
.2 0 1 r
.002 w
.5 .6962 m
.5 .84522 L
s
P
p
.2 0 1 r
.002 w
.5 .6962 m
.58759 .81676 L
s
P
p
.2 0 1 r
.002 w
.54724 .63118 m
.68896 .67723 L
s
P
p
.2 0 1 r
.002 w
.54724 .63118 m
.68896 .58513 L
s
P
p
.2 0 1 r
.002 w
.54724 .63118 m
.63483 .51063 L
s
P
p
0 .4 1 r
.018 w
.5 .64653 m
.45276 .63118 L
s
P
p
0 .4 1 r
.018 w
.5 .64653 m
.5 .6962 L
s
P
p
0 .4 1 r
.018 w
.5 .64653 m
.54724 .63118 L
s
P
p
.2 0 1 r
.002 w
.60158 .28808 m
.64763 .4298 L
s
P
p
.2 0 1 r
.002 w
.60158 .28808 m
.72214 .37567 L
s
P
p
.2 0 1 r
.002 w
.60158 .28808 m
.7506 .28808 L
s
P
p
.2 0 1 r
.002 w
.57675 .21164 m
.6973 .12405 L
s
P
p
.2 0 1 r
.002 w
.57675 .21164 m
.62279 .06992 L
s
P
p
.2 0 1 r
.002 w
.57675 .21164 m
.5307 .06992 L
s
P
p
.2 0 1 r
.002 w
.51173 .25888 m
.39117 .17129 L
s
P
p
.2 0 1 r
.002 w
.51173 .25888 m
.36271 .25888 L
s
P
p
.2 0 1 r
.002 w
.51173 .25888 m
.39117 .34647 L
s
P
p
0 .4 1 r
.018 w
.5614 .25888 m
.60158 .28808 L
s
P
p
0 .4 1 r
.018 w
.5614 .25888 m
.57675 .21164 L
s
P
p
0 .4 1 r
.018 w
.5614 .25888 m
.51173 .25888 L
s
P
p
.2 0 1 r
.002 w
.35402 .5684 m
.35402 .41938 L
s
P
p
.2 0 1 r
.002 w
.35402 .5684 m
.26643 .44784 L
s
P
p
.2 0 1 r
.002 w
.35402 .5684 m
.2123 .52235 L
s
P
p
.2 0 1 r
.002 w
.35402 .64877 m
.2123 .69482 L
s
P
p
.2 0 1 r
.002 w
.35402 .64877 m
.26643 .76932 L
s
P
p
.2 0 1 r
.002 w
.35402 .64877 m
.35402 .79778 L
s
P
p
.2 0 1 r
.002 w
.43046 .62393 m
.51804 .74449 L
s
P
p
.2 0 1 r
.002 w
.43046 .62393 m
.57218 .66998 L
s
P
p
.2 0 1 r
.002 w
.43046 .62393 m
.57218 .57789 L
s
P
p
0 .4 1 r
.018 w
.38322 .60858 m
.35402 .5684 L
s
P
p
0 .4 1 r
.018 w
.38322 .60858 m
.35402 .64877 L
s
P
p
0 .4 1 r
.018 w
.38322 .60858 m
.43046 .62393 L
s
P
p
.2 0 1 r
.016 w
.5 .44784 m
.61678 .60858 L
s
P
p
.2 0 1 r
.016 w
.5 .44784 m
.4386 .25888 L
s
P
p
.2 0 1 r
.016 w
.5 .44784 m
.5 .64653 L
s
P
p
.2 0 1 r
.016 w
.5 .44784 m
.5614 .25888 L
s
P
p
.2 0 1 r
.016 w
.5 .44784 m
.38322 .60858 L
s
P
p
.2 0 1 r
.002 w
.73276 .52571 m
.59103 .57176 L
s
P
p
.2 0 1 r
.002 w
.73276 .52571 m
.64517 .64627 L
s
P
p
.2 0 1 r
.002 w
.73276 .52571 m
.73276 .67472 L
s
P
p
.2 0 1 r
.002 w
.80919 .50087 m
.89678 .62143 L
s
P
p
.2 0 1 r
.002 w
.80919 .50087 m
.95091 .54692 L
s
P
p
.2 0 1 r
.002 w
.80919 .50087 m
.95091 .45483 L
s
P
p
.2 0 1 r
.002 w
.76195 .43585 m
.84954 .3153 L
s
P
p
.2 0 1 r
.002 w
.76195 .43585 m
.76195 .28684 L
s
P
p
.2 0 1 r
.002 w
.76195 .43585 m
.67436 .3153 L
s
P
p
0 .4 1 r
.018 w
.76195 .48553 m
.73276 .52571 L
s
P
p
0 .4 1 r
.018 w
.76195 .48553 m
.80919 .50087 L
s
P
p
0 .4 1 r
.018 w
.76195 .48553 m
.76195 .43585 L
s
P
p
.2 0 1 r
.002 w
.45244 .27815 m
.60145 .27815 L
s
P
p
.2 0 1 r
.002 w
.45244 .27815 m
.57299 .19056 L
s
P
p
.2 0 1 r
.002 w
.45244 .27815 m
.49848 .13643 L
s
P
p
.2 0 1 r
.002 w
.37207 .27815 m
.32602 .13643 L
s
P
p
.2 0 1 r
.002 w
.37207 .27815 m
.25151 .19056 L
s
P
p
.2 0 1 r
.002 w
.37207 .27815 m
.22305 .27815 L
s
P
p
.2 0 1 r
.002 w
.3969 .35458 m
.27635 .44217 L
s
P
p
.2 0 1 r
.002 w
.3969 .35458 m
.35085 .4963 L
s
P
p
.2 0 1 r
.002 w
.3969 .35458 m
.44295 .4963 L
s
P
p
0 .4 1 r
.018 w
.41225 .30734 m
.45244 .27815 L
s
P
p
0 .4 1 r
.018 w
.41225 .30734 m
.37207 .27815 L
s
P
p
0 .4 1 r
.018 w
.41225 .30734 m
.3969 .35458 L
s
P
p
.2 0 1 r
.002 w
.64253 .60022 m
.50081 .55417 L
s
P
p
.2 0 1 r
.002 w
.64253 .60022 m
.50081 .64627 L
s
P
p
.2 0 1 r
.002 w
.64253 .60022 m
.55495 .72077 L
s
P
p
.2 0 1 r
.002 w
.71897 .62505 m
.71897 .77407 L
s
P
p
.2 0 1 r
.002 w
.71897 .62505 m
.80656 .74561 L
s
P
p
.2 0 1 r
.002 w
.71897 .62505 m
.86069 .6711 L
s
P
p
.2 0 1 r
.002 w
.71897 .54468 m
.86069 .49863 L
s
P
p
.2 0 1 r
.002 w
.71897 .54468 m
.80656 .42413 L
s
P
p
.2 0 1 r
.002 w
.71897 .54468 m
.71897 .39567 L
s
P
p
0 .4 1 r
.018 w
.68977 .58487 m
.64253 .60022 L
s
P
p
0 .4 1 r
.018 w
.68977 .58487 m
.71897 .62505 L
s
P
p
0 .4 1 r
.018 w
.68977 .58487 m
.71897 .54468 L
s
P
p
.2 0 1 r
.002 w
.56126 .23517 m
.68182 .32275 L
s
P
p
.2 0 1 r
.002 w
.56126 .23517 m
.71028 .23517 L
s
P
p
.2 0 1 r
.002 w
.56126 .23517 m
.68182 .14758 L
s
P
p
.2 0 1 r
.002 w
.49624 .18793 m
.54229 .04621 L
s
P
p
.2 0 1 r
.002 w
.49624 .18793 m
.4502 .04621 L
s
P
p
.2 0 1 r
.002 w
.49624 .18793 m
.37569 .10034 L
s
P
p
.2 0 1 r
.002 w
.47141 .26436 m
.32239 .26436 L
s
P
p
.2 0 1 r
.002 w
.47141 .26436 m
.35085 .35195 L
s
P
p
.2 0 1 r
.002 w
.47141 .26436 m
.42536 .40608 L
s
P
p
0 .4 1 r
.018 w
.51159 .23517 m
.56126 .23517 L
s
P
p
0 .4 1 r
.018 w
.51159 .23517 m
.49624 .18793 L
s
P
p
0 .4 1 r
.018 w
.51159 .23517 m
.47141 .26436 L
s
P
p
.2 0 1 r
.002 w
.52575 .60746 m
.43816 .48691 L
s
P
p
.2 0 1 r
.002 w
.52575 .60746 m
.38403 .56142 L
s
P
p
.2 0 1 r
.002 w
.52575 .60746 m
.38403 .65351 L
s
P
p
.2 0 1 r
.002 w
.57299 .67248 m
.4854 .79304 L
s
P
p
.2 0 1 r
.002 w
.57299 .67248 m
.57299 .8215 L
s
P
p
.2 0 1 r
.002 w
.57299 .67248 m
.66058 .79304 L
s
P
p
.2 0 1 r
.002 w
.62023 .60746 m
.76195 .65351 L
s
P
p
.2 0 1 r
.002 w
.62023 .60746 m
.76195 .56142 L
s
P
p
.2 0 1 r
.002 w
.62023 .60746 m
.70782 .48691 L
s
P
p
0 .4 1 r
.018 w
.57299 .62281 m
.52575 .60746 L
s
P
p
0 .4 1 r
.018 w
.57299 .62281 m
.57299 .67248 L
s
P
p
0 .4 1 r
.018 w
.57299 .62281 m
.62023 .60746 L
s
P
p
.2 0 1 r
.016 w
.57299 .42413 m
.76195 .48553 L
s
P
p
.2 0 1 r
.016 w
.57299 .42413 m
.41225 .30734 L
s
P
p
.2 0 1 r
.016 w
.57299 .42413 m
.68977 .58487 L
s
P
p
.2 0 1 r
.016 w
.57299 .42413 m
.51159 .23517 L
s
P
p
.2 0 1 r
.016 w
.57299 .42413 m
.57299 .62281 L
s
P
p
1 .6 0 r
.016 w
.5 .32367 m
.42701 .42413 L
s
P
p
1 .6 0 r
.016 w
.5 .32367 m
.5 .44784 L
s
P
p
1 .6 0 r
.016 w
.5 .32367 m
.57299 .42413 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.00573791 0.952381 [
[ 0 0 0 0 ]
[ 1 .94091 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .94091 L
0 .94091 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.42111 .66405 m
.30932 .55225 L
s
P
p
.2 0 1 r
.002 w
.42111 .66405 m
.26496 .63931 L
s
P
p
.2 0 1 r
.002 w
.42111 .66405 m
.28024 .73582 L
s
P
p
.2 0 1 r
.002 w
.48141 .72434 m
.40963 .86521 L
s
P
p
.2 0 1 r
.002 w
.48141 .72434 m
.50614 .8805 L
s
P
p
.2 0 1 r
.002 w
.48141 .72434 m
.5932 .83614 L
s
P
p
.2 0 1 r
.002 w
.52012 .64837 m
.67628 .6731 L
s
P
p
.2 0 1 r
.002 w
.52012 .64837 m
.66099 .57659 L
s
P
p
.2 0 1 r
.002 w
.52012 .64837 m
.5919 .5075 L
s
P
p
0 .4 1 r
.018 w
.47316 .67229 m
.42111 .66405 L
s
P
p
0 .4 1 r
.018 w
.47316 .67229 m
.48141 .72434 L
s
P
p
0 .4 1 r
.018 w
.47316 .67229 m
.52012 .64837 L
s
P
p
.2 0 1 r
.002 w
.52012 .2798 m
.5919 .42067 L
s
P
p
.2 0 1 r
.002 w
.52012 .2798 m
.66099 .35158 L
s
P
p
.2 0 1 r
.002 w
.52012 .2798 m
.67628 .25507 L
s
P
p
.2 0 1 r
.002 w
.48141 .20382 m
.5932 .09203 L
s
P
p
.2 0 1 r
.002 w
.48141 .20382 m
.50614 .04767 L
s
P
p
.2 0 1 r
.002 w
.48141 .20382 m
.40963 .06295 L
s
P
p
.2 0 1 r
.002 w
.42111 .26412 m
.28024 .19234 L
s
P
p
.2 0 1 r
.002 w
.42111 .26412 m
.26496 .28885 L
s
P
p
.2 0 1 r
.002 w
.42111 .26412 m
.30932 .37592 L
s
P
p
0 .4 1 r
.018 w
.47316 .25588 m
.52012 .2798 L
s
P
p
0 .4 1 r
.018 w
.47316 .25588 m
.48141 .20382 L
s
P
p
0 .4 1 r
.018 w
.47316 .25588 m
.42111 .26412 L
s
P
p
.2 0 1 r
.002 w
.30722 .61465 m
.28249 .45849 L
s
P
p
.2 0 1 r
.002 w
.30722 .61465 m
.19542 .50285 L
s
P
p
.2 0 1 r
.002 w
.30722 .61465 m
.15106 .58991 L
s
P
p
.2 0 1 r
.002 w
.32056 .69887 m
.17969 .77064 L
s
P
p
.2 0 1 r
.002 w
.32056 .69887 m
.24878 .83974 L
s
P
p
.2 0 1 r
.002 w
.32056 .69887 m
.34529 .85502 L
s
P
p
.2 0 1 r
.002 w
.39654 .66015 m
.50833 .77195 L
s
P
p
.2 0 1 r
.002 w
.39654 .66015 m
.55269 .68489 L
s
P
p
.2 0 1 r
.002 w
.39654 .66015 m
.53741 .58838 L
s
P
p
0 .4 1 r
.018 w
.34448 .65191 m
.30722 .61465 L
s
P
p
0 .4 1 r
.018 w
.34448 .65191 m
.32056 .69887 L
s
P
p
0 .4 1 r
.018 w
.34448 .65191 m
.39654 .66015 L
s
P
p
.2 0 1 r
.002 w
.61317 .36198 m
.58844 .51814 L
s
P
p
.2 0 1 r
.002 w
.61317 .36198 m
.68495 .50285 L
s
P
p
.2 0 1 r
.002 w
.61317 .36198 m
.75404 .43376 L
s
P
p
.2 0 1 r
.002 w
.62651 .27776 m
.78267 .25303 L
s
P
p
.2 0 1 r
.002 w
.62651 .27776 m
.73831 .16596 L
s
P
p
.2 0 1 r
.002 w
.62651 .27776 m
.65124 .1216 L
s
P
p
.2 0 1 r
.002 w
.54229 .2911 m
.47051 .15023 L
s
P
p
.2 0 1 r
.002 w
.54229 .2911 m
.40142 .21932 L
s
P
p
.2 0 1 r
.002 w
.54229 .2911 m
.38613 .31583 L
s
P
p
0 .4 1 r
.018 w
.58925 .31502 m
.61317 .36198 L
s
P
p
0 .4 1 r
.018 w
.58925 .31502 m
.62651 .27776 L
s
P
p
0 .4 1 r
.018 w
.58925 .31502 m
.54229 .2911 L
s
P
p
.2 0 1 r
.002 w
.24412 .50773 m
.31589 .36686 L
s
P
p
.2 0 1 r
.002 w
.24412 .50773 m
.21938 .35158 L
s
P
p
.2 0 1 r
.002 w
.24412 .50773 m
.13232 .39594 L
s
P
p
.2 0 1 r
.002 w
.2054 .58371 m
.04925 .55898 L
s
P
p
.2 0 1 r
.002 w
.2054 .58371 m
.06453 .65549 L
s
P
p
.2 0 1 r
.002 w
.2054 .58371 m
.13363 .72458 L
s
P
p
.2 0 1 r
.002 w
.28962 .59705 m
.31436 .75321 L
s
P
p
.2 0 1 r
.002 w
.28962 .59705 m
.40142 .70885 L
s
P
p
.2 0 1 r
.002 w
.28962 .59705 m
.44578 .62178 L
s
P
p
0 .4 1 r
.018 w
.25236 .55979 m
.24412 .50773 L
s
P
p
0 .4 1 r
.018 w
.25236 .55979 m
.2054 .58371 L
s
P
p
0 .4 1 r
.018 w
.25236 .55979 m
.28962 .59705 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.47316 .67229 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.47316 .25588 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.34448 .65191 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.58925 .31502 L
s
P
p
.2 0 1 r
.016 w
.44019 .46408 m
.25236 .55979 L
s
P
p
.2 0 1 r
.002 w
.52304 .67289 m
.38217 .60112 L
s
P
p
.2 0 1 r
.002 w
.52304 .67289 m
.36688 .69763 L
s
P
p
.2 0 1 r
.002 w
.52304 .67289 m
.41124 .78469 L
s
P
p
.2 0 1 r
.002 w
.59902 .7116 m
.57428 .86776 L
s
P
p
.2 0 1 r
.002 w
.59902 .7116 m
.67079 .85248 L
s
P
p
.2 0 1 r
.002 w
.59902 .7116 m
.73989 .78338 L
s
P
p
.2 0 1 r
.002 w
.61236 .62738 m
.76851 .60265 L
s
P
p
.2 0 1 r
.002 w
.61236 .62738 m
.72415 .51559 L
s
P
p
.2 0 1 r
.002 w
.61236 .62738 m
.63709 .47123 L
s
P
p
0 .4 1 r
.018 w
.57509 .66465 m
.52304 .67289 L
s
P
p
0 .4 1 r
.018 w
.57509 .66465 m
.59902 .7116 L
s
P
p
0 .4 1 r
.018 w
.57509 .66465 m
.61236 .62738 L
s
P
p
.2 0 1 r
.002 w
.49846 .27686 m
.61026 .38865 L
s
P
p
.2 0 1 r
.002 w
.49846 .27686 m
.65462 .30159 L
s
P
p
.2 0 1 r
.002 w
.49846 .27686 m
.63933 .20508 L
s
P
p
.2 0 1 r
.002 w
.43817 .21656 m
.50995 .07569 L
s
P
p
.2 0 1 r
.002 w
.43817 .21656 m
.41344 .06041 L
s
P
p
.2 0 1 r
.002 w
.43817 .21656 m
.32637 .10477 L
s
P
p
.2 0 1 r
.002 w
.39946 .29254 m
.2433 .26781 L
s
P
p
.2 0 1 r
.002 w
.39946 .29254 m
.25859 .36432 L
s
P
p
.2 0 1 r
.002 w
.39946 .29254 m
.32768 .43341 L
s
P
p
0 .4 1 r
.018 w
.44641 .26861 m
.49846 .27686 L
s
P
p
0 .4 1 r
.018 w
.44641 .26861 m
.43817 .21656 L
s
P
p
0 .4 1 r
.018 w
.44641 .26861 m
.39946 .29254 L
s
P
p
.2 0 1 r
.002 w
.39946 .6611 m
.32768 .52023 L
s
P
p
.2 0 1 r
.002 w
.39946 .6611 m
.25859 .58933 L
s
P
p
.2 0 1 r
.002 w
.39946 .6611 m
.2433 .68584 L
s
P
p
.2 0 1 r
.002 w
.43817 .73708 m
.32637 .84888 L
s
P
p
.2 0 1 r
.002 w
.43817 .73708 m
.41344 .89324 L
s
P
p
.2 0 1 r
.002 w
.43817 .73708 m
.50995 .87795 L
s
P
p
.2 0 1 r
.002 w
.49846 .67678 m
.63933 .74856 L
s
P
p
.2 0 1 r
.002 w
.49846 .67678 m
.65462 .65205 L
s
P
p
.2 0 1 r
.002 w
.49846 .67678 m
.61026 .56499 L
s
P
p
0 .4 1 r
.018 w
.44641 .68503 m
.39946 .6611 L
s
P
p
0 .4 1 r
.018 w
.44641 .68503 m
.43817 .73708 L
s
P
p
0 .4 1 r
.018 w
.44641 .68503 m
.49846 .67678 L
s
P
p
.2 0 1 r
.002 w
.61236 .32626 m
.63709 .48242 L
s
P
p
.2 0 1 r
.002 w
.61236 .32626 m
.72415 .43805 L
s
P
p
.2 0 1 r
.002 w
.61236 .32626 m
.76851 .35099 L
s
P
p
.2 0 1 r
.002 w
.59902 .24204 m
.73989 .17026 L
s
P
p
.2 0 1 r
.002 w
.59902 .24204 m
.67079 .10117 L
s
P
p
.2 0 1 r
.002 w
.59902 .24204 m
.57428 .08588 L
s
P
p
.2 0 1 r
.002 w
.52304 .28075 m
.41124 .16896 L
s
P
p
.2 0 1 r
.002 w
.52304 .28075 m
.36688 .25602 L
s
P
p
.2 0 1 r
.002 w
.52304 .28075 m
.38217 .35253 L
s
P
p
0 .4 1 r
.018 w
.57509 .28899 m
.61236 .32626 L
s
P
p
0 .4 1 r
.018 w
.57509 .28899 m
.59902 .24204 L
s
P
p
0 .4 1 r
.018 w
.57509 .28899 m
.52304 .28075 L
s
P
p
.2 0 1 r
.002 w
.3064 .57893 m
.33114 .42277 L
s
P
p
.2 0 1 r
.002 w
.3064 .57893 m
.23463 .43805 L
s
P
p
.2 0 1 r
.002 w
.3064 .57893 m
.16553 .50715 L
s
P
p
.2 0 1 r
.002 w
.29306 .66315 m
.13691 .68788 L
s
P
p
.2 0 1 r
.002 w
.29306 .66315 m
.18127 .77494 L
s
P
p
.2 0 1 r
.002 w
.29306 .66315 m
.26833 .8193 L
s
P
p
.2 0 1 r
.002 w
.37729 .64981 m
.44906 .79068 L
s
P
p
.2 0 1 r
.002 w
.37729 .64981 m
.51816 .72158 L
s
P
p
.2 0 1 r
.002 w
.37729 .64981 m
.53344 .62507 L
s
P
p
0 .4 1 r
.018 w
.33033 .62588 m
.3064 .57893 L
s
P
p
0 .4 1 r
.018 w
.33033 .62588 m
.29306 .66315 L
s
P
p
0 .4 1 r
.018 w
.33033 .62588 m
.37729 .64981 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.57509 .66465 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.44641 .26861 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.44641 .68503 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.57509 .28899 L
s
P
p
.2 0 1 r
.016 w
.47939 .47682 m
.33033 .62588 L
s
P
p
.2 0 1 r
.002 w
.62271 .64981 m
.46656 .62507 L
s
P
p
.2 0 1 r
.002 w
.62271 .64981 m
.48184 .72158 L
s
P
p
.2 0 1 r
.002 w
.62271 .64981 m
.55094 .79068 L
s
P
p
.2 0 1 r
.002 w
.70694 .66315 m
.73167 .8193 L
s
P
p
.2 0 1 r
.002 w
.70694 .66315 m
.81873 .77494 L
s
P
p
.2 0 1 r
.002 w
.70694 .66315 m
.86309 .68788 L
s
P
p
.2 0 1 r
.002 w
.6936 .57893 m
.83447 .50715 L
s
P
p
.2 0 1 r
.002 w
.6936 .57893 m
.76537 .43805 L
s
P
p
.2 0 1 r
.002 w
.6936 .57893 m
.66886 .42277 L
s
P
p
0 .4 1 r
.018 w
.66967 .62588 m
.62271 .64981 L
s
P
p
0 .4 1 r
.018 w
.66967 .62588 m
.70694 .66315 L
s
P
p
0 .4 1 r
.018 w
.66967 .62588 m
.6936 .57893 L
s
P
p
.2 0 1 r
.002 w
.47696 .28075 m
.61783 .35253 L
s
P
p
.2 0 1 r
.002 w
.47696 .28075 m
.63312 .25602 L
s
P
p
.2 0 1 r
.002 w
.47696 .28075 m
.58876 .16896 L
s
P
p
.2 0 1 r
.002 w
.40098 .24204 m
.42572 .08588 L
s
P
p
.2 0 1 r
.002 w
.40098 .24204 m
.32921 .10117 L
s
P
p
.2 0 1 r
.002 w
.40098 .24204 m
.26011 .17026 L
s
P
p
.2 0 1 r
.002 w
.38764 .32626 m
.23149 .35099 L
s
P
p
.2 0 1 r
.002 w
.38764 .32626 m
.27585 .43805 L
s
P
p
.2 0 1 r
.002 w
.38764 .32626 m
.36291 .48242 L
s
P
p
0 .4 1 r
.018 w
.42491 .28899 m
.47696 .28075 L
s
P
p
0 .4 1 r
.018 w
.42491 .28899 m
.40098 .24204 L
s
P
p
0 .4 1 r
.018 w
.42491 .28899 m
.38764 .32626 L
s
P
p
.2 0 1 r
.002 w
.50154 .67678 m
.38974 .56499 L
s
P
p
.2 0 1 r
.002 w
.50154 .67678 m
.34538 .65205 L
s
P
p
.2 0 1 r
.002 w
.50154 .67678 m
.36067 .74856 L
s
P
p
.2 0 1 r
.002 w
.56183 .73708 m
.49005 .87795 L
s
P
p
.2 0 1 r
.002 w
.56183 .73708 m
.58656 .89324 L
s
P
p
.2 0 1 r
.002 w
.56183 .73708 m
.67363 .84888 L
s
P
p
.2 0 1 r
.002 w
.60054 .6611 m
.7567 .68584 L
s
P
p
.2 0 1 r
.002 w
.60054 .6611 m
.74141 .58933 L
s
P
p
.2 0 1 r
.002 w
.60054 .6611 m
.67232 .52023 L
s
P
p
0 .4 1 r
.018 w
.55359 .68503 m
.50154 .67678 L
s
P
p
0 .4 1 r
.018 w
.55359 .68503 m
.56183 .73708 L
s
P
p
0 .4 1 r
.018 w
.55359 .68503 m
.60054 .6611 L
s
P
p
.2 0 1 r
.002 w
.60054 .29254 m
.67232 .43341 L
s
P
p
.2 0 1 r
.002 w
.60054 .29254 m
.74141 .36432 L
s
P
p
.2 0 1 r
.002 w
.60054 .29254 m
.7567 .26781 L
s
P
p
.2 0 1 r
.002 w
.56183 .21656 m
.67363 .10477 L
s
P
p
.2 0 1 r
.002 w
.56183 .21656 m
.58656 .06041 L
s
P
p
.2 0 1 r
.002 w
.56183 .21656 m
.49005 .07569 L
s
P
p
.2 0 1 r
.002 w
.50154 .27686 m
.36067 .20508 L
s
P
p
.2 0 1 r
.002 w
.50154 .27686 m
.34538 .30159 L
s
P
p
.2 0 1 r
.002 w
.50154 .27686 m
.38974 .38865 L
s
P
p
0 .4 1 r
.018 w
.55359 .26861 m
.60054 .29254 L
s
P
p
0 .4 1 r
.018 w
.55359 .26861 m
.56183 .21656 L
s
P
p
0 .4 1 r
.018 w
.55359 .26861 m
.50154 .27686 L
s
P
p
.2 0 1 r
.002 w
.38764 .62738 m
.36291 .47123 L
s
P
p
.2 0 1 r
.002 w
.38764 .62738 m
.27585 .51559 L
s
P
p
.2 0 1 r
.002 w
.38764 .62738 m
.23149 .60265 L
s
P
p
.2 0 1 r
.002 w
.40098 .7116 m
.26011 .78338 L
s
P
p
.2 0 1 r
.002 w
.40098 .7116 m
.32921 .85248 L
s
P
p
.2 0 1 r
.002 w
.40098 .7116 m
.42572 .86776 L
s
P
p
.2 0 1 r
.002 w
.47696 .67289 m
.58876 .78469 L
s
P
p
.2 0 1 r
.002 w
.47696 .67289 m
.63312 .69763 L
s
P
p
.2 0 1 r
.002 w
.47696 .67289 m
.61783 .60112 L
s
P
p
0 .4 1 r
.018 w
.42491 .66465 m
.38764 .62738 L
s
P
p
0 .4 1 r
.018 w
.42491 .66465 m
.40098 .7116 L
s
P
p
0 .4 1 r
.018 w
.42491 .66465 m
.47696 .67289 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.66967 .62588 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.42491 .28899 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.55359 .68503 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.55359 .26861 L
s
P
p
.2 0 1 r
.016 w
.52061 .47682 m
.42491 .66465 L
s
P
p
.2 0 1 r
.002 w
.71038 .59705 m
.55422 .62178 L
s
P
p
.2 0 1 r
.002 w
.71038 .59705 m
.59858 .70885 L
s
P
p
.2 0 1 r
.002 w
.71038 .59705 m
.68564 .75321 L
s
P
p
.2 0 1 r
.002 w
.7946 .58371 m
.86637 .72458 L
s
P
p
.2 0 1 r
.002 w
.7946 .58371 m
.93547 .65549 L
s
P
p
.2 0 1 r
.002 w
.7946 .58371 m
.95075 .55898 L
s
P
p
.2 0 1 r
.002 w
.75588 .50773 m
.86768 .39594 L
s
P
p
.2 0 1 r
.002 w
.75588 .50773 m
.78062 .35158 L
s
P
p
.2 0 1 r
.002 w
.75588 .50773 m
.68411 .36686 L
s
P
p
0 .4 1 r
.018 w
.74764 .55979 m
.71038 .59705 L
s
P
p
0 .4 1 r
.018 w
.74764 .55979 m
.7946 .58371 L
s
P
p
0 .4 1 r
.018 w
.74764 .55979 m
.75588 .50773 L
s
P
p
.2 0 1 r
.002 w
.45771 .2911 m
.61387 .31583 L
s
P
p
.2 0 1 r
.002 w
.45771 .2911 m
.59858 .21932 L
s
P
p
.2 0 1 r
.002 w
.45771 .2911 m
.52949 .15023 L
s
P
p
.2 0 1 r
.002 w
.37349 .27776 m
.34876 .1216 L
s
P
p
.2 0 1 r
.002 w
.37349 .27776 m
.26169 .16596 L
s
P
p
.2 0 1 r
.002 w
.37349 .27776 m
.21733 .25303 L
s
P
p
.2 0 1 r
.002 w
.38683 .36198 m
.24596 .43376 L
s
P
p
.2 0 1 r
.002 w
.38683 .36198 m
.31505 .50285 L
s
P
p
.2 0 1 r
.002 w
.38683 .36198 m
.41156 .51814 L
s
P
p
0 .4 1 r
.018 w
.41075 .31502 m
.45771 .2911 L
s
P
p
0 .4 1 r
.018 w
.41075 .31502 m
.37349 .27776 L
s
P
p
0 .4 1 r
.018 w
.41075 .31502 m
.38683 .36198 L
s
P
p
.2 0 1 r
.002 w
.60346 .66015 m
.46259 .58838 L
s
P
p
.2 0 1 r
.002 w
.60346 .66015 m
.44731 .68489 L
s
P
p
.2 0 1 r
.002 w
.60346 .66015 m
.49167 .77195 L
s
P
p
.2 0 1 r
.002 w
.67944 .69887 m
.65471 .85502 L
s
P
p
.2 0 1 r
.002 w
.67944 .69887 m
.75122 .83974 L
s
P
p
.2 0 1 r
.002 w
.67944 .69887 m
.82031 .77064 L
s
P
p
.2 0 1 r
.002 w
.69278 .61465 m
.84894 .58991 L
s
P
p
.2 0 1 r
.002 w
.69278 .61465 m
.80458 .50285 L
s
P
p
.2 0 1 r
.002 w
.69278 .61465 m
.71751 .45849 L
s
P
p
0 .4 1 r
.018 w
.65552 .65191 m
.60346 .66015 L
s
P
p
0 .4 1 r
.018 w
.65552 .65191 m
.67944 .69887 L
s
P
p
0 .4 1 r
.018 w
.65552 .65191 m
.69278 .61465 L
s
P
p
.2 0 1 r
.002 w
.57889 .26412 m
.69068 .37592 L
s
P
p
.2 0 1 r
.002 w
.57889 .26412 m
.73504 .28885 L
s
P
p
.2 0 1 r
.002 w
.57889 .26412 m
.71976 .19234 L
s
P
p
.2 0 1 r
.002 w
.51859 .20382 m
.59037 .06295 L
s
P
p
.2 0 1 r
.002 w
.51859 .20382 m
.49386 .04767 L
s
P
p
.2 0 1 r
.002 w
.51859 .20382 m
.4068 .09203 L
s
P
p
.2 0 1 r
.002 w
.47988 .2798 m
.32372 .25507 L
s
P
p
.2 0 1 r
.002 w
.47988 .2798 m
.33901 .35158 L
s
P
p
.2 0 1 r
.002 w
.47988 .2798 m
.4081 .42067 L
s
P
p
0 .4 1 r
.018 w
.52684 .25588 m
.57889 .26412 L
s
P
p
0 .4 1 r
.018 w
.52684 .25588 m
.51859 .20382 L
s
P
p
0 .4 1 r
.018 w
.52684 .25588 m
.47988 .2798 L
s
P
p
.2 0 1 r
.002 w
.47988 .64837 m
.4081 .5075 L
s
P
p
.2 0 1 r
.002 w
.47988 .64837 m
.33901 .57659 L
s
P
p
.2 0 1 r
.002 w
.47988 .64837 m
.32372 .6731 L
s
P
p
.2 0 1 r
.002 w
.51859 .72434 m
.4068 .83614 L
s
P
p
.2 0 1 r
.002 w
.51859 .72434 m
.49386 .8805 L
s
P
p
.2 0 1 r
.002 w
.51859 .72434 m
.59037 .86521 L
s
P
p
.2 0 1 r
.002 w
.57889 .66405 m
.71976 .73582 L
s
P
p
.2 0 1 r
.002 w
.57889 .66405 m
.73504 .63931 L
s
P
p
.2 0 1 r
.002 w
.57889 .66405 m
.69068 .55225 L
s
P
p
0 .4 1 r
.018 w
.52684 .67229 m
.47988 .64837 L
s
P
p
0 .4 1 r
.018 w
.52684 .67229 m
.51859 .72434 L
s
P
p
0 .4 1 r
.018 w
.52684 .67229 m
.57889 .66405 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.74764 .55979 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.41075 .31502 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.65552 .65191 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.52684 .25588 L
s
P
p
.2 0 1 r
.016 w
.55981 .46408 m
.52684 .67229 L
s
P
p
1 .6 0 r
.016 w
.5 .34669 m
.44019 .46408 L
s
P
p
1 .6 0 r
.016 w
.5 .34669 m
.47939 .47682 L
s
P
p
1 .6 0 r
.016 w
.5 .34669 m
.52061 .47682 L
s
P
p
1 .6 0 r
.016 w
.5 .34669 m
.55981 .46408 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0928913 0.952381 [
[ 0 0 0 0 ]
[ 1 .7666 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .7666 L
0 .7666 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.30646 .48672 m
.26634 .36325 L
s
P
p
.2 0 1 r
.002 w
.30646 .48672 m
.20143 .41041 L
s
P
p
.2 0 1 r
.002 w
.30646 .48672 m
.17663 .48672 L
s
P
p
.2 0 1 r
.002 w
.3281 .55332 m
.22306 .62963 L
s
P
p
.2 0 1 r
.002 w
.3281 .55332 m
.28798 .6768 L
s
P
p
.2 0 1 r
.002 w
.3281 .55332 m
.36822 .6768 L
s
P
p
.2 0 1 r
.002 w
.38475 .51216 m
.48978 .58847 L
s
P
p
.2 0 1 r
.002 w
.38475 .51216 m
.51458 .51216 L
s
P
p
.2 0 1 r
.002 w
.38475 .51216 m
.48978 .43585 L
s
P
p
0 .4 1 r
.018 w
.34147 .51216 m
.30646 .48672 L
s
P
p
0 .4 1 r
.018 w
.34147 .51216 m
.3281 .55332 L
s
P
p
0 .4 1 r
.018 w
.34147 .51216 m
.38475 .51216 L
s
P
p
.2 0 1 r
.002 w
.52215 .24249 m
.52215 .37232 L
s
P
p
.2 0 1 r
.002 w
.52215 .24249 m
.59846 .34753 L
s
P
p
.2 0 1 r
.002 w
.52215 .24249 m
.64563 .28261 L
s
P
p
.2 0 1 r
.002 w
.52215 .17247 m
.64563 .13235 L
s
P
p
.2 0 1 r
.002 w
.52215 .17247 m
.59846 .06743 L
s
P
p
.2 0 1 r
.002 w
.52215 .17247 m
.52215 .04264 L
s
P
p
.2 0 1 r
.002 w
.45556 .19411 m
.37924 .08907 L
s
P
p
.2 0 1 r
.002 w
.45556 .19411 m
.33208 .15399 L
s
P
p
.2 0 1 r
.002 w
.45556 .19411 m
.33208 .23423 L
s
P
p
0 .4 1 r
.018 w
.49671 .20748 m
.52215 .24249 L
s
P
p
0 .4 1 r
.018 w
.49671 .20748 m
.52215 .17247 L
s
P
p
0 .4 1 r
.018 w
.49671 .20748 m
.45556 .19411 L
s
P
p
.2 0 1 r
.002 w
.24155 .40812 m
.28166 .28464 L
s
P
p
.2 0 1 r
.002 w
.24155 .40812 m
.20143 .28464 L
s
P
p
.2 0 1 r
.002 w
.24155 .40812 m
.13651 .33181 L
s
P
p
.2 0 1 r
.002 w
.21991 .47471 m
.09008 .47471 L
s
P
p
.2 0 1 r
.002 w
.21991 .47471 m
.11487 .55103 L
s
P
p
.2 0 1 r
.002 w
.21991 .47471 m
.17979 .59819 L
s
P
p
.2 0 1 r
.002 w
.28993 .47471 m
.33005 .59819 L
s
P
p
.2 0 1 r
.002 w
.28993 .47471 m
.39496 .55103 L
s
P
p
.2 0 1 r
.002 w
.28993 .47471 m
.41976 .47471 L
s
P
p
0 .4 1 r
.018 w
.25492 .44928 m
.24155 .40812 L
s
P
p
0 .4 1 r
.018 w
.25492 .44928 m
.21991 .47471 L
s
P
p
0 .4 1 r
.018 w
.25492 .44928 m
.28993 .47471 L
s
P
p
.2 0 1 r
.002 w
.5596 .33731 m
.48329 .44235 L
s
P
p
.2 0 1 r
.002 w
.5596 .33731 m
.5596 .46714 L
s
P
p
.2 0 1 r
.002 w
.5596 .33731 m
.63591 .44235 L
s
P
p
.2 0 1 r
.002 w
.60076 .28066 m
.72423 .32078 L
s
P
p
.2 0 1 r
.002 w
.60076 .28066 m
.72423 .24054 L
s
P
p
.2 0 1 r
.002 w
.60076 .28066 m
.67707 .17563 L
s
P
p
.2 0 1 r
.002 w
.53416 .25902 m
.53416 .12919 L
s
P
p
.2 0 1 r
.002 w
.53416 .25902 m
.45785 .15399 L
s
P
p
.2 0 1 r
.002 w
.53416 .25902 m
.41069 .2189 L
s
P
p
0 .4 1 r
.018 w
.5596 .29403 m
.5596 .33731 L
s
P
p
0 .4 1 r
.018 w
.5596 .29403 m
.60076 .28066 L
s
P
p
0 .4 1 r
.018 w
.5596 .29403 m
.53416 .25902 L
s
P
p
.2 0 1 r
.002 w
.23523 .30637 m
.34027 .23006 L
s
P
p
.2 0 1 r
.002 w
.23523 .30637 m
.27535 .18289 L
s
P
p
.2 0 1 r
.002 w
.23523 .30637 m
.19511 .18289 L
s
P
p
.2 0 1 r
.002 w
.17858 .34753 m
.07355 .27121 L
s
P
p
.2 0 1 r
.002 w
.17858 .34753 m
.04875 .34753 L
s
P
p
.2 0 1 r
.002 w
.17858 .34753 m
.07355 .42384 L
s
P
p
.2 0 1 r
.002 w
.23523 .38869 m
.19511 .51216 L
s
P
p
.2 0 1 r
.002 w
.23523 .38869 m
.27535 .51216 L
s
P
p
.2 0 1 r
.002 w
.23523 .38869 m
.34027 .465 L
s
P
p
0 .4 1 r
.018 w
.22186 .34753 m
.23523 .30637 L
s
P
p
0 .4 1 r
.018 w
.22186 .34753 m
.17858 .34753 L
s
P
p
0 .4 1 r
.018 w
.22186 .34753 m
.23523 .38869 L
s
P
p
.2 0 1 r
.016 w
.39496 .34753 m
.34147 .51216 L
s
P
p
.2 0 1 r
.016 w
.39496 .34753 m
.49671 .20748 L
s
P
p
.2 0 1 r
.016 w
.39496 .34753 m
.25492 .44928 L
s
P
p
.2 0 1 r
.016 w
.39496 .34753 m
.5596 .29403 L
s
P
p
.2 0 1 r
.016 w
.39496 .34753 m
.22186 .34753 L
s
P
p
.2 0 1 r
.002 w
.4701 .55933 m
.36506 .48301 L
s
P
p
.2 0 1 r
.002 w
.4701 .55933 m
.34027 .55933 L
s
P
p
.2 0 1 r
.002 w
.4701 .55933 m
.36506 .63564 L
s
P
p
.2 0 1 r
.002 w
.52675 .60048 m
.48663 .72396 L
s
P
p
.2 0 1 r
.002 w
.52675 .60048 m
.56687 .72396 L
s
P
p
.2 0 1 r
.002 w
.52675 .60048 m
.63178 .6768 L
s
P
p
.2 0 1 r
.002 w
.54838 .53389 m
.67822 .53389 L
s
P
p
.2 0 1 r
.002 w
.54838 .53389 m
.65342 .45758 L
s
P
p
.2 0 1 r
.002 w
.54838 .53389 m
.5885 .41041 L
s
P
p
0 .4 1 r
.018 w
.51337 .55933 m
.4701 .55933 L
s
P
p
0 .4 1 r
.018 w
.51337 .55933 m
.52675 .60048 L
s
P
p
0 .4 1 r
.018 w
.51337 .55933 m
.54838 .53389 L
s
P
p
.2 0 1 r
.002 w
.50104 .23496 m
.57735 .33999 L
s
P
p
.2 0 1 r
.002 w
.50104 .23496 m
.62451 .27508 L
s
P
p
.2 0 1 r
.002 w
.50104 .23496 m
.62451 .19484 L
s
P
p
.2 0 1 r
.002 w
.45988 .17831 m
.53619 .07327 L
s
P
p
.2 0 1 r
.002 w
.45988 .17831 m
.45988 .04848 L
s
P
p
.2 0 1 r
.002 w
.45988 .17831 m
.38357 .07327 L
s
P
p
.2 0 1 r
.002 w
.41872 .23496 m
.29525 .19484 L
s
P
p
.2 0 1 r
.002 w
.41872 .23496 m
.29525 .27508 L
s
P
p
.2 0 1 r
.002 w
.41872 .23496 m
.34241 .33999 L
s
P
p
0 .4 1 r
.018 w
.45988 .22158 m
.50104 .23496 L
s
P
p
0 .4 1 r
.018 w
.45988 .22158 m
.45988 .17831 L
s
P
p
0 .4 1 r
.018 w
.45988 .22158 m
.41872 .23496 L
s
P
p
.2 0 1 r
.002 w
.37138 .53389 m
.33126 .41041 L
s
P
p
.2 0 1 r
.002 w
.37138 .53389 m
.26634 .45758 L
s
P
p
.2 0 1 r
.002 w
.37138 .53389 m
.24155 .53389 L
s
P
p
.2 0 1 r
.002 w
.39301 .60048 m
.28798 .6768 L
s
P
p
.2 0 1 r
.002 w
.39301 .60048 m
.35289 .72396 L
s
P
p
.2 0 1 r
.002 w
.39301 .60048 m
.43313 .72396 L
s
P
p
.2 0 1 r
.002 w
.44966 .55933 m
.5547 .63564 L
s
P
p
.2 0 1 r
.002 w
.44966 .55933 m
.57949 .55933 L
s
P
p
.2 0 1 r
.002 w
.44966 .55933 m
.5547 .48301 L
s
P
p
0 .4 1 r
.018 w
.40639 .55933 m
.37138 .53389 L
s
P
p
0 .4 1 r
.018 w
.40639 .55933 m
.39301 .60048 L
s
P
p
0 .4 1 r
.018 w
.40639 .55933 m
.44966 .55933 L
s
P
p
.2 0 1 r
.002 w
.58707 .28966 m
.58707 .41949 L
s
P
p
.2 0 1 r
.002 w
.58707 .28966 m
.66338 .39469 L
s
P
p
.2 0 1 r
.002 w
.58707 .28966 m
.71054 .32978 L
s
P
p
.2 0 1 r
.002 w
.58707 .21963 m
.71054 .17951 L
s
P
p
.2 0 1 r
.002 w
.58707 .21963 m
.66338 .1146 L
s
P
p
.2 0 1 r
.002 w
.58707 .21963 m
.58707 .0898 L
s
P
p
.2 0 1 r
.002 w
.52047 .24127 m
.44416 .13624 L
s
P
p
.2 0 1 r
.002 w
.52047 .24127 m
.397 .20115 L
s
P
p
.2 0 1 r
.002 w
.52047 .24127 m
.397 .28139 L
s
P
p
0 .4 1 r
.018 w
.56163 .25464 m
.58707 .28966 L
s
P
p
0 .4 1 r
.018 w
.56163 .25464 m
.58707 .21963 L
s
P
p
0 .4 1 r
.018 w
.56163 .25464 m
.52047 .24127 L
s
P
p
.2 0 1 r
.002 w
.30646 .45528 m
.34658 .33181 L
s
P
p
.2 0 1 r
.002 w
.30646 .45528 m
.26634 .33181 L
s
P
p
.2 0 1 r
.002 w
.30646 .45528 m
.20143 .37897 L
s
P
p
.2 0 1 r
.002 w
.28482 .52188 m
.15499 .52188 L
s
P
p
.2 0 1 r
.002 w
.28482 .52188 m
.17979 .59819 L
s
P
p
.2 0 1 r
.002 w
.28482 .52188 m
.2447 .64535 L
s
P
p
.2 0 1 r
.002 w
.35485 .52188 m
.39496 .64535 L
s
P
p
.2 0 1 r
.002 w
.35485 .52188 m
.45988 .59819 L
s
P
p
.2 0 1 r
.002 w
.35485 .52188 m
.48468 .52188 L
s
P
p
0 .4 1 r
.018 w
.31983 .49644 m
.30646 .45528 L
s
P
p
0 .4 1 r
.018 w
.31983 .49644 m
.28482 .52188 L
s
P
p
0 .4 1 r
.018 w
.31983 .49644 m
.35485 .52188 L
s
P
p
.2 0 1 r
.016 w
.45988 .39469 m
.51337 .55933 L
s
P
p
.2 0 1 r
.016 w
.45988 .39469 m
.45988 .22158 L
s
P
p
.2 0 1 r
.016 w
.45988 .39469 m
.40639 .55933 L
s
P
p
.2 0 1 r
.016 w
.45988 .39469 m
.56163 .25464 L
s
P
p
.2 0 1 r
.016 w
.45988 .39469 m
.31983 .49644 L
s
P
p
.2 0 1 r
.002 w
.64515 .52188 m
.51532 .52188 L
s
P
p
.2 0 1 r
.002 w
.64515 .52188 m
.54012 .59819 L
s
P
p
.2 0 1 r
.002 w
.64515 .52188 m
.60504 .64535 L
s
P
p
.2 0 1 r
.002 w
.71518 .52188 m
.7553 .64535 L
s
P
p
.2 0 1 r
.002 w
.71518 .52188 m
.82021 .59819 L
s
P
p
.2 0 1 r
.002 w
.71518 .52188 m
.84501 .52188 L
s
P
p
.2 0 1 r
.002 w
.69354 .45528 m
.79857 .37897 L
s
P
p
.2 0 1 r
.002 w
.69354 .45528 m
.73366 .33181 L
s
P
p
.2 0 1 r
.002 w
.69354 .45528 m
.65342 .33181 L
s
P
p
0 .4 1 r
.018 w
.68017 .49644 m
.64515 .52188 L
s
P
p
0 .4 1 r
.018 w
.68017 .49644 m
.71518 .52188 L
s
P
p
0 .4 1 r
.018 w
.68017 .49644 m
.69354 .45528 L
s
P
p
.2 0 1 r
.002 w
.47953 .24127 m
.603 .28139 L
s
P
p
.2 0 1 r
.002 w
.47953 .24127 m
.603 .20115 L
s
P
p
.2 0 1 r
.002 w
.47953 .24127 m
.55584 .13624 L
s
P
p
.2 0 1 r
.002 w
.41293 .21963 m
.41293 .0898 L
s
P
p
.2 0 1 r
.002 w
.41293 .21963 m
.33662 .1146 L
s
P
p
.2 0 1 r
.002 w
.41293 .21963 m
.28946 .17951 L
s
P
p
.2 0 1 r
.002 w
.41293 .28966 m
.28946 .32978 L
s
P
p
.2 0 1 r
.002 w
.41293 .28966 m
.33662 .39469 L
s
P
p
.2 0 1 r
.002 w
.41293 .28966 m
.41293 .41949 L
s
P
p
0 .4 1 r
.018 w
.43837 .25464 m
.47953 .24127 L
s
P
p
0 .4 1 r
.018 w
.43837 .25464 m
.41293 .21963 L
s
P
p
0 .4 1 r
.018 w
.43837 .25464 m
.41293 .28966 L
s
P
p
.2 0 1 r
.002 w
.55034 .55933 m
.4453 .48301 L
s
P
p
.2 0 1 r
.002 w
.55034 .55933 m
.42051 .55933 L
s
P
p
.2 0 1 r
.002 w
.55034 .55933 m
.4453 .63564 L
s
P
p
.2 0 1 r
.002 w
.60699 .60048 m
.56687 .72396 L
s
P
p
.2 0 1 r
.002 w
.60699 .60048 m
.64711 .72396 L
s
P
p
.2 0 1 r
.002 w
.60699 .60048 m
.71202 .6768 L
s
P
p
.2 0 1 r
.002 w
.62862 .53389 m
.75845 .53389 L
s
P
p
.2 0 1 r
.002 w
.62862 .53389 m
.73366 .45758 L
s
P
p
.2 0 1 r
.002 w
.62862 .53389 m
.66874 .41041 L
s
P
p
0 .4 1 r
.018 w
.59361 .55933 m
.55034 .55933 L
s
P
p
0 .4 1 r
.018 w
.59361 .55933 m
.60699 .60048 L
s
P
p
0 .4 1 r
.018 w
.59361 .55933 m
.62862 .53389 L
s
P
p
.2 0 1 r
.002 w
.58128 .23496 m
.65759 .33999 L
s
P
p
.2 0 1 r
.002 w
.58128 .23496 m
.70475 .27508 L
s
P
p
.2 0 1 r
.002 w
.58128 .23496 m
.70475 .19484 L
s
P
p
.2 0 1 r
.002 w
.54012 .17831 m
.61643 .07327 L
s
P
p
.2 0 1 r
.002 w
.54012 .17831 m
.54012 .04848 L
s
P
p
.2 0 1 r
.002 w
.54012 .17831 m
.46381 .07327 L
s
P
p
.2 0 1 r
.002 w
.49896 .23496 m
.37549 .19484 L
s
P
p
.2 0 1 r
.002 w
.49896 .23496 m
.37549 .27508 L
s
P
p
.2 0 1 r
.002 w
.49896 .23496 m
.42265 .33999 L
s
P
p
0 .4 1 r
.018 w
.54012 .22158 m
.58128 .23496 L
s
P
p
0 .4 1 r
.018 w
.54012 .22158 m
.54012 .17831 L
s
P
p
0 .4 1 r
.018 w
.54012 .22158 m
.49896 .23496 L
s
P
p
.2 0 1 r
.002 w
.45162 .53389 m
.4115 .41041 L
s
P
p
.2 0 1 r
.002 w
.45162 .53389 m
.34658 .45758 L
s
P
p
.2 0 1 r
.002 w
.45162 .53389 m
.32178 .53389 L
s
P
p
.2 0 1 r
.002 w
.47325 .60048 m
.36822 .6768 L
s
P
p
.2 0 1 r
.002 w
.47325 .60048 m
.43313 .72396 L
s
P
p
.2 0 1 r
.002 w
.47325 .60048 m
.51337 .72396 L
s
P
p
.2 0 1 r
.002 w
.5299 .55933 m
.63494 .63564 L
s
P
p
.2 0 1 r
.002 w
.5299 .55933 m
.65973 .55933 L
s
P
p
.2 0 1 r
.002 w
.5299 .55933 m
.63494 .48301 L
s
P
p
0 .4 1 r
.018 w
.48663 .55933 m
.45162 .53389 L
s
P
p
0 .4 1 r
.018 w
.48663 .55933 m
.47325 .60048 L
s
P
p
0 .4 1 r
.018 w
.48663 .55933 m
.5299 .55933 L
s
P
p
.2 0 1 r
.016 w
.54012 .39469 m
.68017 .49644 L
s
P
p
.2 0 1 r
.016 w
.54012 .39469 m
.43837 .25464 L
s
P
p
.2 0 1 r
.016 w
.54012 .39469 m
.59361 .55933 L
s
P
p
.2 0 1 r
.016 w
.54012 .39469 m
.54012 .22158 L
s
P
p
.2 0 1 r
.016 w
.54012 .39469 m
.48663 .55933 L
s
P
p
.2 0 1 r
.002 w
.76477 .38869 m
.65973 .465 L
s
P
p
.2 0 1 r
.002 w
.76477 .38869 m
.72465 .51216 L
s
P
p
.2 0 1 r
.002 w
.76477 .38869 m
.80489 .51216 L
s
P
p
.2 0 1 r
.002 w
.82142 .34753 m
.92645 .42384 L
s
P
p
.2 0 1 r
.002 w
.82142 .34753 m
.95125 .34753 L
s
P
p
.2 0 1 r
.002 w
.82142 .34753 m
.92645 .27121 L
s
P
p
.2 0 1 r
.002 w
.76477 .30637 m
.80489 .18289 L
s
P
p
.2 0 1 r
.002 w
.76477 .30637 m
.72465 .18289 L
s
P
p
.2 0 1 r
.002 w
.76477 .30637 m
.65973 .23006 L
s
P
p
0 .4 1 r
.018 w
.77814 .34753 m
.76477 .38869 L
s
P
p
0 .4 1 r
.018 w
.77814 .34753 m
.82142 .34753 L
s
P
p
0 .4 1 r
.018 w
.77814 .34753 m
.76477 .30637 L
s
P
p
.2 0 1 r
.002 w
.46584 .25902 m
.58931 .2189 L
s
P
p
.2 0 1 r
.002 w
.46584 .25902 m
.54215 .15399 L
s
P
p
.2 0 1 r
.002 w
.46584 .25902 m
.46584 .12919 L
s
P
p
.2 0 1 r
.002 w
.39924 .28066 m
.32293 .17563 L
s
P
p
.2 0 1 r
.002 w
.39924 .28066 m
.27577 .24054 L
s
P
p
.2 0 1 r
.002 w
.39924 .28066 m
.27577 .32078 L
s
P
p
.2 0 1 r
.002 w
.4404 .33731 m
.36409 .44235 L
s
P
p
.2 0 1 r
.002 w
.4404 .33731 m
.4404 .46714 L
s
P
p
.2 0 1 r
.002 w
.4404 .33731 m
.51671 .44235 L
s
P
p
0 .4 1 r
.018 w
.4404 .29403 m
.46584 .25902 L
s
P
p
0 .4 1 r
.018 w
.4404 .29403 m
.39924 .28066 L
s
P
p
0 .4 1 r
.018 w
.4404 .29403 m
.4404 .33731 L
s
P
p
.2 0 1 r
.002 w
.71007 .47471 m
.58024 .47471 L
s
P
p
.2 0 1 r
.002 w
.71007 .47471 m
.60504 .55103 L
s
P
p
.2 0 1 r
.002 w
.71007 .47471 m
.66995 .59819 L
s
P
p
.2 0 1 r
.002 w
.78009 .47471 m
.82021 .59819 L
s
P
p
.2 0 1 r
.002 w
.78009 .47471 m
.88513 .55103 L
s
P
p
.2 0 1 r
.002 w
.78009 .47471 m
.90992 .47471 L
s
P
p
.2 0 1 r
.002 w
.75845 .40812 m
.86349 .33181 L
s
P
p
.2 0 1 r
.002 w
.75845 .40812 m
.79857 .28464 L
s
P
p
.2 0 1 r
.002 w
.75845 .40812 m
.71834 .28464 L
s
P
p
0 .4 1 r
.018 w
.74508 .44928 m
.71007 .47471 L
s
P
p
0 .4 1 r
.018 w
.74508 .44928 m
.78009 .47471 L
s
P
p
0 .4 1 r
.018 w
.74508 .44928 m
.75845 .40812 L
s
P
p
.2 0 1 r
.002 w
.54444 .19411 m
.66792 .23423 L
s
P
p
.2 0 1 r
.002 w
.54444 .19411 m
.66792 .15399 L
s
P
p
.2 0 1 r
.002 w
.54444 .19411 m
.62076 .08907 L
s
P
p
.2 0 1 r
.002 w
.47785 .17247 m
.47785 .04264 L
s
P
p
.2 0 1 r
.002 w
.47785 .17247 m
.40154 .06743 L
s
P
p
.2 0 1 r
.002 w
.47785 .17247 m
.35437 .13235 L
s
P
p
.2 0 1 r
.002 w
.47785 .24249 m
.35437 .28261 L
s
P
p
.2 0 1 r
.002 w
.47785 .24249 m
.40154 .34753 L
s
P
p
.2 0 1 r
.002 w
.47785 .24249 m
.47785 .37232 L
s
P
p
0 .4 1 r
.018 w
.50329 .20748 m
.54444 .19411 L
s
P
p
0 .4 1 r
.018 w
.50329 .20748 m
.47785 .17247 L
s
P
p
0 .4 1 r
.018 w
.50329 .20748 m
.47785 .24249 L
s
P
p
.2 0 1 r
.002 w
.61525 .51216 m
.51022 .43585 L
s
P
p
.2 0 1 r
.002 w
.61525 .51216 m
.48542 .51216 L
s
P
p
.2 0 1 r
.002 w
.61525 .51216 m
.51022 .58847 L
s
P
p
.2 0 1 r
.002 w
.6719 .55332 m
.63178 .6768 L
s
P
p
.2 0 1 r
.002 w
.6719 .55332 m
.71202 .6768 L
s
P
p
.2 0 1 r
.002 w
.6719 .55332 m
.77694 .62963 L
s
P
p
.2 0 1 r
.002 w
.69354 .48672 m
.82337 .48672 L
s
P
p
.2 0 1 r
.002 w
.69354 .48672 m
.79857 .41041 L
s
P
p
.2 0 1 r
.002 w
.69354 .48672 m
.73366 .36325 L
s
P
p
0 .4 1 r
.018 w
.65853 .51216 m
.61525 .51216 L
s
P
p
0 .4 1 r
.018 w
.65853 .51216 m
.6719 .55332 L
s
P
p
0 .4 1 r
.018 w
.65853 .51216 m
.69354 .48672 L
s
P
p
.2 0 1 r
.016 w
.60504 .34753 m
.77814 .34753 L
s
P
p
.2 0 1 r
.016 w
.60504 .34753 m
.4404 .29403 L
s
P
p
.2 0 1 r
.016 w
.60504 .34753 m
.74508 .44928 L
s
P
p
.2 0 1 r
.016 w
.60504 .34753 m
.50329 .20748 L
s
P
p
.2 0 1 r
.016 w
.60504 .34753 m
.65853 .51216 L
s
P
p
1 .6 0 r
.016 w
.5 .27121 m
.39496 .34753 L
s
P
p
1 .6 0 r
.016 w
.5 .27121 m
.45988 .39469 L
s
P
p
1 .6 0 r
.016 w
.5 .27121 m
.54012 .39469 L
s
P
p
1 .6 0 r
.016 w
.5 .27121 m
.60504 .34753 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.081587 0.952381 [
[ 0 0 0 0 ]
[ 1 .78921 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78921 L
0 .78921 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.27517 .37889 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.20765 .42794 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.18186 .50732 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.23015 .65597 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.29768 .70502 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.38114 .70502 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .61316 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.53337 .53378 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .4544 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.3169 .50732 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.33941 .57659 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.39833 .53378 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.54125 .38833 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.62063 .36254 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.66968 .29501 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.66968 .13872 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.62063 .0712 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.54125 .04541 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.3926 .0937 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .16122 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .24469 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .25328 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .18045 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.47198 .20296 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.29111 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.20765 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.14012 .34618 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.09183 .49483 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.11762 .57421 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.18514 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.34144 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.40896 .57421 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.43475 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.24938 .42556 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.22687 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.2997 .49483 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.50083 .46116 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.5802 .48695 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.65958 .46116 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .33471 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .25125 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.70239 .18373 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.55374 .13543 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.47437 .16122 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.42531 .22875 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.5802 .35191 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.62301 .29298 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.55374 .27048 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.35206 .24035 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.28454 .19129 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.20108 .19129 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .28316 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.04884 .36254 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .44191 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.20108 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.28454 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.35206 .48472 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .31972 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.18388 .36254 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .40535 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.35332 .53378 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.51479 .21687 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.26329 .46837 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.5802 .30689 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.2289 .36254 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .49528 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.34081 .57466 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .65404 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.49304 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.57651 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.64403 .69685 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.69233 .5482 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.66653 .46883 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.59901 .41977 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.47585 .57466 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.53478 .61747 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.55728 .5482 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.58741 .34652 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .279 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .19554 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.5446 .06909 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.46522 .0433 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.38585 .06909 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .19554 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .279 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.34304 .34652 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.50804 .23727 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.46522 .17834 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.42241 .23727 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.33144 .41977 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.26391 .46883 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.23812 .5482 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.28642 .69685 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.35394 .74591 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.4374 .74591 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .65404 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.58964 .57466 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .49528 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.37317 .5482 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.39567 .61747 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.4546 .57466 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.59752 .42921 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.67689 .40342 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.72595 .33589 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.72595 .1796 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.67689 .11208 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.59752 .08629 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.44887 .13458 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .20211 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .28557 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .29416 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .22133 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.52825 .24384 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.34738 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.26391 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.19639 .38706 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.14809 .53571 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.17389 .61509 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.24141 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.3977 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.46522 .61509 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.49102 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.30564 .46644 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.28314 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.35597 .53571 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.52087 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.46522 .22336 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.40958 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.57106 .25775 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.31956 .50925 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.50898 .53571 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.53478 .61509 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.6023 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.75859 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.82611 .61509 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.85191 .53571 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.80361 .38706 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.73609 .33801 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.65262 .33801 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.64403 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.71686 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.69436 .46644 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .28557 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .20211 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.55113 .13458 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.40248 .08629 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.32311 .11208 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.27405 .1796 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.27405 .33589 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.32311 .40342 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.40248 .42921 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.47175 .24384 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .22133 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .29416 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .49528 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.41036 .57466 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .65404 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.5626 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.64606 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.71358 .69685 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.76188 .5482 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.73609 .46883 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.66856 .41977 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.5454 .57466 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.60433 .61747 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.62683 .5482 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.65696 .34652 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .279 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .19554 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.61415 .06909 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.53478 .0433 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.4554 .06909 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .19554 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .279 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.41259 .34652 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.57759 .23727 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.53478 .17834 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.49196 .23727 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.40099 .41977 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.33347 .46883 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.30767 .5482 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.35597 .69685 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.42349 .74591 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.50696 .74591 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .65404 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.65919 .57466 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .49528 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.44272 .5482 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.46522 .61747 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.52415 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.68044 .50925 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.42894 .25775 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.59042 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.53478 .22336 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.47913 .57466 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.64794 .48472 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.71546 .53378 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.79892 .53378 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .44191 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.95116 .36254 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .28316 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.79892 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.71546 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.64794 .24035 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .40535 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.81612 .36254 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .31972 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.57469 .22875 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.52563 .16122 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.44626 .13543 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.29761 .18373 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .25125 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .33471 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.34042 .46116 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.4198 .48695 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.49917 .46116 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.44626 .27048 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.37699 .29298 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.4198 .35191 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.56525 .49483 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.59104 .57421 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.65856 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.81486 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.88238 .57421 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.90817 .49483 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.85988 .34618 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.79235 .29713 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.70889 .29713 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.7003 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.77313 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.75062 .42556 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .24469 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .16122 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.6074 .0937 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.45875 .04541 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.37937 .0712 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.33032 .13872 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.33032 .29501 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.37937 .36254 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.45875 .38833 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.52802 .20296 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .18045 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .25328 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .4544 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.46663 .53378 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .61316 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.61886 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.70232 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.76985 .65597 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.81814 .50732 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.79235 .42794 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.72483 .37889 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.60167 .53378 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.66059 .57659 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.6831 .50732 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.7711 .36254 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.4198 .30689 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.73671 .46837 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.48521 .21687 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.64668 .53378 L
s
P
p
1 .6 0 r
.018 w
.5 .29639 m
.40896 .36254 L
s
P
p
1 .6 0 r
.018 w
.5 .29639 m
.46522 .40342 L
s
P
p
1 .6 0 r
.018 w
.5 .29639 m
.53478 .40342 L
s
P
p
1 .6 0 r
.018 w
.5 .29639 m
.59104 .36254 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.081587 0.952381 [
[ 0 0 0 0 ]
[ 1 .78921 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78921 L
0 .78921 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.27517 .37889 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.20765 .42794 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.18186 .50732 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.23015 .65597 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.29768 .70502 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.38114 .70502 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .61316 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.53337 .53378 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.50758 .4544 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.3169 .50732 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.33941 .57659 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.39833 .53378 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.54125 .38833 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.62063 .36254 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.66968 .29501 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.66968 .13872 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.62063 .0712 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.54125 .04541 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.3926 .0937 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .16122 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .24469 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .25328 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .18045 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.47198 .20296 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.29111 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.20765 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.14012 .34618 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.09183 .49483 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.11762 .57421 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.18514 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.34144 .62326 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.40896 .57421 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.43475 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.24938 .42556 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.22687 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.2997 .49483 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.50083 .46116 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.5802 .48695 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.65958 .46116 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .33471 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .25125 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.70239 .18373 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.55374 .13543 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.47437 .16122 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.42531 .22875 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.5802 .35191 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.62301 .29298 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.55374 .27048 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.35206 .24035 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.28454 .19129 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.20108 .19129 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .28316 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.04884 .36254 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.07463 .44191 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.20108 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.28454 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.35206 .48472 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .31972 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.18388 .36254 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .40535 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.35332 .53378 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.51479 .21687 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.26329 .46837 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.5802 .30689 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.2289 .36254 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .49528 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.34081 .57466 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.3666 .65404 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.49304 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.57651 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.64403 .69685 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.69233 .5482 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.66653 .46883 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.59901 .41977 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.47585 .57466 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.53478 .61747 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.55728 .5482 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.58741 .34652 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .279 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .19554 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.5446 .06909 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.46522 .0433 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.38585 .06909 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .19554 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .279 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.34304 .34652 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.50804 .23727 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.46522 .17834 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.42241 .23727 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.33144 .41977 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.26391 .46883 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.23812 .5482 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.28642 .69685 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.35394 .74591 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.4374 .74591 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .65404 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.58964 .57466 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.56385 .49528 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.37317 .5482 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.39567 .61747 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.4546 .57466 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.59752 .42921 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.67689 .40342 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.72595 .33589 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.72595 .1796 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.67689 .11208 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.59752 .08629 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.44887 .13458 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .20211 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .28557 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .29416 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .22133 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.52825 .24384 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.34738 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.26391 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.19639 .38706 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.14809 .53571 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.17389 .61509 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.24141 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.3977 .66414 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.46522 .61509 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.49102 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.30564 .46644 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.28314 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.35597 .53571 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.52087 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.46522 .22336 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.40958 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.57106 .25775 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.31956 .50925 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.50898 .53571 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.53478 .61509 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.6023 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.75859 .66414 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.82611 .61509 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.85191 .53571 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.80361 .38706 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.73609 .33801 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.65262 .33801 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.64403 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.71686 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.69436 .46644 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .28557 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .20211 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.55113 .13458 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.40248 .08629 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.32311 .11208 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.27405 .1796 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.27405 .33589 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.32311 .40342 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.40248 .42921 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.47175 .24384 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .22133 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .29416 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .49528 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.41036 .57466 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.43615 .65404 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.5626 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.64606 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.71358 .69685 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.76188 .5482 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.73609 .46883 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.66856 .41977 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.5454 .57466 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.60433 .61747 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.62683 .5482 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.65696 .34652 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .279 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .19554 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.61415 .06909 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.53478 .0433 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.4554 .06909 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .19554 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .279 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.41259 .34652 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.57759 .23727 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.53478 .17834 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.49196 .23727 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.40099 .41977 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.33347 .46883 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.30767 .5482 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.35597 .69685 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.42349 .74591 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.50696 .74591 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .65404 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.65919 .57466 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.6334 .49528 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.44272 .5482 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.46522 .61747 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.52415 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.68044 .50925 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.42894 .25775 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.59042 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.53478 .22336 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.47913 .57466 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.64794 .48472 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.71546 .53378 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.79892 .53378 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .44191 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.95116 .36254 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.92537 .28316 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.79892 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.71546 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.64794 .24035 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .40535 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.81612 .36254 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .31972 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.57469 .22875 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.52563 .16122 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.44626 .13543 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.29761 .18373 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .25125 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .33471 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.34042 .46116 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.4198 .48695 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.49917 .46116 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.44626 .27048 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.37699 .29298 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.4198 .35191 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.56525 .49483 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.59104 .57421 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.65856 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.81486 .62326 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.88238 .57421 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.90817 .49483 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.85988 .34618 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.79235 .29713 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.70889 .29713 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.7003 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.77313 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.75062 .42556 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .24469 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .16122 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.6074 .0937 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.45875 .04541 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.37937 .0712 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.33032 .13872 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.33032 .29501 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.37937 .36254 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.45875 .38833 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.52802 .20296 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .18045 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .25328 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .4544 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.46663 .53378 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.49242 .61316 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.61886 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.70232 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.76985 .65597 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.81814 .50732 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.79235 .42794 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.72483 .37889 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.60167 .53378 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.66059 .57659 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.6831 .50732 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.7711 .36254 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.4198 .30689 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.73671 .46837 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.48521 .21687 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.64668 .53378 L
s
P
p
.8 1 0 r
.016 w
.5 .29639 m
.40896 .36254 L
s
P
p
.8 1 0 r
.016 w
.5 .29639 m
.46522 .40342 L
s
P
p
.8 1 0 r
.016 w
.5 .29639 m
.53478 .40342 L
s
P
p
.8 1 0 r
.016 w
.5 .29639 m
.59104 .36254 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0318709 0.952381 [
[ 0 0 0 0 ]
[ 1 .88864 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88864 L
0 .88864 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.54336 .58801 m
.38937 .6124 L
s
P
p
.2 0 1 r
.002 w
.54336 .58801 m
.43312 .69825 L
s
P
p
.2 0 1 r
.002 w
.54336 .58801 m
.51897 .742 L
s
P
p
.2 0 1 r
.002 w
.62642 .57485 m
.6972 .71377 L
s
P
p
.2 0 1 r
.002 w
.62642 .57485 m
.76533 .64563 L
s
P
p
.2 0 1 r
.002 w
.62642 .57485 m
.78041 .55046 L
s
P
p
.2 0 1 r
.002 w
.58824 .49993 m
.69849 .38968 L
s
P
p
.2 0 1 r
.002 w
.58824 .49993 m
.61263 .34594 L
s
P
p
.2 0 1 r
.002 w
.58824 .49993 m
.51746 .36101 L
s
P
p
0 .4 1 r
.018 w
.58011 .55126 m
.54336 .58801 L
s
P
p
0 .4 1 r
.018 w
.58011 .55126 m
.62642 .57485 L
s
P
p
0 .4 1 r
.018 w
.58011 .55126 m
.58824 .49993 L
s
P
p
.2 0 1 r
.002 w
.2942 .28629 m
.44819 .31068 L
s
P
p
.2 0 1 r
.002 w
.2942 .28629 m
.43312 .21551 L
s
P
p
.2 0 1 r
.002 w
.2942 .28629 m
.36498 .14738 L
s
P
p
.2 0 1 r
.002 w
.21115 .27314 m
.18676 .11915 L
s
P
p
.2 0 1 r
.002 w
.21115 .27314 m
.1009 .16289 L
s
P
p
.2 0 1 r
.002 w
.21115 .27314 m
.05716 .24875 L
s
P
p
.2 0 1 r
.002 w
.2243 .35619 m
.08538 .42697 L
s
P
p
.2 0 1 r
.002 w
.2243 .35619 m
.15352 .49511 L
s
P
p
.2 0 1 r
.002 w
.2243 .35619 m
.24869 .51018 L
s
P
p
0 .4 1 r
.018 w
.24789 .30989 m
.2942 .28629 L
s
P
p
0 .4 1 r
.018 w
.24789 .30989 m
.21115 .27314 L
s
P
p
0 .4 1 r
.018 w
.24789 .30989 m
.2243 .35619 L
s
P
p
.2 0 1 r
.002 w
.43793 .65023 m
.29902 .57945 L
s
P
p
.2 0 1 r
.002 w
.43793 .65023 m
.28394 .67462 L
s
P
p
.2 0 1 r
.002 w
.43793 .65023 m
.32769 .76048 L
s
P
p
.2 0 1 r
.002 w
.51286 .68841 m
.48847 .8424 L
s
P
p
.2 0 1 r
.002 w
.51286 .68841 m
.58364 .82733 L
s
P
p
.2 0 1 r
.002 w
.51286 .68841 m
.65178 .75919 L
s
P
p
.2 0 1 r
.002 w
.52601 .60536 m
.68 .58097 L
s
P
p
.2 0 1 r
.002 w
.52601 .60536 m
.63626 .49511 L
s
P
p
.2 0 1 r
.002 w
.52601 .60536 m
.5504 .45136 L
s
P
p
0 .4 1 r
.018 w
.48926 .6421 m
.43793 .65023 L
s
P
p
0 .4 1 r
.018 w
.48926 .6421 m
.51286 .68841 L
s
P
p
0 .4 1 r
.018 w
.48926 .6421 m
.52601 .60536 L
s
P
p
.2 0 1 r
.002 w
.4137 .25969 m
.52394 .36994 L
s
P
p
.2 0 1 r
.002 w
.4137 .25969 m
.56769 .28408 L
s
P
p
.2 0 1 r
.002 w
.4137 .25969 m
.55262 .18891 L
s
P
p
.2 0 1 r
.002 w
.35424 .20023 m
.42502 .06131 L
s
P
p
.2 0 1 r
.002 w
.35424 .20023 m
.32985 .04624 L
s
P
p
.2 0 1 r
.002 w
.35424 .20023 m
.24399 .08998 L
s
P
p
.2 0 1 r
.002 w
.31606 .27515 m
.16207 .25076 L
s
P
p
.2 0 1 r
.002 w
.31606 .27515 m
.17715 .34594 L
s
P
p
.2 0 1 r
.002 w
.31606 .27515 m
.24528 .41407 L
s
P
p
0 .4 1 r
.018 w
.36237 .25156 m
.4137 .25969 L
s
P
p
0 .4 1 r
.018 w
.36237 .25156 m
.35424 .20023 L
s
P
p
0 .4 1 r
.018 w
.36237 .25156 m
.31606 .27515 L
s
P
p
.2 0 1 r
.016 w
.39489 .45688 m
.58011 .55126 L
s
P
p
.2 0 1 r
.016 w
.39489 .45688 m
.24789 .30989 L
s
P
p
.2 0 1 r
.016 w
.39489 .45688 m
.48926 .6421 L
s
P
p
.2 0 1 r
.016 w
.39489 .45688 m
.36237 .25156 L
s
P
p
.2 0 1 r
.002 w
.65704 .52289 m
.5468 .63314 L
s
P
p
.2 0 1 r
.002 w
.65704 .52289 m
.63265 .67688 L
s
P
p
.2 0 1 r
.002 w
.65704 .52289 m
.72782 .66181 L
s
P
p
.2 0 1 r
.002 w
.7165 .46343 m
.85542 .53421 L
s
P
p
.2 0 1 r
.002 w
.7165 .46343 m
.87049 .43904 L
s
P
p
.2 0 1 r
.002 w
.7165 .46343 m
.82675 .35318 L
s
P
p
.2 0 1 r
.002 w
.64158 .42525 m
.66597 .27126 L
s
P
p
.2 0 1 r
.002 w
.64158 .42525 m
.5708 .28634 L
s
P
p
.2 0 1 r
.002 w
.64158 .42525 m
.50266 .35447 L
s
P
p
0 .4 1 r
.018 w
.66517 .47156 m
.65704 .52289 L
s
P
p
0 .4 1 r
.018 w
.66517 .47156 m
.7165 .46343 L
s
P
p
0 .4 1 r
.018 w
.66517 .47156 m
.64158 .42525 L
s
P
p
.2 0 1 r
.002 w
.27812 .42525 m
.41704 .35447 L
s
P
p
.2 0 1 r
.002 w
.27812 .42525 m
.34891 .28634 L
s
P
p
.2 0 1 r
.002 w
.27812 .42525 m
.25373 .27126 L
s
P
p
.2 0 1 r
.002 w
.2032 .46343 m
.09295 .35318 L
s
P
p
.2 0 1 r
.002 w
.2032 .46343 m
.04921 .43904 L
s
P
p
.2 0 1 r
.002 w
.2032 .46343 m
.06428 .53421 L
s
P
p
.2 0 1 r
.002 w
.26266 .52289 m
.19188 .66181 L
s
P
p
.2 0 1 r
.002 w
.26266 .52289 m
.28705 .67688 L
s
P
p
.2 0 1 r
.002 w
.26266 .52289 m
.3729 .63314 L
s
P
p
0 .4 1 r
.018 w
.25453 .47156 m
.27812 .42525 L
s
P
p
0 .4 1 r
.018 w
.25453 .47156 m
.2032 .46343 L
s
P
p
0 .4 1 r
.018 w
.25453 .47156 m
.26266 .52289 L
s
P
p
.2 0 1 r
.002 w
.60833 .6352 m
.45433 .65959 L
s
P
p
.2 0 1 r
.002 w
.60833 .6352 m
.49808 .74545 L
s
P
p
.2 0 1 r
.002 w
.60833 .6352 m
.58394 .78919 L
s
P
p
.2 0 1 r
.002 w
.69138 .62205 m
.76216 .76097 L
s
P
p
.2 0 1 r
.002 w
.69138 .62205 m
.8303 .69283 L
s
P
p
.2 0 1 r
.002 w
.69138 .62205 m
.84537 .59766 L
s
P
p
.2 0 1 r
.002 w
.6532 .54712 m
.76345 .43688 L
s
P
p
.2 0 1 r
.002 w
.6532 .54712 m
.67759 .39313 L
s
P
p
.2 0 1 r
.002 w
.6532 .54712 m
.58242 .40821 L
s
P
p
0 .4 1 r
.018 w
.64507 .59845 m
.60833 .6352 L
s
P
p
0 .4 1 r
.018 w
.64507 .59845 m
.69138 .62205 L
s
P
p
0 .4 1 r
.018 w
.64507 .59845 m
.6532 .54712 L
s
P
p
.2 0 1 r
.002 w
.35916 .33349 m
.51315 .35788 L
s
P
p
.2 0 1 r
.002 w
.35916 .33349 m
.49808 .26271 L
s
P
p
.2 0 1 r
.002 w
.35916 .33349 m
.42994 .19457 L
s
P
p
.2 0 1 r
.002 w
.27611 .32034 m
.25172 .16635 L
s
P
p
.2 0 1 r
.002 w
.27611 .32034 m
.16586 .21009 L
s
P
p
.2 0 1 r
.002 w
.27611 .32034 m
.12212 .29595 L
s
P
p
.2 0 1 r
.002 w
.28926 .40339 m
.15035 .47417 L
s
P
p
.2 0 1 r
.002 w
.28926 .40339 m
.21848 .54231 L
s
P
p
.2 0 1 r
.002 w
.28926 .40339 m
.31365 .55738 L
s
P
p
0 .4 1 r
.018 w
.31286 .35709 m
.35916 .33349 L
s
P
p
0 .4 1 r
.018 w
.31286 .35709 m
.27611 .32034 L
s
P
p
0 .4 1 r
.018 w
.31286 .35709 m
.28926 .40339 L
s
P
p
.2 0 1 r
.016 w
.45985 .50408 m
.66517 .47156 L
s
P
p
.2 0 1 r
.016 w
.45985 .50408 m
.25453 .47156 L
s
P
p
.2 0 1 r
.016 w
.45985 .50408 m
.64507 .59845 L
s
P
p
.2 0 1 r
.016 w
.45985 .50408 m
.31286 .35709 L
s
P
p
.2 0 1 r
.002 w
.71074 .40339 m
.68635 .55738 L
s
P
p
.2 0 1 r
.002 w
.71074 .40339 m
.78152 .54231 L
s
P
p
.2 0 1 r
.002 w
.71074 .40339 m
.84965 .47417 L
s
P
p
.2 0 1 r
.002 w
.72389 .32034 m
.87788 .29595 L
s
P
p
.2 0 1 r
.002 w
.72389 .32034 m
.83414 .21009 L
s
P
p
.2 0 1 r
.002 w
.72389 .32034 m
.74828 .16635 L
s
P
p
.2 0 1 r
.002 w
.64084 .33349 m
.57006 .19457 L
s
P
p
.2 0 1 r
.002 w
.64084 .33349 m
.50192 .26271 L
s
P
p
.2 0 1 r
.002 w
.64084 .33349 m
.48685 .35788 L
s
P
p
0 .4 1 r
.018 w
.68714 .35709 m
.71074 .40339 L
s
P
p
0 .4 1 r
.018 w
.68714 .35709 m
.72389 .32034 L
s
P
p
0 .4 1 r
.018 w
.68714 .35709 m
.64084 .33349 L
s
P
p
.2 0 1 r
.002 w
.3468 .54712 m
.41758 .40821 L
s
P
p
.2 0 1 r
.002 w
.3468 .54712 m
.32241 .39313 L
s
P
p
.2 0 1 r
.002 w
.3468 .54712 m
.23655 .43688 L
s
P
p
.2 0 1 r
.002 w
.30862 .62205 m
.15463 .59766 L
s
P
p
.2 0 1 r
.002 w
.30862 .62205 m
.1697 .69283 L
s
P
p
.2 0 1 r
.002 w
.30862 .62205 m
.23784 .76097 L
s
P
p
.2 0 1 r
.002 w
.39167 .6352 m
.41606 .78919 L
s
P
p
.2 0 1 r
.002 w
.39167 .6352 m
.50192 .74545 L
s
P
p
.2 0 1 r
.002 w
.39167 .6352 m
.54567 .65959 L
s
P
p
0 .4 1 r
.018 w
.35493 .59845 m
.3468 .54712 L
s
P
p
0 .4 1 r
.018 w
.35493 .59845 m
.30862 .62205 L
s
P
p
0 .4 1 r
.018 w
.35493 .59845 m
.39167 .6352 L
s
P
p
.2 0 1 r
.002 w
.73734 .52289 m
.6271 .63314 L
s
P
p
.2 0 1 r
.002 w
.73734 .52289 m
.71295 .67688 L
s
P
p
.2 0 1 r
.002 w
.73734 .52289 m
.80812 .66181 L
s
P
p
.2 0 1 r
.002 w
.7968 .46343 m
.93572 .53421 L
s
P
p
.2 0 1 r
.002 w
.7968 .46343 m
.95079 .43904 L
s
P
p
.2 0 1 r
.002 w
.7968 .46343 m
.90705 .35318 L
s
P
p
.2 0 1 r
.002 w
.72188 .42525 m
.74627 .27126 L
s
P
p
.2 0 1 r
.002 w
.72188 .42525 m
.65109 .28634 L
s
P
p
.2 0 1 r
.002 w
.72188 .42525 m
.58296 .35447 L
s
P
p
0 .4 1 r
.018 w
.74547 .47156 m
.73734 .52289 L
s
P
p
0 .4 1 r
.018 w
.74547 .47156 m
.7968 .46343 L
s
P
p
0 .4 1 r
.018 w
.74547 .47156 m
.72188 .42525 L
s
P
p
.2 0 1 r
.002 w
.35842 .42525 m
.49734 .35447 L
s
P
p
.2 0 1 r
.002 w
.35842 .42525 m
.4292 .28634 L
s
P
p
.2 0 1 r
.002 w
.35842 .42525 m
.33403 .27126 L
s
P
p
.2 0 1 r
.002 w
.2835 .46343 m
.17325 .35318 L
s
P
p
.2 0 1 r
.002 w
.2835 .46343 m
.12951 .43904 L
s
P
p
.2 0 1 r
.002 w
.2835 .46343 m
.14458 .53421 L
s
P
p
.2 0 1 r
.002 w
.34296 .52289 m
.27218 .66181 L
s
P
p
.2 0 1 r
.002 w
.34296 .52289 m
.36735 .67688 L
s
P
p
.2 0 1 r
.002 w
.34296 .52289 m
.4532 .63314 L
s
P
p
0 .4 1 r
.018 w
.33483 .47156 m
.35842 .42525 L
s
P
p
0 .4 1 r
.018 w
.33483 .47156 m
.2835 .46343 L
s
P
p
0 .4 1 r
.018 w
.33483 .47156 m
.34296 .52289 L
s
P
p
.2 0 1 r
.016 w
.54015 .50408 m
.68714 .35709 L
s
P
p
.2 0 1 r
.016 w
.54015 .50408 m
.35493 .59845 L
s
P
p
.2 0 1 r
.016 w
.54015 .50408 m
.74547 .47156 L
s
P
p
.2 0 1 r
.016 w
.54015 .50408 m
.33483 .47156 L
s
P
p
.2 0 1 r
.002 w
.68394 .27515 m
.75472 .41407 L
s
P
p
.2 0 1 r
.002 w
.68394 .27515 m
.82285 .34594 L
s
P
p
.2 0 1 r
.002 w
.68394 .27515 m
.83793 .25076 L
s
P
p
.2 0 1 r
.002 w
.64576 .20023 m
.75601 .08998 L
s
P
p
.2 0 1 r
.002 w
.64576 .20023 m
.67015 .04624 L
s
P
p
.2 0 1 r
.002 w
.64576 .20023 m
.57498 .06131 L
s
P
p
.2 0 1 r
.002 w
.5863 .25969 m
.44738 .18891 L
s
P
p
.2 0 1 r
.002 w
.5863 .25969 m
.43231 .28408 L
s
P
p
.2 0 1 r
.002 w
.5863 .25969 m
.47606 .36994 L
s
P
p
0 .4 1 r
.018 w
.63763 .25156 m
.68394 .27515 L
s
P
p
0 .4 1 r
.018 w
.63763 .25156 m
.64576 .20023 L
s
P
p
0 .4 1 r
.018 w
.63763 .25156 m
.5863 .25969 L
s
P
p
.2 0 1 r
.002 w
.47399 .60536 m
.4496 .45136 L
s
P
p
.2 0 1 r
.002 w
.47399 .60536 m
.36374 .49511 L
s
P
p
.2 0 1 r
.002 w
.47399 .60536 m
.32 .58097 L
s
P
p
.2 0 1 r
.002 w
.48714 .68841 m
.34822 .75919 L
s
P
p
.2 0 1 r
.002 w
.48714 .68841 m
.41636 .82733 L
s
P
p
.2 0 1 r
.002 w
.48714 .68841 m
.51153 .8424 L
s
P
p
.2 0 1 r
.002 w
.56207 .65023 m
.67231 .76048 L
s
P
p
.2 0 1 r
.002 w
.56207 .65023 m
.71606 .67462 L
s
P
p
.2 0 1 r
.002 w
.56207 .65023 m
.70098 .57945 L
s
P
p
0 .4 1 r
.018 w
.51074 .6421 m
.47399 .60536 L
s
P
p
0 .4 1 r
.018 w
.51074 .6421 m
.48714 .68841 L
s
P
p
0 .4 1 r
.018 w
.51074 .6421 m
.56207 .65023 L
s
P
p
.2 0 1 r
.002 w
.7757 .35619 m
.75131 .51018 L
s
P
p
.2 0 1 r
.002 w
.7757 .35619 m
.84648 .49511 L
s
P
p
.2 0 1 r
.002 w
.7757 .35619 m
.91462 .42697 L
s
P
p
.2 0 1 r
.002 w
.78885 .27314 m
.94284 .24875 L
s
P
p
.2 0 1 r
.002 w
.78885 .27314 m
.8991 .16289 L
s
P
p
.2 0 1 r
.002 w
.78885 .27314 m
.81324 .11915 L
s
P
p
.2 0 1 r
.002 w
.7058 .28629 m
.63502 .14738 L
s
P
p
.2 0 1 r
.002 w
.7058 .28629 m
.56688 .21551 L
s
P
p
.2 0 1 r
.002 w
.7058 .28629 m
.55181 .31068 L
s
P
p
0 .4 1 r
.018 w
.75211 .30989 m
.7757 .35619 L
s
P
p
0 .4 1 r
.018 w
.75211 .30989 m
.78885 .27314 L
s
P
p
0 .4 1 r
.018 w
.75211 .30989 m
.7058 .28629 L
s
P
p
.2 0 1 r
.002 w
.41176 .49993 m
.48254 .36101 L
s
P
p
.2 0 1 r
.002 w
.41176 .49993 m
.38737 .34594 L
s
P
p
.2 0 1 r
.002 w
.41176 .49993 m
.30151 .38968 L
s
P
p
.2 0 1 r
.002 w
.37358 .57485 m
.21959 .55046 L
s
P
p
.2 0 1 r
.002 w
.37358 .57485 m
.23467 .64563 L
s
P
p
.2 0 1 r
.002 w
.37358 .57485 m
.3028 .71377 L
s
P
p
.2 0 1 r
.002 w
.45664 .58801 m
.48103 .742 L
s
P
p
.2 0 1 r
.002 w
.45664 .58801 m
.56688 .69825 L
s
P
p
.2 0 1 r
.002 w
.45664 .58801 m
.61063 .6124 L
s
P
p
0 .4 1 r
.018 w
.41989 .55126 m
.41176 .49993 L
s
P
p
0 .4 1 r
.018 w
.41989 .55126 m
.37358 .57485 L
s
P
p
0 .4 1 r
.018 w
.41989 .55126 m
.45664 .58801 L
s
P
p
.2 0 1 r
.016 w
.60511 .45688 m
.63763 .25156 L
s
P
p
.2 0 1 r
.016 w
.60511 .45688 m
.51074 .6421 L
s
P
p
.2 0 1 r
.016 w
.60511 .45688 m
.75211 .30989 L
s
P
p
.2 0 1 r
.016 w
.60511 .45688 m
.41989 .55126 L
s
P
p
1 .6 0 r
.016 w
.5 .38051 m
.39489 .45688 L
s
P
p
1 .6 0 r
.016 w
.5 .38051 m
.45985 .50408 L
s
P
p
1 .6 0 r
.016 w
.5 .38051 m
.54015 .50408 L
s
P
p
1 .6 0 r
.016 w
.5 .38051 m
.60511 .45688 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`000?l00`0001H000=<04`080000d`0C00N009<00<0C0000T`L00M<7P000d`0
C00P0003C01<020000?60<H05`0001<014d00`1=0002CAX014d00`1=0002CAT014d00`1=0004CAT0
2DdJ00A=00<0CDd00TdJ009=00D0C@1=0002CAX00/H01@360<H000;65000014000Y<04a<04`0C01<
0P000d`0000D000:C01<C01<04`0C08000=<00005@0:C1P03D`F0003C01<00=<00<0C4`00T`00`1<
000E000:C000C01<04`0C08000=<000050002/H00<H0aP360<H20003aP000100000A00a=600;CAH0
3ddD00m=5@02C@0304e=00E=00<0CDd05`0;CAP02lHC00004006C003aP1<00I<5007C00304a<00E<
4`000d`0C004C003aTa<00E<00<0C0004@02C00304a<009<00?6C4`014`00`1<C00A00U<00<0C4`0
1d`B00I<00?604`01T`D00O600<0a/H01LHA00003@000dd00007C@;61Td00`1=000>0003C@0000m=
00<0C@003@000dd00006C@04aTg6aPM=0P000dd0000=00E=00G6CDe=aP07CA4000==04d01Dd00lI=
aP06C@0304d000l000==04d01dd00lI=C@04C@8000==00003@000lH0aP06aP03CLK600G60P000lH0
000<00003@000d`0C004C003aTa<00I<00@0C4a<3`000d`0C00=C00404a<C0`000E<001<0008C003
aTc600I<00D0C000C00=00M<00C6C4c61T`A00I<00?6C4`02T`@00=<00@0C4c61D`01<I<C002C003
04`000h00lH00`36aP03aP03C<K600K600<0aP003@0000T00Td30003C@1=00A=00?6CDd01dd00`1=
00020003C@0000D00Td30003C@1=00i=00<0C@000P000dd000060004C@0000E=00?6CLH02dd30003
C@0000/01Td00lI=0008C@d000A=000024d00lI=C@08C@<000==00001P001Td0001=00I=00?6CDd0
1Td00`1=0002009=1`001/H0003600O60Td6aP030<H000800/H:00002`000d`00005C003aTa<00<A
24`20003C00000P000=<000024`34@Q<0P000d`0000600A<0P07C0<A1d`200A<2@000d`0C007C0<A
00=<aT`01T`<0003C00000I<00?6C1400Q48C08000=<000020000d`00008C0<A24`20003C00000P0
00?600001lH01D`A4A5<00O60P000lH0000:00002`02C@0304e=00E=00DACA5=4@05C@04aTd0C@/0
0Td00`1=C@05C@054DdACA401dd00`1=000:009=0P000lI=C@02C@08aQ5=4DdAC@02C@0404d0009=
2004C@0404e=00A=00DACA5=4@08C@0404e=C@T000==04d00dd0201=CA5=4DdA0Td20005CLI=04d0
30000dd0C@06C@054DdACA401Dd01<I=04d<0003aP3600K600DAaQ5=4@07aP030<K600`0000800E<
00?6C4`014`01a404D`AaQ402d`600]<00LA015<4D`A00]<2002C003aTa<00A<00LAC15<4D`A00U<
2004C003aTa<00A<00LAC15<4@0A00I<00?6C4`00T`600]<00LAaQ5<4LHA00E<00?6C4`00d`600A<
00?6C4`014`01a5<4D`A01402d`600G60T`02lI<a/HAaQ5<4@0A00I<1LH:00002`001Dd0CDg600==
00H0CDdA0142C@0304e=00E=2`000dd0C@05C@0604e=4@0A0Td00`1=C@05C@T00Td00`1=C@08C@03
4DdA00Y=00<0CDd01P02C@<024d00a404@08C@<00Td90003C@1=009=00<0CDd00Td00a404@04C@06
04e=C@1=3003C@05aTe=C@000Td00a404@02C@0304e=00A=00<0C@002P07aP060<K64@0A0Td00`1=
C@04aP030<H000/0000:0004C00000M<00<0C0001d`01LI<001<00T000A<00001d`00`1<0009C080
00=<0000200<C00304a<00Q<00<0C0003004C00304a<009<00<0C4`00T`00`1<C002C0d000=<0000
1D`00`1<C005C00304a<00=<0P000d`000080003C00000M<00D0C01<0005C003aT`0008000=<0000
1`000lH00009aP0304`0009<0/H00dc6aP030003aP0000T000090003C@0000800dd00lI=C@0<C@@0
00==00001@000dd00002019=10000dd0000600M=00?6CDd04Dd;00A=00?6CDd00Td00`1=0004C@03
aTe=009=2`000dd00002015=10000dd000060003C@0000800Td00lI=C@0:C@03aTe=00@000==0000
1@000lH0000200C600==a/H00lH00dg6C@03aP03CLH000<000?60000200000X01D`00`1<aP04C003
04a<00I<00<0aT`00d`800E<00<0C4`014`00`1<C006C00304a<00=<2P0AC004aTa<aP9<3002C003
aTa<00a<00C6C4c60T`:00E<00?6C<H02T`2aPM<2005C00304c600A<00<0C0001T`00`36C003C0P0
1LH01036aT`4aP05C036aT`00lH00`36aP03aP/0000<00A=00?6CLH01dd2aP03CLI=00A=300GC@X0
0dd01P1=CLI=aP==00@0C@1=0/H2C@04aTe=00==2002C@0704e=CLI=aP07C@;61Td00`1=C@0:00A=
00C6CDg61Td00lI=C@06C@`014d00lI=aP07C@;600==aTd014d<00G600==a/H02<H00dg6aP04aPd0
000<0003C01<00I<00?6C4`014`00lI<C002C00304`000/000=<04`04T`00`1<000<009<00<0C4`0
0d`00lI<C003C0;60T`00`1<C00=00E<00D0C<I<aP06C003aP1<00A<30000d`0C006C003aTc600=<
00?6C4`00d`00`1<000;0003C01<00I<00?6C4`014`00lI<C002C00304`000/000?60<H01lH01Dc6
a/I<00K600<0aP00300000/000==04d00P07C@03aTe=009=00C6CDd00Td00`1=00090005C@1=C@00
3dd01@1=C@1=00/02Dd01<I=a/H3C@03aTe=00A=2`05C@801Dd2aP==00?600001Dd:0005C@00C@00
14d01LI=aTg600==00G6CDd0C@020003C@0000P000E=04e=0007C@03aTe=009=00C6CDd00Td00`1=
00090005aP36aP001/H00dg6aP06aP050<K60<H0300000`00T`0101<C002C003aTc6009<00D0C4a<
0002C00304`000d000E<04a<0007C00504a<C0000T`00`1<000<0003C01<00M<00G604a<aP06C003
04`000/00T`00`1<0005C005aP1<C<H00d`00`1<0002C0d014`00`1<C003C00404a<aP9<00<0C4`0
0T`>0005C01<C0000T`00lI<aP06C00504a<04`03P001LH0a/H000_600D0a/H0aP0>00003P02C@03
04e=00A=00<0CDd00dd20003C@0000l00Td00`1=C@04C@0304e=00==0P000dd0000>0003C@1=00m=
0P000dd0000=0004C@1=00E=00<0CDd00dd0101=04d?00==0P05C@0304e=00==0P03C@l00Td200E=
00<0CDd00dd2009=4002aP801LH00`36aP04aP030<K600l0000?0004C01<00A<00<0C0000T`0101<
04`B0004C01<00A<00<0C0000T`0101<04`B009<00<0C4`02D`00`1<C00B0003C01<00=<00D0C01<
0004C00304`0014000A<04`014`00`1<C002C00404`0C18000A<04`00T`01@1<04`0009<00@0C01<
4P001<H0aP02aP030<H000C600@0aP364000010000e=04e=04d0C@1=04d0009=50003Dd0CDd0C@1=
04d0C@000TdF0003C@1=00I=00<0C@005P06C@0304e=00A=5@06C@0304d000I=5004C@0704d0C@1=
0004CA@01<H01`360<H0aP000/H00`36000@00004P0024`0C4`0C01<0P000d`0000F0008C01<C01<
04`20003C00001D000=<04`00d`00`1<0002C00304`001H000=<04`00T`01P1<C4`0C1P000M<04a<
04`0009<00<0C0005`0024`004`0C01<0P000d`0000F0007aP00aP360002aP030<H00180003o00<0
003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0000E009=
00<0CDd0j00001D00T`00`1<C0280003C01<05d0000B0007C@1=C@1=0002C@0304d001P000E=04e=
0003CAh000==04d080000dd0C@0M0006C@00C@1=0P000dd0000J009=00<0CDd07`000dd0C@0G0000
30000d`00004C0801D`200=<0`000d`0000A00A<00<0C4`00T`J009<00D0C01<0002C1X00T`01@1<
04`0009<6P02C00504`0C0000T`J00A<00<0C4`00T`J009<00<0C00014`D000030000dd00002009=
00<0C@000dd00`1=0002C@@000==00003`000dd0C@08C@0304d001D000Y=001=04d0C@1=0P000dd0
000D000:C@00C@1=04d0C@8000==0000500=CAH000==04d024d00`1=000F00==00<0C@0014d00`1=
000A00002@02C00304`000801d`00`36C005C08000A<04a<3`0<C1L03D`F00e<5`0;C1L03D`G00a<
4P0000/000==04d01Td2aP==0/H8CA001Dd00lI=C@07CA@01Td00lH0C@06CA@01Td00lH0C@06CA40
00==04d01dd00lI=aP06C@0304d000h000==04d00Td0101=CLH4C@0604e=C@1=4P06C@03aTe=00I=
4@0000`00T`200M<00G6C4a<aP03C08000=<0000300014`004`20005C<I<C<H014`20004C000C0h0
00=<00001d`2aPI<00<0C0003P000d`00007C003@/I<00E<00<0C0002`0014`004`200E<0/H2C003
aTa<00=<0P0014`004`:0003C01<00801D`00lI<aP05C08000=<04`03@000d`0000>C00404`0C0h0
000900A=00C6C@363Dd00lI=aP05C@X000==04d01Dd00lI=C@08C@0304d000d000==04d014d00lI=
C@06C@0404e=C@l000E=04e=0002C@04aTe=@PE=00@0CDe=30001Dd004d000]=0/H4C@0504d004d0
2P000dd0C@06C@04aTe=C@;61Td00`1=000<0005C@1=C@0014d00lI=C@04C@0504e=04d03P0000d0
1D`00lI<C006C003aTa<00A<3P000d`0C00?C00304`000X00T`30003C01<00E<00?6C4`01T`00`1<
00020003C00000D00T`30003C01<00E<00?604801T`00`1<0002009<1P03C00304`000800T`00`36
C004C004aP1<C0<000=<04`00T`70003C000009<00D0C4a<0007C00504a<C0000T`2009<1`001d`0
04`0C0003D`0101<04`2009<2P0000d02Dd34@M=00?6C@002@02C@801Td00lI=C@034@Q=0P02C@T0
00==000024d34@Q=0P000dd000080003C@0000I=0T834@03@Te=00E=0P000dd0000800==0P02C@80
0Td34@9=0P02C@800dd:0003C@1=00Q=0a400dg6C@06C@0304d000T000==04d024d34@U=00<0C@00
2`0000X02D`2aP054D`AC1402d`900=<00C6C4`00d`01A5<4D`A00=<00H0C<I<04`;009<00<0C4`0
1D`01A5<4D`A00E<00C6C01<30000d`0C006C0054D`A@Q401D`01<I<04`;0004C03600A<00W6015<
4D`A0<H014`0103604`;0003C03600A<00T0C15<4D`AC00014`00lH0C00<009<00c6C4a<04c64D`A
C143C00404a<aP9<3@0000X024d2aP044De=4@9=00DACDe=aP06C@L014d00lI=C@04C@074DdACA5=
4@0;C@H014d00lI=C@04C@074@0ACA764@0;C@H014d00lI2C@02@P9=00LA@Q524@0A00I21Dd80003
C@0000I=00LACA5=4@0A00I=0P000dd0000600A=00?6CDd014d01a5=4DdA01402dd600A=00?6CDd0
14d01a5=4DdA01401Td00lI=C@02C@X0000:0003C01<00M<00K6C15<4@04C003aTa<009<00<0C000
1`02C00304c600M<00<A01400T`00`1<C004C00304`000T000E<04a<aP03C00604a<4@0A0T`00`1<
C005C0/000E<04a<aP03C00604a<4@0A0T800`12@P04C00304`000X00T`200I<00<A01401T`20003
aT`000X01T`00`1<C002C0034@0A00]<2`02C004aTa<00A<00<A01402D`00`1<000;00002@05C@03
aTe=00==00G6CA5=4@0=C@H000==00000P09C@0304e=00E=00?600000P000dd000060004C@0000M=
00<0C@001dd01LI=001=00T000A=00001dd01@1=048000920Td00d;6C@030003C@0000D01Dd0101=
C@03C@0504d0C@000dd01P1=C@1=00==200:C@0504d0C@000dd00`1=aP03C@0304d000P000==04d0
1dd01@1=04d000Q=0P000dd0000900003003C0030<I<00E<00<0C4`01T`00lI<C00>01=<2`000d`0
000200=<00?6C4`034`40003C00000D000=<00000P03C005aTa2C4800d`00d9<@P03C003@P0000<0
00=<000010000d`0C004C0800T`01`1<04`0C0000T`20003C<I<009<00<0C0001P000d`00004C00:
04a<04`0C01<009<00<0C4`00T`30003C00000D000A<00004d`40003C00000P0000;0004C@00aP==
00?604d01Td00lI=C@02C@<000==00001`04C@03aTg600m=00?6CDd00Td800E=00<0CLH014d00`1=
C@06C@030<I=00==2005C@0404g6@P==00<0@P000Td01T9=CDd0aPA=1`03C@0304e=00;600X0CDd0
C@1=04d00Td00`36aP02C@0404e=C@L01Td02lI=CDd0C@1=04d000Y=2007C@03aTe=00a=00?6CDd0
0Td;00002@04C003aP1<00M<00?6C4`014`00lH0aP05C0X044`00lI<C002C0h03D`2aP03C<I<00=<
3P04C003@Ta<00I<0/H00d;6C003C0/000=<04`00T`01<H0C4`20005C01<04`00P02C0030<I<009<
00<0C0002@0?C003aTc600E<3004C003aTc600Y<00?6C4`00d`=00002`000dd0C@04C@03aTg600A=
0/H8C@`014d00lI=C@02C@03aTe=009=0/H7C@`014d00lI=C@02C@03aTe=00A=00?6CDd014d<00A=
00?6CDd00Td00lI2C@02C@03@Tg600I=2`000dd0C@05C@0;04d0C@1=04d0CLH014d00`1=000:00A=
00?6CLH00Td00lI=C@02C@03aTg600I=30000dd0C@0<C@03aTe=00==00<0C@00300000X000=<0000
1T`00lI<0002C003aTa<00M<00<0C0002@001D`0C4`000M<00?6C4`00T`01<I<C002C00304`000T0
00E<04a<0007C003aTa<009<00C6C4`00T`00`1<00090005C01<C0001T`00d;6C003C004aTa<009<
00<0C0002`0:C00504a<C<H01T`<0005C01<C00024`01LI<C4c6009<00D0C4`0C00:0003C00000U<
00?6C4`024`00`1<000;00002@001Dd004d0009=00@0C@0014d2aP08C@1=C@1=04d20003C@0000P0
0Td200A=00O6CLI=aTg600A=0P000dd0000<0005C@1=C@000Td00lI=aP06C@0504e=04d03P001Dd0
CDd0009=00?6CLH01Td01@1=C@1=00d00Td00`1=C@04C@05aTe=CLH01Td00`1=C@0=0003C@1=00I=
00?6CDd01dd00`1=000=0004C@1=00==00?6CLH00dd02<I=CDd0C@1=3P0000`000A<04`00d`00lH0
C003C08000S6C4a<04`0C0l00T`01`1<C4`0C0001D`00`1<C00A009<00<0C4`014`00`1<C003C080
0T`@009<0P05C00304a<00=<0P02C0h000=<04`03d`01@1<C01<00h00d`00`1<0007C00304`000=<
4002C00304a<009<00D0C4a<0004C00304a<00l0000A0004C@1=00E=00@0CDe=500014d0C@04C@03
04e=009=00@0C@1=4P0014d0C@02C@0504d0C@000Td0101=04dB0004C@1=009=00D0C@1=0002C@04
04d0CA400Td00`1=C@0;C@0304e=014000==04d034d00`1=000A00I=00D0CDe=0006CA00000@0003
C00000U<00<0C4`05004C00904`0C01<04`0009<50002d`0C4`0C01<04`000A<5004C00704`0C01<
0004C1@014`00`1<C003C00304a<009<500?C1D000]<04`0C01<04`0C0020003C00000l0000?0005
C@00C@000dd0201=CDd0C@1=5P0024d0CDd0C@1=0P000dd0000F0008C@00C@1=04d20003C@0001H0
00Q=001=04d0C@8000==00006007CAX000Q=001=04d0C@8000==00005P001Dd004d000==0P000dd0
000A00004P000d`0C0050003C01<08@000E<04`0C01L00004P0014d004d30004C@00CND0003o00<0
003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0000h009<00<0C0007@0014`0
04`20003C000084000=<00001`000d`0000A0000=P001Td0CDd0C@8000==00005P000dd00002C@03
04d0009=00<0C@00P00014d004d30004C@00CA<0000f009<00D0C01<0002C1P00T`00`1<C005C003
04`001/000=<04`080000d`0C00P0003C01<01T000A<001<0P001D`0001<008000A<001<400001D0
00?600000/HJ0004C@1=00I=00<0CDd05002C@0304e=00==00<0CDd00dd00`1=C@0F009=00D0C@1=
0002CAX00Td01@1=04d0009=6P02C@0504d0C@000TdD0008C@00C@1=04d50005C@1=04d00P000dd0
000<00005@05aQX03D`E00m<5`02C00504`0C0000T`H000:C000C01<04`0C08000=<000050002T`0
04`0C01<04`20003C00000d000M<001<04`000=<1`03C00404`0C08000=<00002@00018000?60<H0
0Td01@1=aP3601H00Td00`1=C@03C@03aTe=00==00<0CDd05004C@04aTe=aPE=5`0;CAL03DdF00e=
40001Dd0C@1=008000?6C@000Td01P1=C@1=aP8000E=04d0C@0<00004`001/H0aTc6C0?65`04C0;6
0T`2aPE<4P09C003aTc600M<4`05C003aTa<00E<5@06C003aP1<00I<5006C003aP1<00I<4004C080
00?604`01T`0101<0004C0d0000C00;600I=04e=aTdI00E=00?6CLH01DdD00A=0/H00dg6C@08CA00
00==000024d00lI=C@04C@8000==000030000dd00008C@03aTe=00A=0P000dd0000=0003C@1=00M=
00?6CDd014d20003C@0000P024d00`36C@06C@03aTe=009=00<0CDd014d:00004@02aP030<I<00<A
00@0C<K65005C003aTc600]<4`06C00304a<00A<4P001D`004`0009<0/H7C00504`004`03P001D`0
C4`0009<00?6C4`01T`01@1<C01<00l000A<04`00T`00lI<C003C005aTa<04`00P000d`0000:00I<
00?6C4`02T`00lI<aP03C0`0000C009=00DA015=4@02CA<000E=001=0006C@034De=00A=00D0C@00
C@0>00==00@0CDg60Td0115=CLH2C@0404e=C@/00Td30003C@1=00E=00?64Dd01Td00`1=0002009=
2`000dd0C@05C@03aTe=00I=00<0C@003`08C@03aTe=00Q=4002C@03aTe=00A=00<0CDd01dd?0000
2`000lH000050003aQ5<008A0T`00a7600060003aP0000T000E<001<0003C004aTa<4@I<00D0C000
C00>009<00D0C4c60002C0034Da<00A<00<0C4`03@000d`0C003C00504a<aT`00a48C08000=<0000
1P02C0<024`34@Q<0`02C0L00T`200Q<0ml8C0<00T`70005C000C<H03D`01/I<C4c6C08000=<0000
2@0000T00/H8C@094De=4DdA04dA00Q=0/H:0005C@1=C@0014d34@M=00<0C@002`02C@0304d000I=
0a43C@0604e=04d00Td:00==00<0aTd014d01A5=4DdA00E=00?6C@000Td:009=00<0CDd01Dd01A5=
4DdA00E=00?6C@000Td;0003C@1=00I=00GNCMi=gP05C@03aTd0009=2P04C@0304e=00A=0a46C@06
04e=C@1=2`0000/000?600000`0024`0C01<4D`A0P000d`0C0050003aP0000X024`01A404@0A00Q<
3P07C00704`AC15<0002C00504a<04`02P04C003aTa<00A<00LAaQ5<4D`A00]<1P04C003aTa<00A<
00LAC15<4@0A00]<1P04C003aTa<00A<00OOC=m<g`3O00]<2005C003aT`0009<00DAC1404@02C003
aTc600=<00<0C0002`0000/000C600000Td01@1=04dA008000HAC@00C@02C@<000?600001P02C@80
00==04d014d01`1=0140C@0014d00lH0C@02009=2`03C@0404e=C@8A00<04A400dd0101=CDd<009=
00@0CDg60dd01P1=CA404@9=00<0CDd00dd2009=2@001Dd0CDg600==00H0CDdA0142C@0304e=00A=
00<0C@002P03C@05aTe=C@000Td00mh0gP02C@0304e=00A=00<0C@001`0:C@0<aQ5=0140CA40aTg6
1dd:000030000lH0C003009<00T0C000C01<04`00`000d`0aP0;009<00D0aTa<0004C00304`000A<
00D0C4a<0002C0/00T`00`1<C006C00304a<00E<00C604a<2@0014`0000DC0@000=<00001@0014`0
0007C00504`0C0001D`00lI<00020003C00000L000=<00001d`01@1<04`000E<00?6C0000P000d`0
0008009<00C6C<K614`00a5<4@07C003aTa<00d0000<0003aTd000<000==00000Td0101=C@02C@@0
00==aP002P02C@05aTe=C@000Td00`1=C@03C@0304e=00M=3@04C@0304e=00Y=00?6C@003`03C@03
aTe=00e=2`000dd0000200==00?6CDd03Dd40003C@0000D000==00000P02C@03aTe=00e=10000dd0
000500I=00T0CLI=aTdACA401Dd00`1=C@04C@/0000;0004aTc6aP8000E<001<0002C00304`00080
00=<00000/H00d`00007009<0P000d`0C004C00304a<00=<00P0C4a<aT`0C0800T`600A<0P0AC0<0
0d`700M<00?6C4`00d`00`1<C003C003aTa<00E<2005C00304c600A<00<0C0001T`00`36C003C0P0
1D`00`1<aP04C00304`000I<00<0aT`00d`70005C000C00014`00lI<aP02C00604a<C0360T`01<I<
04`20003C00000P0000:0006aP000<H00Td20006C@1=C@1=0`02C@050<H00<H02`000dd00003C@03
aTe=00]=0P000dd0000:01M=3004C@03aTg600Q=00?6CDd01Dd=00e=0/H00dg6C@03C@h03Dd2aP03
CLI=00==40002Dd0CDg6CLI=0006C@0304d000l0000>0004aT`0C08000A<001<0P0014`004`3aPd0
00=<00000P02C003aTc600=<00O6C<K6C<I<00@000=<00001`03C00604a<C<I<0/H<C00404a<C0T0
00=<00001d`2aPA<0/H4C08000=<00002@04C003aTa<009<00?6C4`014`00lI<C004C0`014`00lI<
C002C003aTa<00A<00?6C4`014`<00Y<00?6C4`02T`=00003@000lH00003aP0504d004d00P001Dg6
a/I=008000?600002@0014d00005C@03aTe=00]=0`000dd000050004C@0000==00?604d00dd2aP03
CLI=00M=0`000dd00008009=00<0CDd03Dd00`1=C@0<0005C@1=C@001dd00lI=C@02C@04aTe=009=
00<0C@002@001Dd0CDd000M=00?6CDd00Td01<I=C@02C@0304d000`01Td01LI=CDg600A=00C6CDe=
3`0001000lH00dc6aP02C0040<I<00?63`03C00704a<C<I<0002C003aTc600I<00<0C4`02`03C003
04a<00M<00?6C4`00T`00lI<C002009<300014`0C003C003aTc600M<00@0C01<3P001D`0C4`0009<
00?6C<H01T`01@1<C01<00h000E<04a<0002C003aTc600I<00D0C4`0C00>00Q<00G6C<I<aP08C0h0
000@0004aP00C@;600==a/H00/H014d00<HB00E=00D0CDe=aP03C@0304d000==3@0014d00003C@03
04g6009=00<0aTd00Td0101=CDd30003C@0000/00Td00`1=C@04C@0304e=00A=00<0CDd04002C@80
1Dd00`1=C@03C@800Td@009=0P05C@0304e=00==0P02C@l000M=001=04d000==00C6CDd00Td00`1=
00020003C@0000/0000C0006aP00aP360P000lH0000C0006C01<04`01d`01P1<C4`0C10000=<04`0
0T`00`1<aP09C00304`0014000=<00000T`01@1<04`0009<0P000d`0000A0004C01<009<00D0C01<
0002C00404`0C18000A<04`00T`01@1<04`0009<00@0C01<4`02C00304a<00Y<4@00018000C60036
0P001LH0003601<000E=04e=0002C@0304e=00==00D0CDd0C@020003C@0000`000E=04e=000;C@05
04e=04d050002Dd0C@1=04d0C@0G00A=00L0C@1=04d000A=5004C@0704d0C@1=0004CA<000M=001=
04d000==00<0C@000Td00`1=000?0000<`000d`0C00200=<00L0C000C01<01@000=<04`00P05C005
04a<04`05P0024`004`0C01<0P000d`0000F0008C000C01<04`20003C00001H000Q<001<04`0C080
00=<00006002C00304`0009<5@0003L00Td00`1=0002CAL000E=04e=0007C@0504d004d0P00014d0
04d20003C@0001<0000j0003C00001d00T`00`1<0002C8P000=<00005P0005X000==00000`000dd0
002O0000o`030000o`030000o`030000o`030000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.109416,
   0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110614, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.109419, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.74027, -0.110617, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.109416, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277,
   -0.110614, 0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.1939, -0.109416, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.270008, -1.2634, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  69.375, 37.5625}} -> {-1.42777, -1.26686, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26686, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.88594, -1.2634, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277,
   -1.26686, 0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.1939, -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.270008, -2.41738, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.74027, -2.42311, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277,
   -2.42311, 0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1939, -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .79618 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0780989 0.952381 [
[ 0 0 0 0 ]
[ 1 .79618 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .79618 L
0 .79618 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.23752 .39825 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.20765 .42813 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.18846 .46577 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.26003 .68603 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.29768 .70521 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.33941 .71182 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .57569 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.53337 .53396 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .49223 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.3169 .5075 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.33941 .57677 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.39833 .53396 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.58298 .3819 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.62063 .36272 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.6505 .33284 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.6505 .10126 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.62063 .07138 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.58298 .0522 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.36273 .12376 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.34355 .16141 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.33694 .20314 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .25347 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .18063 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.47198 .20314 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.24938 .2907 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.20765 .29731 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.17 .31649 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.09844 .53674 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.11762 .57439 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.14749 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.37908 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.40896 .57439 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.42814 .53674 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.24938 .42574 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.22687 .49501 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.2997 .49501 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.53847 .48053 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.5802 .48713 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.62193 .48053 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75806 .29317 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75145 .25144 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.73226 .21379 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.51201 .14223 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.47437 .16141 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.44449 .19128 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.5802 .35209 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.62301 .29317 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.55374 .27066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.32219 .21066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.28454 .19147 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.24281 .18486 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .32099 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.04884 .36272 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .40445 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.24281 .54057 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.28454 .53396 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.32219 .51478 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .31991 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.18388 .36272 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .40553 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.35332 .53396 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.51479 .21705 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.26329 .46855 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.5802 .30708 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.2289 .36272 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .53311 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34081 .57484 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .61657 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.53478 .7527 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.57651 .74609 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.61415 .72691 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.68572 .50665 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.66653 .46901 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.63666 .43913 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.47585 .57484 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.53478 .61766 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.55728 .54839 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.61729 .31683 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.63647 .27918 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.64308 .23745 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.50696 .05009 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.46522 .04348 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.42349 .05009 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.28737 .23745 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.29398 .27918 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.31316 .31683 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.50804 .23745 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.46522 .17853 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.42241 .23745 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.29379 .43913 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.26391 .46901 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.24473 .50665 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.3163 .72691 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.35394 .74609 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.39567 .7527 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .61657 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58964 .57484 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .53311 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.37317 .54839 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.39567 .61766 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.4546 .57484 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.63925 .42278 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.67689 .4036 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.70677 .37372 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.70677 .14214 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.67689 .11226 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.63925 .09308 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.419 .16464 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39981 .20229 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39321 .24402 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .29435 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .22151 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.52825 .24402 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.30564 .33158 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.26391 .33819 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.22627 .35737 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.1547 .57762 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.17389 .61527 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.20376 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.43535 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.46522 .61527 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.48441 .57762 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.30564 .46662 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.28314 .53589 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.35597 .53589 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.52087 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.46522 .22354 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.40958 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.57106 .25793 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.31956 .50943 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.51559 .57762 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.53478 .61527 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.56465 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.79624 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.82611 .61527 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.8453 .57762 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.77373 .35737 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.73609 .33819 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.69436 .33158 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.64403 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.71686 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.69436 .46662 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60679 .24402 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60019 .20229 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.581 .16464 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.36075 .09308 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.32311 .11226 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.29323 .14214 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.29323 .37372 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.32311 .4036 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.36075 .42278 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.47175 .24402 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .22151 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .29435 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .53311 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41036 .57484 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .61657 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.60433 .7527 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.64606 .74609 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.6837 .72691 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.75527 .50665 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.73609 .46901 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.70621 .43913 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.5454 .57484 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.60433 .61766 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.62683 .54839 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.68684 .31683 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.70602 .27918 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.71263 .23745 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.57651 .05009 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.53478 .04348 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.49304 .05009 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.35692 .23745 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.36353 .27918 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.38271 .31683 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.57759 .23745 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.53478 .17853 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.49196 .23745 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.36334 .43913 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.33347 .46901 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.31428 .50665 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.38585 .72691 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.42349 .74609 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.46522 .7527 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .61657 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65919 .57484 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .53311 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.44272 .54839 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.46522 .61766 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.52415 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.68044 .50943 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.42894 .25793 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.59042 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.53478 .22354 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.47913 .57484 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.67781 .51478 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.71546 .53396 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.75719 .54057 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .40445 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.95116 .36272 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .32099 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.75719 .18486 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.71546 .19147 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.67781 .21066 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .40553 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.81612 .36272 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .31991 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.55551 .19128 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.52563 .16141 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.48799 .14223 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.26774 .21379 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24855 .25144 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24194 .29317 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.37807 .48053 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.4198 .48713 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.46153 .48053 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.44626 .27066 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.37699 .29317 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.4198 .35209 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.57186 .53674 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.59104 .57439 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.62092 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.85251 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.88238 .57439 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.90156 .53674 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.83 .31649 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.79235 .29731 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.75062 .2907 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.7003 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.77313 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.75062 .42574 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.66306 .20314 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.65645 .16141 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.63727 .12376 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.41702 .0522 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.37937 .07138 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.3495 .10126 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.3495 .33284 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.37937 .36272 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.41702 .3819 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.52802 .20314 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .18063 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .25347 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .49223 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.46663 .53396 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .57569 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.66059 .71182 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.70232 .70521 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.73997 .68603 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.81154 .46577 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.79235 .42813 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.76248 .39825 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.60167 .53396 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.66059 .57677 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.6831 .5075 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.7711 .36272 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.4198 .30708 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.73671 .46855 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.48521 .21705 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.64668 .53396 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.40896 .36272 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.46522 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.53478 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.59104 .36272 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{188, 149},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002l0000U@P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000;`0002l0000_0000;`0002l0000_0000;`0
002l0000_00005L000=<00002@000d`0001F0000CP02C@L000==00000P000dd0C@040003C@0000D0
0Te?0000CP02C0L000=<00000P000d`0C0040003C00000D00Ta?0000CP000dd0C@060003C@000080
00==04d010000dd000040003C@1=04l0001?009<1P000d`000030003C00000<000=<00001002C500
00170003C@0000D00Td60003C@0000<000==00000`000dd00004009=1`000dd000160000A`000d`0
00050003C01<00D000=<00000`000d`000030003C00000<000=<04`01`000d`000160000B0000dd0
0005009=1@000dd000020003C@1=00@000==00000`02C@L000==0000A`0004T000=<00001002C0D0
00=<00000P000d`0C0040003C00000<00T`60003C00004P000130003C@0000<000==000010000dd0
C@040003C@00008000==04d010000dd000020003C@1=00H000==00000`000dd000120000@@03C0H0
00=<00000`000d`0C0040003C000008000=<04`010000d`000020003C01<00D000=<00001003C480
0013009=1P000dd00003009=10001Dd0001=00<000E=0000C@04009=1@000dd00004009=A00003`0
00=<00001@000d`000050003C000008000=<04`00`001D`0001<00<000E<0000C0030003C01<00@0
00=<00001@000d`000050003C00003/0000l0003C@0000D00dd50003C@00008000==04d00`001Dd0
001=00<000E=0000C@030003C@1=00@000==00000`03C@L000==0000>`0003d000=<00001@000d`0
C0050003C00000800T`30004C000C0D000A<001<0`02C0@000=<00000`000d`0C0070003C00003`0
000n0003C@0000800dd20003C@0000<000M=0000C@1=008000A=001=1@0014d004d20003C@1=00<0
00==00000`000dd00003C@@000==0000?@0003l000=<00000`0014`00002C0<000M<0000C01<0080
00A<001<1@0014`004`20003C01<00<000A<00000T`30003C00000<000=<0000?P0003l000==0000
1002C@<000E=0000C@03009=0P000dd0C@070003C@1=00800Td30005C@0004d00`02C@H000==0000
?P0003L00T`70003C00000<000=<04`00`001D`0001<008000U<04`0C01<04`00`002D`0C01<04`0
C0020005C00004`00`000d`0C0050003C00000D00T`h0000>@000dd000050003C@00008000==0000
0Td2009=00d0C@00C@1=04d0C@1=00<000U=04d0C@1=04d00P0014d0CDd2009=0P000dd000020003
C@0000D000==0000>00003X000=<000010000d`000030005C00004`00`002T`0C01<04`0C002C0D0
0T`02P1<04`0C01<04`30005C00004`01@000d`000040003C00003T0000k009=1@000dd000020003
C@0000800Td20006C@1=04d00dd00`1=00040003C@1=009=00H0C@1=04d2009=10000dd000020003
C@0000<00Tdl0000?@000d`00004C0<000=<00001002C00304a<009<00H0C4a<04`50003C01<009<
00<0C4`00T`00`1<C0060004C00000A<0P000d`0000l0000?P000dd0000200==0P000dd00004009=
0P02C@0304e=009=1`04C@0304e=00800Td60003C@0000==10000dd0000m0000?`02C0<000=<04`0
0d`70003C00000G600=<00001@000dc6aP03aP8000=<00001@04C00304`000800Ta00000@@001Dd0
001=008000==04d00Td5009=1LH2C@D00Td5aP9=1@03C@0504d004d00`000dd000100000;@000d`0
000B0005C00004`00P0014`00003C0@01<H014`004`30003C00000C600=<00000P03C0<000A<001<
0`000d`0000B0003C00002`0000]0003C@0000D000==00002`02C@0504d004d01P04C@G60P001Dd0
001=00800/H7C@H000E=001=0002C@d000==00001@000dd0000/0000;@000d`000050003C00000d0
00E<04`0C00:0003C<K600C600D0C01<0004aP=<2P001D`0C01<00l000=<00001@000d`0000/0000
;@000dd000040003C@0000P05dd>aQQ=2P000dd000040003C@0002`0000]0003C00000@000=<0000
4004C0800d`600o61`03C00304a<009<4P000d`000040003C00002`0000]0003C@0000800dd70003
C@0000X00Td500==0`0?aP@00dd4009=30000dd0000500==10000dd0000/0000;@000d`00003009<
1`000d`0000;00?61P04C0;60T`4aP9<1LH3C0D00lH=0003C00000D00T`50003C00002`0000]0003
C@0000<000==04d01@000dd0000<00?61@04aP9=00?6CDd00/H3C@;60Td5aPD00lH>0003C@0000<0
00==04d01@000dd0000/0000;@000d`000030003C000009<0P000d`0000=00C600<0a/H01LH00dc6
aP03C003aTc600?60T`8aP030<K600;63`000d`00002C08000=<00000`000d`0000/0000;@000dd0
00020003C@0000<00Td@00_600==a/H00/H3C@G60Td=aQ000Td50003C@00008000==0000;00002d0
00=<00000P000d`0000QC0C614`2aP04C<I<C0;600=<a/H01<HIC08000=<00000P000d`0000/0000
;@000dd000020003C@0000<000A=04e=3@03C@g60Td00lI=C@0<C@?61Dd=009=00<0C@0010000dd0
00020003C@0002`0000]00E<1@000d`000020003C00000L014`00`1<C006aP03C<K600?600=<04`0
0d`20003aTa<00[60T`00`1<C002C0T000=<00000P000d`000030003C01<009<;P0002d000A=0000
0dd20003C@0000@000==00000`03C@@000E=0000aP04C@G60P06C@800Td5aP9=0/H30003C@000080
0dd50003C@0000@000A=00000dd20003C@0002`0000]0005C00004`00P03C0L01D`5009<0`04C0;6
00I<a/K6C003C0800d`00`1<C004C003aTa<00;600A<00000T`500E<1`04C00304`0008000=<0000
;00002d000A=001=10000dd0C@02C@801Dd60003C@1=00==0/H4C@03aTe=009=00<0CDd01002C@04
04e=009=00C6CDe=0lH4C@0304d000D01Dd300A=100014d004d^0000;@0014`004`30003C0000080
14`40004C00000A<0`04aP9<00C6C4`01D`400E<0P001<I<C4`5aP<014`30003C00000<00d`40005
C00004`00P000d`0000/0000;@0014d004d20004C@00009=1003C@8014d600?600A=0<K60Td00`1=
C@02C@H014d20005aTe=C@001<H600A=0`03C@<00Td30004C@00C@8000==0000;00002d000=<04`0
0`000d`0000:00E<1P02aP=<0/H014c6C003C0P00d`200=<00?6C4`01<H600I<2`001d`0001<04`0
;P0002d000==04d00P000dd0000<0004C@1=C@C600H0a/I=aTd2aP05CLI=C@000Td:009=00@0CDe=
2LH00`36aP02aPA=3P001Td004d0CBh0000]01Q<1LH4C0030<I<00;61D`:00I<1<H00`36aP07aQQ<
;P0002L000==00000`02C@0304d000`000==00001004aP03CLK600C600==aP001Dd300@A0`06C@03
0<K600K600==a/H00/H60003C@0000/000A=04e=1@000dd0000V00009`000d`00003009<00<0C000
2P02C0T00T`6aP05C<K6C00014`200HA0P04C08000=<a/H01LH3C003aP0000L00T`;0004C01<C0D0
00=<00009P0002L000==00000`03C@/000==00002004C@?614d00`1=C@04C@XA1Dd00`1=C@03C@?6
1Dd:0003C@0000T00dd50003C@0002H0000P0003C00000D000A<00000lH;0003C00000P000I<04a<
04`200Y<314:C005aP00C0000T`00`1<00090003C00000T000=<a/H00`000d`000050003C00001l0
000:00==4`000dd000050004C@0000?65002C@<00Td30003CLK600I=0a4200@A0P034@I=00@0a/K6
0`02C@<00TdD0003CLK600<000==00001@000dd0000B009=2`0000d00d`A0003C00000@000A<0000
0lHC009<0`000d`0C0020005C<K6aP000d`44@9<00<04A400Q400`1<C0044@A<00D0a/K6C0020003
C01<00<00T`C0003C<K600<000=<000010000d`0000@00=<3@0001000dd?0003C@0000@000==0<H0
0lH:0003C@0000D000==00000P0014d004d20004CLK6aP==1143C@HA0dd44@==00D0a/K6C@020004
C@00C@@000==00001@000dd000080006CLK6aP1=1P000dd0000>00==400001<00d`<0003C00000@0
00=<0<H00lH20003C00000D000=<000010000d`000030003C01<008000=<0<H00/H00d`A4@024@03
04a<009<0Q42C08A14`00`0A4@024@9<0lH01`1<001<04`01@000d`000040003C00000D000A<001<
0lH00`1<00050003C00000/00d`C00005P03C@X000==00000`000dd0aP02aP04C@00C@L000==0000
0P02C@D000I=001=04d200?6114200A=0Q42C@8A14d200@A0Td2aP8000==04d00P000dd00003009=
10000dd000050004C@00C@?600<0C@0010000dd0000900==5P0001T00d`80003C000008000=<0<H0
0/H01D`0001<00H000E<0000C0060004C000009<0`02aP<A00<0C4`014`34@800a46C005014A4D`0
0/H3009<0`000d`000040005C00004`01P001D`0001<00?600<0C0000`000d`0000700=<6@0001`0
0dd50003C@0000<01<H01Dd0001=00H000A=001=1P001dd0001=04d00`044@M=00<04A4014d24@03
04e=00E=11401lH0001=04d00`000dd000040004C@00C@H000E=0000C@03aP03C@0000<000==0000
1003CA`0000O009<2LH01Dc6a/I<00<000=<00001003C0L000A<00000T`300@A14`2009<00<04A40
14`24@0304a<008014`44@@00T`30003C00000D00d`60005C00004`00lH00dc6aP02aP03C<K600;6
0d`O00002@0HC@W68Dd34@==1@02C@04014A009=00@04A400Td500==0a4RC@?600==a/H00lHHC@X0
000N00=<2LHQC08A0d`6009<0a44C0<A0T`7009<0Q4QC0C600=<a/H00lH0101<C4`N00006`03C@T0
00==00000/H00dg6C@040007C@0004d0C@070003C@00008000==04d01dd6009=0Q46C@8A0Td700M=
0P000dd000020003C@0000D000==04d00`000dd000020005CLK6CLH00P000dd0000800==6`0001P0
0d`=0003C03600;60T`50003C000008000=<000010000d`0000300M<00@0C01<1@02C08A0T`2009<
0Q42C0H000=<04`024`50003C00000@000=<00000P000d`000030007C<K6C<H0C00>00=<600001D0
0dd@0003C@0000;60Td50003C@00008000==00000`000dd0000300A=00P0CDe=04d0C@D000A=4A4A
0Td2009=0a400dd000040004C@1=009=00<0CDd00dd50003C@0000<000==00000P000dd000030004
CLI=aP8000==00003`03CAD0000B00=<50000d`0aP02aP03C00000<000=<00000P000d`000020003
C00000<00d`300=<00@0C01<1@000d`A4@02C0@00T`24@03C00000@000A<04`00T`300=<1P000d`0
00020003C000008000=<00000`001Tc6C<H0C1D00d`B00003`03CAP000==a/H00/H00dd000030005
C@0004d0100014d00004C@<00dd20004C@00C@@000A=4A5=1P0014dA4Dd50005C@00C@000dd300A=
10000dd000020005C@0004d01@02C@04aTg6CAT00dd?00003003C1/000=<a/H00/H00`1<00030005
C00004`00`0014`00004C0@00d`20004C000C0@00a400d`000040004C14A4@D000A<001<0P02C0@0
14`40005C00004`00`000d`000020007C01<aTc6C00L00=<300000X00TdO0006CLK6aP1=10001Dd0
001=008000A=00000dd00`1=000300==0P0014d004d30004CA4AC@P000A=4A5=100014d004d2009=
1@04C@@000A=001=0`000dd000020003C@1=00==80000dd000090000;003aP8000=<00000P0014`0
04`400A<0P0014`00003C0<000I<0000C002C08A2P024@9<0P001D`0001<00800d`40003C01<00=<
1@0014`004`40003C00000=<;@0002`00dd30005C@0004d00P0014d00004C@8000==00000P03C@<0
00A=00001Td:00M=0`0014d00002C@D000==04d00dd40004C@00C@<000A=00000dd]0000;@03C0<0
00A<001<0P000d`0C003C0@000=<00000P03C0<000=<000024`800Q<0`0014`00002C0D000A<0000
14`20004C000C08000E<0000C002aRh0000W009=1002C@05aTd004d00`000dd0C@04C@T00dd400I=
00<0CDd00Td800A=0P04C@0304d000800dd900A=00@0C@1=0`000dd00002C@;61002CBP0000Y0006
C00004c60T`30005C000C0000d`;00=<1004C00304a<00A<2005C00304a<00A<1002C0/014`01@1<
001<00<000A<a/K60`000d`0000X0000:P0024d004g6CLI=0`000dd0C@03C@T000==00000dd200A=
0`03C@0404e=C@H00dd01@1=C@1=008014d3009=0`000dd0000600E=00<0C@000P000dg6aP02aP80
00==0000:@0002/00d`01LI<aP1<00<014`:0003C01<009<0P04C0D00T`2009<1P02C0800d`400A<
0P03C08000=<00001`05C0<000=<0<H00/H3C2`0000]0005CLK6CLH00Td00`1=C@03C@/024d00`1=
000300==0P02C@H00Td200==1@05C@0504e=04d02`04C@800Td4aP03C@0002`0000]0006C<K6C<H0
1d`<00I<0P000d`00002009<0`03C0@00d`3009<1@000d`0C006C0`01d`01036a/H2C2h0000]0005
C@36CLH014d200?62`04C@@000==00000P03C@<00Td4009=1002C@D000A=00001Dd;0004aTg600A=
00H0aTe=04d^00008`03C0L000A<0<K60d`0101<0003aPX014`50004C00000A<0`02C0@00T`400=<
10000d`0000200A<2`000dc6aP0200E<0/H00`1<0007009<900002H00dd40003CLK600==0/H2C@05
0<K6aTd00P02C@@01Dd50004C@00009=00<0C@000P03C@800dd400==10000dd0000300A=1@02C@80
00E=a/K60002C@04aTe=C@?600==00000`03CBH0000Y00=<00C6C<K60T`01/I<a/I<00C600I<0000
C005C08000=<00000P0014`00002C08000A<00000T`2009<100014`0C4`40003C000008000=<04`0
14`20005C00004`01<H00`1<aP04C0G600@0C4a<:@0002/00/H01dg6a/H0CLH00Td00lI=aP03aP03
C@0000801Td20003C@00008000==00000dd20004C@00009=0P02C@@000==04d00Td30003C@000080
00==04d01Td40003CLK600;600==aTd00lH01036a/H3CB`0000Z00?600=<a/H00d`3aP03C<I<00?6
00<0C0001d`40005C00004`00P02C0L01T`7009<0`001D`0001<00<00T`00`1<C002C08000=<0<H0
0/H00dc6C003aP03C01<009<1<H[0000:@04aP03C@0000800dd2aP03CLK600;60P04C@800Td50003
C@0000800dd500M=0P02C@@00dd50003C@0000800dd00`1=C@03C@800lH2C@;600@0CDe=0`05aRX0
000X0003C<K600;600=<00000`000d`0C002aP04C<K6aPA<0`04C0@000=<00000P02C0T01T`7009<
1@000d`0000200=<0`04C0;60T`2aPA<1@000dc6aP02aP03C00002L0000U00A=0lH00`1=00040004
C@0000C61Dd3009=0P000dd000020004C@00009=2@06C@L00Td40003C@00008000A=04e=1002C@C6
0dd30003C@0000<000==0<H00/H4CBH0000Q00A<00D0C4`0C00300A<0P000d`0000200;60d`2aP=<
00<0C4`00`02C0<000=<04`00T`600=<00<0C4`00`03C0@00d`20004C000009<0P02C0800d`5aP03
C<H000<000=<000014`30005C01<C00014`R00007P03C@@000A=001=100014d00004C@800lH2C@06
aTe=CLH00dd50005C@00C@000Td400==1002C@H00dd2009=0P0014d004d400A=00<0a/H02<H200A=
0`000dd000020004C@00C@@00ddO00006`03C0H000A<001<1@000d`00004009<1LH00dc6aP02aPA<
00@0C4a<0`02C00504a<C0000d`600A<2004C00304`0009<0`06C0K600=<a/H00/H3C0H000=<0000
0`0014`004`600=<700001L014d7009=0`000dd000030003C@0000@000==a/H00lH2C@030<K600C6
14d00`1=C@02C@0304e=00==2@04C@X01Dd00`1=C@02C@0304e=009=1/H00`1=C@03C@;600==0000
10000dd000030004C@00009=1`04CAP0000D00=<2P000d`000020003C00000@000=<00001005aP80
0d`00`36aP06aP=<0/H5C0X014`;00E<1lH3C0?600@0C4a<0P03aP03C<H000D000=<000010000d`0
00020003C00000P00d`E00004P02C@/00Td40003C@0000D000==00001004aPD00dd4aP03CLK600?6
9Dd8aP9=0/H3C@D00/H00dg6C@050003C@0000D000==00000P02C@/00TdC00007P000d`000030003
C00000H000A<00000d`3aPL000=<0<H00lH4C0C600<0C4`00T`4aPD00T`2009<1P000lI<C006C0S6
0T`2aP0304`000H00lH4C08000=<00001P000d`000030003C00001d0000L009=1P000dd0000700E=
00<0C@0020000dd0aP02aP05CLI=CLH00dd2009=00<0CLH01<H014d00002C@800Td400==0/H4C@<0
1Td5aP0304d000P000E=04e=0003C@P000==00001002CAd0000K0003C00000D000=<00001@03C080
00A<001<2`001Tc6a/H0C0;600A<a/K614`200O614`200I<0/H3C003aP1<00A<0lH01Dc6a/H000?6
00=<00002@0014`004`300=<1P000d`000050003C00001X0000J0003C@0000D000==00000`03C@@0
00A=001=30001<I=a/H20004CLK6C@?61Dd200K624d00`36C@02C@;60P04C@050<K6aTd00/H00dd0
0004aP`000A=001=1@03C@@000==00001@000dd0000I00006002C0L000A<00000d`5009<0`000d`0
000:00;600I<aP00C002aP9<00?6C4`00`03C0G614`00`1<C003C0?61D`00`1<C002aP9<0/H0101<
0004aP`000A<00000T`600=<0P000d`00005009<6@0001L000==00001`04C@L000==00000P000dd0
000;00;600==00000P000dd00002aP==1/H2C@;60dd2aP==0lH3C@K60Td01<I=a/H20003C@000080
0lH=0003C@00008000==00001P03C@T000==00005P0001H000=<00001P03C0P00T`40003C00000/0
00?6C4`02D`00lI<C00:C003aTa<00=<1/HFC0C63@000d`00002009<2@03C0L000=<00005@0001d0
0dd90003C@0000<000==00003004aP0304d000<000==00000Td00lI=aP07aP==2LH4C@K60Td01<H0
04d40003C@3600?63P000dd000030003C@0000L000==04d07P0001h000=<00001`000d`000040003
C00000`00lH30006C00004`01<H0101<0003C0801<H2C00404a<C0?60`03C00304`000C600<0C000
0P0014`00003aPh000=<000010000d`000070003C00001d0000N0003C@0000D00Td60003C@0000d0
0Td40003C@00008000==a/H00/H0101=CDd500C61Dd4aPD014d4aP03C@00008000==00000P02C@l0
00==00001002C@L000==00007@0001d000=<00001@000d`000050003C00000d00d`50003C0000080
00=<a/H00T`30003C00000800lH00d`0000300=<00?600000P000d`0000200=<00?600000P000d`0
000300=<3`000d`000050003C00000D000=<0000700001`000==00001002C@L000==00003@0014d0
CDd60007C@00CLI=aP0600A=0lH700;61Dd600;60dd00`1=0005009=00<0C@003P000dd00005009=
1P000dd0000K00006`000d`000040003C00000L000=<00003@02C00304`000D00d`2aP03C<H000@0
14`4aPL01<H4C0D01<H0101<C4`50004C01<C0l000=<00001`000d`000040003C00001X0000Q0003
C@0000L000==00003@001Dd0C@1=00<00dd300?600==00000dd400C61`03aP03C@0000800dd200C6
1003C@8000E=04d0C@0?0003C@0000L000==00008000020000=<00001`000d`0000=0007C000C01<
0002C0H00lH00`1<C00700?62@000lI<aP07009<00@0a/K61`001D`0C01<008000=<00003@000d`0
00070003C00001l0000Y0003C@0000d000A=001=0P000dd0000700?60P000dd0000500?62@03aPL0
00==00000lH90004C@00C@8000==00003@000dd0000X0000:@000d`0000=0004C000C08000=<0000
1`02C0<000=<00001@02C0/00T`70004C000009<2@0014`004`20003C00000d000=<0000:00002P0
00==00003@001Dd0001=008000==00001P03C@@000==00000`03C@/00dd50003C@0000800dd80004
C@00C@<000==00003@000dd0000W00009`000d`0000=0005C00004`00`000d`000050004C01<C0D0
00I<0000C002C0/00T`00`1<00020003C00000<00T`00`1<00060005C00004`00`000d`0000=0003
C00002H0000V0003C@0000d000==00000P001Dd0001=00L00Td00`1=00050003C@00009=00<0C@00
2P0014d0CDd20003C@0000@000A=04e=1`001Dd0001=00@000==00003@000dd0000U0000=P000d`0
00020005C00004`01P001D`0C01<00P000E<04`0C00;0005C01<04`020001D`0C01<00H000E<0000
C0040003C00003D0000e0003C@00008000==00000P000dd000030006C@00C@1=1`001Td004d0C@/0
00==04d00P000dd000050003C@1=008000==00000`000dd000020003C@00008000==0000=00003@0
00=<00000`000d`000020003C00000<000=<04`00P000d`000050003C01<008000=<00002@001T`0
04`0C0L000I<001<04`50003C000008000=<00000`000d`0000c0000<`000dd000040003C@000080
00==00000P0014d004d20003C@0000@000A=001=0P000dd000090004C@00C@8000==0000100014d0
04d20003C@00008000==00000P000dd000040003C@000380000c0003C00000<000=<00000`001D`0
001<00<000A<001<1@001D`0001<008000=<00002@0014`004`30003C00000<000A<001<0`001D`0
001<00D000=<00000`000d`0000b0000<P000dd000040003C@0000<000A=001=0`001Dd0001=00@0
00E=0000C@030003C@0000T000E=0000C@030003C@00008000E=0000C@030004C@00C@D000==0000
10000dd0000a0000<@000d`000050003C00000<000A<001<0`001D`0001<00@000E<0000C0030003
C00000T000E<0000C0030003C000008000E<0000C0030004C000C0D000=<00001@000d`0000`0000
<0000dd000050003C@0000@000==04d010001Dd0001=00<000==00000P001Dd0001=00/000E=0000
C@040005C@0004d00`000dd000020003C@1=00H000==00001@000dd0000_0000>0000d`00004009<
10000d`000020004C000C0@000=<00000P000d`000090003C000008000=<00000P0014`004`40003
C00000800T`60003C00003L0000h0003C@0000@00Td40003C@00008000A=001=10000dd000020003
C@0000T000==00000P000dd000020004C@00C@@000==00000P02C@H000==0000=`0003L000=<0000
1@000d`000030003C000008000=<04`01@000d`000020003C00000T000=<00000P000d`000030003
C01<00@000=<00000`000d`000050003C00003H0000g0003C@0000@00Td40003C@0000<00Td50003
C@0000<000==00002@000dd000030003C@0000<00Td50003C@0000800Td60003C@0003H0000m0003
C01<00@000=<00000`000d`000040003C00000<000=<00002@000d`000030003C00000@000=<0000
0`000d`000020003C01<03h0000m0003C@0000@000==00000`000dd000040003C@0000<000==0000
2@000dd000030003C@0000@000==00000`000dd000040003C@0003`0000l0003C00000@000=<0000
0`02C0D000=<000010000d`000090003C00000@000=<00000`02C0D000=<000010000d`0000k0000
>`000dd000050003C@00008000==04d01@000dd000040003C@0000T000==000010000dd000030003
C@1=00@000==00001@000dd0000j0000@`000d`000040003C00000<000=<000010000d`000090003
C00000@000=<00000`000d`000040003C000048000120003C@0000D000==00000P000dd000050003
C@0000T000==00001@000dd000020003C@0000D000==0000@@00048000=<00001@000d`000020003
C00000D000=<00002@000d`000050003C000008000=<00001@000d`000110000BP000dd0000:0003
C@0000T000==00002P000dd000190000_0000;`0002l0000_0000;`0002l0000_0000;`00000\
\>"],
  ImageRangeCache->{{{0, 187}, {148, 0}} -> {-0.028147, 0.0819997, 0.00564863,
   0.00564863}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .42105 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.136054 0.0100251 0.136054 [
[ 0 0 0 0 ]
[ 1 .42105 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
P
0 0 m
1 0 L
1 .42105 L
0 .42105 L
closepath
clip
newpath
p
p
% Start of sub-graphic
p
0.0238095 0.0100251 0.149123 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0780989 0.952381 [
[ 0 0 0 0 ]
[ 1 .79618 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79618 L
0 .79618 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.23752 .39825 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.20765 .42813 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.18846 .46577 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.26003 .68603 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.29768 .70521 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.33941 .71182 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .57569 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.53337 .53396 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .49223 L
s
P
p
0 .4 1 r
.02 w
.35332 .53396 m
.3169 .5075 L
s
P
p
0 .4 1 r
.02 w
.35332 .53396 m
.33941 .57677 L
s
P
p
0 .4 1 r
.02 w
.35332 .53396 m
.39833 .53396 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.58298 .3819 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.62063 .36272 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.6505 .33284 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.6505 .10126 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.62063 .07138 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.58298 .0522 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.36273 .12376 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.34355 .16141 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.33694 .20314 L
s
P
p
0 .4 1 r
.02 w
.51479 .21705 m
.54125 .25347 L
s
P
p
0 .4 1 r
.02 w
.51479 .21705 m
.54125 .18063 L
s
P
p
0 .4 1 r
.02 w
.51479 .21705 m
.47198 .20314 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.24938 .2907 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.20765 .29731 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.17 .31649 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.09844 .53674 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.11762 .57439 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.14749 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.37908 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.40896 .57439 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.42814 .53674 L
s
P
p
0 .4 1 r
.02 w
.26329 .46855 m
.24938 .42574 L
s
P
p
0 .4 1 r
.02 w
.26329 .46855 m
.22687 .49501 L
s
P
p
0 .4 1 r
.02 w
.26329 .46855 m
.2997 .49501 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.53847 .48053 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.5802 .48713 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.62193 .48053 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75806 .29317 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75145 .25144 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.73226 .21379 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.51201 .14223 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.47437 .16141 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.44449 .19128 L
s
P
p
0 .4 1 r
.02 w
.5802 .30708 m
.5802 .35209 L
s
P
p
0 .4 1 r
.02 w
.5802 .30708 m
.62301 .29317 L
s
P
p
0 .4 1 r
.02 w
.5802 .30708 m
.55374 .27066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.32219 .21066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.28454 .19147 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.24281 .18486 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .32099 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.04884 .36272 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .40445 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.24281 .54057 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.28454 .53396 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.32219 .51478 L
s
P
p
0 .4 1 r
.02 w
.2289 .36272 m
.24281 .31991 L
s
P
p
0 .4 1 r
.02 w
.2289 .36272 m
.18388 .36272 L
s
P
p
0 .4 1 r
.02 w
.2289 .36272 m
.24281 .40553 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.35332 .53396 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.51479 .21705 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.26329 .46855 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.5802 .30708 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.2289 .36272 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .53311 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34081 .57484 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .61657 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.53478 .7527 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.57651 .74609 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.61415 .72691 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.68572 .50665 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.66653 .46901 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.63666 .43913 L
s
P
p
0 .4 1 r
.02 w
.52087 .57484 m
.47585 .57484 L
s
P
p
0 .4 1 r
.02 w
.52087 .57484 m
.53478 .61766 L
s
P
p
0 .4 1 r
.02 w
.52087 .57484 m
.55728 .54839 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.61729 .31683 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.63647 .27918 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.64308 .23745 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.50696 .05009 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.46522 .04348 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.42349 .05009 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.28737 .23745 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.29398 .27918 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.31316 .31683 L
s
P
p
0 .4 1 r
.02 w
.46522 .22354 m
.50804 .23745 L
s
P
p
0 .4 1 r
.02 w
.46522 .22354 m
.46522 .17853 L
s
P
p
0 .4 1 r
.02 w
.46522 .22354 m
.42241 .23745 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.29379 .43913 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.26391 .46901 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.24473 .50665 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.3163 .72691 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.35394 .74609 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.39567 .7527 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .61657 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58964 .57484 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .53311 L
s
P
p
0 .4 1 r
.02 w
.40958 .57484 m
.37317 .54839 L
s
P
p
0 .4 1 r
.02 w
.40958 .57484 m
.39567 .61766 L
s
P
p
0 .4 1 r
.02 w
.40958 .57484 m
.4546 .57484 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.63925 .42278 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.67689 .4036 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.70677 .37372 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.70677 .14214 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.67689 .11226 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.63925 .09308 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.419 .16464 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39981 .20229 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39321 .24402 L
s
P
p
0 .4 1 r
.02 w
.57106 .25793 m
.59752 .29435 L
s
P
p
0 .4 1 r
.02 w
.57106 .25793 m
.59752 .22151 L
s
P
p
0 .4 1 r
.02 w
.57106 .25793 m
.52825 .24402 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.30564 .33158 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.26391 .33819 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.22627 .35737 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.1547 .57762 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.17389 .61527 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.20376 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.43535 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.46522 .61527 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.48441 .57762 L
s
P
p
0 .4 1 r
.02 w
.31956 .50943 m
.30564 .46662 L
s
P
p
0 .4 1 r
.02 w
.31956 .50943 m
.28314 .53589 L
s
P
p
0 .4 1 r
.02 w
.31956 .50943 m
.35597 .53589 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.52087 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.46522 .22354 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.40958 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.57106 .25793 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.31956 .50943 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.51559 .57762 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.53478 .61527 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.56465 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.79624 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.82611 .61527 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.8453 .57762 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.77373 .35737 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.73609 .33819 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.69436 .33158 L
s
P
p
0 .4 1 r
.02 w
.68044 .50943 m
.64403 .53589 L
s
P
p
0 .4 1 r
.02 w
.68044 .50943 m
.71686 .53589 L
s
P
p
0 .4 1 r
.02 w
.68044 .50943 m
.69436 .46662 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60679 .24402 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60019 .20229 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.581 .16464 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.36075 .09308 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.32311 .11226 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.29323 .14214 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.29323 .37372 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.32311 .4036 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.36075 .42278 L
s
P
p
0 .4 1 r
.02 w
.42894 .25793 m
.47175 .24402 L
s
P
p
0 .4 1 r
.02 w
.42894 .25793 m
.40248 .22151 L
s
P
p
0 .4 1 r
.02 w
.42894 .25793 m
.40248 .29435 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .53311 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41036 .57484 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .61657 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.60433 .7527 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.64606 .74609 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.6837 .72691 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.75527 .50665 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.73609 .46901 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.70621 .43913 L
s
P
p
0 .4 1 r
.02 w
.59042 .57484 m
.5454 .57484 L
s
P
p
0 .4 1 r
.02 w
.59042 .57484 m
.60433 .61766 L
s
P
p
0 .4 1 r
.02 w
.59042 .57484 m
.62683 .54839 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.68684 .31683 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.70602 .27918 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.71263 .23745 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.57651 .05009 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.53478 .04348 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.49304 .05009 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.35692 .23745 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.36353 .27918 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.38271 .31683 L
s
P
p
0 .4 1 r
.02 w
.53478 .22354 m
.57759 .23745 L
s
P
p
0 .4 1 r
.02 w
.53478 .22354 m
.53478 .17853 L
s
P
p
0 .4 1 r
.02 w
.53478 .22354 m
.49196 .23745 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.36334 .43913 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.33347 .46901 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.31428 .50665 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.38585 .72691 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.42349 .74609 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.46522 .7527 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .61657 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65919 .57484 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .53311 L
s
P
p
0 .4 1 r
.02 w
.47913 .57484 m
.44272 .54839 L
s
P
p
0 .4 1 r
.02 w
.47913 .57484 m
.46522 .61766 L
s
P
p
0 .4 1 r
.02 w
.47913 .57484 m
.52415 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.68044 .50943 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.42894 .25793 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.59042 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.53478 .22354 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.47913 .57484 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.67781 .51478 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.71546 .53396 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.75719 .54057 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .40445 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.95116 .36272 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .32099 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.75719 .18486 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.71546 .19147 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.67781 .21066 L
s
P
p
0 .4 1 r
.02 w
.7711 .36272 m
.75719 .40553 L
s
P
p
0 .4 1 r
.02 w
.7711 .36272 m
.81612 .36272 L
s
P
p
0 .4 1 r
.02 w
.7711 .36272 m
.75719 .31991 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.55551 .19128 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.52563 .16141 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.48799 .14223 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.26774 .21379 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24855 .25144 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24194 .29317 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.37807 .48053 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.4198 .48713 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.46153 .48053 L
s
P
p
0 .4 1 r
.02 w
.4198 .30708 m
.44626 .27066 L
s
P
p
0 .4 1 r
.02 w
.4198 .30708 m
.37699 .29317 L
s
P
p
0 .4 1 r
.02 w
.4198 .30708 m
.4198 .35209 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.57186 .53674 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.59104 .57439 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.62092 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.85251 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.88238 .57439 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.90156 .53674 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.83 .31649 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.79235 .29731 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.75062 .2907 L
s
P
p
0 .4 1 r
.02 w
.73671 .46855 m
.7003 .49501 L
s
P
p
0 .4 1 r
.02 w
.73671 .46855 m
.77313 .49501 L
s
P
p
0 .4 1 r
.02 w
.73671 .46855 m
.75062 .42574 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.66306 .20314 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.65645 .16141 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.63727 .12376 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.41702 .0522 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.37937 .07138 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.3495 .10126 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.3495 .33284 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.37937 .36272 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.41702 .3819 L
s
P
p
0 .4 1 r
.02 w
.48521 .21705 m
.52802 .20314 L
s
P
p
0 .4 1 r
.02 w
.48521 .21705 m
.45875 .18063 L
s
P
p
0 .4 1 r
.02 w
.48521 .21705 m
.45875 .25347 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .49223 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.46663 .53396 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .57569 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.66059 .71182 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.70232 .70521 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.73997 .68603 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.81154 .46577 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.79235 .42813 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.76248 .39825 L
s
P
p
0 .4 1 r
.02 w
.64668 .53396 m
.60167 .53396 L
s
P
p
0 .4 1 r
.02 w
.64668 .53396 m
.66059 .57677 L
s
P
p
0 .4 1 r
.02 w
.64668 .53396 m
.6831 .5075 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.7711 .36272 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.4198 .30708 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.73671 .46855 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.48521 .21705 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.64668 .53396 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.40896 .36272 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.46522 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.53478 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.59104 .36272 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.0100251 0.286967 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0780989 0.952381 [
[ 0 0 0 0 ]
[ 1 .79618 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79618 L
0 .79618 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.23752 .39825 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.20765 .42813 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.18846 .46577 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.26003 .68603 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.29768 .70521 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.33941 .71182 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .57569 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.53337 .53396 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .49223 L
s
P
p
0 1 1 r
.018 w
.35332 .53396 m
.3169 .5075 L
s
P
p
0 1 1 r
.018 w
.35332 .53396 m
.33941 .57677 L
s
P
p
0 1 1 r
.018 w
.35332 .53396 m
.39833 .53396 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.58298 .3819 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.62063 .36272 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.6505 .33284 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.6505 .10126 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.62063 .07138 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.58298 .0522 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.36273 .12376 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.34355 .16141 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.33694 .20314 L
s
P
p
0 1 1 r
.018 w
.51479 .21705 m
.54125 .25347 L
s
P
p
0 1 1 r
.018 w
.51479 .21705 m
.54125 .18063 L
s
P
p
0 1 1 r
.018 w
.51479 .21705 m
.47198 .20314 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.24938 .2907 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.20765 .29731 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.17 .31649 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.09844 .53674 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.11762 .57439 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.14749 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.37908 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.40896 .57439 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.42814 .53674 L
s
P
p
0 1 1 r
.018 w
.26329 .46855 m
.24938 .42574 L
s
P
p
0 1 1 r
.018 w
.26329 .46855 m
.22687 .49501 L
s
P
p
0 1 1 r
.018 w
.26329 .46855 m
.2997 .49501 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.53847 .48053 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.5802 .48713 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.62193 .48053 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75806 .29317 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75145 .25144 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.73226 .21379 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.51201 .14223 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.47437 .16141 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.44449 .19128 L
s
P
p
0 1 1 r
.018 w
.5802 .30708 m
.5802 .35209 L
s
P
p
0 1 1 r
.018 w
.5802 .30708 m
.62301 .29317 L
s
P
p
0 1 1 r
.018 w
.5802 .30708 m
.55374 .27066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.32219 .21066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.28454 .19147 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.24281 .18486 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .32099 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.04884 .36272 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .40445 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.24281 .54057 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.28454 .53396 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.32219 .51478 L
s
P
p
0 1 1 r
.018 w
.2289 .36272 m
.24281 .31991 L
s
P
p
0 1 1 r
.018 w
.2289 .36272 m
.18388 .36272 L
s
P
p
0 1 1 r
.018 w
.2289 .36272 m
.24281 .40553 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.35332 .53396 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.51479 .21705 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.26329 .46855 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.5802 .30708 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.2289 .36272 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .53311 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34081 .57484 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .61657 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.53478 .7527 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.57651 .74609 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.61415 .72691 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.68572 .50665 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.66653 .46901 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.63666 .43913 L
s
P
p
0 1 1 r
.018 w
.52087 .57484 m
.47585 .57484 L
s
P
p
0 1 1 r
.018 w
.52087 .57484 m
.53478 .61766 L
s
P
p
0 1 1 r
.018 w
.52087 .57484 m
.55728 .54839 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.61729 .31683 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.63647 .27918 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.64308 .23745 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.50696 .05009 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.46522 .04348 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.42349 .05009 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.28737 .23745 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.29398 .27918 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.31316 .31683 L
s
P
p
0 1 1 r
.018 w
.46522 .22354 m
.50804 .23745 L
s
P
p
0 1 1 r
.018 w
.46522 .22354 m
.46522 .17853 L
s
P
p
0 1 1 r
.018 w
.46522 .22354 m
.42241 .23745 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.29379 .43913 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.26391 .46901 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.24473 .50665 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.3163 .72691 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.35394 .74609 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.39567 .7527 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .61657 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58964 .57484 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .53311 L
s
P
p
0 1 1 r
.018 w
.40958 .57484 m
.37317 .54839 L
s
P
p
0 1 1 r
.018 w
.40958 .57484 m
.39567 .61766 L
s
P
p
0 1 1 r
.018 w
.40958 .57484 m
.4546 .57484 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.63925 .42278 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.67689 .4036 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.70677 .37372 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.70677 .14214 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.67689 .11226 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.63925 .09308 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.419 .16464 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39981 .20229 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39321 .24402 L
s
P
p
0 1 1 r
.018 w
.57106 .25793 m
.59752 .29435 L
s
P
p
0 1 1 r
.018 w
.57106 .25793 m
.59752 .22151 L
s
P
p
0 1 1 r
.018 w
.57106 .25793 m
.52825 .24402 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.30564 .33158 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.26391 .33819 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.22627 .35737 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.1547 .57762 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.17389 .61527 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.20376 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.43535 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.46522 .61527 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.48441 .57762 L
s
P
p
0 1 1 r
.018 w
.31956 .50943 m
.30564 .46662 L
s
P
p
0 1 1 r
.018 w
.31956 .50943 m
.28314 .53589 L
s
P
p
0 1 1 r
.018 w
.31956 .50943 m
.35597 .53589 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.52087 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.46522 .22354 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.40958 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.57106 .25793 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.31956 .50943 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.51559 .57762 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.53478 .61527 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.56465 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.79624 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.82611 .61527 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.8453 .57762 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.77373 .35737 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.73609 .33819 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.69436 .33158 L
s
P
p
0 1 1 r
.018 w
.68044 .50943 m
.64403 .53589 L
s
P
p
0 1 1 r
.018 w
.68044 .50943 m
.71686 .53589 L
s
P
p
0 1 1 r
.018 w
.68044 .50943 m
.69436 .46662 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60679 .24402 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60019 .20229 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.581 .16464 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.36075 .09308 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.32311 .11226 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.29323 .14214 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.29323 .37372 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.32311 .4036 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.36075 .42278 L
s
P
p
0 1 1 r
.018 w
.42894 .25793 m
.47175 .24402 L
s
P
p
0 1 1 r
.018 w
.42894 .25793 m
.40248 .22151 L
s
P
p
0 1 1 r
.018 w
.42894 .25793 m
.40248 .29435 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .53311 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41036 .57484 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .61657 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.60433 .7527 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.64606 .74609 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.6837 .72691 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.75527 .50665 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.73609 .46901 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.70621 .43913 L
s
P
p
0 1 1 r
.018 w
.59042 .57484 m
.5454 .57484 L
s
P
p
0 1 1 r
.018 w
.59042 .57484 m
.60433 .61766 L
s
P
p
0 1 1 r
.018 w
.59042 .57484 m
.62683 .54839 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.68684 .31683 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.70602 .27918 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.71263 .23745 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.57651 .05009 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.53478 .04348 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.49304 .05009 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.35692 .23745 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.36353 .27918 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.38271 .31683 L
s
P
p
0 1 1 r
.018 w
.53478 .22354 m
.57759 .23745 L
s
P
p
0 1 1 r
.018 w
.53478 .22354 m
.53478 .17853 L
s
P
p
0 1 1 r
.018 w
.53478 .22354 m
.49196 .23745 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.36334 .43913 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.33347 .46901 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.31428 .50665 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.38585 .72691 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.42349 .74609 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.46522 .7527 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .61657 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65919 .57484 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .53311 L
s
P
p
0 1 1 r
.018 w
.47913 .57484 m
.44272 .54839 L
s
P
p
0 1 1 r
.018 w
.47913 .57484 m
.46522 .61766 L
s
P
p
0 1 1 r
.018 w
.47913 .57484 m
.52415 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.68044 .50943 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.42894 .25793 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.59042 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.53478 .22354 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.47913 .57484 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.67781 .51478 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.71546 .53396 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.75719 .54057 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .40445 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.95116 .36272 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .32099 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.75719 .18486 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.71546 .19147 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.67781 .21066 L
s
P
p
0 1 1 r
.018 w
.7711 .36272 m
.75719 .40553 L
s
P
p
0 1 1 r
.018 w
.7711 .36272 m
.81612 .36272 L
s
P
p
0 1 1 r
.018 w
.7711 .36272 m
.75719 .31991 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.55551 .19128 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.52563 .16141 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.48799 .14223 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.26774 .21379 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24855 .25144 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24194 .29317 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.37807 .48053 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.4198 .48713 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.46153 .48053 L
s
P
p
0 1 1 r
.018 w
.4198 .30708 m
.44626 .27066 L
s
P
p
0 1 1 r
.018 w
.4198 .30708 m
.37699 .29317 L
s
P
p
0 1 1 r
.018 w
.4198 .30708 m
.4198 .35209 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.57186 .53674 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.59104 .57439 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.62092 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.85251 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.88238 .57439 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.90156 .53674 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.83 .31649 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.79235 .29731 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.75062 .2907 L
s
P
p
0 1 1 r
.018 w
.73671 .46855 m
.7003 .49501 L
s
P
p
0 1 1 r
.018 w
.73671 .46855 m
.77313 .49501 L
s
P
p
0 1 1 r
.018 w
.73671 .46855 m
.75062 .42574 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.66306 .20314 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.65645 .16141 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.63727 .12376 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.41702 .0522 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.37937 .07138 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.3495 .10126 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.3495 .33284 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.37937 .36272 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.41702 .3819 L
s
P
p
0 1 1 r
.018 w
.48521 .21705 m
.52802 .20314 L
s
P
p
0 1 1 r
.018 w
.48521 .21705 m
.45875 .18063 L
s
P
p
0 1 1 r
.018 w
.48521 .21705 m
.45875 .25347 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .49223 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.46663 .53396 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .57569 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.66059 .71182 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.70232 .70521 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.73997 .68603 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.81154 .46577 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.79235 .42813 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.76248 .39825 L
s
P
p
0 1 1 r
.018 w
.64668 .53396 m
.60167 .53396 L
s
P
p
0 1 1 r
.018 w
.64668 .53396 m
.66059 .57677 L
s
P
p
0 1 1 r
.018 w
.64668 .53396 m
.6831 .5075 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.7711 .36272 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.4198 .30708 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.73671 .46855 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.48521 .21705 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.64668 .53396 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.40896 .36272 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.46522 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.53478 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.59104 .36272 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.0100251 0.424812 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0784758 0.952381 [
[ 0 0 0 0 ]
[ 1 .79543 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79543 L
0 .79543 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.31622 .50753 m
.22038 .41169 L
s
P
p
.2 0 1 r
.002 w
.31622 .50753 m
.19546 .446 L
s
P
p
.2 0 1 r
.002 w
.33881 .57705 m
.27728 .69782 L
s
P
p
.2 0 1 r
.002 w
.33881 .57705 m
.31761 .71093 L
s
P
p
.2 0 1 r
.002 w
.39796 .53409 m
.53183 .55529 L
s
P
p
.2 0 1 r
.002 w
.39796 .53409 m
.53183 .51288 L
s
P
p
0 .4 1 r
.018 w
.35278 .53409 m
.31622 .50753 L
s
P
p
0 .4 1 r
.018 w
.35278 .53409 m
.33881 .57705 L
s
P
p
0 .4 1 r
.018 w
.35278 .53409 m
.39796 .53409 L
s
P
p
.2 0 1 r
.002 w
.5414 .25256 m
.60294 .37332 L
s
P
p
.2 0 1 r
.002 w
.5414 .25256 m
.63724 .3484 L
s
P
p
.2 0 1 r
.002 w
.5414 .17945 m
.63724 .08361 L
s
P
p
.2 0 1 r
.002 w
.5414 .17945 m
.60294 .05869 L
s
P
p
.2 0 1 r
.002 w
.47188 .20204 m
.35111 .14051 L
s
P
p
.2 0 1 r
.002 w
.47188 .20204 m
.33801 .18084 L
s
P
p
0 .4 1 r
.018 w
.51485 .21601 m
.5414 .25256 L
s
P
p
0 .4 1 r
.018 w
.51485 .21601 m
.5414 .17945 L
s
P
p
0 .4 1 r
.018 w
.51485 .21601 m
.47188 .20204 L
s
P
p
.2 0 1 r
.002 w
.24845 .42547 m
.22725 .2916 L
s
P
p
.2 0 1 r
.002 w
.24845 .42547 m
.18692 .3047 L
s
P
p
.2 0 1 r
.002 w
.22586 .49499 m
.1051 .55653 L
s
P
p
.2 0 1 r
.002 w
.22586 .49499 m
.13002 .59083 L
s
P
p
.2 0 1 r
.002 w
.29897 .49499 m
.39481 .59083 L
s
P
p
.2 0 1 r
.002 w
.29897 .49499 m
.41973 .55653 L
s
P
p
0 .4 1 r
.018 w
.26242 .46844 m
.24845 .42547 L
s
P
p
0 .4 1 r
.018 w
.26242 .46844 m
.22586 .49499 L
s
P
p
0 .4 1 r
.018 w
.26242 .46844 m
.29897 .49499 L
s
P
p
.2 0 1 r
.002 w
.5805 .35155 m
.55929 .48542 L
s
P
p
.2 0 1 r
.002 w
.5805 .35155 m
.6017 .48542 L
s
P
p
.2 0 1 r
.002 w
.62347 .2924 m
.75734 .2712 L
s
P
p
.2 0 1 r
.002 w
.62347 .2924 m
.74423 .23087 L
s
P
p
.2 0 1 r
.002 w
.55394 .26981 m
.49241 .14905 L
s
P
p
.2 0 1 r
.002 w
.55394 .26981 m
.4581 .17397 L
s
P
p
0 .4 1 r
.018 w
.5805 .30637 m
.5805 .35155 L
s
P
p
0 .4 1 r
.018 w
.5805 .30637 m
.62347 .2924 L
s
P
p
0 .4 1 r
.018 w
.5805 .30637 m
.55394 .26981 L
s
P
p
.2 0 1 r
.002 w
.24186 .31924 m
.3034 .19848 L
s
P
p
.2 0 1 r
.002 w
.24186 .31924 m
.26307 .18537 L
s
P
p
.2 0 1 r
.002 w
.18272 .36221 m
.04885 .34101 L
s
P
p
.2 0 1 r
.002 w
.18272 .36221 m
.04885 .38341 L
s
P
p
.2 0 1 r
.002 w
.24186 .40518 m
.26307 .53905 L
s
P
p
.2 0 1 r
.002 w
.24186 .40518 m
.3034 .52595 L
s
P
p
0 .4 1 r
.018 w
.2279 .36221 m
.24186 .31924 L
s
P
p
0 .4 1 r
.018 w
.2279 .36221 m
.18272 .36221 L
s
P
p
0 .4 1 r
.018 w
.2279 .36221 m
.24186 .40518 L
s
P
p
.2 0 1 r
.016 w
.40862 .36221 m
.35278 .53409 L
s
P
p
.2 0 1 r
.016 w
.40862 .36221 m
.51485 .21601 L
s
P
p
.2 0 1 r
.016 w
.40862 .36221 m
.26242 .46844 L
s
P
p
.2 0 1 r
.016 w
.40862 .36221 m
.5805 .30637 L
s
P
p
.2 0 1 r
.016 w
.40862 .36221 m
.2279 .36221 L
s
P
p
.2 0 1 r
.002 w
.47576 .57512 m
.34189 .55391 L
s
P
p
.2 0 1 r
.002 w
.47576 .57512 m
.34189 .59632 L
s
P
p
.2 0 1 r
.002 w
.5349 .61809 m
.55611 .75196 L
s
P
p
.2 0 1 r
.002 w
.5349 .61809 m
.59644 .73885 L
s
P
p
.2 0 1 r
.002 w
.55749 .54856 m
.67826 .48703 L
s
P
p
.2 0 1 r
.002 w
.55749 .54856 m
.65333 .45272 L
s
P
p
0 .4 1 r
.018 w
.52094 .57512 m
.47576 .57512 L
s
P
p
0 .4 1 r
.018 w
.52094 .57512 m
.5349 .61809 L
s
P
p
0 .4 1 r
.018 w
.52094 .57512 m
.55749 .54856 L
s
P
p
.2 0 1 r
.002 w
.50807 .23648 m
.62883 .29802 L
s
P
p
.2 0 1 r
.002 w
.50807 .23648 m
.64194 .25769 L
s
P
p
.2 0 1 r
.002 w
.4651 .17734 m
.4863 .04347 L
s
P
p
.2 0 1 r
.002 w
.4651 .17734 m
.44389 .04347 L
s
P
p
.2 0 1 r
.002 w
.42213 .23648 m
.28826 .25769 L
s
P
p
.2 0 1 r
.002 w
.42213 .23648 m
.30136 .29802 L
s
P
p
0 .4 1 r
.018 w
.4651 .22252 m
.50807 .23648 L
s
P
p
0 .4 1 r
.018 w
.4651 .22252 m
.4651 .17734 L
s
P
p
0 .4 1 r
.018 w
.4651 .22252 m
.42213 .23648 L
s
P
p
.2 0 1 r
.002 w
.3727 .54856 m
.27686 .45272 L
s
P
p
.2 0 1 r
.002 w
.3727 .54856 m
.25193 .48703 L
s
P
p
.2 0 1 r
.002 w
.39529 .61809 m
.33376 .73885 L
s
P
p
.2 0 1 r
.002 w
.39529 .61809 m
.37409 .75196 L
s
P
p
.2 0 1 r
.002 w
.45443 .57512 m
.5883 .59632 L
s
P
p
.2 0 1 r
.002 w
.45443 .57512 m
.5883 .55391 L
s
P
p
0 .4 1 r
.018 w
.40925 .57512 m
.3727 .54856 L
s
P
p
0 .4 1 r
.018 w
.40925 .57512 m
.39529 .61809 L
s
P
p
0 .4 1 r
.018 w
.40925 .57512 m
.45443 .57512 L
s
P
p
.2 0 1 r
.002 w
.59788 .29359 m
.65941 .41436 L
s
P
p
.2 0 1 r
.002 w
.59788 .29359 m
.69372 .38943 L
s
P
p
.2 0 1 r
.002 w
.59788 .22049 m
.69372 .12464 L
s
P
p
.2 0 1 r
.002 w
.59788 .22049 m
.65941 .09972 L
s
P
p
.2 0 1 r
.002 w
.52835 .24308 m
.40759 .18154 L
s
P
p
.2 0 1 r
.002 w
.52835 .24308 m
.39448 .22187 L
s
P
p
0 .4 1 r
.018 w
.57132 .25704 m
.59788 .29359 L
s
P
p
0 .4 1 r
.018 w
.57132 .25704 m
.59788 .22049 L
s
P
p
0 .4 1 r
.018 w
.57132 .25704 m
.52835 .24308 L
s
P
p
.2 0 1 r
.002 w
.30493 .4665 m
.28373 .33263 L
s
P
p
.2 0 1 r
.002 w
.30493 .4665 m
.2434 .34573 L
s
P
p
.2 0 1 r
.002 w
.28234 .53602 m
.16157 .59756 L
s
P
p
.2 0 1 r
.002 w
.28234 .53602 m
.1865 .63186 L
s
P
p
.2 0 1 r
.002 w
.35544 .53602 m
.45128 .63186 L
s
P
p
.2 0 1 r
.002 w
.35544 .53602 m
.47621 .59756 L
s
P
p
0 .4 1 r
.018 w
.31889 .50947 m
.30493 .4665 L
s
P
p
0 .4 1 r
.018 w
.31889 .50947 m
.28234 .53602 L
s
P
p
0 .4 1 r
.018 w
.31889 .50947 m
.35544 .53602 L
s
P
p
.2 0 1 r
.016 w
.4651 .40324 m
.52094 .57512 L
s
P
p
.2 0 1 r
.016 w
.4651 .40324 m
.4651 .22252 L
s
P
p
.2 0 1 r
.016 w
.4651 .40324 m
.40925 .57512 L
s
P
p
.2 0 1 r
.016 w
.4651 .40324 m
.57132 .25704 L
s
P
p
.2 0 1 r
.016 w
.4651 .40324 m
.31889 .50947 L
s
P
p
.2 0 1 r
.002 w
.64456 .53602 m
.52379 .59756 L
s
P
p
.2 0 1 r
.002 w
.64456 .53602 m
.54872 .63186 L
s
P
p
.2 0 1 r
.002 w
.71766 .53602 m
.8135 .63186 L
s
P
p
.2 0 1 r
.002 w
.71766 .53602 m
.83843 .59756 L
s
P
p
.2 0 1 r
.002 w
.69507 .4665 m
.7566 .34573 L
s
P
p
.2 0 1 r
.002 w
.69507 .4665 m
.71627 .33263 L
s
P
p
0 .4 1 r
.018 w
.68111 .50947 m
.64456 .53602 L
s
P
p
0 .4 1 r
.018 w
.68111 .50947 m
.71766 .53602 L
s
P
p
0 .4 1 r
.018 w
.68111 .50947 m
.69507 .4665 L
s
P
p
.2 0 1 r
.002 w
.47165 .24308 m
.60552 .22187 L
s
P
p
.2 0 1 r
.002 w
.47165 .24308 m
.59241 .18154 L
s
P
p
.2 0 1 r
.002 w
.40212 .22049 m
.34059 .09972 L
s
P
p
.2 0 1 r
.002 w
.40212 .22049 m
.30628 .12464 L
s
P
p
.2 0 1 r
.002 w
.40212 .29359 m
.30628 .38943 L
s
P
p
.2 0 1 r
.002 w
.40212 .29359 m
.34059 .41436 L
s
P
p
0 .4 1 r
.018 w
.42868 .25704 m
.47165 .24308 L
s
P
p
0 .4 1 r
.018 w
.42868 .25704 m
.40212 .22049 L
s
P
p
0 .4 1 r
.018 w
.42868 .25704 m
.40212 .29359 L
s
P
p
.2 0 1 r
.002 w
.54557 .57512 m
.4117 .55391 L
s
P
p
.2 0 1 r
.002 w
.54557 .57512 m
.4117 .59632 L
s
P
p
.2 0 1 r
.002 w
.60471 .61809 m
.62591 .75196 L
s
P
p
.2 0 1 r
.002 w
.60471 .61809 m
.66624 .73885 L
s
P
p
.2 0 1 r
.002 w
.6273 .54856 m
.74807 .48703 L
s
P
p
.2 0 1 r
.002 w
.6273 .54856 m
.72314 .45272 L
s
P
p
0 .4 1 r
.018 w
.59075 .57512 m
.54557 .57512 L
s
P
p
0 .4 1 r
.018 w
.59075 .57512 m
.60471 .61809 L
s
P
p
0 .4 1 r
.018 w
.59075 .57512 m
.6273 .54856 L
s
P
p
.2 0 1 r
.002 w
.57787 .23648 m
.69864 .29802 L
s
P
p
.2 0 1 r
.002 w
.57787 .23648 m
.71174 .25769 L
s
P
p
.2 0 1 r
.002 w
.5349 .17734 m
.55611 .04347 L
s
P
p
.2 0 1 r
.002 w
.5349 .17734 m
.5137 .04347 L
s
P
p
.2 0 1 r
.002 w
.49193 .23648 m
.35806 .25769 L
s
P
p
.2 0 1 r
.002 w
.49193 .23648 m
.37117 .29802 L
s
P
p
0 .4 1 r
.018 w
.5349 .22252 m
.57787 .23648 L
s
P
p
0 .4 1 r
.018 w
.5349 .22252 m
.5349 .17734 L
s
P
p
0 .4 1 r
.018 w
.5349 .22252 m
.49193 .23648 L
s
P
p
.2 0 1 r
.002 w
.44251 .54856 m
.34667 .45272 L
s
P
p
.2 0 1 r
.002 w
.44251 .54856 m
.32174 .48703 L
s
P
p
.2 0 1 r
.002 w
.4651 .61809 m
.40356 .73885 L
s
P
p
.2 0 1 r
.002 w
.4651 .61809 m
.44389 .75196 L
s
P
p
.2 0 1 r
.002 w
.52424 .57512 m
.65811 .59632 L
s
P
p
.2 0 1 r
.002 w
.52424 .57512 m
.65811 .55391 L
s
P
p
0 .4 1 r
.018 w
.47906 .57512 m
.44251 .54856 L
s
P
p
0 .4 1 r
.018 w
.47906 .57512 m
.4651 .61809 L
s
P
p
0 .4 1 r
.018 w
.47906 .57512 m
.52424 .57512 L
s
P
p
.2 0 1 r
.016 w
.5349 .40324 m
.68111 .50947 L
s
P
p
.2 0 1 r
.016 w
.5349 .40324 m
.42868 .25704 L
s
P
p
.2 0 1 r
.016 w
.5349 .40324 m
.59075 .57512 L
s
P
p
.2 0 1 r
.016 w
.5349 .40324 m
.5349 .22252 L
s
P
p
.2 0 1 r
.016 w
.5349 .40324 m
.47906 .57512 L
s
P
p
.2 0 1 r
.002 w
.75814 .40518 m
.6966 .52595 L
s
P
p
.2 0 1 r
.002 w
.75814 .40518 m
.73693 .53905 L
s
P
p
.2 0 1 r
.002 w
.81728 .36221 m
.95115 .38341 L
s
P
p
.2 0 1 r
.002 w
.81728 .36221 m
.95115 .34101 L
s
P
p
.2 0 1 r
.002 w
.75814 .31924 m
.73693 .18537 L
s
P
p
.2 0 1 r
.002 w
.75814 .31924 m
.6966 .19848 L
s
P
p
0 .4 1 r
.018 w
.7721 .36221 m
.75814 .40518 L
s
P
p
0 .4 1 r
.018 w
.7721 .36221 m
.81728 .36221 L
s
P
p
0 .4 1 r
.018 w
.7721 .36221 m
.75814 .31924 L
s
P
p
.2 0 1 r
.002 w
.44606 .26981 m
.5419 .17397 L
s
P
p
.2 0 1 r
.002 w
.44606 .26981 m
.50759 .14905 L
s
P
p
.2 0 1 r
.002 w
.37653 .2924 m
.25577 .23087 L
s
P
p
.2 0 1 r
.002 w
.37653 .2924 m
.24266 .2712 L
s
P
p
.2 0 1 r
.002 w
.4195 .35155 m
.3983 .48542 L
s
P
p
.2 0 1 r
.002 w
.4195 .35155 m
.44071 .48542 L
s
P
p
0 .4 1 r
.018 w
.4195 .30637 m
.44606 .26981 L
s
P
p
0 .4 1 r
.018 w
.4195 .30637 m
.37653 .2924 L
s
P
p
0 .4 1 r
.018 w
.4195 .30637 m
.4195 .35155 L
s
P
p
.2 0 1 r
.002 w
.70103 .49499 m
.58027 .55653 L
s
P
p
.2 0 1 r
.002 w
.70103 .49499 m
.60519 .59083 L
s
P
p
.2 0 1 r
.002 w
.77414 .49499 m
.86998 .59083 L
s
P
p
.2 0 1 r
.002 w
.77414 .49499 m
.8949 .55653 L
s
P
p
.2 0 1 r
.002 w
.75155 .42547 m
.81308 .3047 L
s
P
p
.2 0 1 r
.002 w
.75155 .42547 m
.77275 .2916 L
s
P
p
0 .4 1 r
.018 w
.73758 .46844 m
.70103 .49499 L
s
P
p
0 .4 1 r
.018 w
.73758 .46844 m
.77414 .49499 L
s
P
p
0 .4 1 r
.018 w
.73758 .46844 m
.75155 .42547 L
s
P
p
.2 0 1 r
.002 w
.52812 .20204 m
.66199 .18084 L
s
P
p
.2 0 1 r
.002 w
.52812 .20204 m
.64889 .14051 L
s
P
p
.2 0 1 r
.002 w
.4586 .17945 m
.39706 .05869 L
s
P
p
.2 0 1 r
.002 w
.4586 .17945 m
.36276 .08361 L
s
P
p
.2 0 1 r
.002 w
.4586 .25256 m
.36276 .3484 L
s
P
p
.2 0 1 r
.002 w
.4586 .25256 m
.39706 .37332 L
s
P
p
0 .4 1 r
.018 w
.48515 .21601 m
.52812 .20204 L
s
P
p
0 .4 1 r
.018 w
.48515 .21601 m
.4586 .17945 L
s
P
p
0 .4 1 r
.018 w
.48515 .21601 m
.4586 .25256 L
s
P
p
.2 0 1 r
.002 w
.60204 .53409 m
.46817 .51288 L
s
P
p
.2 0 1 r
.002 w
.60204 .53409 m
.46817 .55529 L
s
P
p
.2 0 1 r
.002 w
.66119 .57705 m
.68239 .71093 L
s
P
p
.2 0 1 r
.002 w
.66119 .57705 m
.72272 .69782 L
s
P
p
.2 0 1 r
.002 w
.68378 .50753 m
.80454 .446 L
s
P
p
.2 0 1 r
.002 w
.68378 .50753 m
.77962 .41169 L
s
P
p
0 .4 1 r
.018 w
.64722 .53409 m
.60204 .53409 L
s
P
p
0 .4 1 r
.018 w
.64722 .53409 m
.66119 .57705 L
s
P
p
0 .4 1 r
.018 w
.64722 .53409 m
.68378 .50753 L
s
P
p
.2 0 1 r
.016 w
.59138 .36221 m
.7721 .36221 L
s
P
p
.2 0 1 r
.016 w
.59138 .36221 m
.4195 .30637 L
s
P
p
.2 0 1 r
.016 w
.59138 .36221 m
.73758 .46844 L
s
P
p
.2 0 1 r
.016 w
.59138 .36221 m
.48515 .21601 L
s
P
p
.2 0 1 r
.016 w
.59138 .36221 m
.64722 .53409 L
s
P
p
1 .6 0 r
.016 w
.5 .29582 m
.40862 .36221 L
s
P
p
1 .6 0 r
.016 w
.5 .29582 m
.4651 .40324 L
s
P
p
1 .6 0 r
.016 w
.5 .29582 m
.5349 .40324 L
s
P
p
1 .6 0 r
.016 w
.5 .29582 m
.59138 .36221 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.0100251 0.562657 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.081587 0.952381 [
[ 0 0 0 0 ]
[ 1 .78921 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78921 L
0 .78921 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.39627 .61657 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.20765 .42794 L
s
P
p
.2 0 1 r
.002 w
.3169 .50732 m
.44533 .54905 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.41878 .46734 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.29768 .70502 L
s
P
p
.2 0 1 r
.002 w
.33941 .57659 m
.33941 .44155 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.2699 .49205 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.53337 .53378 L
s
P
p
.2 0 1 r
.002 w
.39833 .53378 m
.2699 .57551 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.3169 .50732 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.33941 .57659 L
s
P
p
0 .4 1 r
.018 w
.35332 .53378 m
.39833 .53378 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.49952 .12485 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.62063 .36254 L
s
P
p
.2 0 1 r
.002 w
.54125 .25328 m
.432 .17391 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.432 .25982 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.62063 .0712 L
s
P
p
.2 0 1 r
.002 w
.54125 .18045 m
.49952 .30888 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.58123 .28233 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.34355 .16122 L
s
P
p
.2 0 1 r
.002 w
.47198 .20296 m
.60702 .20296 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .25328 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.54125 .18045 L
s
P
p
0 .4 1 r
.018 w
.51479 .21687 m
.47198 .20296 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.24938 .5606 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.20765 .29713 L
s
P
p
.2 0 1 r
.002 w
.24938 .42556 m
.32875 .53481 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.3553 .4531 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.11762 .57421 L
s
P
p
.2 0 1 r
.002 w
.22687 .49483 m
.30625 .38558 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.22033 .38558 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.40896 .57421 L
s
P
p
.2 0 1 r
.002 w
.2997 .49483 m
.17127 .4531 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.24938 .42556 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.22687 .49483 L
s
P
p
0 .4 1 r
.018 w
.26329 .46837 m
.2997 .49483 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.62193 .22348 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.5802 .48695 L
s
P
p
.2 0 1 r
.002 w
.5802 .35191 m
.53847 .22348 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.48797 .29298 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.75145 .25125 L
s
P
p
.2 0 1 r
.002 w
.62301 .29298 m
.51376 .37236 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.59547 .39891 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.47437 .16122 L
s
P
p
.2 0 1 r
.002 w
.55374 .27048 m
.66299 .34985 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.5802 .35191 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.62301 .29298 L
s
P
p
0 .4 1 r
.018 w
.5802 .30689 m
.55374 .27048 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.16343 .42898 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.28454 .19129 L
s
P
p
.2 0 1 r
.002 w
.24281 .31972 m
.24281 .45477 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.31232 .40427 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.04884 .36254 L
s
P
p
.2 0 1 r
.002 w
.18388 .36254 m
.31232 .3208 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.24281 .2703 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.28454 .53378 L
s
P
p
.2 0 1 r
.002 w
.24281 .40535 m
.16343 .29609 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .31972 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.18388 .36254 L
s
P
p
0 .4 1 r
.018 w
.2289 .36254 m
.24281 .40535 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.35332 .53378 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.51479 .21687 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.26329 .46837 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.5802 .30689 L
s
P
p
.2 0 1 r
.016 w
.40896 .36254 m
.2289 .36254 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.60428 .61639 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.34081 .57466 L
s
P
p
.2 0 1 r
.002 w
.47585 .57466 m
.60428 .53293 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.53478 .48243 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.57651 .74591 L
s
P
p
.2 0 1 r
.002 w
.53478 .61747 m
.4554 .50822 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.42885 .58993 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.66653 .46883 L
s
P
p
.2 0 1 r
.002 w
.55728 .5482 m
.47791 .65745 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.47585 .57466 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.53478 .61747 L
s
P
p
0 .4 1 r
.018 w
.52087 .57466 m
.55728 .5482 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.39878 .15789 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.63647 .279 L
s
P
p
.2 0 1 r
.002 w
.50804 .23727 m
.37299 .23727 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.42349 .30678 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.46522 .0433 L
s
P
p
.2 0 1 r
.002 w
.46522 .17834 m
.50696 .30678 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.55746 .23727 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.29398 .279 L
s
P
p
.2 0 1 r
.002 w
.42241 .23727 m
.53167 .15789 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.50804 .23727 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.46522 .17834 L
s
P
p
0 .4 1 r
.018 w
.46522 .22336 m
.42241 .23727 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.45254 .65745 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.26391 .46883 L
s
P
p
.2 0 1 r
.002 w
.37317 .5482 m
.5016 .58993 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.47505 .50822 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.35394 .74591 L
s
P
p
.2 0 1 r
.002 w
.39567 .61747 m
.39567 .48243 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.32616 .53293 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.58964 .57466 L
s
P
p
.2 0 1 r
.002 w
.4546 .57466 m
.32616 .61639 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.37317 .5482 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.39567 .61747 L
s
P
p
0 .4 1 r
.018 w
.40958 .57466 m
.4546 .57466 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.55579 .16573 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.67689 .40342 L
s
P
p
.2 0 1 r
.002 w
.59752 .29416 m
.48827 .21479 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.48827 .30071 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.67689 .11208 L
s
P
p
.2 0 1 r
.002 w
.59752 .22133 m
.55579 .34976 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.6375 .32321 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.39981 .20211 L
s
P
p
.2 0 1 r
.002 w
.52825 .24384 m
.66329 .24384 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .29416 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.59752 .22133 L
s
P
p
0 .4 1 r
.018 w
.57106 .25775 m
.52825 .24384 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.30564 .60148 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.26391 .33801 L
s
P
p
.2 0 1 r
.002 w
.30564 .46644 m
.38502 .57569 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.41157 .49398 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.17389 .61509 L
s
P
p
.2 0 1 r
.002 w
.28314 .53571 m
.36251 .42646 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.2766 .42646 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.46522 .61509 L
s
P
p
.2 0 1 r
.002 w
.35597 .53571 m
.22754 .49398 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.30564 .46644 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.28314 .53571 L
s
P
p
0 .4 1 r
.018 w
.31956 .50925 m
.35597 .53571 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.52087 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.46522 .22336 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.40958 .57466 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.57106 .25775 L
s
P
p
.2 0 1 r
.016 w
.46522 .40342 m
.31956 .50925 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.77246 .49398 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.53478 .61509 L
s
P
p
.2 0 1 r
.002 w
.64403 .53571 m
.7234 .42646 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.63749 .42646 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.82611 .61509 L
s
P
p
.2 0 1 r
.002 w
.71686 .53571 m
.58843 .49398 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.61498 .57569 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.73609 .33801 L
s
P
p
.2 0 1 r
.002 w
.69436 .46644 m
.69436 .60148 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.64403 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.71686 .53571 L
s
P
p
0 .4 1 r
.018 w
.68044 .50925 m
.69436 .46644 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.33671 .24384 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.60019 .20211 L
s
P
p
.2 0 1 r
.002 w
.47175 .24384 m
.3625 .32321 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.44421 .34976 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.32311 .11208 L
s
P
p
.2 0 1 r
.002 w
.40248 .22133 m
.51173 .30071 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.51173 .21479 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.32311 .40342 L
s
P
p
.2 0 1 r
.002 w
.40248 .29416 m
.44421 .16573 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.47175 .24384 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .22133 L
s
P
p
0 .4 1 r
.018 w
.42894 .25775 m
.40248 .29416 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.67384 .61639 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.41036 .57466 L
s
P
p
.2 0 1 r
.002 w
.5454 .57466 m
.67384 .53293 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.60433 .48243 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.64606 .74591 L
s
P
p
.2 0 1 r
.002 w
.60433 .61747 m
.52495 .50822 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.4984 .58993 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.73609 .46883 L
s
P
p
.2 0 1 r
.002 w
.62683 .5482 m
.54746 .65745 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.5454 .57466 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.60433 .61747 L
s
P
p
0 .4 1 r
.018 w
.59042 .57466 m
.62683 .5482 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.46833 .15789 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.70602 .279 L
s
P
p
.2 0 1 r
.002 w
.57759 .23727 m
.44254 .23727 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.49304 .30678 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.53478 .0433 L
s
P
p
.2 0 1 r
.002 w
.53478 .17834 m
.57651 .30678 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.62701 .23727 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.36353 .279 L
s
P
p
.2 0 1 r
.002 w
.49196 .23727 m
.60122 .15789 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.57759 .23727 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.53478 .17834 L
s
P
p
0 .4 1 r
.018 w
.53478 .22336 m
.49196 .23727 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.52209 .65745 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.33347 .46883 L
s
P
p
.2 0 1 r
.002 w
.44272 .5482 m
.57115 .58993 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.5446 .50822 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.42349 .74591 L
s
P
p
.2 0 1 r
.002 w
.46522 .61747 m
.46522 .48243 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.39572 .53293 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.65919 .57466 L
s
P
p
.2 0 1 r
.002 w
.52415 .57466 m
.39572 .61639 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.44272 .5482 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.46522 .61747 L
s
P
p
0 .4 1 r
.018 w
.47913 .57466 m
.52415 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.68044 .50925 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.42894 .25775 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.59042 .57466 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.53478 .22336 L
s
P
p
.2 0 1 r
.016 w
.53478 .40342 m
.47913 .57466 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.83657 .29609 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.71546 .53378 L
s
P
p
.2 0 1 r
.002 w
.75719 .40535 m
.75719 .2703 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.68768 .3208 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.95116 .36254 L
s
P
p
.2 0 1 r
.002 w
.81612 .36254 m
.68768 .40427 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.75719 .45477 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.71546 .19129 L
s
P
p
.2 0 1 r
.002 w
.75719 .31972 m
.83657 .42898 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .40535 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.81612 .36254 L
s
P
p
0 .4 1 r
.018 w
.7711 .36254 m
.75719 .31972 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.33701 .34985 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.52563 .16122 L
s
P
p
.2 0 1 r
.002 w
.44626 .27048 m
.40453 .39891 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.48624 .37236 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.24855 .25125 L
s
P
p
.2 0 1 r
.002 w
.37699 .29298 m
.51203 .29298 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.46153 .22348 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.4198 .48695 L
s
P
p
.2 0 1 r
.002 w
.4198 .35191 m
.37807 .22348 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.44626 .27048 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.37699 .29298 L
s
P
p
0 .4 1 r
.018 w
.4198 .30689 m
.4198 .35191 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.82873 .4531 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.59104 .57421 L
s
P
p
.2 0 1 r
.002 w
.7003 .49483 m
.77967 .38558 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.69375 .38558 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.88238 .57421 L
s
P
p
.2 0 1 r
.002 w
.77313 .49483 m
.6447 .4531 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.67125 .53481 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.79235 .29713 L
s
P
p
.2 0 1 r
.002 w
.75062 .42556 m
.75062 .5606 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.7003 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.77313 .49483 L
s
P
p
0 .4 1 r
.018 w
.73671 .46837 m
.75062 .42556 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.39298 .20296 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.65645 .16122 L
s
P
p
.2 0 1 r
.002 w
.52802 .20296 m
.41877 .28233 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.50048 .30888 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.37937 .0712 L
s
P
p
.2 0 1 r
.002 w
.45875 .18045 m
.568 .25982 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.568 .17391 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.37937 .36254 L
s
P
p
.2 0 1 r
.002 w
.45875 .25328 m
.50048 .12485 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.52802 .20296 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .18045 L
s
P
p
0 .4 1 r
.018 w
.48521 .21687 m
.45875 .25328 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.7301 .57551 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.46663 .53378 L
s
P
p
.2 0 1 r
.002 w
.60167 .53378 m
.7301 .49205 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.66059 .44155 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.70232 .70502 L
s
P
p
.2 0 1 r
.002 w
.66059 .57659 m
.58122 .46734 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.55467 .54905 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.79235 .42794 L
s
P
p
.2 0 1 r
.002 w
.6831 .50732 m
.60373 .61657 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.60167 .53378 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.66059 .57659 L
s
P
p
0 .4 1 r
.018 w
.64668 .53378 m
.6831 .50732 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.7711 .36254 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.4198 .30689 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.73671 .46837 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.48521 .21687 L
s
P
p
.2 0 1 r
.016 w
.59104 .36254 m
.64668 .53378 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.40896 .36254 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.46522 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.53478 .40342 L
s
P
p
1 .6 0 r
.016 w
.5 .29639 m
.59104 .36254 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.0100251 0.700501 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0834498 0.952381 [
[ 0 0 0 0 ]
[ 1 .78548 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78548 L
0 .78548 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.30734 .50787 m
.23774 .41207 L
s
P
p
.2 0 1 r
.002 w
.30734 .50787 m
.21154 .43827 L
s
P
p
.2 0 1 r
.002 w
.30734 .50787 m
.19472 .47128 L
s
P
p
.2 0 1 r
.002 w
.33102 .58075 m
.26142 .67655 L
s
P
p
.2 0 1 r
.002 w
.33102 .58075 m
.29443 .69337 L
s
P
p
.2 0 1 r
.002 w
.33102 .58075 m
.33102 .69917 L
s
P
p
.2 0 1 r
.002 w
.39302 .53571 m
.50564 .5723 L
s
P
p
.2 0 1 r
.002 w
.39302 .53571 m
.51143 .53571 L
s
P
p
.2 0 1 r
.002 w
.39302 .53571 m
.50564 .49912 L
s
P
p
0 .4 1 r
.018 w
.34566 .53571 m
.30734 .50787 L
s
P
p
0 .4 1 r
.018 w
.34566 .53571 m
.33102 .58075 L
s
P
p
0 .4 1 r
.018 w
.34566 .53571 m
.39302 .53571 L
s
P
p
.2 0 1 r
.002 w
.5434 .24056 m
.58 .35318 L
s
P
p
.2 0 1 r
.002 w
.5434 .24056 m
.61301 .33636 L
s
P
p
.2 0 1 r
.002 w
.5434 .24056 m
.6392 .31016 L
s
P
p
.2 0 1 r
.002 w
.5434 .16393 m
.6392 .09432 L
s
P
p
.2 0 1 r
.002 w
.5434 .16393 m
.61301 .06813 L
s
P
p
.2 0 1 r
.002 w
.5434 .16393 m
.58 .05131 L
s
P
p
.2 0 1 r
.002 w
.47052 .18761 m
.37472 .11801 L
s
P
p
.2 0 1 r
.002 w
.47052 .18761 m
.3579 .15102 L
s
P
p
.2 0 1 r
.002 w
.47052 .18761 m
.35211 .18761 L
s
P
p
0 .4 1 r
.018 w
.51556 .20224 m
.5434 .24056 L
s
P
p
0 .4 1 r
.018 w
.51556 .20224 m
.5434 .16393 L
s
P
p
0 .4 1 r
.018 w
.51556 .20224 m
.47052 .18761 L
s
P
p
.2 0 1 r
.002 w
.23629 .42184 m
.23629 .30342 L
s
P
p
.2 0 1 r
.002 w
.23629 .42184 m
.1997 .30922 L
s
P
p
.2 0 1 r
.002 w
.23629 .42184 m
.16669 .32604 L
s
P
p
.2 0 1 r
.002 w
.21261 .49472 m
.09999 .53131 L
s
P
p
.2 0 1 r
.002 w
.21261 .49472 m
.11681 .56432 L
s
P
p
.2 0 1 r
.002 w
.21261 .49472 m
.14301 .59052 L
s
P
p
.2 0 1 r
.002 w
.28925 .49472 m
.35885 .59052 L
s
P
p
.2 0 1 r
.002 w
.28925 .49472 m
.38504 .56432 L
s
P
p
.2 0 1 r
.002 w
.28925 .49472 m
.40186 .53131 L
s
P
p
0 .4 1 r
.018 w
.25093 .46688 m
.23629 .42184 L
s
P
p
0 .4 1 r
.018 w
.25093 .46688 m
.21261 .49472 L
s
P
p
0 .4 1 r
.018 w
.25093 .46688 m
.28925 .49472 L
s
P
p
.2 0 1 r
.002 w
.58439 .34434 m
.5478 .45696 L
s
P
p
.2 0 1 r
.002 w
.58439 .34434 m
.58439 .46275 L
s
P
p
.2 0 1 r
.002 w
.58439 .34434 m
.62098 .45696 L
s
P
p
.2 0 1 r
.002 w
.62944 .28234 m
.74785 .28234 L
s
P
p
.2 0 1 r
.002 w
.62944 .28234 m
.74205 .24575 L
s
P
p
.2 0 1 r
.002 w
.62944 .28234 m
.72523 .21274 L
s
P
p
.2 0 1 r
.002 w
.55655 .25866 m
.51996 .14604 L
s
P
p
.2 0 1 r
.002 w
.55655 .25866 m
.48695 .16286 L
s
P
p
.2 0 1 r
.002 w
.55655 .25866 m
.46075 .18905 L
s
P
p
0 .4 1 r
.018 w
.58439 .29697 m
.58439 .34434 L
s
P
p
0 .4 1 r
.018 w
.58439 .29697 m
.62944 .28234 L
s
P
p
0 .4 1 r
.018 w
.58439 .29697 m
.55655 .25866 L
s
P
p
.2 0 1 r
.002 w
.22938 .31047 m
.29898 .21468 L
s
P
p
.2 0 1 r
.002 w
.22938 .31047 m
.26597 .19786 L
s
P
p
.2 0 1 r
.002 w
.22938 .31047 m
.22938 .19206 L
s
P
p
.2 0 1 r
.002 w
.16738 .35552 m
.05476 .31893 L
s
P
p
.2 0 1 r
.002 w
.16738 .35552 m
.04897 .35552 L
s
P
p
.2 0 1 r
.002 w
.16738 .35552 m
.05476 .39211 L
s
P
p
.2 0 1 r
.002 w
.22938 .40057 m
.22938 .51898 L
s
P
p
.2 0 1 r
.002 w
.22938 .40057 m
.26597 .51318 L
s
P
p
.2 0 1 r
.002 w
.22938 .40057 m
.29898 .49636 L
s
P
p
0 .4 1 r
.018 w
.21474 .35552 m
.22938 .31047 L
s
P
p
0 .4 1 r
.018 w
.21474 .35552 m
.16738 .35552 L
s
P
p
0 .4 1 r
.018 w
.21474 .35552 m
.22938 .40057 L
s
P
p
.2 0 1 r
.016 w
.4042 .35552 m
.34566 .53571 L
s
P
p
.2 0 1 r
.016 w
.4042 .35552 m
.51556 .20224 L
s
P
p
.2 0 1 r
.016 w
.4042 .35552 m
.25093 .46688 L
s
P
p
.2 0 1 r
.016 w
.4042 .35552 m
.58439 .29697 L
s
P
p
.2 0 1 r
.016 w
.4042 .35552 m
.21474 .35552 L
s
P
p
.2 0 1 r
.002 w
.47459 .57872 m
.36197 .54213 L
s
P
p
.2 0 1 r
.002 w
.47459 .57872 m
.35618 .57872 L
s
P
p
.2 0 1 r
.002 w
.47459 .57872 m
.36197 .61531 L
s
P
p
.2 0 1 r
.002 w
.53659 .62377 m
.53659 .74218 L
s
P
p
.2 0 1 r
.002 w
.53659 .62377 m
.57318 .73639 L
s
P
p
.2 0 1 r
.002 w
.53659 .62377 m
.60619 .71957 L
s
P
p
.2 0 1 r
.002 w
.56027 .55088 m
.67289 .51429 L
s
P
p
.2 0 1 r
.002 w
.56027 .55088 m
.65607 .48128 L
s
P
p
.2 0 1 r
.002 w
.56027 .55088 m
.62987 .45509 L
s
P
p
0 .4 1 r
.018 w
.52195 .57872 m
.47459 .57872 L
s
P
p
0 .4 1 r
.018 w
.52195 .57872 m
.53659 .62377 L
s
P
p
0 .4 1 r
.018 w
.52195 .57872 m
.56027 .55088 L
s
P
p
.2 0 1 r
.002 w
.50846 .22371 m
.60425 .29331 L
s
P
p
.2 0 1 r
.002 w
.50846 .22371 m
.62107 .2603 L
s
P
p
.2 0 1 r
.002 w
.50846 .22371 m
.62687 .22371 L
s
P
p
.2 0 1 r
.002 w
.46341 .16171 m
.5 .04909 L
s
P
p
.2 0 1 r
.002 w
.46341 .16171 m
.46341 .0433 L
s
P
p
.2 0 1 r
.002 w
.46341 .16171 m
.42682 .04909 L
s
P
p
.2 0 1 r
.002 w
.41836 .22371 m
.29995 .22371 L
s
P
p
.2 0 1 r
.002 w
.41836 .22371 m
.30575 .2603 L
s
P
p
.2 0 1 r
.002 w
.41836 .22371 m
.32256 .29331 L
s
P
p
0 .4 1 r
.018 w
.46341 .20908 m
.50846 .22371 L
s
P
p
0 .4 1 r
.018 w
.46341 .20908 m
.46341 .16171 L
s
P
p
0 .4 1 r
.018 w
.46341 .20908 m
.41836 .22371 L
s
P
p
.2 0 1 r
.002 w
.36654 .55088 m
.29694 .45509 L
s
P
p
.2 0 1 r
.002 w
.36654 .55088 m
.27075 .48128 L
s
P
p
.2 0 1 r
.002 w
.36654 .55088 m
.25393 .51429 L
s
P
p
.2 0 1 r
.002 w
.39023 .62377 m
.32062 .71957 L
s
P
p
.2 0 1 r
.002 w
.39023 .62377 m
.35363 .73639 L
s
P
p
.2 0 1 r
.002 w
.39023 .62377 m
.39023 .74218 L
s
P
p
.2 0 1 r
.002 w
.45223 .57872 m
.56484 .61531 L
s
P
p
.2 0 1 r
.002 w
.45223 .57872 m
.57064 .57872 L
s
P
p
.2 0 1 r
.002 w
.45223 .57872 m
.56484 .54213 L
s
P
p
0 .4 1 r
.018 w
.40486 .57872 m
.36654 .55088 L
s
P
p
0 .4 1 r
.018 w
.40486 .57872 m
.39023 .62377 L
s
P
p
0 .4 1 r
.018 w
.40486 .57872 m
.45223 .57872 L
s
P
p
.2 0 1 r
.002 w
.60261 .28358 m
.6392 .3962 L
s
P
p
.2 0 1 r
.002 w
.60261 .28358 m
.67221 .37938 L
s
P
p
.2 0 1 r
.002 w
.60261 .28358 m
.69841 .35318 L
s
P
p
.2 0 1 r
.002 w
.60261 .20694 m
.69841 .13734 L
s
P
p
.2 0 1 r
.002 w
.60261 .20694 m
.67221 .11114 L
s
P
p
.2 0 1 r
.002 w
.60261 .20694 m
.6392 .09432 L
s
P
p
.2 0 1 r
.002 w
.52972 .23062 m
.43393 .16102 L
s
P
p
.2 0 1 r
.002 w
.52972 .23062 m
.41711 .19403 L
s
P
p
.2 0 1 r
.002 w
.52972 .23062 m
.41131 .23062 L
s
P
p
0 .4 1 r
.018 w
.57477 .24526 m
.60261 .28358 L
s
P
p
0 .4 1 r
.018 w
.57477 .24526 m
.60261 .20694 L
s
P
p
0 .4 1 r
.018 w
.57477 .24526 m
.52972 .23062 L
s
P
p
.2 0 1 r
.002 w
.2955 .46485 m
.2955 .34644 L
s
P
p
.2 0 1 r
.002 w
.2955 .46485 m
.2589 .35223 L
s
P
p
.2 0 1 r
.002 w
.2955 .46485 m
.2259 .36905 L
s
P
p
.2 0 1 r
.002 w
.27181 .53774 m
.1592 .57433 L
s
P
p
.2 0 1 r
.002 w
.27181 .53774 m
.17602 .60734 L
s
P
p
.2 0 1 r
.002 w
.27181 .53774 m
.20221 .63354 L
s
P
p
.2 0 1 r
.002 w
.34845 .53774 m
.41805 .63354 L
s
P
p
.2 0 1 r
.002 w
.34845 .53774 m
.44425 .60734 L
s
P
p
.2 0 1 r
.002 w
.34845 .53774 m
.46107 .57433 L
s
P
p
0 .4 1 r
.018 w
.31013 .5099 m
.2955 .46485 L
s
P
p
0 .4 1 r
.018 w
.31013 .5099 m
.27181 .53774 L
s
P
p
0 .4 1 r
.018 w
.31013 .5099 m
.34845 .53774 L
s
P
p
.2 0 1 r
.016 w
.46341 .39854 m
.52195 .57872 L
s
P
p
.2 0 1 r
.016 w
.46341 .39854 m
.46341 .20908 L
s
P
p
.2 0 1 r
.016 w
.46341 .39854 m
.40486 .57872 L
s
P
p
.2 0 1 r
.016 w
.46341 .39854 m
.57477 .24526 L
s
P
p
.2 0 1 r
.016 w
.46341 .39854 m
.31013 .5099 L
s
P
p
.2 0 1 r
.002 w
.65155 .53774 m
.53893 .57433 L
s
P
p
.2 0 1 r
.002 w
.65155 .53774 m
.55575 .60734 L
s
P
p
.2 0 1 r
.002 w
.65155 .53774 m
.58195 .63354 L
s
P
p
.2 0 1 r
.002 w
.72819 .53774 m
.79779 .63354 L
s
P
p
.2 0 1 r
.002 w
.72819 .53774 m
.82398 .60734 L
s
P
p
.2 0 1 r
.002 w
.72819 .53774 m
.8408 .57433 L
s
P
p
.2 0 1 r
.002 w
.7045 .46485 m
.7741 .36905 L
s
P
p
.2 0 1 r
.002 w
.7045 .46485 m
.7411 .35223 L
s
P
p
.2 0 1 r
.002 w
.7045 .46485 m
.7045 .34644 L
s
P
p
0 .4 1 r
.018 w
.68987 .5099 m
.65155 .53774 L
s
P
p
0 .4 1 r
.018 w
.68987 .5099 m
.72819 .53774 L
s
P
p
0 .4 1 r
.018 w
.68987 .5099 m
.7045 .46485 L
s
P
p
.2 0 1 r
.002 w
.47028 .23062 m
.58869 .23062 L
s
P
p
.2 0 1 r
.002 w
.47028 .23062 m
.58289 .19403 L
s
P
p
.2 0 1 r
.002 w
.47028 .23062 m
.56607 .16102 L
s
P
p
.2 0 1 r
.002 w
.39739 .20694 m
.3608 .09432 L
s
P
p
.2 0 1 r
.002 w
.39739 .20694 m
.32779 .11114 L
s
P
p
.2 0 1 r
.002 w
.39739 .20694 m
.30159 .13734 L
s
P
p
.2 0 1 r
.002 w
.39739 .28358 m
.30159 .35318 L
s
P
p
.2 0 1 r
.002 w
.39739 .28358 m
.32779 .37938 L
s
P
p
.2 0 1 r
.002 w
.39739 .28358 m
.3608 .3962 L
s
P
p
0 .4 1 r
.018 w
.42523 .24526 m
.47028 .23062 L
s
P
p
0 .4 1 r
.018 w
.42523 .24526 m
.39739 .20694 L
s
P
p
0 .4 1 r
.018 w
.42523 .24526 m
.39739 .28358 L
s
P
p
.2 0 1 r
.002 w
.54777 .57872 m
.43516 .54213 L
s
P
p
.2 0 1 r
.002 w
.54777 .57872 m
.42936 .57872 L
s
P
p
.2 0 1 r
.002 w
.54777 .57872 m
.43516 .61531 L
s
P
p
.2 0 1 r
.002 w
.60977 .62377 m
.60977 .74218 L
s
P
p
.2 0 1 r
.002 w
.60977 .62377 m
.64637 .73639 L
s
P
p
.2 0 1 r
.002 w
.60977 .62377 m
.67938 .71957 L
s
P
p
.2 0 1 r
.002 w
.63346 .55088 m
.74607 .51429 L
s
P
p
.2 0 1 r
.002 w
.63346 .55088 m
.72925 .48128 L
s
P
p
.2 0 1 r
.002 w
.63346 .55088 m
.70306 .45509 L
s
P
p
0 .4 1 r
.018 w
.59514 .57872 m
.54777 .57872 L
s
P
p
0 .4 1 r
.018 w
.59514 .57872 m
.60977 .62377 L
s
P
p
0 .4 1 r
.018 w
.59514 .57872 m
.63346 .55088 L
s
P
p
.2 0 1 r
.002 w
.58164 .22371 m
.67744 .29331 L
s
P
p
.2 0 1 r
.002 w
.58164 .22371 m
.69425 .2603 L
s
P
p
.2 0 1 r
.002 w
.58164 .22371 m
.70005 .22371 L
s
P
p
.2 0 1 r
.002 w
.53659 .16171 m
.57318 .04909 L
s
P
p
.2 0 1 r
.002 w
.53659 .16171 m
.53659 .0433 L
s
P
p
.2 0 1 r
.002 w
.53659 .16171 m
.5 .04909 L
s
P
p
.2 0 1 r
.002 w
.49154 .22371 m
.37313 .22371 L
s
P
p
.2 0 1 r
.002 w
.49154 .22371 m
.37893 .2603 L
s
P
p
.2 0 1 r
.002 w
.49154 .22371 m
.39575 .29331 L
s
P
p
0 .4 1 r
.018 w
.53659 .20908 m
.58164 .22371 L
s
P
p
0 .4 1 r
.018 w
.53659 .20908 m
.53659 .16171 L
s
P
p
0 .4 1 r
.018 w
.53659 .20908 m
.49154 .22371 L
s
P
p
.2 0 1 r
.002 w
.43973 .55088 m
.37013 .45509 L
s
P
p
.2 0 1 r
.002 w
.43973 .55088 m
.34393 .48128 L
s
P
p
.2 0 1 r
.002 w
.43973 .55088 m
.32711 .51429 L
s
P
p
.2 0 1 r
.002 w
.46341 .62377 m
.39381 .71957 L
s
P
p
.2 0 1 r
.002 w
.46341 .62377 m
.42682 .73639 L
s
P
p
.2 0 1 r
.002 w
.46341 .62377 m
.46341 .74218 L
s
P
p
.2 0 1 r
.002 w
.52541 .57872 m
.63803 .61531 L
s
P
p
.2 0 1 r
.002 w
.52541 .57872 m
.64382 .57872 L
s
P
p
.2 0 1 r
.002 w
.52541 .57872 m
.63803 .54213 L
s
P
p
0 .4 1 r
.018 w
.47805 .57872 m
.43973 .55088 L
s
P
p
0 .4 1 r
.018 w
.47805 .57872 m
.46341 .62377 L
s
P
p
0 .4 1 r
.018 w
.47805 .57872 m
.52541 .57872 L
s
P
p
.2 0 1 r
.016 w
.53659 .39854 m
.68987 .5099 L
s
P
p
.2 0 1 r
.016 w
.53659 .39854 m
.42523 .24526 L
s
P
p
.2 0 1 r
.016 w
.53659 .39854 m
.59514 .57872 L
s
P
p
.2 0 1 r
.016 w
.53659 .39854 m
.53659 .20908 L
s
P
p
.2 0 1 r
.016 w
.53659 .39854 m
.47805 .57872 L
s
P
p
.2 0 1 r
.002 w
.77062 .40057 m
.70102 .49636 L
s
P
p
.2 0 1 r
.002 w
.77062 .40057 m
.73403 .51318 L
s
P
p
.2 0 1 r
.002 w
.77062 .40057 m
.77062 .51898 L
s
P
p
.2 0 1 r
.002 w
.83262 .35552 m
.94524 .39211 L
s
P
p
.2 0 1 r
.002 w
.83262 .35552 m
.95103 .35552 L
s
P
p
.2 0 1 r
.002 w
.83262 .35552 m
.94524 .31893 L
s
P
p
.2 0 1 r
.002 w
.77062 .31047 m
.77062 .19206 L
s
P
p
.2 0 1 r
.002 w
.77062 .31047 m
.73403 .19786 L
s
P
p
.2 0 1 r
.002 w
.77062 .31047 m
.70102 .21468 L
s
P
p
0 .4 1 r
.018 w
.78526 .35552 m
.77062 .40057 L
s
P
p
0 .4 1 r
.018 w
.78526 .35552 m
.83262 .35552 L
s
P
p
0 .4 1 r
.018 w
.78526 .35552 m
.77062 .31047 L
s
P
p
.2 0 1 r
.002 w
.44345 .25866 m
.53925 .18905 L
s
P
p
.2 0 1 r
.002 w
.44345 .25866 m
.51305 .16286 L
s
P
p
.2 0 1 r
.002 w
.44345 .25866 m
.48004 .14604 L
s
P
p
.2 0 1 r
.002 w
.37056 .28234 m
.27477 .21274 L
s
P
p
.2 0 1 r
.002 w
.37056 .28234 m
.25795 .24575 L
s
P
p
.2 0 1 r
.002 w
.37056 .28234 m
.25215 .28234 L
s
P
p
.2 0 1 r
.002 w
.41561 .34434 m
.37902 .45696 L
s
P
p
.2 0 1 r
.002 w
.41561 .34434 m
.41561 .46275 L
s
P
p
.2 0 1 r
.002 w
.41561 .34434 m
.4522 .45696 L
s
P
p
0 .4 1 r
.018 w
.41561 .29697 m
.44345 .25866 L
s
P
p
0 .4 1 r
.018 w
.41561 .29697 m
.37056 .28234 L
s
P
p
0 .4 1 r
.018 w
.41561 .29697 m
.41561 .34434 L
s
P
p
.2 0 1 r
.002 w
.71075 .49472 m
.59814 .53131 L
s
P
p
.2 0 1 r
.002 w
.71075 .49472 m
.61496 .56432 L
s
P
p
.2 0 1 r
.002 w
.71075 .49472 m
.64115 .59052 L
s
P
p
.2 0 1 r
.002 w
.78739 .49472 m
.85699 .59052 L
s
P
p
.2 0 1 r
.002 w
.78739 .49472 m
.88319 .56432 L
s
P
p
.2 0 1 r
.002 w
.78739 .49472 m
.90001 .53131 L
s
P
p
.2 0 1 r
.002 w
.76371 .42184 m
.83331 .32604 L
s
P
p
.2 0 1 r
.002 w
.76371 .42184 m
.8003 .30922 L
s
P
p
.2 0 1 r
.002 w
.76371 .42184 m
.76371 .30342 L
s
P
p
0 .4 1 r
.018 w
.74907 .46688 m
.71075 .49472 L
s
P
p
0 .4 1 r
.018 w
.74907 .46688 m
.78739 .49472 L
s
P
p
0 .4 1 r
.018 w
.74907 .46688 m
.76371 .42184 L
s
P
p
.2 0 1 r
.002 w
.52948 .18761 m
.64789 .18761 L
s
P
p
.2 0 1 r
.002 w
.52948 .18761 m
.6421 .15102 L
s
P
p
.2 0 1 r
.002 w
.52948 .18761 m
.62528 .11801 L
s
P
p
.2 0 1 r
.002 w
.4566 .16393 m
.42 .05131 L
s
P
p
.2 0 1 r
.002 w
.4566 .16393 m
.38699 .06813 L
s
P
p
.2 0 1 r
.002 w
.4566 .16393 m
.3608 .09432 L
s
P
p
.2 0 1 r
.002 w
.4566 .24056 m
.3608 .31016 L
s
P
p
.2 0 1 r
.002 w
.4566 .24056 m
.38699 .33636 L
s
P
p
.2 0 1 r
.002 w
.4566 .24056 m
.42 .35318 L
s
P
p
0 .4 1 r
.018 w
.48444 .20224 m
.52948 .18761 L
s
P
p
0 .4 1 r
.018 w
.48444 .20224 m
.4566 .16393 L
s
P
p
0 .4 1 r
.018 w
.48444 .20224 m
.4566 .24056 L
s
P
p
.2 0 1 r
.002 w
.60698 .53571 m
.49436 .49912 L
s
P
p
.2 0 1 r
.002 w
.60698 .53571 m
.48857 .53571 L
s
P
p
.2 0 1 r
.002 w
.60698 .53571 m
.49436 .5723 L
s
P
p
.2 0 1 r
.002 w
.66898 .58075 m
.66898 .69917 L
s
P
p
.2 0 1 r
.002 w
.66898 .58075 m
.70557 .69337 L
s
P
p
.2 0 1 r
.002 w
.66898 .58075 m
.73858 .67655 L
s
P
p
.2 0 1 r
.002 w
.69266 .50787 m
.80528 .47128 L
s
P
p
.2 0 1 r
.002 w
.69266 .50787 m
.78846 .43827 L
s
P
p
.2 0 1 r
.002 w
.69266 .50787 m
.76226 .41207 L
s
P
p
0 .4 1 r
.018 w
.65434 .53571 m
.60698 .53571 L
s
P
p
0 .4 1 r
.018 w
.65434 .53571 m
.66898 .58075 L
s
P
p
0 .4 1 r
.018 w
.65434 .53571 m
.69266 .50787 L
s
P
p
.2 0 1 r
.016 w
.5958 .35552 m
.78526 .35552 L
s
P
p
.2 0 1 r
.016 w
.5958 .35552 m
.41561 .29697 L
s
P
p
.2 0 1 r
.016 w
.5958 .35552 m
.74907 .46688 L
s
P
p
.2 0 1 r
.016 w
.5958 .35552 m
.48444 .20224 L
s
P
p
.2 0 1 r
.016 w
.5958 .35552 m
.65434 .53571 L
s
P
p
1 .6 0 r
.016 w
.5 .28592 m
.4042 .35552 L
s
P
p
1 .6 0 r
.016 w
.5 .28592 m
.46341 .39854 L
s
P
p
1 .6 0 r
.016 w
.5 .28592 m
.53659 .39854 L
s
P
p
1 .6 0 r
.016 w
.5 .28592 m
.5958 .35552 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.0100251 0.838346 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0780989 0.952381 [
[ 0 0 0 0 ]
[ 1 .79618 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79618 L
0 .79618 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.022 w
.3169 .5075 m
.23752 .39825 L
s
P
p
.2 0 1 r
.022 w
.3169 .5075 m
.20765 .42813 L
s
P
p
.2 0 1 r
.022 w
.3169 .5075 m
.18846 .46577 L
s
P
p
.2 0 1 r
.022 w
.33941 .57677 m
.26003 .68603 L
s
P
p
.2 0 1 r
.022 w
.33941 .57677 m
.29768 .70521 L
s
P
p
.2 0 1 r
.022 w
.33941 .57677 m
.33941 .71182 L
s
P
p
.2 0 1 r
.022 w
.39833 .53396 m
.52676 .57569 L
s
P
p
.2 0 1 r
.022 w
.39833 .53396 m
.53337 .53396 L
s
P
p
.2 0 1 r
.022 w
.39833 .53396 m
.52676 .49223 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.3169 .5075 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.33941 .57677 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.39833 .53396 L
s
P
p
.2 0 1 r
.022 w
.54125 .25347 m
.58298 .3819 L
s
P
p
.2 0 1 r
.022 w
.54125 .25347 m
.62063 .36272 L
s
P
p
.2 0 1 r
.022 w
.54125 .25347 m
.6505 .33284 L
s
P
p
.2 0 1 r
.022 w
.54125 .18063 m
.6505 .10126 L
s
P
p
.2 0 1 r
.022 w
.54125 .18063 m
.62063 .07138 L
s
P
p
.2 0 1 r
.022 w
.54125 .18063 m
.58298 .0522 L
s
P
p
.2 0 1 r
.022 w
.47198 .20314 m
.36273 .12376 L
s
P
p
.2 0 1 r
.022 w
.47198 .20314 m
.34355 .16141 L
s
P
p
.2 0 1 r
.022 w
.47198 .20314 m
.33694 .20314 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .25347 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .18063 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.47198 .20314 L
s
P
p
.2 0 1 r
.022 w
.24938 .42574 m
.24938 .2907 L
s
P
p
.2 0 1 r
.022 w
.24938 .42574 m
.20765 .29731 L
s
P
p
.2 0 1 r
.022 w
.24938 .42574 m
.17 .31649 L
s
P
p
.2 0 1 r
.022 w
.22687 .49501 m
.09844 .53674 L
s
P
p
.2 0 1 r
.022 w
.22687 .49501 m
.11762 .57439 L
s
P
p
.2 0 1 r
.022 w
.22687 .49501 m
.14749 .60426 L
s
P
p
.2 0 1 r
.022 w
.2997 .49501 m
.37908 .60426 L
s
P
p
.2 0 1 r
.022 w
.2997 .49501 m
.40896 .57439 L
s
P
p
.2 0 1 r
.022 w
.2997 .49501 m
.42814 .53674 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.24938 .42574 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.22687 .49501 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.2997 .49501 L
s
P
p
.2 0 1 r
.022 w
.5802 .35209 m
.53847 .48053 L
s
P
p
.2 0 1 r
.022 w
.5802 .35209 m
.5802 .48713 L
s
P
p
.2 0 1 r
.022 w
.5802 .35209 m
.62193 .48053 L
s
P
p
.2 0 1 r
.022 w
.62301 .29317 m
.75806 .29317 L
s
P
p
.2 0 1 r
.022 w
.62301 .29317 m
.75145 .25144 L
s
P
p
.2 0 1 r
.022 w
.62301 .29317 m
.73226 .21379 L
s
P
p
.2 0 1 r
.022 w
.55374 .27066 m
.51201 .14223 L
s
P
p
.2 0 1 r
.022 w
.55374 .27066 m
.47437 .16141 L
s
P
p
.2 0 1 r
.022 w
.55374 .27066 m
.44449 .19128 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.5802 .35209 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.62301 .29317 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.55374 .27066 L
s
P
p
.2 0 1 r
.022 w
.24281 .31991 m
.32219 .21066 L
s
P
p
.2 0 1 r
.022 w
.24281 .31991 m
.28454 .19147 L
s
P
p
.2 0 1 r
.022 w
.24281 .31991 m
.24281 .18486 L
s
P
p
.2 0 1 r
.022 w
.18388 .36272 m
.05545 .32099 L
s
P
p
.2 0 1 r
.022 w
.18388 .36272 m
.04884 .36272 L
s
P
p
.2 0 1 r
.022 w
.18388 .36272 m
.05545 .40445 L
s
P
p
.2 0 1 r
.022 w
.24281 .40553 m
.24281 .54057 L
s
P
p
.2 0 1 r
.022 w
.24281 .40553 m
.28454 .53396 L
s
P
p
.2 0 1 r
.022 w
.24281 .40553 m
.32219 .51478 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .31991 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.18388 .36272 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .40553 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.35332 .53396 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.51479 .21705 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.26329 .46855 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.5802 .30708 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.2289 .36272 L
s
P
p
.2 0 1 r
.022 w
.47585 .57484 m
.34742 .53311 L
s
P
p
.2 0 1 r
.022 w
.47585 .57484 m
.34081 .57484 L
s
P
p
.2 0 1 r
.022 w
.47585 .57484 m
.34742 .61657 L
s
P
p
.2 0 1 r
.022 w
.53478 .61766 m
.53478 .7527 L
s
P
p
.2 0 1 r
.022 w
.53478 .61766 m
.57651 .74609 L
s
P
p
.2 0 1 r
.022 w
.53478 .61766 m
.61415 .72691 L
s
P
p
.2 0 1 r
.022 w
.55728 .54839 m
.68572 .50665 L
s
P
p
.2 0 1 r
.022 w
.55728 .54839 m
.66653 .46901 L
s
P
p
.2 0 1 r
.022 w
.55728 .54839 m
.63666 .43913 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.47585 .57484 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.53478 .61766 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.55728 .54839 L
s
P
p
.2 0 1 r
.022 w
.50804 .23745 m
.61729 .31683 L
s
P
p
.2 0 1 r
.022 w
.50804 .23745 m
.63647 .27918 L
s
P
p
.2 0 1 r
.022 w
.50804 .23745 m
.64308 .23745 L
s
P
p
.2 0 1 r
.022 w
.46522 .17853 m
.50696 .05009 L
s
P
p
.2 0 1 r
.022 w
.46522 .17853 m
.46522 .04348 L
s
P
p
.2 0 1 r
.022 w
.46522 .17853 m
.42349 .05009 L
s
P
p
.2 0 1 r
.022 w
.42241 .23745 m
.28737 .23745 L
s
P
p
.2 0 1 r
.022 w
.42241 .23745 m
.29398 .27918 L
s
P
p
.2 0 1 r
.022 w
.42241 .23745 m
.31316 .31683 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.50804 .23745 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.46522 .17853 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.42241 .23745 L
s
P
p
.2 0 1 r
.022 w
.37317 .54839 m
.29379 .43913 L
s
P
p
.2 0 1 r
.022 w
.37317 .54839 m
.26391 .46901 L
s
P
p
.2 0 1 r
.022 w
.37317 .54839 m
.24473 .50665 L
s
P
p
.2 0 1 r
.022 w
.39567 .61766 m
.3163 .72691 L
s
P
p
.2 0 1 r
.022 w
.39567 .61766 m
.35394 .74609 L
s
P
p
.2 0 1 r
.022 w
.39567 .61766 m
.39567 .7527 L
s
P
p
.2 0 1 r
.022 w
.4546 .57484 m
.58303 .61657 L
s
P
p
.2 0 1 r
.022 w
.4546 .57484 m
.58964 .57484 L
s
P
p
.2 0 1 r
.022 w
.4546 .57484 m
.58303 .53311 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.37317 .54839 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.39567 .61766 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.4546 .57484 L
s
P
p
.2 0 1 r
.022 w
.59752 .29435 m
.63925 .42278 L
s
P
p
.2 0 1 r
.022 w
.59752 .29435 m
.67689 .4036 L
s
P
p
.2 0 1 r
.022 w
.59752 .29435 m
.70677 .37372 L
s
P
p
.2 0 1 r
.022 w
.59752 .22151 m
.70677 .14214 L
s
P
p
.2 0 1 r
.022 w
.59752 .22151 m
.67689 .11226 L
s
P
p
.2 0 1 r
.022 w
.59752 .22151 m
.63925 .09308 L
s
P
p
.2 0 1 r
.022 w
.52825 .24402 m
.419 .16464 L
s
P
p
.2 0 1 r
.022 w
.52825 .24402 m
.39981 .20229 L
s
P
p
.2 0 1 r
.022 w
.52825 .24402 m
.39321 .24402 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .29435 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .22151 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.52825 .24402 L
s
P
p
.2 0 1 r
.022 w
.30564 .46662 m
.30564 .33158 L
s
P
p
.2 0 1 r
.022 w
.30564 .46662 m
.26391 .33819 L
s
P
p
.2 0 1 r
.022 w
.30564 .46662 m
.22627 .35737 L
s
P
p
.2 0 1 r
.022 w
.28314 .53589 m
.1547 .57762 L
s
P
p
.2 0 1 r
.022 w
.28314 .53589 m
.17389 .61527 L
s
P
p
.2 0 1 r
.022 w
.28314 .53589 m
.20376 .64515 L
s
P
p
.2 0 1 r
.022 w
.35597 .53589 m
.43535 .64515 L
s
P
p
.2 0 1 r
.022 w
.35597 .53589 m
.46522 .61527 L
s
P
p
.2 0 1 r
.022 w
.35597 .53589 m
.48441 .57762 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.30564 .46662 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.28314 .53589 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.35597 .53589 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.52087 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.46522 .22354 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.40958 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.57106 .25793 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.31956 .50943 L
s
P
p
.2 0 1 r
.022 w
.64403 .53589 m
.51559 .57762 L
s
P
p
.2 0 1 r
.022 w
.64403 .53589 m
.53478 .61527 L
s
P
p
.2 0 1 r
.022 w
.64403 .53589 m
.56465 .64515 L
s
P
p
.2 0 1 r
.022 w
.71686 .53589 m
.79624 .64515 L
s
P
p
.2 0 1 r
.022 w
.71686 .53589 m
.82611 .61527 L
s
P
p
.2 0 1 r
.022 w
.71686 .53589 m
.8453 .57762 L
s
P
p
.2 0 1 r
.022 w
.69436 .46662 m
.77373 .35737 L
s
P
p
.2 0 1 r
.022 w
.69436 .46662 m
.73609 .33819 L
s
P
p
.2 0 1 r
.022 w
.69436 .46662 m
.69436 .33158 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.64403 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.71686 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.69436 .46662 L
s
P
p
.2 0 1 r
.022 w
.47175 .24402 m
.60679 .24402 L
s
P
p
.2 0 1 r
.022 w
.47175 .24402 m
.60019 .20229 L
s
P
p
.2 0 1 r
.022 w
.47175 .24402 m
.581 .16464 L
s
P
p
.2 0 1 r
.022 w
.40248 .22151 m
.36075 .09308 L
s
P
p
.2 0 1 r
.022 w
.40248 .22151 m
.32311 .11226 L
s
P
p
.2 0 1 r
.022 w
.40248 .22151 m
.29323 .14214 L
s
P
p
.2 0 1 r
.022 w
.40248 .29435 m
.29323 .37372 L
s
P
p
.2 0 1 r
.022 w
.40248 .29435 m
.32311 .4036 L
s
P
p
.2 0 1 r
.022 w
.40248 .29435 m
.36075 .42278 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.47175 .24402 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .22151 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .29435 L
s
P
p
.2 0 1 r
.022 w
.5454 .57484 m
.41697 .53311 L
s
P
p
.2 0 1 r
.022 w
.5454 .57484 m
.41036 .57484 L
s
P
p
.2 0 1 r
.022 w
.5454 .57484 m
.41697 .61657 L
s
P
p
.2 0 1 r
.022 w
.60433 .61766 m
.60433 .7527 L
s
P
p
.2 0 1 r
.022 w
.60433 .61766 m
.64606 .74609 L
s
P
p
.2 0 1 r
.022 w
.60433 .61766 m
.6837 .72691 L
s
P
p
.2 0 1 r
.022 w
.62683 .54839 m
.75527 .50665 L
s
P
p
.2 0 1 r
.022 w
.62683 .54839 m
.73609 .46901 L
s
P
p
.2 0 1 r
.022 w
.62683 .54839 m
.70621 .43913 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.5454 .57484 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.60433 .61766 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.62683 .54839 L
s
P
p
.2 0 1 r
.022 w
.57759 .23745 m
.68684 .31683 L
s
P
p
.2 0 1 r
.022 w
.57759 .23745 m
.70602 .27918 L
s
P
p
.2 0 1 r
.022 w
.57759 .23745 m
.71263 .23745 L
s
P
p
.2 0 1 r
.022 w
.53478 .17853 m
.57651 .05009 L
s
P
p
.2 0 1 r
.022 w
.53478 .17853 m
.53478 .04348 L
s
P
p
.2 0 1 r
.022 w
.53478 .17853 m
.49304 .05009 L
s
P
p
.2 0 1 r
.022 w
.49196 .23745 m
.35692 .23745 L
s
P
p
.2 0 1 r
.022 w
.49196 .23745 m
.36353 .27918 L
s
P
p
.2 0 1 r
.022 w
.49196 .23745 m
.38271 .31683 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.57759 .23745 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.53478 .17853 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.49196 .23745 L
s
P
p
.2 0 1 r
.022 w
.44272 .54839 m
.36334 .43913 L
s
P
p
.2 0 1 r
.022 w
.44272 .54839 m
.33347 .46901 L
s
P
p
.2 0 1 r
.022 w
.44272 .54839 m
.31428 .50665 L
s
P
p
.2 0 1 r
.022 w
.46522 .61766 m
.38585 .72691 L
s
P
p
.2 0 1 r
.022 w
.46522 .61766 m
.42349 .74609 L
s
P
p
.2 0 1 r
.022 w
.46522 .61766 m
.46522 .7527 L
s
P
p
.2 0 1 r
.022 w
.52415 .57484 m
.65258 .61657 L
s
P
p
.2 0 1 r
.022 w
.52415 .57484 m
.65919 .57484 L
s
P
p
.2 0 1 r
.022 w
.52415 .57484 m
.65258 .53311 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.44272 .54839 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.46522 .61766 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.52415 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.68044 .50943 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.42894 .25793 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.59042 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.53478 .22354 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.47913 .57484 L
s
P
p
.2 0 1 r
.022 w
.75719 .40553 m
.67781 .51478 L
s
P
p
.2 0 1 r
.022 w
.75719 .40553 m
.71546 .53396 L
s
P
p
.2 0 1 r
.022 w
.75719 .40553 m
.75719 .54057 L
s
P
p
.2 0 1 r
.022 w
.81612 .36272 m
.94455 .40445 L
s
P
p
.2 0 1 r
.022 w
.81612 .36272 m
.95116 .36272 L
s
P
p
.2 0 1 r
.022 w
.81612 .36272 m
.94455 .32099 L
s
P
p
.2 0 1 r
.022 w
.75719 .31991 m
.75719 .18486 L
s
P
p
.2 0 1 r
.022 w
.75719 .31991 m
.71546 .19147 L
s
P
p
.2 0 1 r
.022 w
.75719 .31991 m
.67781 .21066 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .40553 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.81612 .36272 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .31991 L
s
P
p
.2 0 1 r
.022 w
.44626 .27066 m
.55551 .19128 L
s
P
p
.2 0 1 r
.022 w
.44626 .27066 m
.52563 .16141 L
s
P
p
.2 0 1 r
.022 w
.44626 .27066 m
.48799 .14223 L
s
P
p
.2 0 1 r
.022 w
.37699 .29317 m
.26774 .21379 L
s
P
p
.2 0 1 r
.022 w
.37699 .29317 m
.24855 .25144 L
s
P
p
.2 0 1 r
.022 w
.37699 .29317 m
.24194 .29317 L
s
P
p
.2 0 1 r
.022 w
.4198 .35209 m
.37807 .48053 L
s
P
p
.2 0 1 r
.022 w
.4198 .35209 m
.4198 .48713 L
s
P
p
.2 0 1 r
.022 w
.4198 .35209 m
.46153 .48053 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.44626 .27066 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.37699 .29317 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.4198 .35209 L
s
P
p
.2 0 1 r
.022 w
.7003 .49501 m
.57186 .53674 L
s
P
p
.2 0 1 r
.022 w
.7003 .49501 m
.59104 .57439 L
s
P
p
.2 0 1 r
.022 w
.7003 .49501 m
.62092 .60426 L
s
P
p
.2 0 1 r
.022 w
.77313 .49501 m
.85251 .60426 L
s
P
p
.2 0 1 r
.022 w
.77313 .49501 m
.88238 .57439 L
s
P
p
.2 0 1 r
.022 w
.77313 .49501 m
.90156 .53674 L
s
P
p
.2 0 1 r
.022 w
.75062 .42574 m
.83 .31649 L
s
P
p
.2 0 1 r
.022 w
.75062 .42574 m
.79235 .29731 L
s
P
p
.2 0 1 r
.022 w
.75062 .42574 m
.75062 .2907 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.7003 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.77313 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.75062 .42574 L
s
P
p
.2 0 1 r
.022 w
.52802 .20314 m
.66306 .20314 L
s
P
p
.2 0 1 r
.022 w
.52802 .20314 m
.65645 .16141 L
s
P
p
.2 0 1 r
.022 w
.52802 .20314 m
.63727 .12376 L
s
P
p
.2 0 1 r
.022 w
.45875 .18063 m
.41702 .0522 L
s
P
p
.2 0 1 r
.022 w
.45875 .18063 m
.37937 .07138 L
s
P
p
.2 0 1 r
.022 w
.45875 .18063 m
.3495 .10126 L
s
P
p
.2 0 1 r
.022 w
.45875 .25347 m
.3495 .33284 L
s
P
p
.2 0 1 r
.022 w
.45875 .25347 m
.37937 .36272 L
s
P
p
.2 0 1 r
.022 w
.45875 .25347 m
.41702 .3819 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.52802 .20314 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .18063 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .25347 L
s
P
p
.2 0 1 r
.022 w
.60167 .53396 m
.47324 .49223 L
s
P
p
.2 0 1 r
.022 w
.60167 .53396 m
.46663 .53396 L
s
P
p
.2 0 1 r
.022 w
.60167 .53396 m
.47324 .57569 L
s
P
p
.2 0 1 r
.022 w
.66059 .57677 m
.66059 .71182 L
s
P
p
.2 0 1 r
.022 w
.66059 .57677 m
.70232 .70521 L
s
P
p
.2 0 1 r
.022 w
.66059 .57677 m
.73997 .68603 L
s
P
p
.2 0 1 r
.022 w
.6831 .5075 m
.81154 .46577 L
s
P
p
.2 0 1 r
.022 w
.6831 .5075 m
.79235 .42813 L
s
P
p
.2 0 1 r
.022 w
.6831 .5075 m
.76248 .39825 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.60167 .53396 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.66059 .57677 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.6831 .5075 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.7711 .36272 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.4198 .30708 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.73671 .46855 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.48521 .21705 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.64668 .53396 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.40896 .36272 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.46522 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.53478 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.59104 .36272 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.0100251 0.97619 0.135338 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0780989 0.952381 [
[ 0 0 0 0 ]
[ 1 .79618 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79618 L
0 .79618 L
closepath
clip
newpath
p
P
p
.8 0 1 r
.002 w
.3169 .5075 m
.23752 .39825 L
s
P
p
.8 0 1 r
.002 w
.3169 .5075 m
.20765 .42813 L
s
P
p
.8 0 1 r
.002 w
.3169 .5075 m
.18846 .46577 L
s
P
p
.8 0 1 r
.002 w
.33941 .57677 m
.26003 .68603 L
s
P
p
.8 0 1 r
.002 w
.33941 .57677 m
.29768 .70521 L
s
P
p
.8 0 1 r
.002 w
.33941 .57677 m
.33941 .71182 L
s
P
p
.8 0 1 r
.002 w
.39833 .53396 m
.52676 .57569 L
s
P
p
.8 0 1 r
.002 w
.39833 .53396 m
.53337 .53396 L
s
P
p
.8 0 1 r
.002 w
.39833 .53396 m
.52676 .49223 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.3169 .5075 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.33941 .57677 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.39833 .53396 L
s
P
p
.8 0 1 r
.002 w
.54125 .25347 m
.58298 .3819 L
s
P
p
.8 0 1 r
.002 w
.54125 .25347 m
.62063 .36272 L
s
P
p
.8 0 1 r
.002 w
.54125 .25347 m
.6505 .33284 L
s
P
p
.8 0 1 r
.002 w
.54125 .18063 m
.6505 .10126 L
s
P
p
.8 0 1 r
.002 w
.54125 .18063 m
.62063 .07138 L
s
P
p
.8 0 1 r
.002 w
.54125 .18063 m
.58298 .0522 L
s
P
p
.8 0 1 r
.002 w
.47198 .20314 m
.36273 .12376 L
s
P
p
.8 0 1 r
.002 w
.47198 .20314 m
.34355 .16141 L
s
P
p
.8 0 1 r
.002 w
.47198 .20314 m
.33694 .20314 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .25347 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .18063 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.47198 .20314 L
s
P
p
.8 0 1 r
.002 w
.24938 .42574 m
.24938 .2907 L
s
P
p
.8 0 1 r
.002 w
.24938 .42574 m
.20765 .29731 L
s
P
p
.8 0 1 r
.002 w
.24938 .42574 m
.17 .31649 L
s
P
p
.8 0 1 r
.002 w
.22687 .49501 m
.09844 .53674 L
s
P
p
.8 0 1 r
.002 w
.22687 .49501 m
.11762 .57439 L
s
P
p
.8 0 1 r
.002 w
.22687 .49501 m
.14749 .60426 L
s
P
p
.8 0 1 r
.002 w
.2997 .49501 m
.37908 .60426 L
s
P
p
.8 0 1 r
.002 w
.2997 .49501 m
.40896 .57439 L
s
P
p
.8 0 1 r
.002 w
.2997 .49501 m
.42814 .53674 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.24938 .42574 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.22687 .49501 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.2997 .49501 L
s
P
p
.8 0 1 r
.002 w
.5802 .35209 m
.53847 .48053 L
s
P
p
.8 0 1 r
.002 w
.5802 .35209 m
.5802 .48713 L
s
P
p
.8 0 1 r
.002 w
.5802 .35209 m
.62193 .48053 L
s
P
p
.8 0 1 r
.002 w
.62301 .29317 m
.75806 .29317 L
s
P
p
.8 0 1 r
.002 w
.62301 .29317 m
.75145 .25144 L
s
P
p
.8 0 1 r
.002 w
.62301 .29317 m
.73226 .21379 L
s
P
p
.8 0 1 r
.002 w
.55374 .27066 m
.51201 .14223 L
s
P
p
.8 0 1 r
.002 w
.55374 .27066 m
.47437 .16141 L
s
P
p
.8 0 1 r
.002 w
.55374 .27066 m
.44449 .19128 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.5802 .35209 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.62301 .29317 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.55374 .27066 L
s
P
p
.8 0 1 r
.002 w
.24281 .31991 m
.32219 .21066 L
s
P
p
.8 0 1 r
.002 w
.24281 .31991 m
.28454 .19147 L
s
P
p
.8 0 1 r
.002 w
.24281 .31991 m
.24281 .18486 L
s
P
p
.8 0 1 r
.002 w
.18388 .36272 m
.05545 .32099 L
s
P
p
.8 0 1 r
.002 w
.18388 .36272 m
.04884 .36272 L
s
P
p
.8 0 1 r
.002 w
.18388 .36272 m
.05545 .40445 L
s
P
p
.8 0 1 r
.002 w
.24281 .40553 m
.24281 .54057 L
s
P
p
.8 0 1 r
.002 w
.24281 .40553 m
.28454 .53396 L
s
P
p
.8 0 1 r
.002 w
.24281 .40553 m
.32219 .51478 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .31991 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.18388 .36272 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .40553 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.35332 .53396 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.51479 .21705 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.26329 .46855 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.5802 .30708 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.2289 .36272 L
s
P
p
.8 0 1 r
.002 w
.47585 .57484 m
.34742 .53311 L
s
P
p
.8 0 1 r
.002 w
.47585 .57484 m
.34081 .57484 L
s
P
p
.8 0 1 r
.002 w
.47585 .57484 m
.34742 .61657 L
s
P
p
.8 0 1 r
.002 w
.53478 .61766 m
.53478 .7527 L
s
P
p
.8 0 1 r
.002 w
.53478 .61766 m
.57651 .74609 L
s
P
p
.8 0 1 r
.002 w
.53478 .61766 m
.61415 .72691 L
s
P
p
.8 0 1 r
.002 w
.55728 .54839 m
.68572 .50665 L
s
P
p
.8 0 1 r
.002 w
.55728 .54839 m
.66653 .46901 L
s
P
p
.8 0 1 r
.002 w
.55728 .54839 m
.63666 .43913 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.47585 .57484 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.53478 .61766 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.55728 .54839 L
s
P
p
.8 0 1 r
.002 w
.50804 .23745 m
.61729 .31683 L
s
P
p
.8 0 1 r
.002 w
.50804 .23745 m
.63647 .27918 L
s
P
p
.8 0 1 r
.002 w
.50804 .23745 m
.64308 .23745 L
s
P
p
.8 0 1 r
.002 w
.46522 .17853 m
.50696 .05009 L
s
P
p
.8 0 1 r
.002 w
.46522 .17853 m
.46522 .04348 L
s
P
p
.8 0 1 r
.002 w
.46522 .17853 m
.42349 .05009 L
s
P
p
.8 0 1 r
.002 w
.42241 .23745 m
.28737 .23745 L
s
P
p
.8 0 1 r
.002 w
.42241 .23745 m
.29398 .27918 L
s
P
p
.8 0 1 r
.002 w
.42241 .23745 m
.31316 .31683 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.50804 .23745 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.46522 .17853 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.42241 .23745 L
s
P
p
.8 0 1 r
.002 w
.37317 .54839 m
.29379 .43913 L
s
P
p
.8 0 1 r
.002 w
.37317 .54839 m
.26391 .46901 L
s
P
p
.8 0 1 r
.002 w
.37317 .54839 m
.24473 .50665 L
s
P
p
.8 0 1 r
.002 w
.39567 .61766 m
.3163 .72691 L
s
P
p
.8 0 1 r
.002 w
.39567 .61766 m
.35394 .74609 L
s
P
p
.8 0 1 r
.002 w
.39567 .61766 m
.39567 .7527 L
s
P
p
.8 0 1 r
.002 w
.4546 .57484 m
.58303 .61657 L
s
P
p
.8 0 1 r
.002 w
.4546 .57484 m
.58964 .57484 L
s
P
p
.8 0 1 r
.002 w
.4546 .57484 m
.58303 .53311 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.37317 .54839 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.39567 .61766 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.4546 .57484 L
s
P
p
.8 0 1 r
.002 w
.59752 .29435 m
.63925 .42278 L
s
P
p
.8 0 1 r
.002 w
.59752 .29435 m
.67689 .4036 L
s
P
p
.8 0 1 r
.002 w
.59752 .29435 m
.70677 .37372 L
s
P
p
.8 0 1 r
.002 w
.59752 .22151 m
.70677 .14214 L
s
P
p
.8 0 1 r
.002 w
.59752 .22151 m
.67689 .11226 L
s
P
p
.8 0 1 r
.002 w
.59752 .22151 m
.63925 .09308 L
s
P
p
.8 0 1 r
.002 w
.52825 .24402 m
.419 .16464 L
s
P
p
.8 0 1 r
.002 w
.52825 .24402 m
.39981 .20229 L
s
P
p
.8 0 1 r
.002 w
.52825 .24402 m
.39321 .24402 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .29435 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .22151 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.52825 .24402 L
s
P
p
.8 0 1 r
.002 w
.30564 .46662 m
.30564 .33158 L
s
P
p
.8 0 1 r
.002 w
.30564 .46662 m
.26391 .33819 L
s
P
p
.8 0 1 r
.002 w
.30564 .46662 m
.22627 .35737 L
s
P
p
.8 0 1 r
.002 w
.28314 .53589 m
.1547 .57762 L
s
P
p
.8 0 1 r
.002 w
.28314 .53589 m
.17389 .61527 L
s
P
p
.8 0 1 r
.002 w
.28314 .53589 m
.20376 .64515 L
s
P
p
.8 0 1 r
.002 w
.35597 .53589 m
.43535 .64515 L
s
P
p
.8 0 1 r
.002 w
.35597 .53589 m
.46522 .61527 L
s
P
p
.8 0 1 r
.002 w
.35597 .53589 m
.48441 .57762 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.30564 .46662 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.28314 .53589 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.35597 .53589 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.52087 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.46522 .22354 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.40958 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.57106 .25793 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.31956 .50943 L
s
P
p
.8 0 1 r
.002 w
.64403 .53589 m
.51559 .57762 L
s
P
p
.8 0 1 r
.002 w
.64403 .53589 m
.53478 .61527 L
s
P
p
.8 0 1 r
.002 w
.64403 .53589 m
.56465 .64515 L
s
P
p
.8 0 1 r
.002 w
.71686 .53589 m
.79624 .64515 L
s
P
p
.8 0 1 r
.002 w
.71686 .53589 m
.82611 .61527 L
s
P
p
.8 0 1 r
.002 w
.71686 .53589 m
.8453 .57762 L
s
P
p
.8 0 1 r
.002 w
.69436 .46662 m
.77373 .35737 L
s
P
p
.8 0 1 r
.002 w
.69436 .46662 m
.73609 .33819 L
s
P
p
.8 0 1 r
.002 w
.69436 .46662 m
.69436 .33158 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.64403 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.71686 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.69436 .46662 L
s
P
p
.8 0 1 r
.002 w
.47175 .24402 m
.60679 .24402 L
s
P
p
.8 0 1 r
.002 w
.47175 .24402 m
.60019 .20229 L
s
P
p
.8 0 1 r
.002 w
.47175 .24402 m
.581 .16464 L
s
P
p
.8 0 1 r
.002 w
.40248 .22151 m
.36075 .09308 L
s
P
p
.8 0 1 r
.002 w
.40248 .22151 m
.32311 .11226 L
s
P
p
.8 0 1 r
.002 w
.40248 .22151 m
.29323 .14214 L
s
P
p
.8 0 1 r
.002 w
.40248 .29435 m
.29323 .37372 L
s
P
p
.8 0 1 r
.002 w
.40248 .29435 m
.32311 .4036 L
s
P
p
.8 0 1 r
.002 w
.40248 .29435 m
.36075 .42278 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.47175 .24402 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .22151 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .29435 L
s
P
p
.8 0 1 r
.002 w
.5454 .57484 m
.41697 .53311 L
s
P
p
.8 0 1 r
.002 w
.5454 .57484 m
.41036 .57484 L
s
P
p
.8 0 1 r
.002 w
.5454 .57484 m
.41697 .61657 L
s
P
p
.8 0 1 r
.002 w
.60433 .61766 m
.60433 .7527 L
s
P
p
.8 0 1 r
.002 w
.60433 .61766 m
.64606 .74609 L
s
P
p
.8 0 1 r
.002 w
.60433 .61766 m
.6837 .72691 L
s
P
p
.8 0 1 r
.002 w
.62683 .54839 m
.75527 .50665 L
s
P
p
.8 0 1 r
.002 w
.62683 .54839 m
.73609 .46901 L
s
P
p
.8 0 1 r
.002 w
.62683 .54839 m
.70621 .43913 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.5454 .57484 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.60433 .61766 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.62683 .54839 L
s
P
p
.8 0 1 r
.002 w
.57759 .23745 m
.68684 .31683 L
s
P
p
.8 0 1 r
.002 w
.57759 .23745 m
.70602 .27918 L
s
P
p
.8 0 1 r
.002 w
.57759 .23745 m
.71263 .23745 L
s
P
p
.8 0 1 r
.002 w
.53478 .17853 m
.57651 .05009 L
s
P
p
.8 0 1 r
.002 w
.53478 .17853 m
.53478 .04348 L
s
P
p
.8 0 1 r
.002 w
.53478 .17853 m
.49304 .05009 L
s
P
p
.8 0 1 r
.002 w
.49196 .23745 m
.35692 .23745 L
s
P
p
.8 0 1 r
.002 w
.49196 .23745 m
.36353 .27918 L
s
P
p
.8 0 1 r
.002 w
.49196 .23745 m
.38271 .31683 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.57759 .23745 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.53478 .17853 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.49196 .23745 L
s
P
p
.8 0 1 r
.002 w
.44272 .54839 m
.36334 .43913 L
s
P
p
.8 0 1 r
.002 w
.44272 .54839 m
.33347 .46901 L
s
P
p
.8 0 1 r
.002 w
.44272 .54839 m
.31428 .50665 L
s
P
p
.8 0 1 r
.002 w
.46522 .61766 m
.38585 .72691 L
s
P
p
.8 0 1 r
.002 w
.46522 .61766 m
.42349 .74609 L
s
P
p
.8 0 1 r
.002 w
.46522 .61766 m
.46522 .7527 L
s
P
p
.8 0 1 r
.002 w
.52415 .57484 m
.65258 .61657 L
s
P
p
.8 0 1 r
.002 w
.52415 .57484 m
.65919 .57484 L
s
P
p
.8 0 1 r
.002 w
.52415 .57484 m
.65258 .53311 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.44272 .54839 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.46522 .61766 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.52415 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.68044 .50943 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.42894 .25793 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.59042 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.53478 .22354 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.47913 .57484 L
s
P
p
.8 0 1 r
.002 w
.75719 .40553 m
.67781 .51478 L
s
P
p
.8 0 1 r
.002 w
.75719 .40553 m
.71546 .53396 L
s
P
p
.8 0 1 r
.002 w
.75719 .40553 m
.75719 .54057 L
s
P
p
.8 0 1 r
.002 w
.81612 .36272 m
.94455 .40445 L
s
P
p
.8 0 1 r
.002 w
.81612 .36272 m
.95116 .36272 L
s
P
p
.8 0 1 r
.002 w
.81612 .36272 m
.94455 .32099 L
s
P
p
.8 0 1 r
.002 w
.75719 .31991 m
.75719 .18486 L
s
P
p
.8 0 1 r
.002 w
.75719 .31991 m
.71546 .19147 L
s
P
p
.8 0 1 r
.002 w
.75719 .31991 m
.67781 .21066 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .40553 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.81612 .36272 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .31991 L
s
P
p
.8 0 1 r
.002 w
.44626 .27066 m
.55551 .19128 L
s
P
p
.8 0 1 r
.002 w
.44626 .27066 m
.52563 .16141 L
s
P
p
.8 0 1 r
.002 w
.44626 .27066 m
.48799 .14223 L
s
P
p
.8 0 1 r
.002 w
.37699 .29317 m
.26774 .21379 L
s
P
p
.8 0 1 r
.002 w
.37699 .29317 m
.24855 .25144 L
s
P
p
.8 0 1 r
.002 w
.37699 .29317 m
.24194 .29317 L
s
P
p
.8 0 1 r
.002 w
.4198 .35209 m
.37807 .48053 L
s
P
p
.8 0 1 r
.002 w
.4198 .35209 m
.4198 .48713 L
s
P
p
.8 0 1 r
.002 w
.4198 .35209 m
.46153 .48053 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.44626 .27066 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.37699 .29317 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.4198 .35209 L
s
P
p
.8 0 1 r
.002 w
.7003 .49501 m
.57186 .53674 L
s
P
p
.8 0 1 r
.002 w
.7003 .49501 m
.59104 .57439 L
s
P
p
.8 0 1 r
.002 w
.7003 .49501 m
.62092 .60426 L
s
P
p
.8 0 1 r
.002 w
.77313 .49501 m
.85251 .60426 L
s
P
p
.8 0 1 r
.002 w
.77313 .49501 m
.88238 .57439 L
s
P
p
.8 0 1 r
.002 w
.77313 .49501 m
.90156 .53674 L
s
P
p
.8 0 1 r
.002 w
.75062 .42574 m
.83 .31649 L
s
P
p
.8 0 1 r
.002 w
.75062 .42574 m
.79235 .29731 L
s
P
p
.8 0 1 r
.002 w
.75062 .42574 m
.75062 .2907 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.7003 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.77313 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.75062 .42574 L
s
P
p
.8 0 1 r
.002 w
.52802 .20314 m
.66306 .20314 L
s
P
p
.8 0 1 r
.002 w
.52802 .20314 m
.65645 .16141 L
s
P
p
.8 0 1 r
.002 w
.52802 .20314 m
.63727 .12376 L
s
P
p
.8 0 1 r
.002 w
.45875 .18063 m
.41702 .0522 L
s
P
p
.8 0 1 r
.002 w
.45875 .18063 m
.37937 .07138 L
s
P
p
.8 0 1 r
.002 w
.45875 .18063 m
.3495 .10126 L
s
P
p
.8 0 1 r
.002 w
.45875 .25347 m
.3495 .33284 L
s
P
p
.8 0 1 r
.002 w
.45875 .25347 m
.37937 .36272 L
s
P
p
.8 0 1 r
.002 w
.45875 .25347 m
.41702 .3819 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.52802 .20314 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .18063 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .25347 L
s
P
p
.8 0 1 r
.002 w
.60167 .53396 m
.47324 .49223 L
s
P
p
.8 0 1 r
.002 w
.60167 .53396 m
.46663 .53396 L
s
P
p
.8 0 1 r
.002 w
.60167 .53396 m
.47324 .57569 L
s
P
p
.8 0 1 r
.002 w
.66059 .57677 m
.66059 .71182 L
s
P
p
.8 0 1 r
.002 w
.66059 .57677 m
.70232 .70521 L
s
P
p
.8 0 1 r
.002 w
.66059 .57677 m
.73997 .68603 L
s
P
p
.8 0 1 r
.002 w
.6831 .5075 m
.81154 .46577 L
s
P
p
.8 0 1 r
.002 w
.6831 .5075 m
.79235 .42813 L
s
P
p
.8 0 1 r
.002 w
.6831 .5075 m
.76248 .39825 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.60167 .53396 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.66059 .57677 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.6831 .5075 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.7711 .36272 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.4198 .30708 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.73671 .46855 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.48521 .21705 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.64668 .53396 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.40896 .36272 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.46522 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.53478 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.59104 .36272 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.14787 0.149123 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0384054 0.952381 [
[ 0 0 0 0 ]
[ 1 .87557 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .87557 L
0 .87557 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.21861 .46265 m
.21861 .31102 L
s
P
p
.2 0 1 r
.002 w
.21861 .46265 m
.17175 .31844 L
s
P
p
.2 0 1 r
.002 w
.21861 .46265 m
.12948 .33998 L
s
P
p
.2 0 1 r
.002 w
.19334 .54042 m
.04913 .58728 L
s
P
p
.2 0 1 r
.002 w
.19334 .54042 m
.07067 .62954 L
s
P
p
.2 0 1 r
.002 w
.19334 .54042 m
.10421 .66309 L
s
P
p
.2 0 1 r
.002 w
.27511 .54042 m
.36423 .66309 L
s
P
p
.2 0 1 r
.002 w
.27511 .54042 m
.39778 .62954 L
s
P
p
.2 0 1 r
.002 w
.27511 .54042 m
.41931 .58728 L
s
P
p
0 .4 1 r
.018 w
.23422 .51071 m
.21861 .46265 L
s
P
p
0 .4 1 r
.018 w
.23422 .51071 m
.19334 .54042 L
s
P
p
0 .4 1 r
.018 w
.23422 .51071 m
.27511 .54042 L
s
P
p
.2 0 1 r
.002 w
.57695 .32112 m
.57695 .47275 L
s
P
p
.2 0 1 r
.002 w
.57695 .32112 m
.62381 .46533 L
s
P
p
.2 0 1 r
.002 w
.57695 .32112 m
.66607 .44379 L
s
P
p
.2 0 1 r
.002 w
.60222 .24335 m
.74642 .19649 L
s
P
p
.2 0 1 r
.002 w
.60222 .24335 m
.72489 .15423 L
s
P
p
.2 0 1 r
.002 w
.60222 .24335 m
.69134 .12068 L
s
P
p
.2 0 1 r
.002 w
.52044 .24335 m
.43132 .12068 L
s
P
p
.2 0 1 r
.002 w
.52044 .24335 m
.39778 .15423 L
s
P
p
.2 0 1 r
.002 w
.52044 .24335 m
.37624 .19649 L
s
P
p
0 .4 1 r
.018 w
.56133 .27306 m
.57695 .32112 L
s
P
p
0 .4 1 r
.018 w
.56133 .27306 m
.60222 .24335 L
s
P
p
0 .4 1 r
.018 w
.56133 .27306 m
.52044 .24335 L
s
P
p
.2 0 1 r
.016 w
.39778 .39188 m
.23422 .51071 L
s
P
p
.2 0 1 r
.016 w
.39778 .39188 m
.56133 .27306 L
s
P
p
.2 0 1 r
.002 w
.35759 .60035 m
.26847 .47768 L
s
P
p
.2 0 1 r
.002 w
.35759 .60035 m
.23493 .51123 L
s
P
p
.2 0 1 r
.002 w
.35759 .60035 m
.21339 .55349 L
s
P
p
.2 0 1 r
.002 w
.38286 .67812 m
.29374 .80079 L
s
P
p
.2 0 1 r
.002 w
.38286 .67812 m
.33601 .82232 L
s
P
p
.2 0 1 r
.002 w
.38286 .67812 m
.38286 .82975 L
s
P
p
.2 0 1 r
.002 w
.44902 .63005 m
.59323 .67691 L
s
P
p
.2 0 1 r
.002 w
.44902 .63005 m
.60065 .63005 L
s
P
p
.2 0 1 r
.002 w
.44902 .63005 m
.59323 .5832 L
s
P
p
0 .4 1 r
.018 w
.39848 .63005 m
.35759 .60035 L
s
P
p
0 .4 1 r
.018 w
.39848 .63005 m
.38286 .67812 L
s
P
p
0 .4 1 r
.018 w
.39848 .63005 m
.44902 .63005 L
s
P
p
.2 0 1 r
.002 w
.56432 .27522 m
.65344 .39789 L
s
P
p
.2 0 1 r
.002 w
.56432 .27522 m
.68698 .36434 L
s
P
p
.2 0 1 r
.002 w
.56432 .27522 m
.70852 .32208 L
s
P
p
.2 0 1 r
.002 w
.53905 .19745 m
.62817 .07478 L
s
P
p
.2 0 1 r
.002 w
.53905 .19745 m
.5859 .05325 L
s
P
p
.2 0 1 r
.002 w
.53905 .19745 m
.53905 .04582 L
s
P
p
.2 0 1 r
.002 w
.47289 .24552 m
.32868 .19866 L
s
P
p
.2 0 1 r
.002 w
.47289 .24552 m
.32126 .24552 L
s
P
p
.2 0 1 r
.002 w
.47289 .24552 m
.32868 .29237 L
s
P
p
0 .4 1 r
.018 w
.52343 .24552 m
.56432 .27522 L
s
P
p
0 .4 1 r
.018 w
.52343 .24552 m
.53905 .19745 L
s
P
p
0 .4 1 r
.018 w
.52343 .24552 m
.47289 .24552 L
s
P
p
.2 0 1 r
.016 w
.46095 .43779 m
.39848 .63005 L
s
P
p
.2 0 1 r
.016 w
.46095 .43779 m
.52343 .24552 L
s
P
p
.2 0 1 r
.002 w
.55098 .63005 m
.40677 .5832 L
s
P
p
.2 0 1 r
.002 w
.55098 .63005 m
.39935 .63005 L
s
P
p
.2 0 1 r
.002 w
.55098 .63005 m
.40677 .67691 L
s
P
p
.2 0 1 r
.002 w
.61714 .67812 m
.61714 .82975 L
s
P
p
.2 0 1 r
.002 w
.61714 .67812 m
.66399 .82232 L
s
P
p
.2 0 1 r
.002 w
.61714 .67812 m
.70626 .80079 L
s
P
p
.2 0 1 r
.002 w
.64241 .60035 m
.78661 .55349 L
s
P
p
.2 0 1 r
.002 w
.64241 .60035 m
.76507 .51123 L
s
P
p
.2 0 1 r
.002 w
.64241 .60035 m
.73153 .47768 L
s
P
p
0 .4 1 r
.018 w
.60152 .63005 m
.55098 .63005 L
s
P
p
0 .4 1 r
.018 w
.60152 .63005 m
.61714 .67812 L
s
P
p
0 .4 1 r
.018 w
.60152 .63005 m
.64241 .60035 L
s
P
p
.2 0 1 r
.002 w
.52711 .24552 m
.67132 .29237 L
s
P
p
.2 0 1 r
.002 w
.52711 .24552 m
.67874 .24552 L
s
P
p
.2 0 1 r
.002 w
.52711 .24552 m
.67132 .19866 L
s
P
p
.2 0 1 r
.002 w
.46095 .19745 m
.46095 .04582 L
s
P
p
.2 0 1 r
.002 w
.46095 .19745 m
.4141 .05325 L
s
P
p
.2 0 1 r
.002 w
.46095 .19745 m
.37183 .07478 L
s
P
p
.2 0 1 r
.002 w
.43568 .27522 m
.29148 .32208 L
s
P
p
.2 0 1 r
.002 w
.43568 .27522 m
.31302 .36434 L
s
P
p
.2 0 1 r
.002 w
.43568 .27522 m
.34656 .39789 L
s
P
p
0 .4 1 r
.018 w
.47657 .24552 m
.52711 .24552 L
s
P
p
0 .4 1 r
.018 w
.47657 .24552 m
.46095 .19745 L
s
P
p
0 .4 1 r
.018 w
.47657 .24552 m
.43568 .27522 L
s
P
p
.2 0 1 r
.016 w
.53905 .43779 m
.60152 .63005 L
s
P
p
.2 0 1 r
.016 w
.53905 .43779 m
.47657 .24552 L
s
P
p
.2 0 1 r
.002 w
.72489 .54042 m
.58069 .58728 L
s
P
p
.2 0 1 r
.002 w
.72489 .54042 m
.60222 .62954 L
s
P
p
.2 0 1 r
.002 w
.72489 .54042 m
.63577 .66309 L
s
P
p
.2 0 1 r
.002 w
.80666 .54042 m
.89579 .66309 L
s
P
p
.2 0 1 r
.002 w
.80666 .54042 m
.92933 .62954 L
s
P
p
.2 0 1 r
.002 w
.80666 .54042 m
.95087 .58728 L
s
P
p
.2 0 1 r
.002 w
.78139 .46265 m
.87052 .33998 L
s
P
p
.2 0 1 r
.002 w
.78139 .46265 m
.82825 .31844 L
s
P
p
.2 0 1 r
.002 w
.78139 .46265 m
.78139 .31102 L
s
P
p
0 .4 1 r
.018 w
.76578 .51071 m
.72489 .54042 L
s
P
p
0 .4 1 r
.018 w
.76578 .51071 m
.80666 .54042 L
s
P
p
0 .4 1 r
.018 w
.76578 .51071 m
.78139 .46265 L
s
P
p
.2 0 1 r
.002 w
.47956 .24335 m
.62376 .19649 L
s
P
p
.2 0 1 r
.002 w
.47956 .24335 m
.60222 .15423 L
s
P
p
.2 0 1 r
.002 w
.47956 .24335 m
.56868 .12068 L
s
P
p
.2 0 1 r
.002 w
.39778 .24335 m
.30866 .12068 L
s
P
p
.2 0 1 r
.002 w
.39778 .24335 m
.27511 .15423 L
s
P
p
.2 0 1 r
.002 w
.39778 .24335 m
.25358 .19649 L
s
P
p
.2 0 1 r
.002 w
.42305 .32112 m
.33393 .44379 L
s
P
p
.2 0 1 r
.002 w
.42305 .32112 m
.37619 .46533 L
s
P
p
.2 0 1 r
.002 w
.42305 .32112 m
.42305 .47275 L
s
P
p
0 .4 1 r
.018 w
.43867 .27306 m
.47956 .24335 L
s
P
p
0 .4 1 r
.018 w
.43867 .27306 m
.39778 .24335 L
s
P
p
0 .4 1 r
.018 w
.43867 .27306 m
.42305 .32112 L
s
P
p
.2 0 1 r
.016 w
.60222 .39188 m
.76578 .51071 L
s
P
p
.2 0 1 r
.016 w
.60222 .39188 m
.43867 .27306 L
s
P
p
1 .6 0 r
.016 w
.5 .31762 m
.39778 .39188 L
s
P
p
1 .6 0 r
.016 w
.5 .31762 m
.46095 .43779 L
s
P
p
1 .6 0 r
.016 w
.5 .31762 m
.53905 .43779 L
s
P
p
1 .6 0 r
.016 w
.5 .31762 m
.60222 .39188 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.14787 0.286967 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0828379 0.952381 [
[ 0 0 0 0 ]
[ 1 .78671 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78671 L
0 .78671 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.31466 .48538 m
.23113 .37042 L
s
P
p
.2 0 1 r
.002 w
.31466 .48538 m
.1997 .40185 L
s
P
p
.2 0 1 r
.002 w
.31466 .48538 m
.17952 .44147 L
s
P
p
.2 0 1 r
.002 w
.33834 .55826 m
.25482 .67322 L
s
P
p
.2 0 1 r
.002 w
.33834 .55826 m
.29443 .6934 L
s
P
p
.2 0 1 r
.002 w
.33834 .55826 m
.33834 .70036 L
s
P
p
.2 0 1 r
.002 w
.40034 .51322 m
.53548 .55713 L
s
P
p
.2 0 1 r
.002 w
.40034 .51322 m
.54243 .51322 L
s
P
p
.2 0 1 r
.002 w
.40034 .51322 m
.53548 .46931 L
s
P
p
0 .4 1 r
.018 w
.35297 .51322 m
.31466 .48538 L
s
P
p
0 .4 1 r
.018 w
.35297 .51322 m
.33834 .55826 L
s
P
p
0 .4 1 r
.018 w
.35297 .51322 m
.40034 .51322 L
s
P
p
.2 0 1 r
.002 w
.52948 .25976 m
.57339 .3949 L
s
P
p
.2 0 1 r
.002 w
.52948 .25976 m
.61301 .37471 L
s
P
p
.2 0 1 r
.002 w
.52948 .25976 m
.64444 .34328 L
s
P
p
.2 0 1 r
.002 w
.52948 .18312 m
.64444 .0996 L
s
P
p
.2 0 1 r
.002 w
.52948 .18312 m
.61301 .06816 L
s
P
p
.2 0 1 r
.002 w
.52948 .18312 m
.57339 .04798 L
s
P
p
.2 0 1 r
.002 w
.4566 .2068 m
.34164 .12328 L
s
P
p
.2 0 1 r
.002 w
.4566 .2068 m
.32146 .16289 L
s
P
p
.2 0 1 r
.002 w
.4566 .2068 m
.3145 .2068 L
s
P
p
0 .4 1 r
.018 w
.50164 .22144 m
.52948 .25976 L
s
P
p
0 .4 1 r
.018 w
.50164 .22144 m
.52948 .18312 L
s
P
p
0 .4 1 r
.018 w
.50164 .22144 m
.4566 .2068 L
s
P
p
.2 0 1 r
.002 w
.25545 .40795 m
.25545 .26585 L
s
P
p
.2 0 1 r
.002 w
.25545 .40795 m
.21154 .27281 L
s
P
p
.2 0 1 r
.002 w
.25545 .40795 m
.17193 .29299 L
s
P
p
.2 0 1 r
.002 w
.23177 .48083 m
.09663 .52474 L
s
P
p
.2 0 1 r
.002 w
.23177 .48083 m
.11681 .56436 L
s
P
p
.2 0 1 r
.002 w
.23177 .48083 m
.14825 .59579 L
s
P
p
.2 0 1 r
.002 w
.3084 .48083 m
.39193 .59579 L
s
P
p
.2 0 1 r
.002 w
.3084 .48083 m
.42336 .56436 L
s
P
p
.2 0 1 r
.002 w
.3084 .48083 m
.44355 .52474 L
s
P
p
0 .4 1 r
.018 w
.27009 .45299 m
.25545 .40795 L
s
P
p
0 .4 1 r
.018 w
.27009 .45299 m
.23177 .48083 L
s
P
p
0 .4 1 r
.018 w
.27009 .45299 m
.3084 .48083 L
s
P
p
.2 0 1 r
.002 w
.56187 .35169 m
.51796 .48683 L
s
P
p
.2 0 1 r
.002 w
.56187 .35169 m
.56187 .49378 L
s
P
p
.2 0 1 r
.002 w
.56187 .35169 m
.60578 .48683 L
s
P
p
.2 0 1 r
.002 w
.60691 .28969 m
.74901 .28969 L
s
P
p
.2 0 1 r
.002 w
.60691 .28969 m
.74205 .24578 L
s
P
p
.2 0 1 r
.002 w
.60691 .28969 m
.72187 .20617 L
s
P
p
.2 0 1 r
.002 w
.53403 .26601 m
.49012 .13087 L
s
P
p
.2 0 1 r
.002 w
.53403 .26601 m
.4505 .15105 L
s
P
p
.2 0 1 r
.002 w
.53403 .26601 m
.41907 .18248 L
s
P
p
0 .4 1 r
.018 w
.56187 .30432 m
.56187 .35169 L
s
P
p
0 .4 1 r
.018 w
.56187 .30432 m
.60691 .28969 L
s
P
p
0 .4 1 r
.018 w
.56187 .30432 m
.53403 .26601 L
s
P
p
.2 0 1 r
.002 w
.25306 .31051 m
.33658 .19555 L
s
P
p
.2 0 1 r
.002 w
.25306 .31051 m
.29697 .17537 L
s
P
p
.2 0 1 r
.002 w
.25306 .31051 m
.25306 .16841 L
s
P
p
.2 0 1 r
.002 w
.19106 .35555 m
.05592 .31164 L
s
P
p
.2 0 1 r
.002 w
.19106 .35555 m
.04897 .35555 L
s
P
p
.2 0 1 r
.002 w
.19106 .35555 m
.05592 .39946 L
s
P
p
.2 0 1 r
.002 w
.25306 .4006 m
.25306 .54269 L
s
P
p
.2 0 1 r
.002 w
.25306 .4006 m
.29697 .53574 L
s
P
p
.2 0 1 r
.002 w
.25306 .4006 m
.33658 .51556 L
s
P
p
0 .4 1 r
.018 w
.23843 .35555 m
.25306 .31051 L
s
P
p
0 .4 1 r
.018 w
.23843 .35555 m
.19106 .35555 L
s
P
p
0 .4 1 r
.018 w
.23843 .35555 m
.25306 .4006 L
s
P
p
.2 0 1 r
.016 w
.4042 .35555 m
.35297 .51322 L
s
P
p
.2 0 1 r
.016 w
.4042 .35555 m
.50164 .22144 L
s
P
p
.2 0 1 r
.016 w
.4042 .35555 m
.27009 .45299 L
s
P
p
.2 0 1 r
.016 w
.4042 .35555 m
.56187 .30432 L
s
P
p
.2 0 1 r
.016 w
.4042 .35555 m
.23843 .35555 L
s
P
p
.2 0 1 r
.002 w
.46727 .55623 m
.33213 .51232 L
s
P
p
.2 0 1 r
.002 w
.46727 .55623 m
.32518 .55623 L
s
P
p
.2 0 1 r
.002 w
.46727 .55623 m
.33213 .60014 L
s
P
p
.2 0 1 r
.002 w
.52927 .60128 m
.52927 .74337 L
s
P
p
.2 0 1 r
.002 w
.52927 .60128 m
.57318 .73642 L
s
P
p
.2 0 1 r
.002 w
.52927 .60128 m
.61279 .71624 L
s
P
p
.2 0 1 r
.002 w
.55296 .52839 m
.6881 .48448 L
s
P
p
.2 0 1 r
.002 w
.55296 .52839 m
.66791 .44487 L
s
P
p
.2 0 1 r
.002 w
.55296 .52839 m
.63648 .41343 L
s
P
p
0 .4 1 r
.018 w
.51464 .55623 m
.46727 .55623 L
s
P
p
0 .4 1 r
.018 w
.51464 .55623 m
.52927 .60128 L
s
P
p
0 .4 1 r
.018 w
.51464 .55623 m
.55296 .52839 L
s
P
p
.2 0 1 r
.002 w
.50846 .24743 m
.62341 .33095 L
s
P
p
.2 0 1 r
.002 w
.50846 .24743 m
.6436 .29134 L
s
P
p
.2 0 1 r
.002 w
.50846 .24743 m
.65055 .24743 L
s
P
p
.2 0 1 r
.002 w
.46341 .18543 m
.50732 .05029 L
s
P
p
.2 0 1 r
.002 w
.46341 .18543 m
.46341 .04333 L
s
P
p
.2 0 1 r
.002 w
.46341 .18543 m
.4195 .05029 L
s
P
p
.2 0 1 r
.002 w
.41836 .24743 m
.27627 .24743 L
s
P
p
.2 0 1 r
.002 w
.41836 .24743 m
.28322 .29134 L
s
P
p
.2 0 1 r
.002 w
.41836 .24743 m
.3034 .33095 L
s
P
p
0 .4 1 r
.018 w
.46341 .23279 m
.50846 .24743 L
s
P
p
0 .4 1 r
.018 w
.46341 .23279 m
.46341 .18543 L
s
P
p
0 .4 1 r
.018 w
.46341 .23279 m
.41836 .24743 L
s
P
p
.2 0 1 r
.002 w
.37386 .52839 m
.29034 .41343 L
s
P
p
.2 0 1 r
.002 w
.37386 .52839 m
.2589 .44487 L
s
P
p
.2 0 1 r
.002 w
.37386 .52839 m
.23872 .48448 L
s
P
p
.2 0 1 r
.002 w
.39754 .60128 m
.31402 .71624 L
s
P
p
.2 0 1 r
.002 w
.39754 .60128 m
.35363 .73642 L
s
P
p
.2 0 1 r
.002 w
.39754 .60128 m
.39754 .74337 L
s
P
p
.2 0 1 r
.002 w
.45955 .55623 m
.59469 .60014 L
s
P
p
.2 0 1 r
.002 w
.45955 .55623 m
.60164 .55623 L
s
P
p
.2 0 1 r
.002 w
.45955 .55623 m
.59469 .51232 L
s
P
p
0 .4 1 r
.018 w
.41218 .55623 m
.37386 .52839 L
s
P
p
0 .4 1 r
.018 w
.41218 .55623 m
.39754 .60128 L
s
P
p
0 .4 1 r
.018 w
.41218 .55623 m
.45955 .55623 L
s
P
p
.2 0 1 r
.002 w
.58869 .30277 m
.6326 .43791 L
s
P
p
.2 0 1 r
.002 w
.58869 .30277 m
.67221 .41773 L
s
P
p
.2 0 1 r
.002 w
.58869 .30277 m
.70365 .38629 L
s
P
p
.2 0 1 r
.002 w
.58869 .22613 m
.70365 .14261 L
s
P
p
.2 0 1 r
.002 w
.58869 .22613 m
.67221 .11118 L
s
P
p
.2 0 1 r
.002 w
.58869 .22613 m
.6326 .09099 L
s
P
p
.2 0 1 r
.002 w
.5158 .24982 m
.40085 .16629 L
s
P
p
.2 0 1 r
.002 w
.5158 .24982 m
.38066 .20591 L
s
P
p
.2 0 1 r
.002 w
.5158 .24982 m
.37371 .24982 L
s
P
p
0 .4 1 r
.018 w
.56085 .26445 m
.58869 .30277 L
s
P
p
0 .4 1 r
.018 w
.56085 .26445 m
.58869 .22613 L
s
P
p
0 .4 1 r
.018 w
.56085 .26445 m
.5158 .24982 L
s
P
p
.2 0 1 r
.002 w
.31466 .45096 m
.31466 .30887 L
s
P
p
.2 0 1 r
.002 w
.31466 .45096 m
.27075 .31582 L
s
P
p
.2 0 1 r
.002 w
.31466 .45096 m
.23113 .33601 L
s
P
p
.2 0 1 r
.002 w
.29097 .52385 m
.15583 .56776 L
s
P
p
.2 0 1 r
.002 w
.29097 .52385 m
.17602 .60737 L
s
P
p
.2 0 1 r
.002 w
.29097 .52385 m
.20745 .63881 L
s
P
p
.2 0 1 r
.002 w
.36761 .52385 m
.45113 .63881 L
s
P
p
.2 0 1 r
.002 w
.36761 .52385 m
.48257 .60737 L
s
P
p
.2 0 1 r
.002 w
.36761 .52385 m
.50275 .56776 L
s
P
p
0 .4 1 r
.018 w
.32929 .49601 m
.31466 .45096 L
s
P
p
0 .4 1 r
.018 w
.32929 .49601 m
.29097 .52385 L
s
P
p
0 .4 1 r
.018 w
.32929 .49601 m
.36761 .52385 L
s
P
p
.2 0 1 r
.016 w
.46341 .39857 m
.51464 .55623 L
s
P
p
.2 0 1 r
.016 w
.46341 .39857 m
.46341 .23279 L
s
P
p
.2 0 1 r
.016 w
.46341 .39857 m
.41218 .55623 L
s
P
p
.2 0 1 r
.016 w
.46341 .39857 m
.56085 .26445 L
s
P
p
.2 0 1 r
.016 w
.46341 .39857 m
.32929 .49601 L
s
P
p
.2 0 1 r
.002 w
.63239 .52385 m
.49725 .56776 L
s
P
p
.2 0 1 r
.002 w
.63239 .52385 m
.51743 .60737 L
s
P
p
.2 0 1 r
.002 w
.63239 .52385 m
.54887 .63881 L
s
P
p
.2 0 1 r
.002 w
.70903 .52385 m
.79255 .63881 L
s
P
p
.2 0 1 r
.002 w
.70903 .52385 m
.82398 .60737 L
s
P
p
.2 0 1 r
.002 w
.70903 .52385 m
.84417 .56776 L
s
P
p
.2 0 1 r
.002 w
.68534 .45096 m
.76887 .33601 L
s
P
p
.2 0 1 r
.002 w
.68534 .45096 m
.72925 .31582 L
s
P
p
.2 0 1 r
.002 w
.68534 .45096 m
.68534 .30887 L
s
P
p
0 .4 1 r
.018 w
.67071 .49601 m
.63239 .52385 L
s
P
p
0 .4 1 r
.018 w
.67071 .49601 m
.70903 .52385 L
s
P
p
0 .4 1 r
.018 w
.67071 .49601 m
.68534 .45096 L
s
P
p
.2 0 1 r
.002 w
.4842 .24982 m
.62629 .24982 L
s
P
p
.2 0 1 r
.002 w
.4842 .24982 m
.61934 .20591 L
s
P
p
.2 0 1 r
.002 w
.4842 .24982 m
.59915 .16629 L
s
P
p
.2 0 1 r
.002 w
.41131 .22613 m
.3674 .09099 L
s
P
p
.2 0 1 r
.002 w
.41131 .22613 m
.32779 .11118 L
s
P
p
.2 0 1 r
.002 w
.41131 .22613 m
.29635 .14261 L
s
P
p
.2 0 1 r
.002 w
.41131 .30277 m
.29635 .38629 L
s
P
p
.2 0 1 r
.002 w
.41131 .30277 m
.32779 .41773 L
s
P
p
.2 0 1 r
.002 w
.41131 .30277 m
.3674 .43791 L
s
P
p
0 .4 1 r
.018 w
.43915 .26445 m
.4842 .24982 L
s
P
p
0 .4 1 r
.018 w
.43915 .26445 m
.41131 .22613 L
s
P
p
0 .4 1 r
.018 w
.43915 .26445 m
.41131 .30277 L
s
P
p
.2 0 1 r
.002 w
.54045 .55623 m
.40531 .51232 L
s
P
p
.2 0 1 r
.002 w
.54045 .55623 m
.39836 .55623 L
s
P
p
.2 0 1 r
.002 w
.54045 .55623 m
.40531 .60014 L
s
P
p
.2 0 1 r
.002 w
.60246 .60128 m
.60246 .74337 L
s
P
p
.2 0 1 r
.002 w
.60246 .60128 m
.64637 .73642 L
s
P
p
.2 0 1 r
.002 w
.60246 .60128 m
.68598 .71624 L
s
P
p
.2 0 1 r
.002 w
.62614 .52839 m
.76128 .48448 L
s
P
p
.2 0 1 r
.002 w
.62614 .52839 m
.7411 .44487 L
s
P
p
.2 0 1 r
.002 w
.62614 .52839 m
.70966 .41343 L
s
P
p
0 .4 1 r
.018 w
.58782 .55623 m
.54045 .55623 L
s
P
p
0 .4 1 r
.018 w
.58782 .55623 m
.60246 .60128 L
s
P
p
0 .4 1 r
.018 w
.58782 .55623 m
.62614 .52839 L
s
P
p
.2 0 1 r
.002 w
.58164 .24743 m
.6966 .33095 L
s
P
p
.2 0 1 r
.002 w
.58164 .24743 m
.71678 .29134 L
s
P
p
.2 0 1 r
.002 w
.58164 .24743 m
.72373 .24743 L
s
P
p
.2 0 1 r
.002 w
.53659 .18543 m
.5805 .05029 L
s
P
p
.2 0 1 r
.002 w
.53659 .18543 m
.53659 .04333 L
s
P
p
.2 0 1 r
.002 w
.53659 .18543 m
.49268 .05029 L
s
P
p
.2 0 1 r
.002 w
.49154 .24743 m
.34945 .24743 L
s
P
p
.2 0 1 r
.002 w
.49154 .24743 m
.3564 .29134 L
s
P
p
.2 0 1 r
.002 w
.49154 .24743 m
.37659 .33095 L
s
P
p
0 .4 1 r
.018 w
.53659 .23279 m
.58164 .24743 L
s
P
p
0 .4 1 r
.018 w
.53659 .23279 m
.53659 .18543 L
s
P
p
0 .4 1 r
.018 w
.53659 .23279 m
.49154 .24743 L
s
P
p
.2 0 1 r
.002 w
.44704 .52839 m
.36352 .41343 L
s
P
p
.2 0 1 r
.002 w
.44704 .52839 m
.33209 .44487 L
s
P
p
.2 0 1 r
.002 w
.44704 .52839 m
.3119 .48448 L
s
P
p
.2 0 1 r
.002 w
.47073 .60128 m
.38721 .71624 L
s
P
p
.2 0 1 r
.002 w
.47073 .60128 m
.42682 .73642 L
s
P
p
.2 0 1 r
.002 w
.47073 .60128 m
.47073 .74337 L
s
P
p
.2 0 1 r
.002 w
.53273 .55623 m
.66787 .60014 L
s
P
p
.2 0 1 r
.002 w
.53273 .55623 m
.67482 .55623 L
s
P
p
.2 0 1 r
.002 w
.53273 .55623 m
.66787 .51232 L
s
P
p
0 .4 1 r
.018 w
.48536 .55623 m
.44704 .52839 L
s
P
p
0 .4 1 r
.018 w
.48536 .55623 m
.47073 .60128 L
s
P
p
0 .4 1 r
.018 w
.48536 .55623 m
.53273 .55623 L
s
P
p
.2 0 1 r
.016 w
.53659 .39857 m
.67071 .49601 L
s
P
p
.2 0 1 r
.016 w
.53659 .39857 m
.43915 .26445 L
s
P
p
.2 0 1 r
.016 w
.53659 .39857 m
.58782 .55623 L
s
P
p
.2 0 1 r
.016 w
.53659 .39857 m
.53659 .23279 L
s
P
p
.2 0 1 r
.016 w
.53659 .39857 m
.48536 .55623 L
s
P
p
.2 0 1 r
.002 w
.74694 .4006 m
.66342 .51556 L
s
P
p
.2 0 1 r
.002 w
.74694 .4006 m
.70303 .53574 L
s
P
p
.2 0 1 r
.002 w
.74694 .4006 m
.74694 .54269 L
s
P
p
.2 0 1 r
.002 w
.80894 .35555 m
.94408 .39946 L
s
P
p
.2 0 1 r
.002 w
.80894 .35555 m
.95103 .35555 L
s
P
p
.2 0 1 r
.002 w
.80894 .35555 m
.94408 .31164 L
s
P
p
.2 0 1 r
.002 w
.74694 .31051 m
.74694 .16841 L
s
P
p
.2 0 1 r
.002 w
.74694 .31051 m
.70303 .17537 L
s
P
p
.2 0 1 r
.002 w
.74694 .31051 m
.66342 .19555 L
s
P
p
0 .4 1 r
.018 w
.76157 .35555 m
.74694 .4006 L
s
P
p
0 .4 1 r
.018 w
.76157 .35555 m
.80894 .35555 L
s
P
p
0 .4 1 r
.018 w
.76157 .35555 m
.74694 .31051 L
s
P
p
.2 0 1 r
.002 w
.46597 .26601 m
.58093 .18248 L
s
P
p
.2 0 1 r
.002 w
.46597 .26601 m
.5495 .15105 L
s
P
p
.2 0 1 r
.002 w
.46597 .26601 m
.50988 .13087 L
s
P
p
.2 0 1 r
.002 w
.39309 .28969 m
.27813 .20617 L
s
P
p
.2 0 1 r
.002 w
.39309 .28969 m
.25795 .24578 L
s
P
p
.2 0 1 r
.002 w
.39309 .28969 m
.25099 .28969 L
s
P
p
.2 0 1 r
.002 w
.43813 .35169 m
.39422 .48683 L
s
P
p
.2 0 1 r
.002 w
.43813 .35169 m
.43813 .49378 L
s
P
p
.2 0 1 r
.002 w
.43813 .35169 m
.48204 .48683 L
s
P
p
0 .4 1 r
.018 w
.43813 .30432 m
.46597 .26601 L
s
P
p
0 .4 1 r
.018 w
.43813 .30432 m
.39309 .28969 L
s
P
p
0 .4 1 r
.018 w
.43813 .30432 m
.43813 .35169 L
s
P
p
.2 0 1 r
.002 w
.6916 .48083 m
.55645 .52474 L
s
P
p
.2 0 1 r
.002 w
.6916 .48083 m
.57664 .56436 L
s
P
p
.2 0 1 r
.002 w
.6916 .48083 m
.60807 .59579 L
s
P
p
.2 0 1 r
.002 w
.76823 .48083 m
.85175 .59579 L
s
P
p
.2 0 1 r
.002 w
.76823 .48083 m
.88319 .56436 L
s
P
p
.2 0 1 r
.002 w
.76823 .48083 m
.90337 .52474 L
s
P
p
.2 0 1 r
.002 w
.74455 .40795 m
.82807 .29299 L
s
P
p
.2 0 1 r
.002 w
.74455 .40795 m
.78846 .27281 L
s
P
p
.2 0 1 r
.002 w
.74455 .40795 m
.74455 .26585 L
s
P
p
0 .4 1 r
.018 w
.72991 .45299 m
.6916 .48083 L
s
P
p
0 .4 1 r
.018 w
.72991 .45299 m
.76823 .48083 L
s
P
p
0 .4 1 r
.018 w
.72991 .45299 m
.74455 .40795 L
s
P
p
.2 0 1 r
.002 w
.5434 .2068 m
.6855 .2068 L
s
P
p
.2 0 1 r
.002 w
.5434 .2068 m
.67854 .16289 L
s
P
p
.2 0 1 r
.002 w
.5434 .2068 m
.65836 .12328 L
s
P
p
.2 0 1 r
.002 w
.47052 .18312 m
.42661 .04798 L
s
P
p
.2 0 1 r
.002 w
.47052 .18312 m
.38699 .06816 L
s
P
p
.2 0 1 r
.002 w
.47052 .18312 m
.35556 .0996 L
s
P
p
.2 0 1 r
.002 w
.47052 .25976 m
.35556 .34328 L
s
P
p
.2 0 1 r
.002 w
.47052 .25976 m
.38699 .37471 L
s
P
p
.2 0 1 r
.002 w
.47052 .25976 m
.42661 .3949 L
s
P
p
0 .4 1 r
.018 w
.49836 .22144 m
.5434 .2068 L
s
P
p
0 .4 1 r
.018 w
.49836 .22144 m
.47052 .18312 L
s
P
p
0 .4 1 r
.018 w
.49836 .22144 m
.47052 .25976 L
s
P
p
.2 0 1 r
.002 w
.59966 .51322 m
.46452 .46931 L
s
P
p
.2 0 1 r
.002 w
.59966 .51322 m
.45757 .51322 L
s
P
p
.2 0 1 r
.002 w
.59966 .51322 m
.46452 .55713 L
s
P
p
.2 0 1 r
.002 w
.66166 .55826 m
.66166 .70036 L
s
P
p
.2 0 1 r
.002 w
.66166 .55826 m
.70557 .6934 L
s
P
p
.2 0 1 r
.002 w
.66166 .55826 m
.74518 .67322 L
s
P
p
.2 0 1 r
.002 w
.68534 .48538 m
.82048 .44147 L
s
P
p
.2 0 1 r
.002 w
.68534 .48538 m
.8003 .40185 L
s
P
p
.2 0 1 r
.002 w
.68534 .48538 m
.76887 .37042 L
s
P
p
0 .4 1 r
.018 w
.64703 .51322 m
.59966 .51322 L
s
P
p
0 .4 1 r
.018 w
.64703 .51322 m
.66166 .55826 L
s
P
p
0 .4 1 r
.018 w
.64703 .51322 m
.68534 .48538 L
s
P
p
.2 0 1 r
.016 w
.5958 .35555 m
.76157 .35555 L
s
P
p
.2 0 1 r
.016 w
.5958 .35555 m
.43813 .30432 L
s
P
p
.2 0 1 r
.016 w
.5958 .35555 m
.72991 .45299 L
s
P
p
.2 0 1 r
.016 w
.5958 .35555 m
.49836 .22144 L
s
P
p
.2 0 1 r
.016 w
.5958 .35555 m
.64703 .51322 L
s
P
p
1 .6 0 r
.016 w
.5 .28595 m
.4042 .35555 L
s
P
p
1 .6 0 r
.016 w
.5 .28595 m
.46341 .39857 L
s
P
p
1 .6 0 r
.016 w
.5 .28595 m
.53659 .39857 L
s
P
p
1 .6 0 r
.016 w
.5 .28595 m
.5958 .35555 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.14787 0.424812 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0780989 0.952381 [
[ 0 0 0 0 ]
[ 1 .79618 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79618 L
0 .79618 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.23752 .39825 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.20765 .42813 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.18846 .46577 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.26003 .68603 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.29768 .70521 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.33941 .71182 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .57569 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.53337 .53396 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .49223 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.3169 .5075 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.33941 .57677 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.39833 .53396 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.58298 .3819 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.62063 .36272 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.6505 .33284 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.6505 .10126 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.62063 .07138 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.58298 .0522 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.36273 .12376 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.34355 .16141 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.33694 .20314 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .25347 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .18063 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.47198 .20314 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.24938 .2907 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.20765 .29731 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.17 .31649 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.09844 .53674 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.11762 .57439 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.14749 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.37908 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.40896 .57439 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.42814 .53674 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.24938 .42574 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.22687 .49501 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.2997 .49501 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.53847 .48053 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.5802 .48713 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.62193 .48053 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75806 .29317 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75145 .25144 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.73226 .21379 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.51201 .14223 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.47437 .16141 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.44449 .19128 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.5802 .35209 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.62301 .29317 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.55374 .27066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.32219 .21066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.28454 .19147 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.24281 .18486 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .32099 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.04884 .36272 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .40445 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.24281 .54057 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.28454 .53396 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.32219 .51478 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .31991 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.18388 .36272 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .40553 L
s
P
p
.2 0 1 r
.014 w
.40896 .36272 m
.35332 .53396 L
s
P
p
.2 0 1 r
.014 w
.40896 .36272 m
.51479 .21705 L
s
P
p
.2 0 1 r
.014 w
.40896 .36272 m
.26329 .46855 L
s
P
p
.2 0 1 r
.014 w
.40896 .36272 m
.5802 .30708 L
s
P
p
.2 0 1 r
.014 w
.40896 .36272 m
.2289 .36272 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .53311 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34081 .57484 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .61657 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.53478 .7527 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.57651 .74609 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.61415 .72691 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.68572 .50665 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.66653 .46901 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.63666 .43913 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.47585 .57484 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.53478 .61766 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.55728 .54839 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.61729 .31683 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.63647 .27918 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.64308 .23745 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.50696 .05009 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.46522 .04348 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.42349 .05009 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.28737 .23745 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.29398 .27918 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.31316 .31683 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.50804 .23745 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.46522 .17853 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.42241 .23745 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.29379 .43913 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.26391 .46901 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.24473 .50665 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.3163 .72691 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.35394 .74609 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.39567 .7527 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .61657 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58964 .57484 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .53311 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.37317 .54839 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.39567 .61766 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.4546 .57484 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.63925 .42278 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.67689 .4036 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.70677 .37372 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.70677 .14214 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.67689 .11226 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.63925 .09308 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.419 .16464 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39981 .20229 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39321 .24402 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .29435 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .22151 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.52825 .24402 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.30564 .33158 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.26391 .33819 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.22627 .35737 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.1547 .57762 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.17389 .61527 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.20376 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.43535 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.46522 .61527 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.48441 .57762 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.30564 .46662 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.28314 .53589 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.35597 .53589 L
s
P
p
.2 0 1 r
.014 w
.46522 .4036 m
.52087 .57484 L
s
P
p
.2 0 1 r
.014 w
.46522 .4036 m
.46522 .22354 L
s
P
p
.2 0 1 r
.014 w
.46522 .4036 m
.40958 .57484 L
s
P
p
.2 0 1 r
.014 w
.46522 .4036 m
.57106 .25793 L
s
P
p
.2 0 1 r
.014 w
.46522 .4036 m
.31956 .50943 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.51559 .57762 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.53478 .61527 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.56465 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.79624 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.82611 .61527 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.8453 .57762 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.77373 .35737 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.73609 .33819 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.69436 .33158 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.64403 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.71686 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.69436 .46662 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60679 .24402 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60019 .20229 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.581 .16464 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.36075 .09308 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.32311 .11226 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.29323 .14214 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.29323 .37372 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.32311 .4036 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.36075 .42278 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.47175 .24402 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .22151 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .29435 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .53311 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41036 .57484 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .61657 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.60433 .7527 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.64606 .74609 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.6837 .72691 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.75527 .50665 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.73609 .46901 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.70621 .43913 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.5454 .57484 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.60433 .61766 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.62683 .54839 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.68684 .31683 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.70602 .27918 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.71263 .23745 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.57651 .05009 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.53478 .04348 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.49304 .05009 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.35692 .23745 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.36353 .27918 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.38271 .31683 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.57759 .23745 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.53478 .17853 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.49196 .23745 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.36334 .43913 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.33347 .46901 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.31428 .50665 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.38585 .72691 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.42349 .74609 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.46522 .7527 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .61657 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65919 .57484 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .53311 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.44272 .54839 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.46522 .61766 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.52415 .57484 L
s
P
p
.2 0 1 r
.014 w
.53478 .4036 m
.68044 .50943 L
s
P
p
.2 0 1 r
.014 w
.53478 .4036 m
.42894 .25793 L
s
P
p
.2 0 1 r
.014 w
.53478 .4036 m
.59042 .57484 L
s
P
p
.2 0 1 r
.014 w
.53478 .4036 m
.53478 .22354 L
s
P
p
.2 0 1 r
.014 w
.53478 .4036 m
.47913 .57484 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.67781 .51478 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.71546 .53396 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.75719 .54057 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .40445 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.95116 .36272 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .32099 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.75719 .18486 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.71546 .19147 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.67781 .21066 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .40553 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.81612 .36272 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .31991 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.55551 .19128 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.52563 .16141 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.48799 .14223 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.26774 .21379 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24855 .25144 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24194 .29317 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.37807 .48053 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.4198 .48713 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.46153 .48053 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.44626 .27066 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.37699 .29317 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.4198 .35209 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.57186 .53674 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.59104 .57439 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.62092 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.85251 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.88238 .57439 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.90156 .53674 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.83 .31649 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.79235 .29731 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.75062 .2907 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.7003 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.77313 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.75062 .42574 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.66306 .20314 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.65645 .16141 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.63727 .12376 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.41702 .0522 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.37937 .07138 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.3495 .10126 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.3495 .33284 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.37937 .36272 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.41702 .3819 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.52802 .20314 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .18063 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .25347 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .49223 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.46663 .53396 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .57569 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.66059 .71182 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.70232 .70521 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.73997 .68603 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.81154 .46577 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.79235 .42813 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.76248 .39825 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.60167 .53396 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.66059 .57677 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.6831 .5075 L
s
P
p
.2 0 1 r
.014 w
.59104 .36272 m
.7711 .36272 L
s
P
p
.2 0 1 r
.014 w
.59104 .36272 m
.4198 .30708 L
s
P
p
.2 0 1 r
.014 w
.59104 .36272 m
.73671 .46855 L
s
P
p
.2 0 1 r
.014 w
.59104 .36272 m
.48521 .21705 L
s
P
p
.2 0 1 r
.014 w
.59104 .36272 m
.64668 .53396 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.40896 .36272 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.46522 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.53478 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.59104 .36272 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.14787 0.562657 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0780989 0.952381 [
[ 0 0 0 0 ]
[ 1 .79618 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79618 L
0 .79618 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.23752 .39825 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.20765 .42813 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.18846 .46577 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.26003 .68603 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.29768 .70521 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.33941 .71182 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .57569 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.53337 .53396 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .49223 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.3169 .5075 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.33941 .57677 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.39833 .53396 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.58298 .3819 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.62063 .36272 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.6505 .33284 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.6505 .10126 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.62063 .07138 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.58298 .0522 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.36273 .12376 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.34355 .16141 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.33694 .20314 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .25347 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .18063 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.47198 .20314 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.24938 .2907 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.20765 .29731 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.17 .31649 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.09844 .53674 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.11762 .57439 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.14749 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.37908 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.40896 .57439 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.42814 .53674 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.24938 .42574 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.22687 .49501 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.2997 .49501 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.53847 .48053 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.5802 .48713 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.62193 .48053 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75806 .29317 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75145 .25144 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.73226 .21379 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.51201 .14223 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.47437 .16141 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.44449 .19128 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.5802 .35209 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.62301 .29317 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.55374 .27066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.32219 .21066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.28454 .19147 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.24281 .18486 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .32099 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.04884 .36272 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .40445 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.24281 .54057 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.28454 .53396 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.32219 .51478 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .31991 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.18388 .36272 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .40553 L
s
P
p
0 .4 1 r
.016 w
.40896 .36272 m
.35332 .53396 L
s
P
p
0 .4 1 r
.016 w
.40896 .36272 m
.51479 .21705 L
s
P
p
0 .4 1 r
.016 w
.40896 .36272 m
.26329 .46855 L
s
P
p
0 .4 1 r
.016 w
.40896 .36272 m
.5802 .30708 L
s
P
p
0 .4 1 r
.016 w
.40896 .36272 m
.2289 .36272 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .53311 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34081 .57484 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .61657 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.53478 .7527 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.57651 .74609 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.61415 .72691 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.68572 .50665 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.66653 .46901 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.63666 .43913 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.47585 .57484 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.53478 .61766 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.55728 .54839 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.61729 .31683 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.63647 .27918 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.64308 .23745 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.50696 .05009 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.46522 .04348 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.42349 .05009 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.28737 .23745 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.29398 .27918 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.31316 .31683 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.50804 .23745 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.46522 .17853 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.42241 .23745 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.29379 .43913 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.26391 .46901 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.24473 .50665 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.3163 .72691 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.35394 .74609 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.39567 .7527 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .61657 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58964 .57484 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .53311 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.37317 .54839 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.39567 .61766 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.4546 .57484 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.63925 .42278 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.67689 .4036 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.70677 .37372 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.70677 .14214 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.67689 .11226 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.63925 .09308 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.419 .16464 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39981 .20229 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39321 .24402 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .29435 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .22151 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.52825 .24402 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.30564 .33158 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.26391 .33819 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.22627 .35737 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.1547 .57762 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.17389 .61527 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.20376 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.43535 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.46522 .61527 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.48441 .57762 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.30564 .46662 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.28314 .53589 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.35597 .53589 L
s
P
p
0 .4 1 r
.016 w
.46522 .4036 m
.52087 .57484 L
s
P
p
0 .4 1 r
.016 w
.46522 .4036 m
.46522 .22354 L
s
P
p
0 .4 1 r
.016 w
.46522 .4036 m
.40958 .57484 L
s
P
p
0 .4 1 r
.016 w
.46522 .4036 m
.57106 .25793 L
s
P
p
0 .4 1 r
.016 w
.46522 .4036 m
.31956 .50943 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.51559 .57762 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.53478 .61527 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.56465 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.79624 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.82611 .61527 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.8453 .57762 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.77373 .35737 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.73609 .33819 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.69436 .33158 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.64403 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.71686 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.69436 .46662 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60679 .24402 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60019 .20229 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.581 .16464 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.36075 .09308 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.32311 .11226 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.29323 .14214 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.29323 .37372 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.32311 .4036 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.36075 .42278 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.47175 .24402 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .22151 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .29435 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .53311 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41036 .57484 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .61657 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.60433 .7527 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.64606 .74609 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.6837 .72691 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.75527 .50665 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.73609 .46901 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.70621 .43913 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.5454 .57484 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.60433 .61766 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.62683 .54839 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.68684 .31683 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.70602 .27918 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.71263 .23745 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.57651 .05009 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.53478 .04348 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.49304 .05009 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.35692 .23745 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.36353 .27918 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.38271 .31683 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.57759 .23745 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.53478 .17853 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.49196 .23745 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.36334 .43913 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.33347 .46901 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.31428 .50665 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.38585 .72691 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.42349 .74609 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.46522 .7527 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .61657 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65919 .57484 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .53311 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.44272 .54839 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.46522 .61766 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.52415 .57484 L
s
P
p
0 .4 1 r
.016 w
.53478 .4036 m
.68044 .50943 L
s
P
p
0 .4 1 r
.016 w
.53478 .4036 m
.42894 .25793 L
s
P
p
0 .4 1 r
.016 w
.53478 .4036 m
.59042 .57484 L
s
P
p
0 .4 1 r
.016 w
.53478 .4036 m
.53478 .22354 L
s
P
p
0 .4 1 r
.016 w
.53478 .4036 m
.47913 .57484 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.67781 .51478 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.71546 .53396 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.75719 .54057 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .40445 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.95116 .36272 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .32099 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.75719 .18486 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.71546 .19147 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.67781 .21066 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .40553 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.81612 .36272 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .31991 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.55551 .19128 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.52563 .16141 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.48799 .14223 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.26774 .21379 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24855 .25144 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24194 .29317 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.37807 .48053 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.4198 .48713 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.46153 .48053 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.44626 .27066 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.37699 .29317 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.4198 .35209 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.57186 .53674 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.59104 .57439 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.62092 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.85251 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.88238 .57439 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.90156 .53674 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.83 .31649 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.79235 .29731 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.75062 .2907 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.7003 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.77313 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.75062 .42574 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.66306 .20314 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.65645 .16141 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.63727 .12376 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.41702 .0522 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.37937 .07138 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.3495 .10126 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.3495 .33284 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.37937 .36272 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.41702 .3819 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.52802 .20314 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .18063 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .25347 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .49223 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.46663 .53396 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .57569 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.66059 .71182 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.70232 .70521 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.73997 .68603 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.81154 .46577 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.79235 .42813 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.76248 .39825 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.60167 .53396 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.66059 .57677 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.6831 .5075 L
s
P
p
0 .4 1 r
.016 w
.59104 .36272 m
.7711 .36272 L
s
P
p
0 .4 1 r
.016 w
.59104 .36272 m
.4198 .30708 L
s
P
p
0 .4 1 r
.016 w
.59104 .36272 m
.73671 .46855 L
s
P
p
0 .4 1 r
.016 w
.59104 .36272 m
.48521 .21705 L
s
P
p
0 .4 1 r
.016 w
.59104 .36272 m
.64668 .53396 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.40896 .36272 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.46522 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.53478 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.59104 .36272 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.14787 0.700501 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0500678 0.952381 [
[ 0 0 0 0 ]
[ 1 .85225 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .85225 L
0 .85225 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.14698 .59845 L
s
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.15417 .64385 L
s
P
p
.2 0 1 r
.002 w
.29387 .59845 m
.17503 .6848 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.41462 .76264 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.45557 .74178 L
s
P
p
.2 0 1 r
.002 w
.36922 .62294 m
.48806 .70928 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.29387 .59845 L
s
P
p
0 .4 1 r
.018 w
.34044 .58332 m
.36922 .62294 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .28399 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.71195 .2386 L
s
P
p
.2 0 1 r
.002 w
.56505 .2386 m
.70476 .1932 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.50096 .04513 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.45557 .05232 L
s
P
p
.2 0 1 r
.002 w
.50096 .19203 m
.41462 .07319 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.56505 .2386 L
s
P
p
0 .4 1 r
.018 w
.51609 .2386 m
.50096 .19203 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.0771 .4107 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.05624 .45165 L
s
P
p
.2 0 1 r
.002 w
.19594 .49704 m
.04905 .49704 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.19712 .70084 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.24251 .70803 L
s
P
p
.2 0 1 r
.002 w
.24251 .56114 m
.28791 .70084 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.19594 .49704 L
s
P
p
0 .4 1 r
.018 w
.24251 .51217 m
.24251 .56114 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.7132 .48415 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.74569 .45165 L
s
P
p
.2 0 1 r
.002 w
.62685 .36531 m
.76656 .4107 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.68871 .17112 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.64776 .15025 L
s
P
p
.2 0 1 r
.002 w
.60237 .28996 m
.60237 .14306 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.62685 .36531 L
s
P
p
0 .4 1 r
.018 w
.58724 .33653 m
.60237 .28996 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.13093 .21773 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.08998 .2386 L
s
P
p
.2 0 1 r
.002 w
.17633 .35744 m
.05749 .27109 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.05749 .52301 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.08998 .5555 L
s
P
p
.2 0 1 r
.002 w
.17633 .43666 m
.13093 .57637 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .35744 L
s
P
p
0 .4 1 r
.018 w
.20511 .39705 m
.17633 .43666 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.34044 .58332 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.51609 .2386 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.24251 .51217 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.58724 .33653 L
s
P
p
.2 0 1 r
.016 w
.40097 .39705 m
.20511 .39705 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.37508 .75375 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.40757 .78625 L
s
P
p
.2 0 1 r
.002 w
.49392 .66741 m
.44852 .80711 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.6881 .72927 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.70897 .68832 L
s
P
p
.2 0 1 r
.002 w
.56926 .64292 m
.71616 .64292 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.49392 .66741 L
s
P
p
0 .4 1 r
.018 w
.5227 .62779 m
.56926 .64292 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.64149 .17149 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.62063 .13054 L
s
P
p
.2 0 1 r
.002 w
.50179 .21688 m
.58813 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.33622 .09804 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.30372 .13054 L
s
P
p
.2 0 1 r
.002 w
.42256 .21688 m
.28285 .17149 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.50179 .21688 L
s
P
p
0 .4 1 r
.018 w
.46217 .24566 m
.42256 .21688 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.20819 .64292 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.21538 .68832 L
s
P
p
.2 0 1 r
.002 w
.35508 .64292 m
.23624 .72927 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.47582 .80711 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.51677 .78625 L
s
P
p
.2 0 1 r
.002 w
.43043 .66741 m
.54927 .75375 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.35508 .64292 L
s
P
p
0 .4 1 r
.018 w
.40165 .62779 m
.43043 .66741 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .32846 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.77316 .28307 L
s
P
p
.2 0 1 r
.002 w
.62626 .28307 m
.76597 .23767 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.56216 .0896 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.51677 .09679 L
s
P
p
.2 0 1 r
.002 w
.56216 .2365 m
.47582 .11766 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.62626 .28307 L
s
P
p
0 .4 1 r
.018 w
.5773 .28307 m
.56216 .2365 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.13831 .45517 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.11745 .49612 L
s
P
p
.2 0 1 r
.002 w
.25715 .54151 m
.11026 .54151 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.25833 .74531 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.30372 .7525 L
s
P
p
.2 0 1 r
.002 w
.30372 .60561 m
.34911 .74531 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.25715 .54151 L
s
P
p
0 .4 1 r
.018 w
.30372 .55664 m
.30372 .60561 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5227 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.46217 .24566 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.40165 .62779 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.5773 .28307 L
s
P
p
.2 0 1 r
.016 w
.46217 .44152 m
.30372 .55664 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.65089 .74531 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.69628 .7525 L
s
P
p
.2 0 1 r
.002 w
.69628 .60561 m
.74167 .74531 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.88974 .54151 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.88255 .49612 L
s
P
p
.2 0 1 r
.002 w
.74285 .54151 m
.86169 .45517 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.69628 .60561 L
s
P
p
0 .4 1 r
.018 w
.69628 .55664 m
.74285 .54151 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.52418 .11766 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.48323 .09679 L
s
P
p
.2 0 1 r
.002 w
.43784 .2365 m
.43784 .0896 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .23767 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.22684 .28307 L
s
P
p
.2 0 1 r
.002 w
.37374 .28307 m
.23403 .32846 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.43784 .2365 L
s
P
p
0 .4 1 r
.018 w
.4227 .28307 m
.37374 .28307 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.45073 .75375 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.48323 .78625 L
s
P
p
.2 0 1 r
.002 w
.56957 .66741 m
.52418 .80711 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.76376 .72927 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.78462 .68832 L
s
P
p
.2 0 1 r
.002 w
.64492 .64292 m
.79181 .64292 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.56957 .66741 L
s
P
p
0 .4 1 r
.018 w
.59835 .62779 m
.64492 .64292 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.71715 .17149 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.69628 .13054 L
s
P
p
.2 0 1 r
.002 w
.57744 .21688 m
.66378 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.41187 .09804 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.37937 .13054 L
s
P
p
.2 0 1 r
.002 w
.49821 .21688 m
.35851 .17149 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.57744 .21688 L
s
P
p
0 .4 1 r
.018 w
.53783 .24566 m
.49821 .21688 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.28384 .64292 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.29103 .68832 L
s
P
p
.2 0 1 r
.002 w
.43074 .64292 m
.3119 .72927 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.55148 .80711 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.59243 .78625 L
s
P
p
.2 0 1 r
.002 w
.50608 .66741 m
.62492 .75375 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.43074 .64292 L
s
P
p
0 .4 1 r
.018 w
.4773 .62779 m
.50608 .66741 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.69628 .55664 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4227 .28307 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.59835 .62779 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.53783 .24566 L
s
P
p
.2 0 1 r
.016 w
.53783 .44152 m
.4773 .62779 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.86907 .57637 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.91002 .5555 L
s
P
p
.2 0 1 r
.002 w
.82367 .43666 m
.94251 .52301 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.94251 .27109 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.91002 .2386 L
s
P
p
.2 0 1 r
.002 w
.82367 .35744 m
.86907 .21773 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .43666 L
s
P
p
0 .4 1 r
.018 w
.79489 .39705 m
.82367 .35744 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.39763 .14306 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.35224 .15025 L
s
P
p
.2 0 1 r
.002 w
.39763 .28996 m
.31129 .17112 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.23344 .4107 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.25431 .45165 L
s
P
p
.2 0 1 r
.002 w
.37315 .36531 m
.2868 .48415 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.39763 .28996 L
s
P
p
0 .4 1 r
.018 w
.41276 .33653 m
.37315 .36531 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.71209 .70084 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.75749 .70803 L
s
P
p
.2 0 1 r
.002 w
.75749 .56114 m
.80288 .70084 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.95095 .49704 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.94376 .45165 L
s
P
p
.2 0 1 r
.002 w
.80406 .49704 m
.9229 .4107 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.75749 .56114 L
s
P
p
0 .4 1 r
.018 w
.75749 .51217 m
.80406 .49704 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.58538 .07319 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.54443 .05232 L
s
P
p
.2 0 1 r
.002 w
.49904 .19203 m
.49904 .04513 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .1932 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.28805 .2386 L
s
P
p
.2 0 1 r
.002 w
.43495 .2386 m
.29524 .28399 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.49904 .19203 L
s
P
p
0 .4 1 r
.018 w
.48391 .2386 m
.43495 .2386 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.51194 .70928 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.54443 .74178 L
s
P
p
.2 0 1 r
.002 w
.63078 .62294 m
.58538 .76264 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.82497 .6848 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.84583 .64385 L
s
P
p
.2 0 1 r
.002 w
.70613 .59845 m
.85302 .59845 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.63078 .62294 L
s
P
p
0 .4 1 r
.018 w
.65956 .58332 m
.70613 .59845 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.79489 .39705 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.41276 .33653 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.75749 .51217 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.48391 .2386 L
s
P
p
.2 0 1 r
.016 w
.59903 .39705 m
.65956 .58332 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.40097 .39705 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.46217 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.53783 .44152 L
s
P
p
1 .6 0 r
.016 w
.5 .3251 m
.59903 .39705 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.14787 0.838346 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0780989 0.952381 [
[ 0 0 0 0 ]
[ 1 .79618 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79618 L
0 .79618 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.32686 .49755 m
.28513 .36911 L
s
P
p
.2 0 1 r
.002 w
.32686 .49755 m
.24748 .38829 L
s
P
p
.2 0 1 r
.002 w
.32686 .49755 m
.21761 .41817 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.26003 .68603 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.29768 .70521 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.33941 .71182 L
s
P
p
.2 0 1 r
.002 w
.39613 .52005 m
.53117 .52005 L
s
P
p
.2 0 1 r
.002 w
.39613 .52005 m
.52456 .47832 L
s
P
p
.2 0 1 r
.002 w
.39613 .52005 m
.50538 .44068 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.32686 .49755 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.33941 .57677 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.39613 .52005 L
s
P
p
.2 0 1 r
.002 w
.5287 .25986 m
.5287 .3949 L
s
P
p
.2 0 1 r
.002 w
.5287 .25986 m
.57043 .38829 L
s
P
p
.2 0 1 r
.002 w
.5287 .25986 m
.60808 .36911 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.6505 .10126 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.62063 .07138 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.58298 .0522 L
s
P
p
.2 0 1 r
.002 w
.46978 .21705 m
.34134 .17532 L
s
P
p
.2 0 1 r
.002 w
.46978 .21705 m
.33473 .21705 L
s
P
p
.2 0 1 r
.002 w
.46978 .21705 m
.34134 .25878 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.5287 .25986 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .18063 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.46978 .21705 L
s
P
p
.2 0 1 r
.002 w
.26329 .42354 m
.30502 .29511 L
s
P
p
.2 0 1 r
.002 w
.26329 .42354 m
.26329 .2885 L
s
P
p
.2 0 1 r
.002 w
.26329 .42354 m
.22156 .29511 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.09844 .53674 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.11762 .57439 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.14749 .60426 L
s
P
p
.2 0 1 r
.002 w
.3061 .48246 m
.41535 .56184 L
s
P
p
.2 0 1 r
.002 w
.3061 .48246 m
.43453 .52419 L
s
P
p
.2 0 1 r
.002 w
.3061 .48246 m
.44114 .48246 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.26329 .42354 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.22687 .49501 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.3061 .48246 L
s
P
p
.2 0 1 r
.002 w
.56629 .34989 m
.48691 .45914 L
s
P
p
.2 0 1 r
.002 w
.56629 .34989 m
.52456 .47832 L
s
P
p
.2 0 1 r
.002 w
.56629 .34989 m
.56629 .48493 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75806 .29317 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75145 .25144 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.73226 .21379 L
s
P
p
.2 0 1 r
.002 w
.54378 .28062 m
.46441 .17137 L
s
P
p
.2 0 1 r
.002 w
.54378 .28062 m
.43453 .20124 L
s
P
p
.2 0 1 r
.002 w
.54378 .28062 m
.41535 .23889 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.56629 .34989 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.62301 .29317 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.54378 .28062 L
s
P
p
.2 0 1 r
.002 w
.25536 .3263 m
.36461 .24692 L
s
P
p
.2 0 1 r
.002 w
.25536 .3263 m
.33473 .21705 L
s
P
p
.2 0 1 r
.002 w
.25536 .3263 m
.29709 .19787 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .32099 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.04884 .36272 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .40445 L
s
P
p
.2 0 1 r
.002 w
.25536 .39914 m
.29709 .52757 L
s
P
p
.2 0 1 r
.002 w
.25536 .39914 m
.33473 .50839 L
s
P
p
.2 0 1 r
.002 w
.25536 .39914 m
.36461 .47851 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.25536 .3263 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.18388 .36272 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.25536 .39914 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.35332 .53396 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.51479 .21705 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.26329 .46855 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.5802 .30708 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.2289 .36272 L
s
P
p
.2 0 1 r
.002 w
.47805 .56093 m
.3688 .48156 L
s
P
p
.2 0 1 r
.002 w
.47805 .56093 m
.34962 .5192 L
s
P
p
.2 0 1 r
.002 w
.47805 .56093 m
.34301 .56093 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.53478 .7527 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.57651 .74609 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.61415 .72691 L
s
P
p
.2 0 1 r
.002 w
.54732 .53843 m
.65658 .45905 L
s
P
p
.2 0 1 r
.002 w
.54732 .53843 m
.6267 .42917 L
s
P
p
.2 0 1 r
.002 w
.54732 .53843 m
.58905 .40999 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.47805 .56093 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.53478 .61766 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.54732 .53843 L
s
P
p
.2 0 1 r
.002 w
.50164 .25 m
.58102 .35925 L
s
P
p
.2 0 1 r
.002 w
.50164 .25 m
.61089 .32938 L
s
P
p
.2 0 1 r
.002 w
.50164 .25 m
.63008 .29173 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.50696 .05009 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.46522 .04348 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.42349 .05009 L
s
P
p
.2 0 1 r
.002 w
.42881 .25 m
.30037 .29173 L
s
P
p
.2 0 1 r
.002 w
.42881 .25 m
.31956 .32938 L
s
P
p
.2 0 1 r
.002 w
.42881 .25 m
.34943 .35925 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.50164 .25 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.46522 .17853 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.42881 .25 L
s
P
p
.2 0 1 r
.002 w
.38312 .53843 m
.34139 .40999 L
s
P
p
.2 0 1 r
.002 w
.38312 .53843 m
.30375 .42917 L
s
P
p
.2 0 1 r
.002 w
.38312 .53843 m
.27387 .45905 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.3163 .72691 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.35394 .74609 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.39567 .7527 L
s
P
p
.2 0 1 r
.002 w
.45239 .56093 m
.58744 .56093 L
s
P
p
.2 0 1 r
.002 w
.45239 .56093 m
.58083 .5192 L
s
P
p
.2 0 1 r
.002 w
.45239 .56093 m
.56165 .48156 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.38312 .53843 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.39567 .61766 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.45239 .56093 L
s
P
p
.2 0 1 r
.002 w
.58497 .30074 m
.58497 .43578 L
s
P
p
.2 0 1 r
.002 w
.58497 .30074 m
.6267 .42917 L
s
P
p
.2 0 1 r
.002 w
.58497 .30074 m
.66435 .40999 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.70677 .14214 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.67689 .11226 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.63925 .09308 L
s
P
p
.2 0 1 r
.002 w
.52605 .25793 m
.39761 .2162 L
s
P
p
.2 0 1 r
.002 w
.52605 .25793 m
.391 .25793 L
s
P
p
.2 0 1 r
.002 w
.52605 .25793 m
.39761 .29966 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.58497 .30074 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .22151 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.52605 .25793 L
s
P
p
.2 0 1 r
.002 w
.31956 .46442 m
.36129 .33599 L
s
P
p
.2 0 1 r
.002 w
.31956 .46442 m
.31956 .32938 L
s
P
p
.2 0 1 r
.002 w
.31956 .46442 m
.27782 .33599 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.1547 .57762 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.17389 .61527 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.20376 .64515 L
s
P
p
.2 0 1 r
.002 w
.36237 .52334 m
.47162 .60272 L
s
P
p
.2 0 1 r
.002 w
.36237 .52334 m
.4908 .56508 L
s
P
p
.2 0 1 r
.002 w
.36237 .52334 m
.49741 .52334 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.31956 .46442 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.28314 .53589 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.36237 .52334 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.52087 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.46522 .22354 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.40958 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.57106 .25793 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.31956 .50943 L
s
P
p
.2 0 1 r
.002 w
.63763 .52334 m
.50259 .52334 L
s
P
p
.2 0 1 r
.002 w
.63763 .52334 m
.5092 .56508 L
s
P
p
.2 0 1 r
.002 w
.63763 .52334 m
.52838 .60272 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.79624 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.82611 .61527 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.8453 .57762 L
s
P
p
.2 0 1 r
.002 w
.68044 .46442 m
.72218 .33599 L
s
P
p
.2 0 1 r
.002 w
.68044 .46442 m
.68044 .32938 L
s
P
p
.2 0 1 r
.002 w
.68044 .46442 m
.63871 .33599 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.63763 .52334 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.71686 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.68044 .46442 L
s
P
p
.2 0 1 r
.002 w
.47395 .25793 m
.60239 .29966 L
s
P
p
.2 0 1 r
.002 w
.47395 .25793 m
.609 .25793 L
s
P
p
.2 0 1 r
.002 w
.47395 .25793 m
.60239 .2162 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.36075 .09308 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.32311 .11226 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.29323 .14214 L
s
P
p
.2 0 1 r
.002 w
.41503 .30074 m
.33565 .40999 L
s
P
p
.2 0 1 r
.002 w
.41503 .30074 m
.3733 .42917 L
s
P
p
.2 0 1 r
.002 w
.41503 .30074 m
.41503 .43578 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.47395 .25793 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .22151 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.41503 .30074 L
s
P
p
.2 0 1 r
.002 w
.54761 .56093 m
.43835 .48156 L
s
P
p
.2 0 1 r
.002 w
.54761 .56093 m
.41917 .5192 L
s
P
p
.2 0 1 r
.002 w
.54761 .56093 m
.41256 .56093 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.60433 .7527 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.64606 .74609 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.6837 .72691 L
s
P
p
.2 0 1 r
.002 w
.61688 .53843 m
.72613 .45905 L
s
P
p
.2 0 1 r
.002 w
.61688 .53843 m
.69625 .42917 L
s
P
p
.2 0 1 r
.002 w
.61688 .53843 m
.65861 .40999 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.54761 .56093 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.60433 .61766 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.61688 .53843 L
s
P
p
.2 0 1 r
.002 w
.57119 .25 m
.65057 .35925 L
s
P
p
.2 0 1 r
.002 w
.57119 .25 m
.68044 .32938 L
s
P
p
.2 0 1 r
.002 w
.57119 .25 m
.69963 .29173 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.57651 .05009 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.53478 .04348 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.49304 .05009 L
s
P
p
.2 0 1 r
.002 w
.49836 .25 m
.36992 .29173 L
s
P
p
.2 0 1 r
.002 w
.49836 .25 m
.38911 .32938 L
s
P
p
.2 0 1 r
.002 w
.49836 .25 m
.41898 .35925 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.57119 .25 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.53478 .17853 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.49836 .25 L
s
P
p
.2 0 1 r
.002 w
.45268 .53843 m
.41095 .40999 L
s
P
p
.2 0 1 r
.002 w
.45268 .53843 m
.3733 .42917 L
s
P
p
.2 0 1 r
.002 w
.45268 .53843 m
.34342 .45905 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.38585 .72691 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.42349 .74609 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.46522 .7527 L
s
P
p
.2 0 1 r
.002 w
.52195 .56093 m
.65699 .56093 L
s
P
p
.2 0 1 r
.002 w
.52195 .56093 m
.65038 .5192 L
s
P
p
.2 0 1 r
.002 w
.52195 .56093 m
.6312 .48156 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.45268 .53843 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.46522 .61766 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.52195 .56093 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.68044 .50943 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.42894 .25793 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.59042 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.53478 .22354 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.47913 .57484 L
s
P
p
.2 0 1 r
.002 w
.74464 .39914 m
.63539 .47851 L
s
P
p
.2 0 1 r
.002 w
.74464 .39914 m
.66527 .50839 L
s
P
p
.2 0 1 r
.002 w
.74464 .39914 m
.70291 .52757 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .40445 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.95116 .36272 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .32099 L
s
P
p
.2 0 1 r
.002 w
.74464 .3263 m
.70291 .19787 L
s
P
p
.2 0 1 r
.002 w
.74464 .3263 m
.66527 .21705 L
s
P
p
.2 0 1 r
.002 w
.74464 .3263 m
.63539 .24692 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.74464 .39914 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.81612 .36272 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.74464 .3263 L
s
P
p
.2 0 1 r
.002 w
.45622 .28062 m
.58465 .23889 L
s
P
p
.2 0 1 r
.002 w
.45622 .28062 m
.56547 .20124 L
s
P
p
.2 0 1 r
.002 w
.45622 .28062 m
.53559 .17137 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.26774 .21379 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24855 .25144 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24194 .29317 L
s
P
p
.2 0 1 r
.002 w
.43371 .34989 m
.43371 .48493 L
s
P
p
.2 0 1 r
.002 w
.43371 .34989 m
.47544 .47832 L
s
P
p
.2 0 1 r
.002 w
.43371 .34989 m
.51309 .45914 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.45622 .28062 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.37699 .29317 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.43371 .34989 L
s
P
p
.2 0 1 r
.002 w
.6939 .48246 m
.55886 .48246 L
s
P
p
.2 0 1 r
.002 w
.6939 .48246 m
.56547 .52419 L
s
P
p
.2 0 1 r
.002 w
.6939 .48246 m
.58465 .56184 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.85251 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.88238 .57439 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.90156 .53674 L
s
P
p
.2 0 1 r
.002 w
.73671 .42354 m
.77844 .29511 L
s
P
p
.2 0 1 r
.002 w
.73671 .42354 m
.73671 .2885 L
s
P
p
.2 0 1 r
.002 w
.73671 .42354 m
.69498 .29511 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.6939 .48246 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.77313 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.73671 .42354 L
s
P
p
.2 0 1 r
.002 w
.53022 .21705 m
.65866 .25878 L
s
P
p
.2 0 1 r
.002 w
.53022 .21705 m
.66527 .21705 L
s
P
p
.2 0 1 r
.002 w
.53022 .21705 m
.65866 .17532 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.41702 .0522 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.37937 .07138 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.3495 .10126 L
s
P
p
.2 0 1 r
.002 w
.4713 .25986 m
.39192 .36911 L
s
P
p
.2 0 1 r
.002 w
.4713 .25986 m
.42957 .38829 L
s
P
p
.2 0 1 r
.002 w
.4713 .25986 m
.4713 .3949 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.53022 .21705 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .18063 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.4713 .25986 L
s
P
p
.2 0 1 r
.002 w
.60387 .52005 m
.49462 .44068 L
s
P
p
.2 0 1 r
.002 w
.60387 .52005 m
.47544 .47832 L
s
P
p
.2 0 1 r
.002 w
.60387 .52005 m
.46883 .52005 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.66059 .71182 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.70232 .70521 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.73997 .68603 L
s
P
p
.2 0 1 r
.002 w
.67314 .49755 m
.78239 .41817 L
s
P
p
.2 0 1 r
.002 w
.67314 .49755 m
.75252 .38829 L
s
P
p
.2 0 1 r
.002 w
.67314 .49755 m
.71487 .36911 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.60387 .52005 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.66059 .57677 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.67314 .49755 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.7711 .36272 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.4198 .30708 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.73671 .46855 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.48521 .21705 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.64668 .53396 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.40896 .36272 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.46522 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.53478 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.59104 .36272 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.14787 0.97619 0.273183 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0828379 0.952381 [
[ 0 0 0 0 ]
[ 1 .78671 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .78671 L
0 .78671 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3265 .52182 m
.24298 .40686 L
s
P
p
.2 0 1 r
.002 w
.3265 .52182 m
.21154 .4383 L
s
P
p
.2 0 1 r
.002 w
.3265 .52182 m
.19136 .47791 L
s
P
p
.2 0 1 r
.002 w
.33834 .55826 m
.25482 .67322 L
s
P
p
.2 0 1 r
.002 w
.33834 .55826 m
.29443 .6934 L
s
P
p
.2 0 1 r
.002 w
.33834 .55826 m
.33834 .70036 L
s
P
p
.2 0 1 r
.002 w
.36934 .53574 m
.50448 .57965 L
s
P
p
.2 0 1 r
.002 w
.36934 .53574 m
.51143 .53574 L
s
P
p
.2 0 1 r
.002 w
.36934 .53574 m
.50448 .49183 L
s
P
p
0 .4 1 r
.018 w
.34566 .53574 m
.3265 .52182 L
s
P
p
0 .4 1 r
.018 w
.34566 .53574 m
.33834 .55826 L
s
P
p
0 .4 1 r
.018 w
.34566 .53574 m
.36934 .53574 L
s
P
p
.2 0 1 r
.002 w
.52948 .22144 m
.57339 .35658 L
s
P
p
.2 0 1 r
.002 w
.52948 .22144 m
.61301 .33639 L
s
P
p
.2 0 1 r
.002 w
.52948 .22144 m
.64444 .30496 L
s
P
p
.2 0 1 r
.002 w
.52948 .18312 m
.64444 .0996 L
s
P
p
.2 0 1 r
.002 w
.52948 .18312 m
.61301 .06816 L
s
P
p
.2 0 1 r
.002 w
.52948 .18312 m
.57339 .04798 L
s
P
p
.2 0 1 r
.002 w
.49304 .19496 m
.37808 .11144 L
s
P
p
.2 0 1 r
.002 w
.49304 .19496 m
.3579 .15105 L
s
P
p
.2 0 1 r
.002 w
.49304 .19496 m
.35095 .19496 L
s
P
p
0 .4 1 r
.018 w
.51556 .20228 m
.52948 .22144 L
s
P
p
0 .4 1 r
.018 w
.51556 .20228 m
.52948 .18312 L
s
P
p
0 .4 1 r
.018 w
.51556 .20228 m
.49304 .19496 L
s
P
p
.2 0 1 r
.002 w
.24361 .44439 m
.24361 .3023 L
s
P
p
.2 0 1 r
.002 w
.24361 .44439 m
.1997 .30925 L
s
P
p
.2 0 1 r
.002 w
.24361 .44439 m
.16009 .32943 L
s
P
p
.2 0 1 r
.002 w
.23177 .48083 m
.09663 .52474 L
s
P
p
.2 0 1 r
.002 w
.23177 .48083 m
.11681 .56436 L
s
P
p
.2 0 1 r
.002 w
.23177 .48083 m
.14825 .59579 L
s
P
p
.2 0 1 r
.002 w
.27009 .48083 m
.35361 .59579 L
s
P
p
.2 0 1 r
.002 w
.27009 .48083 m
.38504 .56436 L
s
P
p
.2 0 1 r
.002 w
.27009 .48083 m
.40523 .52474 L
s
P
p
0 .4 1 r
.018 w
.25093 .46691 m
.24361 .44439 L
s
P
p
0 .4 1 r
.018 w
.25093 .46691 m
.23177 .48083 L
s
P
p
0 .4 1 r
.018 w
.25093 .46691 m
.27009 .48083 L
s
P
p
.2 0 1 r
.002 w
.58439 .32069 m
.54048 .45583 L
s
P
p
.2 0 1 r
.002 w
.58439 .32069 m
.58439 .46278 L
s
P
p
.2 0 1 r
.002 w
.58439 .32069 m
.6283 .45583 L
s
P
p
.2 0 1 r
.002 w
.60691 .28969 m
.74901 .28969 L
s
P
p
.2 0 1 r
.002 w
.60691 .28969 m
.74205 .24578 L
s
P
p
.2 0 1 r
.002 w
.60691 .28969 m
.72187 .20617 L
s
P
p
.2 0 1 r
.002 w
.57047 .27785 m
.52656 .14271 L
s
P
p
.2 0 1 r
.002 w
.57047 .27785 m
.48695 .16289 L
s
P
p
.2 0 1 r
.002 w
.57047 .27785 m
.45551 .19433 L
s
P
p
0 .4 1 r
.018 w
.58439 .29701 m
.58439 .32069 L
s
P
p
0 .4 1 r
.018 w
.58439 .29701 m
.60691 .28969 L
s
P
p
0 .4 1 r
.018 w
.58439 .29701 m
.57047 .27785 L
s
P
p
.2 0 1 r
.002 w
.22206 .33303 m
.30558 .21807 L
s
P
p
.2 0 1 r
.002 w
.22206 .33303 m
.26597 .19789 L
s
P
p
.2 0 1 r
.002 w
.22206 .33303 m
.22206 .19093 L
s
P
p
.2 0 1 r
.002 w
.19106 .35555 m
.05592 .31164 L
s
P
p
.2 0 1 r
.002 w
.19106 .35555 m
.04897 .35555 L
s
P
p
.2 0 1 r
.002 w
.19106 .35555 m
.05592 .39946 L
s
P
p
.2 0 1 r
.002 w
.22206 .37808 m
.22206 .52017 L
s
P
p
.2 0 1 r
.002 w
.22206 .37808 m
.26597 .51322 L
s
P
p
.2 0 1 r
.002 w
.22206 .37808 m
.30558 .49303 L
s
P
p
0 .4 1 r
.018 w
.21474 .35555 m
.22206 .33303 L
s
P
p
0 .4 1 r
.018 w
.21474 .35555 m
.19106 .35555 L
s
P
p
0 .4 1 r
.018 w
.21474 .35555 m
.22206 .37808 L
s
P
p
.2 0 1 r
.016 w
.4042 .35555 m
.34566 .53574 L
s
P
p
.2 0 1 r
.016 w
.4042 .35555 m
.51556 .20228 L
s
P
p
.2 0 1 r
.016 w
.4042 .35555 m
.25093 .46691 L
s
P
p
.2 0 1 r
.016 w
.4042 .35555 m
.58439 .29701 L
s
P
p
.2 0 1 r
.016 w
.4042 .35555 m
.21474 .35555 L
s
P
p
.2 0 1 r
.002 w
.49827 .57876 m
.36313 .53485 L
s
P
p
.2 0 1 r
.002 w
.49827 .57876 m
.35618 .57876 L
s
P
p
.2 0 1 r
.002 w
.49827 .57876 m
.36313 .62266 L
s
P
p
.2 0 1 r
.002 w
.52927 .60128 m
.52927 .74337 L
s
P
p
.2 0 1 r
.002 w
.52927 .60128 m
.57318 .73642 L
s
P
p
.2 0 1 r
.002 w
.52927 .60128 m
.61279 .71624 L
s
P
p
.2 0 1 r
.002 w
.54111 .56484 m
.67625 .52093 L
s
P
p
.2 0 1 r
.002 w
.54111 .56484 m
.65607 .48131 L
s
P
p
.2 0 1 r
.002 w
.54111 .56484 m
.62464 .44988 L
s
P
p
0 .4 1 r
.018 w
.52195 .57876 m
.49827 .57876 L
s
P
p
0 .4 1 r
.018 w
.52195 .57876 m
.52927 .60128 L
s
P
p
0 .4 1 r
.018 w
.52195 .57876 m
.54111 .56484 L
s
P
p
.2 0 1 r
.002 w
.48593 .21643 m
.60089 .29995 L
s
P
p
.2 0 1 r
.002 w
.48593 .21643 m
.62107 .26034 L
s
P
p
.2 0 1 r
.002 w
.48593 .21643 m
.62803 .21643 L
s
P
p
.2 0 1 r
.002 w
.46341 .18543 m
.50732 .05029 L
s
P
p
.2 0 1 r
.002 w
.46341 .18543 m
.46341 .04333 L
s
P
p
.2 0 1 r
.002 w
.46341 .18543 m
.4195 .05029 L
s
P
p
.2 0 1 r
.002 w
.44089 .21643 m
.29879 .21643 L
s
P
p
.2 0 1 r
.002 w
.44089 .21643 m
.30575 .26034 L
s
P
p
.2 0 1 r
.002 w
.44089 .21643 m
.32593 .29995 L
s
P
p
0 .4 1 r
.018 w
.46341 .20911 m
.48593 .21643 L
s
P
p
0 .4 1 r
.018 w
.46341 .20911 m
.46341 .18543 L
s
P
p
0 .4 1 r
.018 w
.46341 .20911 m
.44089 .21643 L
s
P
p
.2 0 1 r
.002 w
.3857 .56484 m
.30218 .44988 L
s
P
p
.2 0 1 r
.002 w
.3857 .56484 m
.27075 .48131 L
s
P
p
.2 0 1 r
.002 w
.3857 .56484 m
.25056 .52093 L
s
P
p
.2 0 1 r
.002 w
.39754 .60128 m
.31402 .71624 L
s
P
p
.2 0 1 r
.002 w
.39754 .60128 m
.35363 .73642 L
s
P
p
.2 0 1 r
.002 w
.39754 .60128 m
.39754 .74337 L
s
P
p
.2 0 1 r
.002 w
.42854 .57876 m
.56368 .62266 L
s
P
p
.2 0 1 r
.002 w
.42854 .57876 m
.57064 .57876 L
s
P
p
.2 0 1 r
.002 w
.42854 .57876 m
.56368 .53485 L
s
P
p
0 .4 1 r
.018 w
.40486 .57876 m
.3857 .56484 L
s
P
p
0 .4 1 r
.018 w
.40486 .57876 m
.39754 .60128 L
s
P
p
0 .4 1 r
.018 w
.40486 .57876 m
.42854 .57876 L
s
P
p
.2 0 1 r
.002 w
.58869 .26445 m
.6326 .39959 L
s
P
p
.2 0 1 r
.002 w
.58869 .26445 m
.67221 .37941 L
s
P
p
.2 0 1 r
.002 w
.58869 .26445 m
.70365 .34797 L
s
P
p
.2 0 1 r
.002 w
.58869 .22613 m
.70365 .14261 L
s
P
p
.2 0 1 r
.002 w
.58869 .22613 m
.67221 .11118 L
s
P
p
.2 0 1 r
.002 w
.58869 .22613 m
.6326 .09099 L
s
P
p
.2 0 1 r
.002 w
.55225 .23797 m
.43729 .15445 L
s
P
p
.2 0 1 r
.002 w
.55225 .23797 m
.41711 .19406 L
s
P
p
.2 0 1 r
.002 w
.55225 .23797 m
.41015 .23797 L
s
P
p
0 .4 1 r
.018 w
.57477 .24529 m
.58869 .26445 L
s
P
p
0 .4 1 r
.018 w
.57477 .24529 m
.58869 .22613 L
s
P
p
0 .4 1 r
.018 w
.57477 .24529 m
.55225 .23797 L
s
P
p
.2 0 1 r
.002 w
.30281 .48741 m
.30281 .34531 L
s
P
p
.2 0 1 r
.002 w
.30281 .48741 m
.2589 .35227 L
s
P
p
.2 0 1 r
.002 w
.30281 .48741 m
.21929 .37245 L
s
P
p
.2 0 1 r
.002 w
.29097 .52385 m
.15583 .56776 L
s
P
p
.2 0 1 r
.002 w
.29097 .52385 m
.17602 .60737 L
s
P
p
.2 0 1 r
.002 w
.29097 .52385 m
.20745 .63881 L
s
P
p
.2 0 1 r
.002 w
.32929 .52385 m
.41281 .63881 L
s
P
p
.2 0 1 r
.002 w
.32929 .52385 m
.44425 .60737 L
s
P
p
.2 0 1 r
.002 w
.32929 .52385 m
.46443 .56776 L
s
P
p
0 .4 1 r
.018 w
.31013 .50993 m
.30281 .48741 L
s
P
p
0 .4 1 r
.018 w
.31013 .50993 m
.29097 .52385 L
s
P
p
0 .4 1 r
.018 w
.31013 .50993 m
.32929 .52385 L
s
P
p
.2 0 1 r
.016 w
.46341 .39857 m
.52195 .57876 L
s
P
p
.2 0 1 r
.016 w
.46341 .39857 m
.46341 .20911 L
s
P
p
.2 0 1 r
.016 w
.46341 .39857 m
.40486 .57876 L
s
P
p
.2 0 1 r
.016 w
.46341 .39857 m
.57477 .24529 L
s
P
p
.2 0 1 r
.016 w
.46341 .39857 m
.31013 .50993 L
s
P
p
.2 0 1 r
.002 w
.67071 .52385 m
.53557 .56776 L
s
P
p
.2 0 1 r
.002 w
.67071 .52385 m
.55575 .60737 L
s
P
p
.2 0 1 r
.002 w
.67071 .52385 m
.58719 .63881 L
s
P
p
.2 0 1 r
.002 w
.70903 .52385 m
.79255 .63881 L
s
P
p
.2 0 1 r
.002 w
.70903 .52385 m
.82398 .60737 L
s
P
p
.2 0 1 r
.002 w
.70903 .52385 m
.84417 .56776 L
s
P
p
.2 0 1 r
.002 w
.69719 .48741 m
.78071 .37245 L
s
P
p
.2 0 1 r
.002 w
.69719 .48741 m
.7411 .35227 L
s
P
p
.2 0 1 r
.002 w
.69719 .48741 m
.69719 .34531 L
s
P
p
0 .4 1 r
.018 w
.68987 .50993 m
.67071 .52385 L
s
P
p
0 .4 1 r
.018 w
.68987 .50993 m
.70903 .52385 L
s
P
p
0 .4 1 r
.018 w
.68987 .50993 m
.69719 .48741 L
s
P
p
.2 0 1 r
.002 w
.44775 .23797 m
.58985 .23797 L
s
P
p
.2 0 1 r
.002 w
.44775 .23797 m
.58289 .19406 L
s
P
p
.2 0 1 r
.002 w
.44775 .23797 m
.56271 .15445 L
s
P
p
.2 0 1 r
.002 w
.41131 .22613 m
.3674 .09099 L
s
P
p
.2 0 1 r
.002 w
.41131 .22613 m
.32779 .11118 L
s
P
p
.2 0 1 r
.002 w
.41131 .22613 m
.29635 .14261 L
s
P
p
.2 0 1 r
.002 w
.41131 .26445 m
.29635 .34797 L
s
P
p
.2 0 1 r
.002 w
.41131 .26445 m
.32779 .37941 L
s
P
p
.2 0 1 r
.002 w
.41131 .26445 m
.3674 .39959 L
s
P
p
0 .4 1 r
.018 w
.42523 .24529 m
.44775 .23797 L
s
P
p
0 .4 1 r
.018 w
.42523 .24529 m
.41131 .22613 L
s
P
p
0 .4 1 r
.018 w
.42523 .24529 m
.41131 .26445 L
s
P
p
.2 0 1 r
.002 w
.57146 .57876 m
.43632 .53485 L
s
P
p
.2 0 1 r
.002 w
.57146 .57876 m
.42936 .57876 L
s
P
p
.2 0 1 r
.002 w
.57146 .57876 m
.43632 .62266 L
s
P
p
.2 0 1 r
.002 w
.60246 .60128 m
.60246 .74337 L
s
P
p
.2 0 1 r
.002 w
.60246 .60128 m
.64637 .73642 L
s
P
p
.2 0 1 r
.002 w
.60246 .60128 m
.68598 .71624 L
s
P
p
.2 0 1 r
.002 w
.6143 .56484 m
.74944 .52093 L
s
P
p
.2 0 1 r
.002 w
.6143 .56484 m
.72925 .48131 L
s
P
p
.2 0 1 r
.002 w
.6143 .56484 m
.69782 .44988 L
s
P
p
0 .4 1 r
.018 w
.59514 .57876 m
.57146 .57876 L
s
P
p
0 .4 1 r
.018 w
.59514 .57876 m
.60246 .60128 L
s
P
p
0 .4 1 r
.018 w
.59514 .57876 m
.6143 .56484 L
s
P
p
.2 0 1 r
.002 w
.55911 .21643 m
.67407 .29995 L
s
P
p
.2 0 1 r
.002 w
.55911 .21643 m
.69425 .26034 L
s
P
p
.2 0 1 r
.002 w
.55911 .21643 m
.70121 .21643 L
s
P
p
.2 0 1 r
.002 w
.53659 .18543 m
.5805 .05029 L
s
P
p
.2 0 1 r
.002 w
.53659 .18543 m
.53659 .04333 L
s
P
p
.2 0 1 r
.002 w
.53659 .18543 m
.49268 .05029 L
s
P
p
.2 0 1 r
.002 w
.51407 .21643 m
.37197 .21643 L
s
P
p
.2 0 1 r
.002 w
.51407 .21643 m
.37893 .26034 L
s
P
p
.2 0 1 r
.002 w
.51407 .21643 m
.39911 .29995 L
s
P
p
0 .4 1 r
.018 w
.53659 .20911 m
.55911 .21643 L
s
P
p
0 .4 1 r
.018 w
.53659 .20911 m
.53659 .18543 L
s
P
p
0 .4 1 r
.018 w
.53659 .20911 m
.51407 .21643 L
s
P
p
.2 0 1 r
.002 w
.45889 .56484 m
.37536 .44988 L
s
P
p
.2 0 1 r
.002 w
.45889 .56484 m
.34393 .48131 L
s
P
p
.2 0 1 r
.002 w
.45889 .56484 m
.32375 .52093 L
s
P
p
.2 0 1 r
.002 w
.47073 .60128 m
.38721 .71624 L
s
P
p
.2 0 1 r
.002 w
.47073 .60128 m
.42682 .73642 L
s
P
p
.2 0 1 r
.002 w
.47073 .60128 m
.47073 .74337 L
s
P
p
.2 0 1 r
.002 w
.50173 .57876 m
.63687 .62266 L
s
P
p
.2 0 1 r
.002 w
.50173 .57876 m
.64382 .57876 L
s
P
p
.2 0 1 r
.002 w
.50173 .57876 m
.63687 .53485 L
s
P
p
0 .4 1 r
.018 w
.47805 .57876 m
.45889 .56484 L
s
P
p
0 .4 1 r
.018 w
.47805 .57876 m
.47073 .60128 L
s
P
p
0 .4 1 r
.018 w
.47805 .57876 m
.50173 .57876 L
s
P
p
.2 0 1 r
.016 w
.53659 .39857 m
.68987 .50993 L
s
P
p
.2 0 1 r
.016 w
.53659 .39857 m
.42523 .24529 L
s
P
p
.2 0 1 r
.016 w
.53659 .39857 m
.59514 .57876 L
s
P
p
.2 0 1 r
.016 w
.53659 .39857 m
.53659 .20911 L
s
P
p
.2 0 1 r
.016 w
.53659 .39857 m
.47805 .57876 L
s
P
p
.2 0 1 r
.002 w
.77794 .37808 m
.69442 .49303 L
s
P
p
.2 0 1 r
.002 w
.77794 .37808 m
.73403 .51322 L
s
P
p
.2 0 1 r
.002 w
.77794 .37808 m
.77794 .52017 L
s
P
p
.2 0 1 r
.002 w
.80894 .35555 m
.94408 .39946 L
s
P
p
.2 0 1 r
.002 w
.80894 .35555 m
.95103 .35555 L
s
P
p
.2 0 1 r
.002 w
.80894 .35555 m
.94408 .31164 L
s
P
p
.2 0 1 r
.002 w
.77794 .33303 m
.77794 .19093 L
s
P
p
.2 0 1 r
.002 w
.77794 .33303 m
.73403 .19789 L
s
P
p
.2 0 1 r
.002 w
.77794 .33303 m
.69442 .21807 L
s
P
p
0 .4 1 r
.018 w
.78526 .35555 m
.77794 .37808 L
s
P
p
0 .4 1 r
.018 w
.78526 .35555 m
.80894 .35555 L
s
P
p
0 .4 1 r
.018 w
.78526 .35555 m
.77794 .33303 L
s
P
p
.2 0 1 r
.002 w
.42953 .27785 m
.54449 .19433 L
s
P
p
.2 0 1 r
.002 w
.42953 .27785 m
.51305 .16289 L
s
P
p
.2 0 1 r
.002 w
.42953 .27785 m
.47344 .14271 L
s
P
p
.2 0 1 r
.002 w
.39309 .28969 m
.27813 .20617 L
s
P
p
.2 0 1 r
.002 w
.39309 .28969 m
.25795 .24578 L
s
P
p
.2 0 1 r
.002 w
.39309 .28969 m
.25099 .28969 L
s
P
p
.2 0 1 r
.002 w
.41561 .32069 m
.3717 .45583 L
s
P
p
.2 0 1 r
.002 w
.41561 .32069 m
.41561 .46278 L
s
P
p
.2 0 1 r
.002 w
.41561 .32069 m
.45952 .45583 L
s
P
p
0 .4 1 r
.018 w
.41561 .29701 m
.42953 .27785 L
s
P
p
0 .4 1 r
.018 w
.41561 .29701 m
.39309 .28969 L
s
P
p
0 .4 1 r
.018 w
.41561 .29701 m
.41561 .32069 L
s
P
p
.2 0 1 r
.002 w
.72991 .48083 m
.59477 .52474 L
s
P
p
.2 0 1 r
.002 w
.72991 .48083 m
.61496 .56436 L
s
P
p
.2 0 1 r
.002 w
.72991 .48083 m
.64639 .59579 L
s
P
p
.2 0 1 r
.002 w
.76823 .48083 m
.85175 .59579 L
s
P
p
.2 0 1 r
.002 w
.76823 .48083 m
.88319 .56436 L
s
P
p
.2 0 1 r
.002 w
.76823 .48083 m
.90337 .52474 L
s
P
p
.2 0 1 r
.002 w
.75639 .44439 m
.83991 .32943 L
s
P
p
.2 0 1 r
.002 w
.75639 .44439 m
.8003 .30925 L
s
P
p
.2 0 1 r
.002 w
.75639 .44439 m
.75639 .3023 L
s
P
p
0 .4 1 r
.018 w
.74907 .46691 m
.72991 .48083 L
s
P
p
0 .4 1 r
.018 w
.74907 .46691 m
.76823 .48083 L
s
P
p
0 .4 1 r
.018 w
.74907 .46691 m
.75639 .44439 L
s
P
p
.2 0 1 r
.002 w
.50696 .19496 m
.64905 .19496 L
s
P
p
.2 0 1 r
.002 w
.50696 .19496 m
.6421 .15105 L
s
P
p
.2 0 1 r
.002 w
.50696 .19496 m
.62192 .11144 L
s
P
p
.2 0 1 r
.002 w
.47052 .18312 m
.42661 .04798 L
s
P
p
.2 0 1 r
.002 w
.47052 .18312 m
.38699 .06816 L
s
P
p
.2 0 1 r
.002 w
.47052 .18312 m
.35556 .0996 L
s
P
p
.2 0 1 r
.002 w
.47052 .22144 m
.35556 .30496 L
s
P
p
.2 0 1 r
.002 w
.47052 .22144 m
.38699 .33639 L
s
P
p
.2 0 1 r
.002 w
.47052 .22144 m
.42661 .35658 L
s
P
p
0 .4 1 r
.018 w
.48444 .20228 m
.50696 .19496 L
s
P
p
0 .4 1 r
.018 w
.48444 .20228 m
.47052 .18312 L
s
P
p
0 .4 1 r
.018 w
.48444 .20228 m
.47052 .22144 L
s
P
p
.2 0 1 r
.002 w
.63066 .53574 m
.49552 .49183 L
s
P
p
.2 0 1 r
.002 w
.63066 .53574 m
.48857 .53574 L
s
P
p
.2 0 1 r
.002 w
.63066 .53574 m
.49552 .57965 L
s
P
p
.2 0 1 r
.002 w
.66166 .55826 m
.66166 .70036 L
s
P
p
.2 0 1 r
.002 w
.66166 .55826 m
.70557 .6934 L
s
P
p
.2 0 1 r
.002 w
.66166 .55826 m
.74518 .67322 L
s
P
p
.2 0 1 r
.002 w
.6735 .52182 m
.80864 .47791 L
s
P
p
.2 0 1 r
.002 w
.6735 .52182 m
.78846 .4383 L
s
P
p
.2 0 1 r
.002 w
.6735 .52182 m
.75702 .40686 L
s
P
p
0 .4 1 r
.018 w
.65434 .53574 m
.63066 .53574 L
s
P
p
0 .4 1 r
.018 w
.65434 .53574 m
.66166 .55826 L
s
P
p
0 .4 1 r
.018 w
.65434 .53574 m
.6735 .52182 L
s
P
p
.2 0 1 r
.016 w
.5958 .35555 m
.78526 .35555 L
s
P
p
.2 0 1 r
.016 w
.5958 .35555 m
.41561 .29701 L
s
P
p
.2 0 1 r
.016 w
.5958 .35555 m
.74907 .46691 L
s
P
p
.2 0 1 r
.016 w
.5958 .35555 m
.48444 .20228 L
s
P
p
.2 0 1 r
.016 w
.5958 .35555 m
.65434 .53574 L
s
P
p
1 .6 0 r
.016 w
.5 .28595 m
.4042 .35555 L
s
P
p
1 .6 0 r
.016 w
.5 .28595 m
.46341 .39857 L
s
P
p
1 .6 0 r
.016 w
.5 .28595 m
.53659 .39857 L
s
P
p
1 .6 0 r
.016 w
.5 .28595 m
.5958 .35555 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
p
% Start of sub-graphic
p
0.0238095 0.285714 0.149123 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.172483 0.952381 [
[ 0 0 0 0 ]
[ 1 .60741 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .60741 L
0 .60741 L
closepath
clip
newpath
p
P
p
1 .6 0 r
.016 w
.5 .044 m
.05816 .36502 L
s
P
p
1 .6 0 r
.016 w
.5 .044 m
.33123 .56341 L
s
P
p
1 .6 0 r
.016 w
.5 .044 m
.66877 .56341 L
s
P
p
1 .6 0 r
.016 w
.5 .044 m
.94184 .36502 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.161654 0.285714 0.286967 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0709572 0.952381 [
[ 0 0 0 0 ]
[ 1 .81047 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .81047 L
0 .81047 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.26327 .44157 m
.22199 .31452 L
s
P
p
.2 0 1 r
.002 w
.26327 .44157 m
.18476 .3335 L
s
P
p
.2 0 1 r
.002 w
.26327 .44157 m
.1552 .36305 L
s
P
p
.2 0 1 r
.002 w
.26327 .51361 m
.1552 .59213 L
s
P
p
.2 0 1 r
.002 w
.26327 .51361 m
.18476 .62168 L
s
P
p
.2 0 1 r
.002 w
.26327 .51361 m
.22199 .64065 L
s
P
p
.2 0 1 r
.002 w
.33179 .49135 m
.43986 .56986 L
s
P
p
.2 0 1 r
.002 w
.33179 .49135 m
.45883 .53263 L
s
P
p
.2 0 1 r
.002 w
.33179 .49135 m
.46537 .49135 L
s
P
p
0 .4 1 r
.018 w
.28944 .47759 m
.26327 .44157 L
s
P
p
0 .4 1 r
.018 w
.28944 .47759 m
.26327 .51361 L
s
P
p
0 .4 1 r
.018 w
.28944 .47759 m
.33179 .49135 L
s
P
p
.2 0 1 r
.002 w
.55198 .27116 m
.55198 .40474 L
s
P
p
.2 0 1 r
.002 w
.55198 .27116 m
.59326 .3982 L
s
P
p
.2 0 1 r
.002 w
.55198 .27116 m
.6305 .37922 L
s
P
p
.2 0 1 r
.002 w
.57425 .20264 m
.70129 .16136 L
s
P
p
.2 0 1 r
.002 w
.57425 .20264 m
.68231 .12412 L
s
P
p
.2 0 1 r
.002 w
.57425 .20264 m
.65276 .09457 L
s
P
p
.2 0 1 r
.002 w
.5022 .20264 m
.42368 .09457 L
s
P
p
.2 0 1 r
.002 w
.5022 .20264 m
.39413 .12412 L
s
P
p
.2 0 1 r
.002 w
.5022 .20264 m
.37516 .16136 L
s
P
p
0 .4 1 r
.018 w
.53822 .22881 m
.55198 .27116 L
s
P
p
0 .4 1 r
.018 w
.53822 .22881 m
.57425 .20264 L
s
P
p
0 .4 1 r
.018 w
.53822 .22881 m
.5022 .20264 L
s
P
p
.2 0 1 r
.002 w
.22474 .34401 m
.26602 .21697 L
s
P
p
.2 0 1 r
.002 w
.22474 .34401 m
.22474 .21043 L
s
P
p
.2 0 1 r
.002 w
.22474 .34401 m
.18346 .21697 L
s
P
p
.2 0 1 r
.002 w
.1824 .40229 m
.04882 .40229 L
s
P
p
.2 0 1 r
.002 w
.1824 .40229 m
.05535 .44357 L
s
P
p
.2 0 1 r
.002 w
.1824 .40229 m
.07433 .48081 L
s
P
p
.2 0 1 r
.002 w
.25092 .42456 m
.29219 .5516 L
s
P
p
.2 0 1 r
.002 w
.25092 .42456 m
.32943 .53263 L
s
P
p
.2 0 1 r
.002 w
.25092 .42456 m
.35898 .50307 L
s
P
p
0 .4 1 r
.018 w
.22474 .38853 m
.22474 .34401 L
s
P
p
0 .4 1 r
.018 w
.22474 .38853 m
.1824 .40229 L
s
P
p
0 .4 1 r
.018 w
.22474 .38853 m
.25092 .42456 L
s
P
p
.2 0 1 r
.002 w
.55848 .37584 m
.47996 .48391 L
s
P
p
.2 0 1 r
.002 w
.55848 .37584 m
.5172 .50289 L
s
P
p
.2 0 1 r
.002 w
.55848 .37584 m
.55848 .50942 L
s
P
p
.2 0 1 r
.002 w
.61676 .3335 m
.74381 .37478 L
s
P
p
.2 0 1 r
.002 w
.61676 .3335 m
.75034 .3335 L
s
P
p
.2 0 1 r
.002 w
.61676 .3335 m
.74381 .29222 L
s
P
p
.2 0 1 r
.002 w
.55848 .29115 m
.55848 .15757 L
s
P
p
.2 0 1 r
.002 w
.55848 .29115 m
.5172 .16411 L
s
P
p
.2 0 1 r
.002 w
.55848 .29115 m
.47996 .18308 L
s
P
p
0 .4 1 r
.018 w
.57224 .3335 m
.55848 .37584 L
s
P
p
0 .4 1 r
.018 w
.57224 .3335 m
.61676 .3335 L
s
P
p
0 .4 1 r
.018 w
.57224 .3335 m
.55848 .29115 L
s
P
p
.2 0 1 r
.002 w
.25092 .24244 m
.35898 .16392 L
s
P
p
.2 0 1 r
.002 w
.25092 .24244 m
.32943 .13437 L
s
P
p
.2 0 1 r
.002 w
.25092 .24244 m
.29219 .1154 L
s
P
p
.2 0 1 r
.002 w
.1824 .2647 m
.07433 .18618 L
s
P
p
.2 0 1 r
.002 w
.1824 .2647 m
.05535 .22342 L
s
P
p
.2 0 1 r
.002 w
.1824 .2647 m
.04882 .2647 L
s
P
p
.2 0 1 r
.002 w
.22474 .32299 m
.18346 .45003 L
s
P
p
.2 0 1 r
.002 w
.22474 .32299 m
.22474 .45657 L
s
P
p
.2 0 1 r
.002 w
.22474 .32299 m
.26602 .45003 L
s
P
p
0 .4 1 r
.018 w
.22474 .27846 m
.25092 .24244 L
s
P
p
0 .4 1 r
.018 w
.22474 .27846 m
.1824 .2647 L
s
P
p
0 .4 1 r
.018 w
.22474 .27846 m
.22474 .32299 L
s
P
p
.2 0 1 r
.016 w
.39413 .3335 m
.28944 .47759 L
s
P
p
.2 0 1 r
.016 w
.39413 .3335 m
.53822 .22881 L
s
P
p
.2 0 1 r
.016 w
.39413 .3335 m
.22474 .38853 L
s
P
p
.2 0 1 r
.016 w
.39413 .3335 m
.57224 .3335 L
s
P
p
.2 0 1 r
.016 w
.39413 .3335 m
.22474 .27846 L
s
P
p
.2 0 1 r
.002 w
.39222 .5535 m
.28415 .47499 L
s
P
p
.2 0 1 r
.002 w
.39222 .5535 m
.26518 .51222 L
s
P
p
.2 0 1 r
.002 w
.39222 .5535 m
.25864 .5535 L
s
P
p
.2 0 1 r
.002 w
.43457 .61179 m
.39329 .73883 L
s
P
p
.2 0 1 r
.002 w
.43457 .61179 m
.43457 .74537 L
s
P
p
.2 0 1 r
.002 w
.43457 .61179 m
.47585 .73883 L
s
P
p
.2 0 1 r
.002 w
.47692 .5535 m
.6105 .5535 L
s
P
p
.2 0 1 r
.002 w
.47692 .5535 m
.60396 .51222 L
s
P
p
.2 0 1 r
.002 w
.47692 .5535 m
.58499 .47499 L
s
P
p
0 .4 1 r
.018 w
.43457 .56726 m
.39222 .5535 L
s
P
p
0 .4 1 r
.018 w
.43457 .56726 m
.43457 .61179 L
s
P
p
0 .4 1 r
.018 w
.43457 .56726 m
.47692 .5535 L
s
P
p
.2 0 1 r
.002 w
.52563 .24594 m
.60415 .35401 L
s
P
p
.2 0 1 r
.002 w
.52563 .24594 m
.6337 .32445 L
s
P
p
.2 0 1 r
.002 w
.52563 .24594 m
.65267 .28722 L
s
P
p
.2 0 1 r
.002 w
.50337 .17742 m
.58188 .06935 L
s
P
p
.2 0 1 r
.002 w
.50337 .17742 m
.54465 .05038 L
s
P
p
.2 0 1 r
.002 w
.50337 .17742 m
.50337 .04384 L
s
P
p
.2 0 1 r
.002 w
.44508 .21977 m
.31804 .17849 L
s
P
p
.2 0 1 r
.002 w
.44508 .21977 m
.3115 .21977 L
s
P
p
.2 0 1 r
.002 w
.44508 .21977 m
.31804 .26104 L
s
P
p
0 .4 1 r
.018 w
.48961 .21977 m
.52563 .24594 L
s
P
p
0 .4 1 r
.018 w
.48961 .21977 m
.50337 .17742 L
s
P
p
0 .4 1 r
.018 w
.48961 .21977 m
.44508 .21977 L
s
P
p
.2 0 1 r
.002 w
.30371 .49722 m
.26243 .37018 L
s
P
p
.2 0 1 r
.002 w
.30371 .49722 m
.22519 .38916 L
s
P
p
.2 0 1 r
.002 w
.30371 .49722 m
.19564 .41871 L
s
P
p
.2 0 1 r
.002 w
.30371 .56927 m
.19564 .64778 L
s
P
p
.2 0 1 r
.002 w
.30371 .56927 m
.22519 .67734 L
s
P
p
.2 0 1 r
.002 w
.30371 .56927 m
.26243 .69631 L
s
P
p
.2 0 1 r
.002 w
.37223 .54701 m
.4803 .62552 L
s
P
p
.2 0 1 r
.002 w
.37223 .54701 m
.49927 .58828 L
s
P
p
.2 0 1 r
.002 w
.37223 .54701 m
.50581 .54701 L
s
P
p
0 .4 1 r
.018 w
.32988 .53325 m
.30371 .49722 L
s
P
p
0 .4 1 r
.018 w
.32988 .53325 m
.30371 .56927 L
s
P
p
0 .4 1 r
.018 w
.32988 .53325 m
.37223 .54701 L
s
P
p
.2 0 1 r
.002 w
.59242 .32681 m
.59242 .46039 L
s
P
p
.2 0 1 r
.002 w
.59242 .32681 m
.6337 .45386 L
s
P
p
.2 0 1 r
.002 w
.59242 .32681 m
.67094 .43488 L
s
P
p
.2 0 1 r
.002 w
.61468 .2583 m
.74173 .21702 L
s
P
p
.2 0 1 r
.002 w
.61468 .2583 m
.72275 .17978 L
s
P
p
.2 0 1 r
.002 w
.61468 .2583 m
.6932 .15023 L
s
P
p
.2 0 1 r
.002 w
.54264 .2583 m
.46412 .15023 L
s
P
p
.2 0 1 r
.002 w
.54264 .2583 m
.43457 .17978 L
s
P
p
.2 0 1 r
.002 w
.54264 .2583 m
.4156 .21702 L
s
P
p
0 .4 1 r
.018 w
.57866 .28447 m
.59242 .32681 L
s
P
p
0 .4 1 r
.018 w
.57866 .28447 m
.61468 .2583 L
s
P
p
0 .4 1 r
.018 w
.57866 .28447 m
.54264 .2583 L
s
P
p
.2 0 1 r
.002 w
.26518 .39967 m
.30646 .27262 L
s
P
p
.2 0 1 r
.002 w
.26518 .39967 m
.26518 .26609 L
s
P
p
.2 0 1 r
.002 w
.26518 .39967 m
.2239 .27262 L
s
P
p
.2 0 1 r
.002 w
.22283 .45795 m
.08925 .45795 L
s
P
p
.2 0 1 r
.002 w
.22283 .45795 m
.09579 .49923 L
s
P
p
.2 0 1 r
.002 w
.22283 .45795 m
.11477 .53647 L
s
P
p
.2 0 1 r
.002 w
.29135 .48022 m
.33263 .60726 L
s
P
p
.2 0 1 r
.002 w
.29135 .48022 m
.36987 .58828 L
s
P
p
.2 0 1 r
.002 w
.29135 .48022 m
.39942 .55873 L
s
P
p
0 .4 1 r
.018 w
.26518 .44419 m
.26518 .39967 L
s
P
p
0 .4 1 r
.018 w
.26518 .44419 m
.22283 .45795 L
s
P
p
0 .4 1 r
.018 w
.26518 .44419 m
.29135 .48022 L
s
P
p
.2 0 1 r
.016 w
.43457 .38916 m
.43457 .56726 L
s
P
p
.2 0 1 r
.016 w
.43457 .38916 m
.48961 .21977 L
s
P
p
.2 0 1 r
.016 w
.43457 .38916 m
.32988 .53325 L
s
P
p
.2 0 1 r
.016 w
.43457 .38916 m
.57866 .28447 L
s
P
p
.2 0 1 r
.016 w
.43457 .38916 m
.26518 .44419 L
s
P
p
.2 0 1 r
.002 w
.56234 .56827 m
.42876 .56827 L
s
P
p
.2 0 1 r
.002 w
.56234 .56827 m
.4353 .60954 L
s
P
p
.2 0 1 r
.002 w
.56234 .56827 m
.45427 .64678 L
s
P
p
.2 0 1 r
.002 w
.63086 .59053 m
.67214 .71757 L
s
P
p
.2 0 1 r
.002 w
.63086 .59053 m
.70938 .6986 L
s
P
p
.2 0 1 r
.002 w
.63086 .59053 m
.73893 .66904 L
s
P
p
.2 0 1 r
.002 w
.63086 .51848 m
.73893 .43997 L
s
P
p
.2 0 1 r
.002 w
.63086 .51848 m
.70938 .41041 L
s
P
p
.2 0 1 r
.002 w
.63086 .51848 m
.67214 .39144 L
s
P
p
0 .4 1 r
.018 w
.60469 .55451 m
.56234 .56827 L
s
P
p
0 .4 1 r
.018 w
.60469 .55451 m
.63086 .59053 L
s
P
p
0 .4 1 r
.018 w
.60469 .55451 m
.63086 .51848 L
s
P
p
.2 0 1 r
.002 w
.48949 .24103 m
.61653 .2823 L
s
P
p
.2 0 1 r
.002 w
.48949 .24103 m
.62307 .24103 L
s
P
p
.2 0 1 r
.002 w
.48949 .24103 m
.61653 .19975 L
s
P
p
.2 0 1 r
.002 w
.4312 .19868 m
.4312 .0651 L
s
P
p
.2 0 1 r
.002 w
.4312 .19868 m
.38992 .07164 L
s
P
p
.2 0 1 r
.002 w
.4312 .19868 m
.35269 .09061 L
s
P
p
.2 0 1 r
.002 w
.40894 .2672 m
.2819 .30848 L
s
P
p
.2 0 1 r
.002 w
.40894 .2672 m
.30087 .34571 L
s
P
p
.2 0 1 r
.002 w
.40894 .2672 m
.33042 .37527 L
s
P
p
0 .4 1 r
.018 w
.44496 .24103 m
.48949 .24103 L
s
P
p
0 .4 1 r
.018 w
.44496 .24103 m
.4312 .19868 L
s
P
p
0 .4 1 r
.018 w
.44496 .24103 m
.40894 .2672 L
s
P
p
.2 0 1 r
.002 w
.45765 .57476 m
.34958 .49625 L
s
P
p
.2 0 1 r
.002 w
.45765 .57476 m
.33061 .53348 L
s
P
p
.2 0 1 r
.002 w
.45765 .57476 m
.32407 .57476 L
s
P
p
.2 0 1 r
.002 w
.5 .63305 m
.45872 .76009 L
s
P
p
.2 0 1 r
.002 w
.5 .63305 m
.5 .76663 L
s
P
p
.2 0 1 r
.002 w
.5 .63305 m
.54128 .76009 L
s
P
p
.2 0 1 r
.002 w
.54235 .57476 m
.67593 .57476 L
s
P
p
.2 0 1 r
.002 w
.54235 .57476 m
.66939 .53348 L
s
P
p
.2 0 1 r
.002 w
.54235 .57476 m
.65042 .49625 L
s
P
p
0 .4 1 r
.018 w
.5 .58852 m
.45765 .57476 L
s
P
p
0 .4 1 r
.018 w
.5 .58852 m
.5 .63305 L
s
P
p
0 .4 1 r
.018 w
.5 .58852 m
.54235 .57476 L
s
P
p
.2 0 1 r
.002 w
.59106 .2672 m
.66958 .37527 L
s
P
p
.2 0 1 r
.002 w
.59106 .2672 m
.69913 .34571 L
s
P
p
.2 0 1 r
.002 w
.59106 .2672 m
.7181 .30848 L
s
P
p
.2 0 1 r
.002 w
.5688 .19868 m
.64731 .09061 L
s
P
p
.2 0 1 r
.002 w
.5688 .19868 m
.61008 .07164 L
s
P
p
.2 0 1 r
.002 w
.5688 .19868 m
.5688 .0651 L
s
P
p
.2 0 1 r
.002 w
.51051 .24103 m
.38347 .19975 L
s
P
p
.2 0 1 r
.002 w
.51051 .24103 m
.37693 .24103 L
s
P
p
.2 0 1 r
.002 w
.51051 .24103 m
.38347 .2823 L
s
P
p
0 .4 1 r
.018 w
.55504 .24103 m
.59106 .2672 L
s
P
p
0 .4 1 r
.018 w
.55504 .24103 m
.5688 .19868 L
s
P
p
0 .4 1 r
.018 w
.55504 .24103 m
.51051 .24103 L
s
P
p
.2 0 1 r
.002 w
.36914 .51848 m
.32786 .39144 L
s
P
p
.2 0 1 r
.002 w
.36914 .51848 m
.29062 .41041 L
s
P
p
.2 0 1 r
.002 w
.36914 .51848 m
.26107 .43997 L
s
P
p
.2 0 1 r
.002 w
.36914 .59053 m
.26107 .66904 L
s
P
p
.2 0 1 r
.002 w
.36914 .59053 m
.29062 .6986 L
s
P
p
.2 0 1 r
.002 w
.36914 .59053 m
.32786 .71757 L
s
P
p
.2 0 1 r
.002 w
.43766 .56827 m
.54573 .64678 L
s
P
p
.2 0 1 r
.002 w
.43766 .56827 m
.5647 .60954 L
s
P
p
.2 0 1 r
.002 w
.43766 .56827 m
.57124 .56827 L
s
P
p
0 .4 1 r
.018 w
.39531 .55451 m
.36914 .51848 L
s
P
p
0 .4 1 r
.018 w
.39531 .55451 m
.36914 .59053 L
s
P
p
0 .4 1 r
.018 w
.39531 .55451 m
.43766 .56827 L
s
P
p
.2 0 1 r
.016 w
.5 .41041 m
.60469 .55451 L
s
P
p
.2 0 1 r
.016 w
.5 .41041 m
.44496 .24103 L
s
P
p
.2 0 1 r
.016 w
.5 .41041 m
.5 .58852 L
s
P
p
.2 0 1 r
.016 w
.5 .41041 m
.55504 .24103 L
s
P
p
.2 0 1 r
.016 w
.5 .41041 m
.39531 .55451 L
s
P
p
.2 0 1 r
.002 w
.70865 .48022 m
.60058 .55873 L
s
P
p
.2 0 1 r
.002 w
.70865 .48022 m
.63013 .58828 L
s
P
p
.2 0 1 r
.002 w
.70865 .48022 m
.66737 .60726 L
s
P
p
.2 0 1 r
.002 w
.77717 .45795 m
.88523 .53647 L
s
P
p
.2 0 1 r
.002 w
.77717 .45795 m
.90421 .49923 L
s
P
p
.2 0 1 r
.002 w
.77717 .45795 m
.91075 .45795 L
s
P
p
.2 0 1 r
.002 w
.73482 .39967 m
.7761 .27262 L
s
P
p
.2 0 1 r
.002 w
.73482 .39967 m
.73482 .26609 L
s
P
p
.2 0 1 r
.002 w
.73482 .39967 m
.69354 .27262 L
s
P
p
0 .4 1 r
.018 w
.73482 .44419 m
.70865 .48022 L
s
P
p
0 .4 1 r
.018 w
.73482 .44419 m
.77717 .45795 L
s
P
p
0 .4 1 r
.018 w
.73482 .44419 m
.73482 .39967 L
s
P
p
.2 0 1 r
.002 w
.45736 .2583 m
.5844 .21702 L
s
P
p
.2 0 1 r
.002 w
.45736 .2583 m
.56543 .17978 L
s
P
p
.2 0 1 r
.002 w
.45736 .2583 m
.53588 .15023 L
s
P
p
.2 0 1 r
.002 w
.38532 .2583 m
.3068 .15023 L
s
P
p
.2 0 1 r
.002 w
.38532 .2583 m
.27725 .17978 L
s
P
p
.2 0 1 r
.002 w
.38532 .2583 m
.25827 .21702 L
s
P
p
.2 0 1 r
.002 w
.40758 .32681 m
.32906 .43488 L
s
P
p
.2 0 1 r
.002 w
.40758 .32681 m
.3663 .45386 L
s
P
p
.2 0 1 r
.002 w
.40758 .32681 m
.40758 .46039 L
s
P
p
0 .4 1 r
.018 w
.42134 .28447 m
.45736 .2583 L
s
P
p
0 .4 1 r
.018 w
.42134 .28447 m
.38532 .2583 L
s
P
p
0 .4 1 r
.018 w
.42134 .28447 m
.40758 .32681 L
s
P
p
.2 0 1 r
.002 w
.62777 .54701 m
.49419 .54701 L
s
P
p
.2 0 1 r
.002 w
.62777 .54701 m
.50073 .58828 L
s
P
p
.2 0 1 r
.002 w
.62777 .54701 m
.5197 .62552 L
s
P
p
.2 0 1 r
.002 w
.69629 .56927 m
.73757 .69631 L
s
P
p
.2 0 1 r
.002 w
.69629 .56927 m
.77481 .67734 L
s
P
p
.2 0 1 r
.002 w
.69629 .56927 m
.80436 .64778 L
s
P
p
.2 0 1 r
.002 w
.69629 .49722 m
.80436 .41871 L
s
P
p
.2 0 1 r
.002 w
.69629 .49722 m
.77481 .38916 L
s
P
p
.2 0 1 r
.002 w
.69629 .49722 m
.73757 .37018 L
s
P
p
0 .4 1 r
.018 w
.67012 .53325 m
.62777 .54701 L
s
P
p
0 .4 1 r
.018 w
.67012 .53325 m
.69629 .56927 L
s
P
p
0 .4 1 r
.018 w
.67012 .53325 m
.69629 .49722 L
s
P
p
.2 0 1 r
.002 w
.55492 .21977 m
.68196 .26104 L
s
P
p
.2 0 1 r
.002 w
.55492 .21977 m
.6885 .21977 L
s
P
p
.2 0 1 r
.002 w
.55492 .21977 m
.68196 .17849 L
s
P
p
.2 0 1 r
.002 w
.49663 .17742 m
.49663 .04384 L
s
P
p
.2 0 1 r
.002 w
.49663 .17742 m
.45535 .05038 L
s
P
p
.2 0 1 r
.002 w
.49663 .17742 m
.41812 .06935 L
s
P
p
.2 0 1 r
.002 w
.47437 .24594 m
.34733 .28722 L
s
P
p
.2 0 1 r
.002 w
.47437 .24594 m
.3663 .32445 L
s
P
p
.2 0 1 r
.002 w
.47437 .24594 m
.39585 .35401 L
s
P
p
0 .4 1 r
.018 w
.51039 .21977 m
.55492 .21977 L
s
P
p
0 .4 1 r
.018 w
.51039 .21977 m
.49663 .17742 L
s
P
p
0 .4 1 r
.018 w
.51039 .21977 m
.47437 .24594 L
s
P
p
.2 0 1 r
.002 w
.52308 .5535 m
.41501 .47499 L
s
P
p
.2 0 1 r
.002 w
.52308 .5535 m
.39604 .51222 L
s
P
p
.2 0 1 r
.002 w
.52308 .5535 m
.3895 .5535 L
s
P
p
.2 0 1 r
.002 w
.56543 .61179 m
.52415 .73883 L
s
P
p
.2 0 1 r
.002 w
.56543 .61179 m
.56543 .74537 L
s
P
p
.2 0 1 r
.002 w
.56543 .61179 m
.60671 .73883 L
s
P
p
.2 0 1 r
.002 w
.60778 .5535 m
.74136 .5535 L
s
P
p
.2 0 1 r
.002 w
.60778 .5535 m
.73482 .51222 L
s
P
p
.2 0 1 r
.002 w
.60778 .5535 m
.71585 .47499 L
s
P
p
0 .4 1 r
.018 w
.56543 .56726 m
.52308 .5535 L
s
P
p
0 .4 1 r
.018 w
.56543 .56726 m
.56543 .61179 L
s
P
p
0 .4 1 r
.018 w
.56543 .56726 m
.60778 .5535 L
s
P
p
.2 0 1 r
.016 w
.56543 .38916 m
.73482 .44419 L
s
P
p
.2 0 1 r
.016 w
.56543 .38916 m
.42134 .28447 L
s
P
p
.2 0 1 r
.016 w
.56543 .38916 m
.67012 .53325 L
s
P
p
.2 0 1 r
.016 w
.56543 .38916 m
.51039 .21977 L
s
P
p
.2 0 1 r
.016 w
.56543 .38916 m
.56543 .56726 L
s
P
p
.2 0 1 r
.002 w
.77526 .32299 m
.73398 .45003 L
s
P
p
.2 0 1 r
.002 w
.77526 .32299 m
.77526 .45657 L
s
P
p
.2 0 1 r
.002 w
.77526 .32299 m
.81654 .45003 L
s
P
p
.2 0 1 r
.002 w
.8176 .2647 m
.95118 .2647 L
s
P
p
.2 0 1 r
.002 w
.8176 .2647 m
.94465 .22342 L
s
P
p
.2 0 1 r
.002 w
.8176 .2647 m
.92567 .18618 L
s
P
p
.2 0 1 r
.002 w
.74908 .24244 m
.70781 .1154 L
s
P
p
.2 0 1 r
.002 w
.74908 .24244 m
.67057 .13437 L
s
P
p
.2 0 1 r
.002 w
.74908 .24244 m
.64102 .16392 L
s
P
p
0 .4 1 r
.018 w
.77526 .27846 m
.77526 .32299 L
s
P
p
0 .4 1 r
.018 w
.77526 .27846 m
.8176 .2647 L
s
P
p
0 .4 1 r
.018 w
.77526 .27846 m
.74908 .24244 L
s
P
p
.2 0 1 r
.002 w
.44152 .29115 m
.52004 .18308 L
s
P
p
.2 0 1 r
.002 w
.44152 .29115 m
.4828 .16411 L
s
P
p
.2 0 1 r
.002 w
.44152 .29115 m
.44152 .15757 L
s
P
p
.2 0 1 r
.002 w
.38324 .3335 m
.25619 .29222 L
s
P
p
.2 0 1 r
.002 w
.38324 .3335 m
.24966 .3335 L
s
P
p
.2 0 1 r
.002 w
.38324 .3335 m
.25619 .37478 L
s
P
p
.2 0 1 r
.002 w
.44152 .37584 m
.44152 .50942 L
s
P
p
.2 0 1 r
.002 w
.44152 .37584 m
.4828 .50289 L
s
P
p
.2 0 1 r
.002 w
.44152 .37584 m
.52004 .48391 L
s
P
p
0 .4 1 r
.018 w
.42776 .3335 m
.44152 .29115 L
s
P
p
0 .4 1 r
.018 w
.42776 .3335 m
.38324 .3335 L
s
P
p
0 .4 1 r
.018 w
.42776 .3335 m
.44152 .37584 L
s
P
p
.2 0 1 r
.002 w
.74908 .42456 m
.64102 .50307 L
s
P
p
.2 0 1 r
.002 w
.74908 .42456 m
.67057 .53263 L
s
P
p
.2 0 1 r
.002 w
.74908 .42456 m
.70781 .5516 L
s
P
p
.2 0 1 r
.002 w
.8176 .40229 m
.92567 .48081 L
s
P
p
.2 0 1 r
.002 w
.8176 .40229 m
.94465 .44357 L
s
P
p
.2 0 1 r
.002 w
.8176 .40229 m
.95118 .40229 L
s
P
p
.2 0 1 r
.002 w
.77526 .34401 m
.81654 .21697 L
s
P
p
.2 0 1 r
.002 w
.77526 .34401 m
.77526 .21043 L
s
P
p
.2 0 1 r
.002 w
.77526 .34401 m
.73398 .21697 L
s
P
p
0 .4 1 r
.018 w
.77526 .38853 m
.74908 .42456 L
s
P
p
0 .4 1 r
.018 w
.77526 .38853 m
.8176 .40229 L
s
P
p
0 .4 1 r
.018 w
.77526 .38853 m
.77526 .34401 L
s
P
p
.2 0 1 r
.002 w
.4978 .20264 m
.62484 .16136 L
s
P
p
.2 0 1 r
.002 w
.4978 .20264 m
.60587 .12412 L
s
P
p
.2 0 1 r
.002 w
.4978 .20264 m
.57632 .09457 L
s
P
p
.2 0 1 r
.002 w
.42575 .20264 m
.34724 .09457 L
s
P
p
.2 0 1 r
.002 w
.42575 .20264 m
.31769 .12412 L
s
P
p
.2 0 1 r
.002 w
.42575 .20264 m
.29871 .16136 L
s
P
p
.2 0 1 r
.002 w
.44802 .27116 m
.3695 .37922 L
s
P
p
.2 0 1 r
.002 w
.44802 .27116 m
.40674 .3982 L
s
P
p
.2 0 1 r
.002 w
.44802 .27116 m
.44802 .40474 L
s
P
p
0 .4 1 r
.018 w
.46178 .22881 m
.4978 .20264 L
s
P
p
0 .4 1 r
.018 w
.46178 .22881 m
.42575 .20264 L
s
P
p
0 .4 1 r
.018 w
.46178 .22881 m
.44802 .27116 L
s
P
p
.2 0 1 r
.002 w
.66821 .49135 m
.53463 .49135 L
s
P
p
.2 0 1 r
.002 w
.66821 .49135 m
.54117 .53263 L
s
P
p
.2 0 1 r
.002 w
.66821 .49135 m
.56014 .56986 L
s
P
p
.2 0 1 r
.002 w
.73673 .51361 m
.77801 .64065 L
s
P
p
.2 0 1 r
.002 w
.73673 .51361 m
.81524 .62168 L
s
P
p
.2 0 1 r
.002 w
.73673 .51361 m
.8448 .59213 L
s
P
p
.2 0 1 r
.002 w
.73673 .44157 m
.8448 .36305 L
s
P
p
.2 0 1 r
.002 w
.73673 .44157 m
.81524 .3335 L
s
P
p
.2 0 1 r
.002 w
.73673 .44157 m
.77801 .31452 L
s
P
p
0 .4 1 r
.018 w
.71056 .47759 m
.66821 .49135 L
s
P
p
0 .4 1 r
.018 w
.71056 .47759 m
.73673 .51361 L
s
P
p
0 .4 1 r
.018 w
.71056 .47759 m
.73673 .44157 L
s
P
p
.2 0 1 r
.016 w
.60587 .3335 m
.77526 .27846 L
s
P
p
.2 0 1 r
.016 w
.60587 .3335 m
.42776 .3335 L
s
P
p
.2 0 1 r
.016 w
.60587 .3335 m
.77526 .38853 L
s
P
p
.2 0 1 r
.016 w
.60587 .3335 m
.46178 .22881 L
s
P
p
.2 0 1 r
.016 w
.60587 .3335 m
.71056 .47759 L
s
P
p
1 .6 0 r
.016 w
.5 .2991 m
.39413 .3335 L
s
P
p
1 .6 0 r
.016 w
.5 .2991 m
.43457 .38916 L
s
P
p
1 .6 0 r
.016 w
.5 .2991 m
.5 .41041 L
s
P
p
1 .6 0 r
.016 w
.5 .2991 m
.56543 .38916 L
s
P
p
1 .6 0 r
.016 w
.5 .2991 m
.60587 .3335 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.299499 0.285714 0.424812 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0895692 0.952381 [
[ 0 0 0 0 ]
[ 1 .77324 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .77324 L
0 .77324 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.24974 .39102 m
.22932 .26209 L
s
P
p
.2 0 1 r
.002 w
.24974 .39102 m
.19048 .27471 L
s
P
p
.2 0 1 r
.002 w
.24974 .39102 m
.15744 .29872 L
s
P
p
.2 0 1 r
.002 w
.23873 .46055 m
.12242 .51981 L
s
P
p
.2 0 1 r
.002 w
.23873 .46055 m
.14643 .55285 L
s
P
p
.2 0 1 r
.002 w
.23873 .46055 m
.17947 .57686 L
s
P
p
.2 0 1 r
.002 w
.30826 .44954 m
.40056 .54184 L
s
P
p
.2 0 1 r
.002 w
.30826 .44954 m
.42457 .5088 L
s
P
p
.2 0 1 r
.002 w
.30826 .44954 m
.43719 .46996 L
s
P
p
0 .4 1 r
.018 w
.2695 .42978 m
.24974 .39102 L
s
P
p
0 .4 1 r
.018 w
.2695 .42978 m
.23873 .46055 L
s
P
p
0 .4 1 r
.018 w
.2695 .42978 m
.30826 .44954 L
s
P
p
.2 0 1 r
.002 w
.55444 .27068 m
.53402 .3996 L
s
P
p
.2 0 1 r
.002 w
.55444 .27068 m
.57486 .3996 L
s
P
p
.2 0 1 r
.002 w
.55444 .27068 m
.6137 .38698 L
s
P
p
.2 0 1 r
.002 w
.5864 .20795 m
.71533 .18753 L
s
P
p
.2 0 1 r
.002 w
.5864 .20795 m
.70271 .14869 L
s
P
p
.2 0 1 r
.002 w
.5864 .20795 m
.6787 .11565 L
s
P
p
.2 0 1 r
.002 w
.51687 .19694 m
.45761 .08063 L
s
P
p
.2 0 1 r
.002 w
.51687 .19694 m
.42457 .10464 L
s
P
p
.2 0 1 r
.002 w
.51687 .19694 m
.40056 .13768 L
s
P
p
0 .4 1 r
.018 w
.54764 .2277 m
.55444 .27068 L
s
P
p
0 .4 1 r
.018 w
.54764 .2277 m
.5864 .20795 L
s
P
p
0 .4 1 r
.018 w
.54764 .2277 m
.51687 .19694 L
s
P
p
.2 0 1 r
.002 w
.22747 .29097 m
.28673 .17466 L
s
P
p
.2 0 1 r
.002 w
.22747 .29097 m
.24789 .16204 L
s
P
p
.2 0 1 r
.002 w
.22747 .29097 m
.20705 .16204 L
s
P
p
.2 0 1 r
.002 w
.17769 .34075 m
.04876 .32033 L
s
P
p
.2 0 1 r
.002 w
.17769 .34075 m
.04876 .36117 L
s
P
p
.2 0 1 r
.002 w
.17769 .34075 m
.06138 .40001 L
s
P
p
.2 0 1 r
.002 w
.24042 .37271 m
.26084 .50164 L
s
P
p
.2 0 1 r
.002 w
.24042 .37271 m
.29968 .48902 L
s
P
p
.2 0 1 r
.002 w
.24042 .37271 m
.33272 .46501 L
s
P
p
0 .4 1 r
.018 w
.22066 .33394 m
.22747 .29097 L
s
P
p
0 .4 1 r
.018 w
.22066 .33394 m
.17769 .34075 L
s
P
p
0 .4 1 r
.018 w
.22066 .33394 m
.24042 .37271 L
s
P
p
.2 0 1 r
.002 w
.54471 .37271 m
.45241 .46501 L
s
P
p
.2 0 1 r
.002 w
.54471 .37271 m
.48545 .48902 L
s
P
p
.2 0 1 r
.002 w
.54471 .37271 m
.52429 .50164 L
s
P
p
.2 0 1 r
.002 w
.60744 .34075 m
.72374 .40001 L
s
P
p
.2 0 1 r
.002 w
.60744 .34075 m
.73636 .36117 L
s
P
p
.2 0 1 r
.002 w
.60744 .34075 m
.73636 .32033 L
s
P
p
.2 0 1 r
.002 w
.55766 .29097 m
.57808 .16204 L
s
P
p
.2 0 1 r
.002 w
.55766 .29097 m
.53724 .16204 L
s
P
p
.2 0 1 r
.002 w
.55766 .29097 m
.4984 .17466 L
s
P
p
0 .4 1 r
.018 w
.56446 .33394 m
.54471 .37271 L
s
P
p
0 .4 1 r
.018 w
.56446 .33394 m
.60744 .34075 L
s
P
p
0 .4 1 r
.018 w
.56446 .33394 m
.55766 .29097 L
s
P
p
.2 0 1 r
.002 w
.26826 .19694 m
.38456 .13768 L
s
P
p
.2 0 1 r
.002 w
.26826 .19694 m
.36056 .10464 L
s
P
p
.2 0 1 r
.002 w
.26826 .19694 m
.32752 .08063 L
s
P
p
.2 0 1 r
.002 w
.19872 .20795 m
.10642 .11565 L
s
P
p
.2 0 1 r
.002 w
.19872 .20795 m
.08242 .14869 L
s
P
p
.2 0 1 r
.002 w
.19872 .20795 m
.0698 .18753 L
s
P
p
.2 0 1 r
.002 w
.23068 .27068 m
.17142 .38698 L
s
P
p
.2 0 1 r
.002 w
.23068 .27068 m
.21026 .3996 L
s
P
p
.2 0 1 r
.002 w
.23068 .27068 m
.2511 .3996 L
s
P
p
0 .4 1 r
.018 w
.23749 .2277 m
.26826 .19694 L
s
P
p
0 .4 1 r
.018 w
.23749 .2277 m
.19872 .20795 L
s
P
p
0 .4 1 r
.018 w
.23749 .2277 m
.23068 .27068 L
s
P
p
.2 0 1 r
.016 w
.39256 .30672 m
.2695 .42978 L
s
P
p
.2 0 1 r
.016 w
.39256 .30672 m
.54764 .2277 L
s
P
p
.2 0 1 r
.016 w
.39256 .30672 m
.22066 .33394 L
s
P
p
.2 0 1 r
.016 w
.39256 .30672 m
.56446 .33394 L
s
P
p
.2 0 1 r
.016 w
.39256 .30672 m
.23749 .2277 L
s
P
p
.2 0 1 r
.002 w
.43487 .55171 m
.31856 .49245 L
s
P
p
.2 0 1 r
.002 w
.43487 .55171 m
.30594 .53129 L
s
P
p
.2 0 1 r
.002 w
.43487 .55171 m
.30594 .57213 L
s
P
p
.2 0 1 r
.002 w
.48465 .6015 m
.46423 .73042 L
s
P
p
.2 0 1 r
.002 w
.48465 .6015 m
.50507 .73042 L
s
P
p
.2 0 1 r
.002 w
.48465 .6015 m
.54391 .7178 L
s
P
p
.2 0 1 r
.002 w
.51661 .53877 m
.64554 .51835 L
s
P
p
.2 0 1 r
.002 w
.51661 .53877 m
.63292 .47951 L
s
P
p
.2 0 1 r
.002 w
.51661 .53877 m
.60891 .44647 L
s
P
p
0 .4 1 r
.018 w
.47784 .55852 m
.43487 .55171 L
s
P
p
0 .4 1 r
.018 w
.47784 .55852 m
.48465 .6015 L
s
P
p
0 .4 1 r
.018 w
.47784 .55852 m
.51661 .53877 L
s
P
p
.2 0 1 r
.002 w
.51661 .23447 m
.60891 .32677 L
s
P
p
.2 0 1 r
.002 w
.51661 .23447 m
.63292 .29374 L
s
P
p
.2 0 1 r
.002 w
.51661 .23447 m
.64554 .25489 L
s
P
p
.2 0 1 r
.002 w
.48465 .17175 m
.54391 .05544 L
s
P
p
.2 0 1 r
.002 w
.48465 .17175 m
.50507 .04282 L
s
P
p
.2 0 1 r
.002 w
.48465 .17175 m
.46423 .04282 L
s
P
p
.2 0 1 r
.002 w
.43487 .22153 m
.30594 .20111 L
s
P
p
.2 0 1 r
.002 w
.43487 .22153 m
.30594 .24195 L
s
P
p
.2 0 1 r
.002 w
.43487 .22153 m
.31856 .28079 L
s
P
p
0 .4 1 r
.018 w
.47784 .21472 m
.51661 .23447 L
s
P
p
0 .4 1 r
.018 w
.47784 .21472 m
.48465 .17175 L
s
P
p
0 .4 1 r
.018 w
.47784 .21472 m
.43487 .22153 L
s
P
p
.2 0 1 r
.002 w
.34084 .51093 m
.28158 .39462 L
s
P
p
.2 0 1 r
.002 w
.34084 .51093 m
.24854 .41863 L
s
P
p
.2 0 1 r
.002 w
.34084 .51093 m
.22453 .45167 L
s
P
p
.2 0 1 r
.002 w
.35185 .58046 m
.25955 .67276 L
s
P
p
.2 0 1 r
.002 w
.35185 .58046 m
.29259 .69677 L
s
P
p
.2 0 1 r
.002 w
.35185 .58046 m
.33143 .70939 L
s
P
p
.2 0 1 r
.002 w
.41458 .5485 m
.53088 .60776 L
s
P
p
.2 0 1 r
.002 w
.41458 .5485 m
.5435 .56892 L
s
P
p
.2 0 1 r
.002 w
.41458 .5485 m
.5435 .52808 L
s
P
p
0 .4 1 r
.018 w
.3716 .54169 m
.34084 .51093 L
s
P
p
0 .4 1 r
.018 w
.3716 .54169 m
.35185 .58046 L
s
P
p
0 .4 1 r
.018 w
.3716 .54169 m
.41458 .5485 L
s
P
p
.2 0 1 r
.002 w
.59344 .30232 m
.61386 .43125 L
s
P
p
.2 0 1 r
.002 w
.59344 .30232 m
.6527 .41863 L
s
P
p
.2 0 1 r
.002 w
.59344 .30232 m
.68574 .39462 L
s
P
p
.2 0 1 r
.002 w
.60445 .23279 m
.72075 .17353 L
s
P
p
.2 0 1 r
.002 w
.60445 .23279 m
.69675 .14049 L
s
P
p
.2 0 1 r
.002 w
.60445 .23279 m
.66371 .11648 L
s
P
p
.2 0 1 r
.002 w
.53491 .2438 m
.44261 .1515 L
s
P
p
.2 0 1 r
.002 w
.53491 .2438 m
.41861 .18454 L
s
P
p
.2 0 1 r
.002 w
.53491 .2438 m
.40599 .22338 L
s
P
p
0 .4 1 r
.018 w
.57368 .26355 m
.59344 .30232 L
s
P
p
0 .4 1 r
.018 w
.57368 .26355 m
.60445 .23279 L
s
P
p
0 .4 1 r
.018 w
.57368 .26355 m
.53491 .2438 L
s
P
p
.2 0 1 r
.002 w
.28874 .42266 m
.30916 .29374 L
s
P
p
.2 0 1 r
.002 w
.28874 .42266 m
.26832 .29374 L
s
P
p
.2 0 1 r
.002 w
.28874 .42266 m
.22948 .30636 L
s
P
p
.2 0 1 r
.002 w
.25678 .48539 m
.12785 .50581 L
s
P
p
.2 0 1 r
.002 w
.25678 .48539 m
.14047 .54465 L
s
P
p
.2 0 1 r
.002 w
.25678 .48539 m
.16448 .57769 L
s
P
p
.2 0 1 r
.002 w
.32631 .4964 m
.38557 .61271 L
s
P
p
.2 0 1 r
.002 w
.32631 .4964 m
.41861 .5887 L
s
P
p
.2 0 1 r
.002 w
.32631 .4964 m
.44261 .55566 L
s
P
p
0 .4 1 r
.018 w
.29554 .46564 m
.28874 .42266 L
s
P
p
0 .4 1 r
.018 w
.29554 .46564 m
.25678 .48539 L
s
P
p
0 .4 1 r
.018 w
.29554 .46564 m
.32631 .4964 L
s
P
p
.2 0 1 r
.016 w
.45062 .38662 m
.47784 .55852 L
s
P
p
.2 0 1 r
.016 w
.45062 .38662 m
.47784 .21472 L
s
P
p
.2 0 1 r
.016 w
.45062 .38662 m
.3716 .54169 L
s
P
p
.2 0 1 r
.016 w
.45062 .38662 m
.57368 .26355 L
s
P
p
.2 0 1 r
.016 w
.45062 .38662 m
.29554 .46564 L
s
P
p
.2 0 1 r
.002 w
.67369 .4964 m
.55739 .55566 L
s
P
p
.2 0 1 r
.002 w
.67369 .4964 m
.58139 .5887 L
s
P
p
.2 0 1 r
.002 w
.67369 .4964 m
.61443 .61271 L
s
P
p
.2 0 1 r
.002 w
.74322 .48539 m
.83552 .57769 L
s
P
p
.2 0 1 r
.002 w
.74322 .48539 m
.85953 .54465 L
s
P
p
.2 0 1 r
.002 w
.74322 .48539 m
.87215 .50581 L
s
P
p
.2 0 1 r
.002 w
.71126 .42266 m
.77052 .30636 L
s
P
p
.2 0 1 r
.002 w
.71126 .42266 m
.73168 .29374 L
s
P
p
.2 0 1 r
.002 w
.71126 .42266 m
.69084 .29374 L
s
P
p
0 .4 1 r
.018 w
.70446 .46564 m
.67369 .4964 L
s
P
p
0 .4 1 r
.018 w
.70446 .46564 m
.74322 .48539 L
s
P
p
0 .4 1 r
.018 w
.70446 .46564 m
.71126 .42266 L
s
P
p
.2 0 1 r
.002 w
.46509 .2438 m
.59401 .22338 L
s
P
p
.2 0 1 r
.002 w
.46509 .2438 m
.58139 .18454 L
s
P
p
.2 0 1 r
.002 w
.46509 .2438 m
.55739 .1515 L
s
P
p
.2 0 1 r
.002 w
.39555 .23279 m
.33629 .11648 L
s
P
p
.2 0 1 r
.002 w
.39555 .23279 m
.30325 .14049 L
s
P
p
.2 0 1 r
.002 w
.39555 .23279 m
.27925 .17353 L
s
P
p
.2 0 1 r
.002 w
.40656 .30232 m
.31426 .39462 L
s
P
p
.2 0 1 r
.002 w
.40656 .30232 m
.3473 .41863 L
s
P
p
.2 0 1 r
.002 w
.40656 .30232 m
.38614 .43125 L
s
P
p
0 .4 1 r
.018 w
.42632 .26355 m
.46509 .2438 L
s
P
p
0 .4 1 r
.018 w
.42632 .26355 m
.39555 .23279 L
s
P
p
0 .4 1 r
.018 w
.42632 .26355 m
.40656 .30232 L
s
P
p
.2 0 1 r
.002 w
.58542 .5485 m
.4565 .52808 L
s
P
p
.2 0 1 r
.002 w
.58542 .5485 m
.4565 .56892 L
s
P
p
.2 0 1 r
.002 w
.58542 .5485 m
.46912 .60776 L
s
P
p
.2 0 1 r
.002 w
.64815 .58046 m
.66857 .70939 L
s
P
p
.2 0 1 r
.002 w
.64815 .58046 m
.70741 .69677 L
s
P
p
.2 0 1 r
.002 w
.64815 .58046 m
.74045 .67276 L
s
P
p
.2 0 1 r
.002 w
.65916 .51093 m
.77547 .45167 L
s
P
p
.2 0 1 r
.002 w
.65916 .51093 m
.75146 .41863 L
s
P
p
.2 0 1 r
.002 w
.65916 .51093 m
.71842 .39462 L
s
P
p
0 .4 1 r
.018 w
.6284 .54169 m
.58542 .5485 L
s
P
p
0 .4 1 r
.018 w
.6284 .54169 m
.64815 .58046 L
s
P
p
0 .4 1 r
.018 w
.6284 .54169 m
.65916 .51093 L
s
P
p
.2 0 1 r
.002 w
.56513 .22153 m
.68144 .28079 L
s
P
p
.2 0 1 r
.002 w
.56513 .22153 m
.69406 .24195 L
s
P
p
.2 0 1 r
.002 w
.56513 .22153 m
.69406 .20111 L
s
P
p
.2 0 1 r
.002 w
.51535 .17175 m
.53577 .04282 L
s
P
p
.2 0 1 r
.002 w
.51535 .17175 m
.49493 .04282 L
s
P
p
.2 0 1 r
.002 w
.51535 .17175 m
.45609 .05544 L
s
P
p
.2 0 1 r
.002 w
.48339 .23447 m
.35446 .25489 L
s
P
p
.2 0 1 r
.002 w
.48339 .23447 m
.36708 .29374 L
s
P
p
.2 0 1 r
.002 w
.48339 .23447 m
.39109 .32677 L
s
P
p
0 .4 1 r
.018 w
.52216 .21472 m
.56513 .22153 L
s
P
p
0 .4 1 r
.018 w
.52216 .21472 m
.51535 .17175 L
s
P
p
0 .4 1 r
.018 w
.52216 .21472 m
.48339 .23447 L
s
P
p
.2 0 1 r
.002 w
.48339 .53877 m
.39109 .44647 L
s
P
p
.2 0 1 r
.002 w
.48339 .53877 m
.36708 .47951 L
s
P
p
.2 0 1 r
.002 w
.48339 .53877 m
.35446 .51835 L
s
P
p
.2 0 1 r
.002 w
.51535 .6015 m
.45609 .7178 L
s
P
p
.2 0 1 r
.002 w
.51535 .6015 m
.49493 .73042 L
s
P
p
.2 0 1 r
.002 w
.51535 .6015 m
.53577 .73042 L
s
P
p
.2 0 1 r
.002 w
.56513 .55171 m
.69406 .57213 L
s
P
p
.2 0 1 r
.002 w
.56513 .55171 m
.69406 .53129 L
s
P
p
.2 0 1 r
.002 w
.56513 .55171 m
.68144 .49245 L
s
P
p
0 .4 1 r
.018 w
.52216 .55852 m
.48339 .53877 L
s
P
p
0 .4 1 r
.018 w
.52216 .55852 m
.51535 .6015 L
s
P
p
0 .4 1 r
.018 w
.52216 .55852 m
.56513 .55171 L
s
P
p
.2 0 1 r
.016 w
.54938 .38662 m
.70446 .46564 L
s
P
p
.2 0 1 r
.016 w
.54938 .38662 m
.42632 .26355 L
s
P
p
.2 0 1 r
.016 w
.54938 .38662 m
.6284 .54169 L
s
P
p
.2 0 1 r
.016 w
.54938 .38662 m
.52216 .21472 L
s
P
p
.2 0 1 r
.016 w
.54938 .38662 m
.52216 .55852 L
s
P
p
.2 0 1 r
.002 w
.76932 .27068 m
.7489 .3996 L
s
P
p
.2 0 1 r
.002 w
.76932 .27068 m
.78974 .3996 L
s
P
p
.2 0 1 r
.002 w
.76932 .27068 m
.82858 .38698 L
s
P
p
.2 0 1 r
.002 w
.80128 .20795 m
.9302 .18753 L
s
P
p
.2 0 1 r
.002 w
.80128 .20795 m
.91758 .14869 L
s
P
p
.2 0 1 r
.002 w
.80128 .20795 m
.89358 .11565 L
s
P
p
.2 0 1 r
.002 w
.73174 .19694 m
.67248 .08063 L
s
P
p
.2 0 1 r
.002 w
.73174 .19694 m
.63944 .10464 L
s
P
p
.2 0 1 r
.002 w
.73174 .19694 m
.61544 .13768 L
s
P
p
0 .4 1 r
.018 w
.76251 .2277 m
.76932 .27068 L
s
P
p
0 .4 1 r
.018 w
.76251 .2277 m
.80128 .20795 L
s
P
p
0 .4 1 r
.018 w
.76251 .2277 m
.73174 .19694 L
s
P
p
.2 0 1 r
.002 w
.44234 .29097 m
.5016 .17466 L
s
P
p
.2 0 1 r
.002 w
.44234 .29097 m
.46276 .16204 L
s
P
p
.2 0 1 r
.002 w
.44234 .29097 m
.42192 .16204 L
s
P
p
.2 0 1 r
.002 w
.39256 .34075 m
.26364 .32033 L
s
P
p
.2 0 1 r
.002 w
.39256 .34075 m
.26364 .36117 L
s
P
p
.2 0 1 r
.002 w
.39256 .34075 m
.27626 .40001 L
s
P
p
.2 0 1 r
.002 w
.45529 .37271 m
.47571 .50164 L
s
P
p
.2 0 1 r
.002 w
.45529 .37271 m
.51455 .48902 L
s
P
p
.2 0 1 r
.002 w
.45529 .37271 m
.54759 .46501 L
s
P
p
0 .4 1 r
.018 w
.43554 .33394 m
.44234 .29097 L
s
P
p
0 .4 1 r
.018 w
.43554 .33394 m
.39256 .34075 L
s
P
p
0 .4 1 r
.018 w
.43554 .33394 m
.45529 .37271 L
s
P
p
.2 0 1 r
.002 w
.75958 .37271 m
.66728 .46501 L
s
P
p
.2 0 1 r
.002 w
.75958 .37271 m
.70032 .48902 L
s
P
p
.2 0 1 r
.002 w
.75958 .37271 m
.73916 .50164 L
s
P
p
.2 0 1 r
.002 w
.82231 .34075 m
.93862 .40001 L
s
P
p
.2 0 1 r
.002 w
.82231 .34075 m
.95124 .36117 L
s
P
p
.2 0 1 r
.002 w
.82231 .34075 m
.95124 .32033 L
s
P
p
.2 0 1 r
.002 w
.77253 .29097 m
.79295 .16204 L
s
P
p
.2 0 1 r
.002 w
.77253 .29097 m
.75211 .16204 L
s
P
p
.2 0 1 r
.002 w
.77253 .29097 m
.71327 .17466 L
s
P
p
0 .4 1 r
.018 w
.77934 .33394 m
.75958 .37271 L
s
P
p
0 .4 1 r
.018 w
.77934 .33394 m
.82231 .34075 L
s
P
p
0 .4 1 r
.018 w
.77934 .33394 m
.77253 .29097 L
s
P
p
.2 0 1 r
.002 w
.48313 .19694 m
.59944 .13768 L
s
P
p
.2 0 1 r
.002 w
.48313 .19694 m
.57543 .10464 L
s
P
p
.2 0 1 r
.002 w
.48313 .19694 m
.54239 .08063 L
s
P
p
.2 0 1 r
.002 w
.4136 .20795 m
.3213 .11565 L
s
P
p
.2 0 1 r
.002 w
.4136 .20795 m
.29729 .14869 L
s
P
p
.2 0 1 r
.002 w
.4136 .20795 m
.28467 .18753 L
s
P
p
.2 0 1 r
.002 w
.44556 .27068 m
.3863 .38698 L
s
P
p
.2 0 1 r
.002 w
.44556 .27068 m
.42514 .3996 L
s
P
p
.2 0 1 r
.002 w
.44556 .27068 m
.46598 .3996 L
s
P
p
0 .4 1 r
.018 w
.45236 .2277 m
.48313 .19694 L
s
P
p
0 .4 1 r
.018 w
.45236 .2277 m
.4136 .20795 L
s
P
p
0 .4 1 r
.018 w
.45236 .2277 m
.44556 .27068 L
s
P
p
.2 0 1 r
.002 w
.69174 .44954 m
.56281 .46996 L
s
P
p
.2 0 1 r
.002 w
.69174 .44954 m
.57543 .5088 L
s
P
p
.2 0 1 r
.002 w
.69174 .44954 m
.59944 .54184 L
s
P
p
.2 0 1 r
.002 w
.76127 .46055 m
.82053 .57686 L
s
P
p
.2 0 1 r
.002 w
.76127 .46055 m
.85357 .55285 L
s
P
p
.2 0 1 r
.002 w
.76127 .46055 m
.87758 .51981 L
s
P
p
.2 0 1 r
.002 w
.75026 .39102 m
.84256 .29872 L
s
P
p
.2 0 1 r
.002 w
.75026 .39102 m
.80952 .27471 L
s
P
p
.2 0 1 r
.002 w
.75026 .39102 m
.77068 .26209 L
s
P
p
0 .4 1 r
.018 w
.7305 .42978 m
.69174 .44954 L
s
P
p
0 .4 1 r
.018 w
.7305 .42978 m
.76127 .46055 L
s
P
p
0 .4 1 r
.018 w
.7305 .42978 m
.75026 .39102 L
s
P
p
.2 0 1 r
.016 w
.60744 .30672 m
.76251 .2277 L
s
P
p
.2 0 1 r
.016 w
.60744 .30672 m
.43554 .33394 L
s
P
p
.2 0 1 r
.016 w
.60744 .30672 m
.77934 .33394 L
s
P
p
.2 0 1 r
.016 w
.60744 .30672 m
.45236 .2277 L
s
P
p
.2 0 1 r
.016 w
.60744 .30672 m
.7305 .42978 L
s
P
p
1 .6 0 r
.016 w
.5 .2897 m
.39256 .30672 L
s
P
p
1 .6 0 r
.016 w
.5 .2897 m
.45062 .38662 L
s
P
p
1 .6 0 r
.016 w
.5 .2897 m
.54938 .38662 L
s
P
p
1 .6 0 r
.016 w
.5 .2897 m
.60744 .30672 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.437343 0.285714 0.562657 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0926189 0.952381 [
[ 0 0 0 0 ]
[ 1 .76714 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .76714 L
0 .76714 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.30646 .4809 m
.23015 .37587 L
s
P
p
.2 0 1 r
.002 w
.30646 .4809 m
.20143 .40459 L
s
P
p
.2 0 1 r
.002 w
.30646 .4809 m
.18298 .44078 L
s
P
p
.2 0 1 r
.002 w
.3281 .5475 m
.25179 .65253 L
s
P
p
.2 0 1 r
.002 w
.3281 .5475 m
.28798 .67097 L
s
P
p
.2 0 1 r
.002 w
.3281 .5475 m
.3281 .67733 L
s
P
p
.2 0 1 r
.002 w
.38475 .50634 m
.50822 .54646 L
s
P
p
.2 0 1 r
.002 w
.38475 .50634 m
.51458 .50634 L
s
P
p
.2 0 1 r
.002 w
.38475 .50634 m
.50822 .46622 L
s
P
p
0 .4 1 r
.018 w
.34147 .50634 m
.30646 .4809 L
s
P
p
0 .4 1 r
.018 w
.34147 .50634 m
.3281 .5475 L
s
P
p
0 .4 1 r
.018 w
.34147 .50634 m
.38475 .50634 L
s
P
p
.2 0 1 r
.002 w
.52215 .23667 m
.56227 .36014 L
s
P
p
.2 0 1 r
.002 w
.52215 .23667 m
.59846 .3417 L
s
P
p
.2 0 1 r
.002 w
.52215 .23667 m
.62719 .31298 L
s
P
p
.2 0 1 r
.002 w
.52215 .16664 m
.62719 .09033 L
s
P
p
.2 0 1 r
.002 w
.52215 .16664 m
.59846 .06161 L
s
P
p
.2 0 1 r
.002 w
.52215 .16664 m
.56227 .04317 L
s
P
p
.2 0 1 r
.002 w
.45556 .18828 m
.35052 .11197 L
s
P
p
.2 0 1 r
.002 w
.45556 .18828 m
.33208 .14816 L
s
P
p
.2 0 1 r
.002 w
.45556 .18828 m
.32573 .18828 L
s
P
p
0 .4 1 r
.018 w
.49671 .20166 m
.52215 .23667 L
s
P
p
0 .4 1 r
.018 w
.49671 .20166 m
.52215 .16664 L
s
P
p
0 .4 1 r
.018 w
.49671 .20166 m
.45556 .18828 L
s
P
p
.2 0 1 r
.002 w
.24155 .40229 m
.24155 .27246 L
s
P
p
.2 0 1 r
.002 w
.24155 .40229 m
.20143 .27882 L
s
P
p
.2 0 1 r
.002 w
.24155 .40229 m
.16523 .29726 L
s
P
p
.2 0 1 r
.002 w
.21991 .46889 m
.09643 .50901 L
s
P
p
.2 0 1 r
.002 w
.21991 .46889 m
.11487 .5452 L
s
P
p
.2 0 1 r
.002 w
.21991 .46889 m
.14359 .57393 L
s
P
p
.2 0 1 r
.002 w
.28993 .46889 m
.36624 .57393 L
s
P
p
.2 0 1 r
.002 w
.28993 .46889 m
.39496 .5452 L
s
P
p
.2 0 1 r
.002 w
.28993 .46889 m
.41341 .50901 L
s
P
p
0 .4 1 r
.018 w
.25492 .44345 m
.24155 .40229 L
s
P
p
0 .4 1 r
.018 w
.25492 .44345 m
.21991 .46889 L
s
P
p
0 .4 1 r
.018 w
.25492 .44345 m
.28993 .46889 L
s
P
p
.2 0 1 r
.002 w
.5596 .33149 m
.51948 .45496 L
s
P
p
.2 0 1 r
.002 w
.5596 .33149 m
.5596 .46132 L
s
P
p
.2 0 1 r
.002 w
.5596 .33149 m
.59972 .45496 L
s
P
p
.2 0 1 r
.002 w
.60076 .27484 m
.73059 .27484 L
s
P
p
.2 0 1 r
.002 w
.60076 .27484 m
.72423 .23472 L
s
P
p
.2 0 1 r
.002 w
.60076 .27484 m
.70579 .19852 L
s
P
p
.2 0 1 r
.002 w
.53416 .2532 m
.49404 .12972 L
s
P
p
.2 0 1 r
.002 w
.53416 .2532 m
.45785 .14816 L
s
P
p
.2 0 1 r
.002 w
.53416 .2532 m
.42913 .17689 L
s
P
p
0 .4 1 r
.018 w
.5596 .28821 m
.5596 .33149 L
s
P
p
0 .4 1 r
.018 w
.5596 .28821 m
.60076 .27484 L
s
P
p
0 .4 1 r
.018 w
.5596 .28821 m
.53416 .2532 L
s
P
p
.2 0 1 r
.002 w
.23523 .30054 m
.31154 .19551 L
s
P
p
.2 0 1 r
.002 w
.23523 .30054 m
.27535 .17707 L
s
P
p
.2 0 1 r
.002 w
.23523 .30054 m
.23523 .17071 L
s
P
p
.2 0 1 r
.002 w
.17858 .3417 m
.0551 .30158 L
s
P
p
.2 0 1 r
.002 w
.17858 .3417 m
.04875 .3417 L
s
P
p
.2 0 1 r
.002 w
.17858 .3417 m
.0551 .38182 L
s
P
p
.2 0 1 r
.002 w
.23523 .38286 m
.23523 .51269 L
s
P
p
.2 0 1 r
.002 w
.23523 .38286 m
.27535 .50634 L
s
P
p
.2 0 1 r
.002 w
.23523 .38286 m
.31154 .4879 L
s
P
p
0 .4 1 r
.018 w
.22186 .3417 m
.23523 .30054 L
s
P
p
0 .4 1 r
.018 w
.22186 .3417 m
.17858 .3417 L
s
P
p
0 .4 1 r
.018 w
.22186 .3417 m
.23523 .38286 L
s
P
p
.2 0 1 r
.016 w
.39496 .3417 m
.34147 .50634 L
s
P
p
.2 0 1 r
.016 w
.39496 .3417 m
.49671 .20166 L
s
P
p
.2 0 1 r
.016 w
.39496 .3417 m
.25492 .44345 L
s
P
p
.2 0 1 r
.016 w
.39496 .3417 m
.5596 .28821 L
s
P
p
.2 0 1 r
.016 w
.39496 .3417 m
.22186 .3417 L
s
P
p
.2 0 1 r
.002 w
.4701 .5535 m
.34662 .51338 L
s
P
p
.2 0 1 r
.002 w
.4701 .5535 m
.34027 .5535 L
s
P
p
.2 0 1 r
.002 w
.4701 .5535 m
.34662 .59362 L
s
P
p
.2 0 1 r
.002 w
.52675 .59466 m
.52675 .72449 L
s
P
p
.2 0 1 r
.002 w
.52675 .59466 m
.56687 .71814 L
s
P
p
.2 0 1 r
.002 w
.52675 .59466 m
.60306 .6997 L
s
P
p
.2 0 1 r
.002 w
.54838 .52806 m
.67186 .48794 L
s
P
p
.2 0 1 r
.002 w
.54838 .52806 m
.65342 .45175 L
s
P
p
.2 0 1 r
.002 w
.54838 .52806 m
.6247 .42303 L
s
P
p
0 .4 1 r
.018 w
.51337 .5535 m
.4701 .5535 L
s
P
p
0 .4 1 r
.018 w
.51337 .5535 m
.52675 .59466 L
s
P
p
0 .4 1 r
.018 w
.51337 .5535 m
.54838 .52806 L
s
P
p
.2 0 1 r
.002 w
.50104 .22913 m
.60607 .30545 L
s
P
p
.2 0 1 r
.002 w
.50104 .22913 m
.62451 .26925 L
s
P
p
.2 0 1 r
.002 w
.50104 .22913 m
.63087 .22913 L
s
P
p
.2 0 1 r
.002 w
.45988 .17248 m
.5 .04901 L
s
P
p
.2 0 1 r
.002 w
.45988 .17248 m
.45988 .04265 L
s
P
p
.2 0 1 r
.002 w
.45988 .17248 m
.41976 .04901 L
s
P
p
.2 0 1 r
.002 w
.41872 .22913 m
.28889 .22913 L
s
P
p
.2 0 1 r
.002 w
.41872 .22913 m
.29525 .26925 L
s
P
p
.2 0 1 r
.002 w
.41872 .22913 m
.31369 .30545 L
s
P
p
0 .4 1 r
.018 w
.45988 .21576 m
.50104 .22913 L
s
P
p
0 .4 1 r
.018 w
.45988 .21576 m
.45988 .17248 L
s
P
p
0 .4 1 r
.018 w
.45988 .21576 m
.41872 .22913 L
s
P
p
.2 0 1 r
.002 w
.37138 .52806 m
.29506 .42303 L
s
P
p
.2 0 1 r
.002 w
.37138 .52806 m
.26634 .45175 L
s
P
p
.2 0 1 r
.002 w
.37138 .52806 m
.2479 .48794 L
s
P
p
.2 0 1 r
.002 w
.39301 .59466 m
.3167 .6997 L
s
P
p
.2 0 1 r
.002 w
.39301 .59466 m
.35289 .71814 L
s
P
p
.2 0 1 r
.002 w
.39301 .59466 m
.39301 .72449 L
s
P
p
.2 0 1 r
.002 w
.44966 .5535 m
.57314 .59362 L
s
P
p
.2 0 1 r
.002 w
.44966 .5535 m
.57949 .5535 L
s
P
p
.2 0 1 r
.002 w
.44966 .5535 m
.57314 .51338 L
s
P
p
0 .4 1 r
.018 w
.40639 .5535 m
.37138 .52806 L
s
P
p
0 .4 1 r
.018 w
.40639 .5535 m
.39301 .59466 L
s
P
p
0 .4 1 r
.018 w
.40639 .5535 m
.44966 .5535 L
s
P
p
.2 0 1 r
.002 w
.58707 .28383 m
.62719 .40731 L
s
P
p
.2 0 1 r
.002 w
.58707 .28383 m
.66338 .38887 L
s
P
p
.2 0 1 r
.002 w
.58707 .28383 m
.6921 .36014 L
s
P
p
.2 0 1 r
.002 w
.58707 .21381 m
.6921 .1375 L
s
P
p
.2 0 1 r
.002 w
.58707 .21381 m
.66338 .10877 L
s
P
p
.2 0 1 r
.002 w
.58707 .21381 m
.62719 .09033 L
s
P
p
.2 0 1 r
.002 w
.52047 .23545 m
.41544 .15913 L
s
P
p
.2 0 1 r
.002 w
.52047 .23545 m
.397 .19533 L
s
P
p
.2 0 1 r
.002 w
.52047 .23545 m
.39064 .23545 L
s
P
p
0 .4 1 r
.018 w
.56163 .24882 m
.58707 .28383 L
s
P
p
0 .4 1 r
.018 w
.56163 .24882 m
.58707 .21381 L
s
P
p
0 .4 1 r
.018 w
.56163 .24882 m
.52047 .23545 L
s
P
p
.2 0 1 r
.002 w
.30646 .44946 m
.30646 .31963 L
s
P
p
.2 0 1 r
.002 w
.30646 .44946 m
.26634 .32598 L
s
P
p
.2 0 1 r
.002 w
.30646 .44946 m
.23015 .34442 L
s
P
p
.2 0 1 r
.002 w
.28482 .51605 m
.16135 .55617 L
s
P
p
.2 0 1 r
.002 w
.28482 .51605 m
.17979 .59237 L
s
P
p
.2 0 1 r
.002 w
.28482 .51605 m
.20851 .62109 L
s
P
p
.2 0 1 r
.002 w
.35485 .51605 m
.43116 .62109 L
s
P
p
.2 0 1 r
.002 w
.35485 .51605 m
.45988 .59237 L
s
P
p
.2 0 1 r
.002 w
.35485 .51605 m
.47832 .55617 L
s
P
p
0 .4 1 r
.018 w
.31983 .49062 m
.30646 .44946 L
s
P
p
0 .4 1 r
.018 w
.31983 .49062 m
.28482 .51605 L
s
P
p
0 .4 1 r
.018 w
.31983 .49062 m
.35485 .51605 L
s
P
p
.2 0 1 r
.016 w
.45988 .38887 m
.51337 .5535 L
s
P
p
.2 0 1 r
.016 w
.45988 .38887 m
.45988 .21576 L
s
P
p
.2 0 1 r
.016 w
.45988 .38887 m
.40639 .5535 L
s
P
p
.2 0 1 r
.016 w
.45988 .38887 m
.56163 .24882 L
s
P
p
.2 0 1 r
.016 w
.45988 .38887 m
.31983 .49062 L
s
P
p
.2 0 1 r
.002 w
.64515 .51605 m
.52168 .55617 L
s
P
p
.2 0 1 r
.002 w
.64515 .51605 m
.54012 .59237 L
s
P
p
.2 0 1 r
.002 w
.64515 .51605 m
.56884 .62109 L
s
P
p
.2 0 1 r
.002 w
.71518 .51605 m
.79149 .62109 L
s
P
p
.2 0 1 r
.002 w
.71518 .51605 m
.82021 .59237 L
s
P
p
.2 0 1 r
.002 w
.71518 .51605 m
.83865 .55617 L
s
P
p
.2 0 1 r
.002 w
.69354 .44946 m
.76985 .34442 L
s
P
p
.2 0 1 r
.002 w
.69354 .44946 m
.73366 .32598 L
s
P
p
.2 0 1 r
.002 w
.69354 .44946 m
.69354 .31963 L
s
P
p
0 .4 1 r
.018 w
.68017 .49062 m
.64515 .51605 L
s
P
p
0 .4 1 r
.018 w
.68017 .49062 m
.71518 .51605 L
s
P
p
0 .4 1 r
.018 w
.68017 .49062 m
.69354 .44946 L
s
P
p
.2 0 1 r
.002 w
.47953 .23545 m
.60936 .23545 L
s
P
p
.2 0 1 r
.002 w
.47953 .23545 m
.603 .19533 L
s
P
p
.2 0 1 r
.002 w
.47953 .23545 m
.58456 .15913 L
s
P
p
.2 0 1 r
.002 w
.41293 .21381 m
.37281 .09033 L
s
P
p
.2 0 1 r
.002 w
.41293 .21381 m
.33662 .10877 L
s
P
p
.2 0 1 r
.002 w
.41293 .21381 m
.3079 .1375 L
s
P
p
.2 0 1 r
.002 w
.41293 .28383 m
.3079 .36014 L
s
P
p
.2 0 1 r
.002 w
.41293 .28383 m
.33662 .38887 L
s
P
p
.2 0 1 r
.002 w
.41293 .28383 m
.37281 .40731 L
s
P
p
0 .4 1 r
.018 w
.43837 .24882 m
.47953 .23545 L
s
P
p
0 .4 1 r
.018 w
.43837 .24882 m
.41293 .21381 L
s
P
p
0 .4 1 r
.018 w
.43837 .24882 m
.41293 .28383 L
s
P
p
.2 0 1 r
.002 w
.55034 .5535 m
.42686 .51338 L
s
P
p
.2 0 1 r
.002 w
.55034 .5535 m
.42051 .5535 L
s
P
p
.2 0 1 r
.002 w
.55034 .5535 m
.42686 .59362 L
s
P
p
.2 0 1 r
.002 w
.60699 .59466 m
.60699 .72449 L
s
P
p
.2 0 1 r
.002 w
.60699 .59466 m
.64711 .71814 L
s
P
p
.2 0 1 r
.002 w
.60699 .59466 m
.6833 .6997 L
s
P
p
.2 0 1 r
.002 w
.62862 .52806 m
.7521 .48794 L
s
P
p
.2 0 1 r
.002 w
.62862 .52806 m
.73366 .45175 L
s
P
p
.2 0 1 r
.002 w
.62862 .52806 m
.70494 .42303 L
s
P
p
0 .4 1 r
.018 w
.59361 .5535 m
.55034 .5535 L
s
P
p
0 .4 1 r
.018 w
.59361 .5535 m
.60699 .59466 L
s
P
p
0 .4 1 r
.018 w
.59361 .5535 m
.62862 .52806 L
s
P
p
.2 0 1 r
.002 w
.58128 .22913 m
.68631 .30545 L
s
P
p
.2 0 1 r
.002 w
.58128 .22913 m
.70475 .26925 L
s
P
p
.2 0 1 r
.002 w
.58128 .22913 m
.71111 .22913 L
s
P
p
.2 0 1 r
.002 w
.54012 .17248 m
.58024 .04901 L
s
P
p
.2 0 1 r
.002 w
.54012 .17248 m
.54012 .04265 L
s
P
p
.2 0 1 r
.002 w
.54012 .17248 m
.5 .04901 L
s
P
p
.2 0 1 r
.002 w
.49896 .22913 m
.36913 .22913 L
s
P
p
.2 0 1 r
.002 w
.49896 .22913 m
.37549 .26925 L
s
P
p
.2 0 1 r
.002 w
.49896 .22913 m
.39393 .30545 L
s
P
p
0 .4 1 r
.018 w
.54012 .21576 m
.58128 .22913 L
s
P
p
0 .4 1 r
.018 w
.54012 .21576 m
.54012 .17248 L
s
P
p
0 .4 1 r
.018 w
.54012 .21576 m
.49896 .22913 L
s
P
p
.2 0 1 r
.002 w
.45162 .52806 m
.3753 .42303 L
s
P
p
.2 0 1 r
.002 w
.45162 .52806 m
.34658 .45175 L
s
P
p
.2 0 1 r
.002 w
.45162 .52806 m
.32814 .48794 L
s
P
p
.2 0 1 r
.002 w
.47325 .59466 m
.39694 .6997 L
s
P
p
.2 0 1 r
.002 w
.47325 .59466 m
.43313 .71814 L
s
P
p
.2 0 1 r
.002 w
.47325 .59466 m
.47325 .72449 L
s
P
p
.2 0 1 r
.002 w
.5299 .5535 m
.65338 .59362 L
s
P
p
.2 0 1 r
.002 w
.5299 .5535 m
.65973 .5535 L
s
P
p
.2 0 1 r
.002 w
.5299 .5535 m
.65338 .51338 L
s
P
p
0 .4 1 r
.018 w
.48663 .5535 m
.45162 .52806 L
s
P
p
0 .4 1 r
.018 w
.48663 .5535 m
.47325 .59466 L
s
P
p
0 .4 1 r
.018 w
.48663 .5535 m
.5299 .5535 L
s
P
p
.2 0 1 r
.016 w
.54012 .38887 m
.68017 .49062 L
s
P
p
.2 0 1 r
.016 w
.54012 .38887 m
.43837 .24882 L
s
P
p
.2 0 1 r
.016 w
.54012 .38887 m
.59361 .5535 L
s
P
p
.2 0 1 r
.016 w
.54012 .38887 m
.54012 .21576 L
s
P
p
.2 0 1 r
.016 w
.54012 .38887 m
.48663 .5535 L
s
P
p
.2 0 1 r
.002 w
.76477 .38286 m
.68846 .4879 L
s
P
p
.2 0 1 r
.002 w
.76477 .38286 m
.72465 .50634 L
s
P
p
.2 0 1 r
.002 w
.76477 .38286 m
.76477 .51269 L
s
P
p
.2 0 1 r
.002 w
.82142 .3417 m
.9449 .38182 L
s
P
p
.2 0 1 r
.002 w
.82142 .3417 m
.95125 .3417 L
s
P
p
.2 0 1 r
.002 w
.82142 .3417 m
.9449 .30158 L
s
P
p
.2 0 1 r
.002 w
.76477 .30054 m
.76477 .17071 L
s
P
p
.2 0 1 r
.002 w
.76477 .30054 m
.72465 .17707 L
s
P
p
.2 0 1 r
.002 w
.76477 .30054 m
.68846 .19551 L
s
P
p
0 .4 1 r
.018 w
.77814 .3417 m
.76477 .38286 L
s
P
p
0 .4 1 r
.018 w
.77814 .3417 m
.82142 .3417 L
s
P
p
0 .4 1 r
.018 w
.77814 .3417 m
.76477 .30054 L
s
P
p
.2 0 1 r
.002 w
.46584 .2532 m
.57087 .17689 L
s
P
p
.2 0 1 r
.002 w
.46584 .2532 m
.54215 .14816 L
s
P
p
.2 0 1 r
.002 w
.46584 .2532 m
.50596 .12972 L
s
P
p
.2 0 1 r
.002 w
.39924 .27484 m
.29421 .19852 L
s
P
p
.2 0 1 r
.002 w
.39924 .27484 m
.27577 .23472 L
s
P
p
.2 0 1 r
.002 w
.39924 .27484 m
.26941 .27484 L
s
P
p
.2 0 1 r
.002 w
.4404 .33149 m
.40028 .45496 L
s
P
p
.2 0 1 r
.002 w
.4404 .33149 m
.4404 .46132 L
s
P
p
.2 0 1 r
.002 w
.4404 .33149 m
.48052 .45496 L
s
P
p
0 .4 1 r
.018 w
.4404 .28821 m
.46584 .2532 L
s
P
p
0 .4 1 r
.018 w
.4404 .28821 m
.39924 .27484 L
s
P
p
0 .4 1 r
.018 w
.4404 .28821 m
.4404 .33149 L
s
P
p
.2 0 1 r
.002 w
.71007 .46889 m
.58659 .50901 L
s
P
p
.2 0 1 r
.002 w
.71007 .46889 m
.60504 .5452 L
s
P
p
.2 0 1 r
.002 w
.71007 .46889 m
.63376 .57393 L
s
P
p
.2 0 1 r
.002 w
.78009 .46889 m
.85641 .57393 L
s
P
p
.2 0 1 r
.002 w
.78009 .46889 m
.88513 .5452 L
s
P
p
.2 0 1 r
.002 w
.78009 .46889 m
.90357 .50901 L
s
P
p
.2 0 1 r
.002 w
.75845 .40229 m
.83477 .29726 L
s
P
p
.2 0 1 r
.002 w
.75845 .40229 m
.79857 .27882 L
s
P
p
.2 0 1 r
.002 w
.75845 .40229 m
.75845 .27246 L
s
P
p
0 .4 1 r
.018 w
.74508 .44345 m
.71007 .46889 L
s
P
p
0 .4 1 r
.018 w
.74508 .44345 m
.78009 .46889 L
s
P
p
0 .4 1 r
.018 w
.74508 .44345 m
.75845 .40229 L
s
P
p
.2 0 1 r
.002 w
.54444 .18828 m
.67427 .18828 L
s
P
p
.2 0 1 r
.002 w
.54444 .18828 m
.66792 .14816 L
s
P
p
.2 0 1 r
.002 w
.54444 .18828 m
.64948 .11197 L
s
P
p
.2 0 1 r
.002 w
.47785 .16664 m
.43773 .04317 L
s
P
p
.2 0 1 r
.002 w
.47785 .16664 m
.40154 .06161 L
s
P
p
.2 0 1 r
.002 w
.47785 .16664 m
.37281 .09033 L
s
P
p
.2 0 1 r
.002 w
.47785 .23667 m
.37281 .31298 L
s
P
p
.2 0 1 r
.002 w
.47785 .23667 m
.40154 .3417 L
s
P
p
.2 0 1 r
.002 w
.47785 .23667 m
.43773 .36014 L
s
P
p
0 .4 1 r
.018 w
.50329 .20166 m
.54444 .18828 L
s
P
p
0 .4 1 r
.018 w
.50329 .20166 m
.47785 .16664 L
s
P
p
0 .4 1 r
.018 w
.50329 .20166 m
.47785 .23667 L
s
P
p
.2 0 1 r
.002 w
.61525 .50634 m
.49178 .46622 L
s
P
p
.2 0 1 r
.002 w
.61525 .50634 m
.48542 .50634 L
s
P
p
.2 0 1 r
.002 w
.61525 .50634 m
.49178 .54646 L
s
P
p
.2 0 1 r
.002 w
.6719 .5475 m
.6719 .67733 L
s
P
p
.2 0 1 r
.002 w
.6719 .5475 m
.71202 .67097 L
s
P
p
.2 0 1 r
.002 w
.6719 .5475 m
.74821 .65253 L
s
P
p
.2 0 1 r
.002 w
.69354 .4809 m
.81702 .44078 L
s
P
p
.2 0 1 r
.002 w
.69354 .4809 m
.79857 .40459 L
s
P
p
.2 0 1 r
.002 w
.69354 .4809 m
.76985 .37587 L
s
P
p
0 .4 1 r
.018 w
.65853 .50634 m
.61525 .50634 L
s
P
p
0 .4 1 r
.018 w
.65853 .50634 m
.6719 .5475 L
s
P
p
0 .4 1 r
.018 w
.65853 .50634 m
.69354 .4809 L
s
P
p
.2 0 1 r
.016 w
.60504 .3417 m
.77814 .3417 L
s
P
p
.2 0 1 r
.016 w
.60504 .3417 m
.4404 .28821 L
s
P
p
.2 0 1 r
.016 w
.60504 .3417 m
.74508 .44345 L
s
P
p
.2 0 1 r
.016 w
.60504 .3417 m
.50329 .20166 L
s
P
p
.2 0 1 r
.016 w
.60504 .3417 m
.65853 .50634 L
s
P
p
1 .6 0 r
.016 w
.5 .26539 m
.39496 .3417 L
s
P
p
1 .6 0 r
.016 w
.5 .26539 m
.45988 .38887 L
s
P
p
1 .6 0 r
.016 w
.5 .26539 m
.54012 .38887 L
s
P
p
1 .6 0 r
.016 w
.5 .26539 m
.60504 .3417 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.575188 0.285714 0.700501 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0780989 0.952381 [
[ 0 0 0 0 ]
[ 1 .79618 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79618 L
0 .79618 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.23752 .39825 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.20765 .42813 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.18846 .46577 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.26003 .68603 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.29768 .70521 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.33941 .71182 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .57569 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.53337 .53396 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .49223 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.3169 .5075 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.33941 .57677 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.39833 .53396 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.58298 .3819 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.62063 .36272 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.6505 .33284 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.6505 .10126 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.62063 .07138 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.58298 .0522 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.36273 .12376 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.34355 .16141 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.33694 .20314 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .25347 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .18063 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.47198 .20314 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.24938 .2907 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.20765 .29731 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.17 .31649 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.09844 .53674 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.11762 .57439 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.14749 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.37908 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.40896 .57439 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.42814 .53674 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.24938 .42574 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.22687 .49501 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.2997 .49501 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.53847 .48053 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.5802 .48713 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.62193 .48053 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75806 .29317 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75145 .25144 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.73226 .21379 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.51201 .14223 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.47437 .16141 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.44449 .19128 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.5802 .35209 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.62301 .29317 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.55374 .27066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.32219 .21066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.28454 .19147 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.24281 .18486 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .32099 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.04884 .36272 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .40445 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.24281 .54057 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.28454 .53396 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.32219 .51478 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .31991 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.18388 .36272 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .40553 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.35332 .53396 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.51479 .21705 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.26329 .46855 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.5802 .30708 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.2289 .36272 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .53311 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34081 .57484 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .61657 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.53478 .7527 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.57651 .74609 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.61415 .72691 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.68572 .50665 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.66653 .46901 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.63666 .43913 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.47585 .57484 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.53478 .61766 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.55728 .54839 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.61729 .31683 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.63647 .27918 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.64308 .23745 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.50696 .05009 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.46522 .04348 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.42349 .05009 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.28737 .23745 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.29398 .27918 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.31316 .31683 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.50804 .23745 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.46522 .17853 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.42241 .23745 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.29379 .43913 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.26391 .46901 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.24473 .50665 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.3163 .72691 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.35394 .74609 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.39567 .7527 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .61657 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58964 .57484 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .53311 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.37317 .54839 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.39567 .61766 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.4546 .57484 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.63925 .42278 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.67689 .4036 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.70677 .37372 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.70677 .14214 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.67689 .11226 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.63925 .09308 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.419 .16464 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39981 .20229 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39321 .24402 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .29435 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .22151 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.52825 .24402 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.30564 .33158 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.26391 .33819 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.22627 .35737 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.1547 .57762 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.17389 .61527 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.20376 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.43535 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.46522 .61527 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.48441 .57762 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.30564 .46662 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.28314 .53589 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.35597 .53589 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.52087 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.46522 .22354 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.40958 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.57106 .25793 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.31956 .50943 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.51559 .57762 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.53478 .61527 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.56465 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.79624 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.82611 .61527 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.8453 .57762 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.77373 .35737 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.73609 .33819 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.69436 .33158 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.64403 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.71686 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.69436 .46662 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60679 .24402 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60019 .20229 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.581 .16464 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.36075 .09308 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.32311 .11226 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.29323 .14214 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.29323 .37372 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.32311 .4036 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.36075 .42278 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.47175 .24402 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .22151 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .29435 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .53311 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41036 .57484 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .61657 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.60433 .7527 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.64606 .74609 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.6837 .72691 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.75527 .50665 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.73609 .46901 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.70621 .43913 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.5454 .57484 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.60433 .61766 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.62683 .54839 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.68684 .31683 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.70602 .27918 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.71263 .23745 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.57651 .05009 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.53478 .04348 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.49304 .05009 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.35692 .23745 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.36353 .27918 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.38271 .31683 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.57759 .23745 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.53478 .17853 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.49196 .23745 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.36334 .43913 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.33347 .46901 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.31428 .50665 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.38585 .72691 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.42349 .74609 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.46522 .7527 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .61657 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65919 .57484 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .53311 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.44272 .54839 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.46522 .61766 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.52415 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.68044 .50943 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.42894 .25793 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.59042 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.53478 .22354 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.47913 .57484 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.67781 .51478 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.71546 .53396 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.75719 .54057 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .40445 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.95116 .36272 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .32099 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.75719 .18486 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.71546 .19147 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.67781 .21066 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .40553 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.81612 .36272 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .31991 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.55551 .19128 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.52563 .16141 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.48799 .14223 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.26774 .21379 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24855 .25144 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24194 .29317 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.37807 .48053 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.4198 .48713 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.46153 .48053 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.44626 .27066 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.37699 .29317 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.4198 .35209 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.57186 .53674 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.59104 .57439 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.62092 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.85251 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.88238 .57439 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.90156 .53674 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.83 .31649 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.79235 .29731 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.75062 .2907 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.7003 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.77313 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.75062 .42574 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.66306 .20314 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.65645 .16141 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.63727 .12376 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.41702 .0522 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.37937 .07138 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.3495 .10126 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.3495 .33284 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.37937 .36272 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.41702 .3819 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.52802 .20314 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .18063 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .25347 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .49223 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.46663 .53396 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .57569 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.66059 .71182 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.70232 .70521 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.73997 .68603 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.81154 .46577 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.79235 .42813 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.76248 .39825 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.60167 .53396 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.66059 .57677 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.6831 .5075 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.7711 .36272 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.4198 .30708 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.73671 .46855 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.48521 .21705 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.64668 .53396 L
s
P
p
1 .6 0 r
.014 w
.5 .29657 m
.40896 .36272 L
s
P
p
1 .6 0 r
.014 w
.5 .29657 m
.46522 .4036 L
s
P
p
1 .6 0 r
.014 w
.5 .29657 m
.53478 .4036 L
s
P
p
1 .6 0 r
.014 w
.5 .29657 m
.59104 .36272 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.713033 0.285714 0.838346 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0780989 0.952381 [
[ 0 0 0 0 ]
[ 1 .79618 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .79618 L
0 .79618 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.23752 .39825 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.20765 .42813 L
s
P
p
.2 0 1 r
.002 w
.3169 .5075 m
.18846 .46577 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.26003 .68603 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.29768 .70521 L
s
P
p
.2 0 1 r
.002 w
.33941 .57677 m
.33941 .71182 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .57569 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.53337 .53396 L
s
P
p
.2 0 1 r
.002 w
.39833 .53396 m
.52676 .49223 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.3169 .5075 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.33941 .57677 L
s
P
p
0 .4 1 r
.018 w
.35332 .53396 m
.39833 .53396 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.58298 .3819 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.62063 .36272 L
s
P
p
.2 0 1 r
.002 w
.54125 .25347 m
.6505 .33284 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.6505 .10126 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.62063 .07138 L
s
P
p
.2 0 1 r
.002 w
.54125 .18063 m
.58298 .0522 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.36273 .12376 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.34355 .16141 L
s
P
p
.2 0 1 r
.002 w
.47198 .20314 m
.33694 .20314 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .25347 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.54125 .18063 L
s
P
p
0 .4 1 r
.018 w
.51479 .21705 m
.47198 .20314 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.24938 .2907 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.20765 .29731 L
s
P
p
.2 0 1 r
.002 w
.24938 .42574 m
.17 .31649 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.09844 .53674 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.11762 .57439 L
s
P
p
.2 0 1 r
.002 w
.22687 .49501 m
.14749 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.37908 .60426 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.40896 .57439 L
s
P
p
.2 0 1 r
.002 w
.2997 .49501 m
.42814 .53674 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.24938 .42574 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.22687 .49501 L
s
P
p
0 .4 1 r
.018 w
.26329 .46855 m
.2997 .49501 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.53847 .48053 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.5802 .48713 L
s
P
p
.2 0 1 r
.002 w
.5802 .35209 m
.62193 .48053 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75806 .29317 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.75145 .25144 L
s
P
p
.2 0 1 r
.002 w
.62301 .29317 m
.73226 .21379 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.51201 .14223 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.47437 .16141 L
s
P
p
.2 0 1 r
.002 w
.55374 .27066 m
.44449 .19128 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.5802 .35209 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.62301 .29317 L
s
P
p
0 .4 1 r
.018 w
.5802 .30708 m
.55374 .27066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.32219 .21066 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.28454 .19147 L
s
P
p
.2 0 1 r
.002 w
.24281 .31991 m
.24281 .18486 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .32099 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.04884 .36272 L
s
P
p
.2 0 1 r
.002 w
.18388 .36272 m
.05545 .40445 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.24281 .54057 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.28454 .53396 L
s
P
p
.2 0 1 r
.002 w
.24281 .40553 m
.32219 .51478 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .31991 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.18388 .36272 L
s
P
p
0 .4 1 r
.018 w
.2289 .36272 m
.24281 .40553 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.35332 .53396 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.51479 .21705 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.26329 .46855 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.5802 .30708 L
s
P
p
.2 0 1 r
.016 w
.40896 .36272 m
.2289 .36272 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .53311 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34081 .57484 L
s
P
p
.2 0 1 r
.002 w
.47585 .57484 m
.34742 .61657 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.53478 .7527 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.57651 .74609 L
s
P
p
.2 0 1 r
.002 w
.53478 .61766 m
.61415 .72691 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.68572 .50665 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.66653 .46901 L
s
P
p
.2 0 1 r
.002 w
.55728 .54839 m
.63666 .43913 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.47585 .57484 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.53478 .61766 L
s
P
p
0 .4 1 r
.018 w
.52087 .57484 m
.55728 .54839 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.61729 .31683 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.63647 .27918 L
s
P
p
.2 0 1 r
.002 w
.50804 .23745 m
.64308 .23745 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.50696 .05009 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.46522 .04348 L
s
P
p
.2 0 1 r
.002 w
.46522 .17853 m
.42349 .05009 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.28737 .23745 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.29398 .27918 L
s
P
p
.2 0 1 r
.002 w
.42241 .23745 m
.31316 .31683 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.50804 .23745 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.46522 .17853 L
s
P
p
0 .4 1 r
.018 w
.46522 .22354 m
.42241 .23745 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.29379 .43913 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.26391 .46901 L
s
P
p
.2 0 1 r
.002 w
.37317 .54839 m
.24473 .50665 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.3163 .72691 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.35394 .74609 L
s
P
p
.2 0 1 r
.002 w
.39567 .61766 m
.39567 .7527 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .61657 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58964 .57484 L
s
P
p
.2 0 1 r
.002 w
.4546 .57484 m
.58303 .53311 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.37317 .54839 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.39567 .61766 L
s
P
p
0 .4 1 r
.018 w
.40958 .57484 m
.4546 .57484 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.63925 .42278 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.67689 .4036 L
s
P
p
.2 0 1 r
.002 w
.59752 .29435 m
.70677 .37372 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.70677 .14214 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.67689 .11226 L
s
P
p
.2 0 1 r
.002 w
.59752 .22151 m
.63925 .09308 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.419 .16464 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39981 .20229 L
s
P
p
.2 0 1 r
.002 w
.52825 .24402 m
.39321 .24402 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .29435 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.59752 .22151 L
s
P
p
0 .4 1 r
.018 w
.57106 .25793 m
.52825 .24402 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.30564 .33158 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.26391 .33819 L
s
P
p
.2 0 1 r
.002 w
.30564 .46662 m
.22627 .35737 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.1547 .57762 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.17389 .61527 L
s
P
p
.2 0 1 r
.002 w
.28314 .53589 m
.20376 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.43535 .64515 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.46522 .61527 L
s
P
p
.2 0 1 r
.002 w
.35597 .53589 m
.48441 .57762 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.30564 .46662 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.28314 .53589 L
s
P
p
0 .4 1 r
.018 w
.31956 .50943 m
.35597 .53589 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.52087 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.46522 .22354 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.40958 .57484 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.57106 .25793 L
s
P
p
.2 0 1 r
.016 w
.46522 .4036 m
.31956 .50943 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.51559 .57762 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.53478 .61527 L
s
P
p
.2 0 1 r
.002 w
.64403 .53589 m
.56465 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.79624 .64515 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.82611 .61527 L
s
P
p
.2 0 1 r
.002 w
.71686 .53589 m
.8453 .57762 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.77373 .35737 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.73609 .33819 L
s
P
p
.2 0 1 r
.002 w
.69436 .46662 m
.69436 .33158 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.64403 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.71686 .53589 L
s
P
p
0 .4 1 r
.018 w
.68044 .50943 m
.69436 .46662 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60679 .24402 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.60019 .20229 L
s
P
p
.2 0 1 r
.002 w
.47175 .24402 m
.581 .16464 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.36075 .09308 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.32311 .11226 L
s
P
p
.2 0 1 r
.002 w
.40248 .22151 m
.29323 .14214 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.29323 .37372 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.32311 .4036 L
s
P
p
.2 0 1 r
.002 w
.40248 .29435 m
.36075 .42278 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.47175 .24402 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .22151 L
s
P
p
0 .4 1 r
.018 w
.42894 .25793 m
.40248 .29435 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .53311 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41036 .57484 L
s
P
p
.2 0 1 r
.002 w
.5454 .57484 m
.41697 .61657 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.60433 .7527 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.64606 .74609 L
s
P
p
.2 0 1 r
.002 w
.60433 .61766 m
.6837 .72691 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.75527 .50665 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.73609 .46901 L
s
P
p
.2 0 1 r
.002 w
.62683 .54839 m
.70621 .43913 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.5454 .57484 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.60433 .61766 L
s
P
p
0 .4 1 r
.018 w
.59042 .57484 m
.62683 .54839 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.68684 .31683 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.70602 .27918 L
s
P
p
.2 0 1 r
.002 w
.57759 .23745 m
.71263 .23745 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.57651 .05009 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.53478 .04348 L
s
P
p
.2 0 1 r
.002 w
.53478 .17853 m
.49304 .05009 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.35692 .23745 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.36353 .27918 L
s
P
p
.2 0 1 r
.002 w
.49196 .23745 m
.38271 .31683 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.57759 .23745 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.53478 .17853 L
s
P
p
0 .4 1 r
.018 w
.53478 .22354 m
.49196 .23745 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.36334 .43913 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.33347 .46901 L
s
P
p
.2 0 1 r
.002 w
.44272 .54839 m
.31428 .50665 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.38585 .72691 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.42349 .74609 L
s
P
p
.2 0 1 r
.002 w
.46522 .61766 m
.46522 .7527 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .61657 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65919 .57484 L
s
P
p
.2 0 1 r
.002 w
.52415 .57484 m
.65258 .53311 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.44272 .54839 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.46522 .61766 L
s
P
p
0 .4 1 r
.018 w
.47913 .57484 m
.52415 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.68044 .50943 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.42894 .25793 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.59042 .57484 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.53478 .22354 L
s
P
p
.2 0 1 r
.016 w
.53478 .4036 m
.47913 .57484 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.67781 .51478 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.71546 .53396 L
s
P
p
.2 0 1 r
.002 w
.75719 .40553 m
.75719 .54057 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .40445 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.95116 .36272 L
s
P
p
.2 0 1 r
.002 w
.81612 .36272 m
.94455 .32099 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.75719 .18486 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.71546 .19147 L
s
P
p
.2 0 1 r
.002 w
.75719 .31991 m
.67781 .21066 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .40553 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.81612 .36272 L
s
P
p
0 .4 1 r
.018 w
.7711 .36272 m
.75719 .31991 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.55551 .19128 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.52563 .16141 L
s
P
p
.2 0 1 r
.002 w
.44626 .27066 m
.48799 .14223 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.26774 .21379 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24855 .25144 L
s
P
p
.2 0 1 r
.002 w
.37699 .29317 m
.24194 .29317 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.37807 .48053 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.4198 .48713 L
s
P
p
.2 0 1 r
.002 w
.4198 .35209 m
.46153 .48053 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.44626 .27066 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.37699 .29317 L
s
P
p
0 .4 1 r
.018 w
.4198 .30708 m
.4198 .35209 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.57186 .53674 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.59104 .57439 L
s
P
p
.2 0 1 r
.002 w
.7003 .49501 m
.62092 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.85251 .60426 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.88238 .57439 L
s
P
p
.2 0 1 r
.002 w
.77313 .49501 m
.90156 .53674 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.83 .31649 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.79235 .29731 L
s
P
p
.2 0 1 r
.002 w
.75062 .42574 m
.75062 .2907 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.7003 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.77313 .49501 L
s
P
p
0 .4 1 r
.018 w
.73671 .46855 m
.75062 .42574 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.66306 .20314 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.65645 .16141 L
s
P
p
.2 0 1 r
.002 w
.52802 .20314 m
.63727 .12376 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.41702 .0522 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.37937 .07138 L
s
P
p
.2 0 1 r
.002 w
.45875 .18063 m
.3495 .10126 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.3495 .33284 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.37937 .36272 L
s
P
p
.2 0 1 r
.002 w
.45875 .25347 m
.41702 .3819 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.52802 .20314 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .18063 L
s
P
p
0 .4 1 r
.018 w
.48521 .21705 m
.45875 .25347 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .49223 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.46663 .53396 L
s
P
p
.2 0 1 r
.002 w
.60167 .53396 m
.47324 .57569 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.66059 .71182 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.70232 .70521 L
s
P
p
.2 0 1 r
.002 w
.66059 .57677 m
.73997 .68603 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.81154 .46577 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.79235 .42813 L
s
P
p
.2 0 1 r
.002 w
.6831 .5075 m
.76248 .39825 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.60167 .53396 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.66059 .57677 L
s
P
p
0 .4 1 r
.018 w
.64668 .53396 m
.6831 .5075 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.7711 .36272 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.4198 .30708 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.73671 .46855 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.48521 .21705 L
s
P
p
.2 0 1 r
.016 w
.59104 .36272 m
.64668 .53396 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.40896 .36272 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.46522 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.53478 .4036 L
s
P
p
1 .6 0 r
.016 w
.5 .29657 m
.59104 .36272 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.850877 0.285714 0.97619 0.411028 MathSubStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0318709 0.952381 [
[ 0 0 0 0 ]
[ 1 .88864 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 0 m
1 0 L
1 .88864 L
0 .88864 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.54336 .58801 m
.40445 .65879 L
s
P
p
.2 0 1 r
.002 w
.54336 .58801 m
.43312 .69825 L
s
P
p
.2 0 1 r
.002 w
.54336 .58801 m
.47258 .72692 L
s
P
p
.2 0 1 r
.002 w
.62642 .57485 m
.73666 .6851 L
s
P
p
.2 0 1 r
.002 w
.62642 .57485 m
.76533 .64563 L
s
P
p
.2 0 1 r
.002 w
.62642 .57485 m
.78041 .59924 L
s
P
p
.2 0 1 r
.002 w
.58824 .49993 m
.65902 .36101 L
s
P
p
.2 0 1 r
.002 w
.58824 .49993 m
.61263 .34594 L
s
P
p
.2 0 1 r
.002 w
.58824 .49993 m
.56385 .34594 L
s
P
p
0 .4 1 r
.018 w
.58011 .55126 m
.54336 .58801 L
s
P
p
0 .4 1 r
.018 w
.58011 .55126 m
.62642 .57485 L
s
P
p
0 .4 1 r
.018 w
.58011 .55126 m
.58824 .49993 L
s
P
p
.2 0 1 r
.002 w
.2942 .28629 m
.44819 .2619 L
s
P
p
.2 0 1 r
.002 w
.2942 .28629 m
.43312 .21551 L
s
P
p
.2 0 1 r
.002 w
.2942 .28629 m
.40445 .17605 L
s
P
p
.2 0 1 r
.002 w
.21115 .27314 m
.14036 .13422 L
s
P
p
.2 0 1 r
.002 w
.21115 .27314 m
.1009 .16289 L
s
P
p
.2 0 1 r
.002 w
.21115 .27314 m
.07223 .20236 L
s
P
p
.2 0 1 r
.002 w
.2243 .35619 m
.11406 .46644 L
s
P
p
.2 0 1 r
.002 w
.2243 .35619 m
.15352 .49511 L
s
P
p
.2 0 1 r
.002 w
.2243 .35619 m
.19991 .51018 L
s
P
p
0 .4 1 r
.018 w
.24789 .30989 m
.2942 .28629 L
s
P
p
0 .4 1 r
.018 w
.24789 .30989 m
.21115 .27314 L
s
P
p
0 .4 1 r
.018 w
.24789 .30989 m
.2243 .35619 L
s
P
p
.2 0 1 r
.002 w
.43793 .65023 m
.28394 .62584 L
s
P
p
.2 0 1 r
.002 w
.43793 .65023 m
.28394 .67462 L
s
P
p
.2 0 1 r
.002 w
.43793 .65023 m
.29902 .72102 L
s
P
p
.2 0 1 r
.002 w
.51286 .68841 m
.53725 .8424 L
s
P
p
.2 0 1 r
.002 w
.51286 .68841 m
.58364 .82733 L
s
P
p
.2 0 1 r
.002 w
.51286 .68841 m
.6231 .79866 L
s
P
p
.2 0 1 r
.002 w
.52601 .60536 m
.66493 .53457 L
s
P
p
.2 0 1 r
.002 w
.52601 .60536 m
.63626 .49511 L
s
P
p
.2 0 1 r
.002 w
.52601 .60536 m
.59679 .46644 L
s
P
p
0 .4 1 r
.018 w
.48926 .6421 m
.43793 .65023 L
s
P
p
0 .4 1 r
.018 w
.48926 .6421 m
.51286 .68841 L
s
P
p
0 .4 1 r
.018 w
.48926 .6421 m
.52601 .60536 L
s
P
p
.2 0 1 r
.002 w
.4137 .25969 m
.55262 .33047 L
s
P
p
.2 0 1 r
.002 w
.4137 .25969 m
.56769 .28408 L
s
P
p
.2 0 1 r
.002 w
.4137 .25969 m
.56769 .2353 L
s
P
p
.2 0 1 r
.002 w
.35424 .20023 m
.37863 .04624 L
s
P
p
.2 0 1 r
.002 w
.35424 .20023 m
.32985 .04624 L
s
P
p
.2 0 1 r
.002 w
.35424 .20023 m
.28346 .06131 L
s
P
p
.2 0 1 r
.002 w
.31606 .27515 m
.16207 .29954 L
s
P
p
.2 0 1 r
.002 w
.31606 .27515 m
.17715 .34594 L
s
P
p
.2 0 1 r
.002 w
.31606 .27515 m
.20582 .3854 L
s
P
p
0 .4 1 r
.018 w
.36237 .25156 m
.4137 .25969 L
s
P
p
0 .4 1 r
.018 w
.36237 .25156 m
.35424 .20023 L
s
P
p
0 .4 1 r
.018 w
.36237 .25156 m
.31606 .27515 L
s
P
p
.2 0 1 r
.016 w
.39489 .45688 m
.58011 .55126 L
s
P
p
.2 0 1 r
.016 w
.39489 .45688 m
.24789 .30989 L
s
P
p
.2 0 1 r
.016 w
.39489 .45688 m
.48926 .6421 L
s
P
p
.2 0 1 r
.016 w
.39489 .45688 m
.36237 .25156 L
s
P
p
.2 0 1 r
.002 w
.65704 .52289 m
.58626 .66181 L
s
P
p
.2 0 1 r
.002 w
.65704 .52289 m
.63265 .67688 L
s
P
p
.2 0 1 r
.002 w
.65704 .52289 m
.68143 .67688 L
s
P
p
.2 0 1 r
.002 w
.7165 .46343 m
.87049 .48782 L
s
P
p
.2 0 1 r
.002 w
.7165 .46343 m
.87049 .43904 L
s
P
p
.2 0 1 r
.002 w
.7165 .46343 m
.85542 .39265 L
s
P
p
.2 0 1 r
.002 w
.64158 .42525 m
.61719 .27126 L
s
P
p
.2 0 1 r
.002 w
.64158 .42525 m
.5708 .28634 L
s
P
p
.2 0 1 r
.002 w
.64158 .42525 m
.53133 .31501 L
s
P
p
0 .4 1 r
.018 w
.66517 .47156 m
.65704 .52289 L
s
P
p
0 .4 1 r
.018 w
.66517 .47156 m
.7165 .46343 L
s
P
p
0 .4 1 r
.018 w
.66517 .47156 m
.64158 .42525 L
s
P
p
.2 0 1 r
.002 w
.27812 .42525 m
.38837 .31501 L
s
P
p
.2 0 1 r
.002 w
.27812 .42525 m
.34891 .28634 L
s
P
p
.2 0 1 r
.002 w
.27812 .42525 m
.30251 .27126 L
s
P
p
.2 0 1 r
.002 w
.2032 .46343 m
.06428 .39265 L
s
P
p
.2 0 1 r
.002 w
.2032 .46343 m
.04921 .43904 L
s
P
p
.2 0 1 r
.002 w
.2032 .46343 m
.04921 .48782 L
s
P
p
.2 0 1 r
.002 w
.26266 .52289 m
.23827 .67688 L
s
P
p
.2 0 1 r
.002 w
.26266 .52289 m
.28705 .67688 L
s
P
p
.2 0 1 r
.002 w
.26266 .52289 m
.33344 .66181 L
s
P
p
0 .4 1 r
.018 w
.25453 .47156 m
.27812 .42525 L
s
P
p
0 .4 1 r
.018 w
.25453 .47156 m
.2032 .46343 L
s
P
p
0 .4 1 r
.018 w
.25453 .47156 m
.26266 .52289 L
s
P
p
.2 0 1 r
.002 w
.60833 .6352 m
.46941 .70599 L
s
P
p
.2 0 1 r
.002 w
.60833 .6352 m
.49808 .74545 L
s
P
p
.2 0 1 r
.002 w
.60833 .6352 m
.53754 .77412 L
s
P
p
.2 0 1 r
.002 w
.69138 .62205 m
.80162 .73229 L
s
P
p
.2 0 1 r
.002 w
.69138 .62205 m
.8303 .69283 L
s
P
p
.2 0 1 r
.002 w
.69138 .62205 m
.84537 .64644 L
s
P
p
.2 0 1 r
.002 w
.6532 .54712 m
.72399 .40821 L
s
P
p
.2 0 1 r
.002 w
.6532 .54712 m
.67759 .39313 L
s
P
p
.2 0 1 r
.002 w
.6532 .54712 m
.62881 .39313 L
s
P
p
0 .4 1 r
.018 w
.64507 .59845 m
.60833 .6352 L
s
P
p
0 .4 1 r
.018 w
.64507 .59845 m
.69138 .62205 L
s
P
p
0 .4 1 r
.018 w
.64507 .59845 m
.6532 .54712 L
s
P
p
.2 0 1 r
.002 w
.35916 .33349 m
.51315 .3091 L
s
P
p
.2 0 1 r
.002 w
.35916 .33349 m
.49808 .26271 L
s
P
p
.2 0 1 r
.002 w
.35916 .33349 m
.46941 .22325 L
s
P
p
.2 0 1 r
.002 w
.27611 .32034 m
.20533 .18142 L
s
P
p
.2 0 1 r
.002 w
.27611 .32034 m
.16586 .21009 L
s
P
p
.2 0 1 r
.002 w
.27611 .32034 m
.13719 .24956 L
s
P
p
.2 0 1 r
.002 w
.28926 .40339 m
.17902 .51364 L
s
P
p
.2 0 1 r
.002 w
.28926 .40339 m
.21848 .54231 L
s
P
p
.2 0 1 r
.002 w
.28926 .40339 m
.26487 .55738 L
s
P
p
0 .4 1 r
.018 w
.31286 .35709 m
.35916 .33349 L
s
P
p
0 .4 1 r
.018 w
.31286 .35709 m
.27611 .32034 L
s
P
p
0 .4 1 r
.018 w
.31286 .35709 m
.28926 .40339 L
s
P
p
.2 0 1 r
.016 w
.45985 .50408 m
.66517 .47156 L
s
P
p
.2 0 1 r
.016 w
.45985 .50408 m
.25453 .47156 L
s
P
p
.2 0 1 r
.016 w
.45985 .50408 m
.64507 .59845 L
s
P
p
.2 0 1 r
.016 w
.45985 .50408 m
.31286 .35709 L
s
P
p
.2 0 1 r
.002 w
.71074 .40339 m
.73513 .55738 L
s
P
p
.2 0 1 r
.002 w
.71074 .40339 m
.78152 .54231 L
s
P
p
.2 0 1 r
.002 w
.71074 .40339 m
.82098 .51364 L
s
P
p
.2 0 1 r
.002 w
.72389 .32034 m
.86281 .24956 L
s
P
p
.2 0 1 r
.002 w
.72389 .32034 m
.83414 .21009 L
s
P
p
.2 0 1 r
.002 w
.72389 .32034 m
.79467 .18142 L
s
P
p
.2 0 1 r
.002 w
.64084 .33349 m
.53059 .22325 L
s
P
p
.2 0 1 r
.002 w
.64084 .33349 m
.50192 .26271 L
s
P
p
.2 0 1 r
.002 w
.64084 .33349 m
.48685 .3091 L
s
P
p
0 .4 1 r
.018 w
.68714 .35709 m
.71074 .40339 L
s
P
p
0 .4 1 r
.018 w
.68714 .35709 m
.72389 .32034 L
s
P
p
0 .4 1 r
.018 w
.68714 .35709 m
.64084 .33349 L
s
P
p
.2 0 1 r
.002 w
.3468 .54712 m
.37119 .39313 L
s
P
p
.2 0 1 r
.002 w
.3468 .54712 m
.32241 .39313 L
s
P
p
.2 0 1 r
.002 w
.3468 .54712 m
.27601 .40821 L
s
P
p
.2 0 1 r
.002 w
.30862 .62205 m
.15463 .64644 L
s
P
p
.2 0 1 r
.002 w
.30862 .62205 m
.1697 .69283 L
s
P
p
.2 0 1 r
.002 w
.30862 .62205 m
.19838 .73229 L
s
P
p
.2 0 1 r
.002 w
.39167 .6352 m
.46246 .77412 L
s
P
p
.2 0 1 r
.002 w
.39167 .6352 m
.50192 .74545 L
s
P
p
.2 0 1 r
.002 w
.39167 .6352 m
.53059 .70599 L
s
P
p
0 .4 1 r
.018 w
.35493 .59845 m
.3468 .54712 L
s
P
p
0 .4 1 r
.018 w
.35493 .59845 m
.30862 .62205 L
s
P
p
0 .4 1 r
.018 w
.35493 .59845 m
.39167 .6352 L
s
P
p
.2 0 1 r
.002 w
.73734 .52289 m
.66656 .66181 L
s
P
p
.2 0 1 r
.002 w
.73734 .52289 m
.71295 .67688 L
s
P
p
.2 0 1 r
.002 w
.73734 .52289 m
.76173 .67688 L
s
P
p
.2 0 1 r
.002 w
.7968 .46343 m
.95079 .48782 L
s
P
p
.2 0 1 r
.002 w
.7968 .46343 m
.95079 .43904 L
s
P
p
.2 0 1 r
.002 w
.7968 .46343 m
.93572 .39265 L
s
P
p
.2 0 1 r
.002 w
.72188 .42525 m
.69749 .27126 L
s
P
p
.2 0 1 r
.002 w
.72188 .42525 m
.65109 .28634 L
s
P
p
.2 0 1 r
.002 w
.72188 .42525 m
.61163 .31501 L
s
P
p
0 .4 1 r
.018 w
.74547 .47156 m
.73734 .52289 L
s
P
p
0 .4 1 r
.018 w
.74547 .47156 m
.7968 .46343 L
s
P
p
0 .4 1 r
.018 w
.74547 .47156 m
.72188 .42525 L
s
P
p
.2 0 1 r
.002 w
.35842 .42525 m
.46867 .31501 L
s
P
p
.2 0 1 r
.002 w
.35842 .42525 m
.4292 .28634 L
s
P
p
.2 0 1 r
.002 w
.35842 .42525 m
.38281 .27126 L
s
P
p
.2 0 1 r
.002 w
.2835 .46343 m
.14458 .39265 L
s
P
p
.2 0 1 r
.002 w
.2835 .46343 m
.12951 .43904 L
s
P
p
.2 0 1 r
.002 w
.2835 .46343 m
.12951 .48782 L
s
P
p
.2 0 1 r
.002 w
.34296 .52289 m
.31857 .67688 L
s
P
p
.2 0 1 r
.002 w
.34296 .52289 m
.36735 .67688 L
s
P
p
.2 0 1 r
.002 w
.34296 .52289 m
.41374 .66181 L
s
P
p
0 .4 1 r
.018 w
.33483 .47156 m
.35842 .42525 L
s
P
p
0 .4 1 r
.018 w
.33483 .47156 m
.2835 .46343 L
s
P
p
0 .4 1 r
.018 w
.33483 .47156 m
.34296 .52289 L
s
P
p
.2 0 1 r
.016 w
.54015 .50408 m
.68714 .35709 L
s
P
p
.2 0 1 r
.016 w
.54015 .50408 m
.35493 .59845 L
s
P
p
.2 0 1 r
.016 w
.54015 .50408 m
.74547 .47156 L
s
P
p
.2 0 1 r
.016 w
.54015 .50408 m
.33483 .47156 L
s
P
p
.2 0 1 r
.002 w
.68394 .27515 m
.79418 .3854 L
s
P
p
.2 0 1 r
.002 w
.68394 .27515 m
.82285 .34594 L
s
P
p
.2 0 1 r
.002 w
.68394 .27515 m
.83793 .29954 L
s
P
p
.2 0 1 r
.002 w
.64576 .20023 m
.71654 .06131 L
s
P
p
.2 0 1 r
.002 w
.64576 .20023 m
.67015 .04624 L
s
P
p
.2 0 1 r
.002 w
.64576 .20023 m
.62137 .04624 L
s
P
p
.2 0 1 r
.002 w
.5863 .25969 m
.43231 .2353 L
s
P
p
.2 0 1 r
.002 w
.5863 .25969 m
.43231 .28408 L
s
P
p
.2 0 1 r
.002 w
.5863 .25969 m
.44738 .33047 L
s
P
p
0 .4 1 r
.018 w
.63763 .25156 m
.68394 .27515 L
s
P
p
0 .4 1 r
.018 w
.63763 .25156 m
.64576 .20023 L
s
P
p
0 .4 1 r
.018 w
.63763 .25156 m
.5863 .25969 L
s
P
p
.2 0 1 r
.002 w
.47399 .60536 m
.40321 .46644 L
s
P
p
.2 0 1 r
.002 w
.47399 .60536 m
.36374 .49511 L
s
P
p
.2 0 1 r
.002 w
.47399 .60536 m
.33507 .53457 L
s
P
p
.2 0 1 r
.002 w
.48714 .68841 m
.3769 .79866 L
s
P
p
.2 0 1 r
.002 w
.48714 .68841 m
.41636 .82733 L
s
P
p
.2 0 1 r
.002 w
.48714 .68841 m
.46275 .8424 L
s
P
p
.2 0 1 r
.002 w
.56207 .65023 m
.70098 .72102 L
s
P
p
.2 0 1 r
.002 w
.56207 .65023 m
.71606 .67462 L
s
P
p
.2 0 1 r
.002 w
.56207 .65023 m
.71606 .62584 L
s
P
p
0 .4 1 r
.018 w
.51074 .6421 m
.47399 .60536 L
s
P
p
0 .4 1 r
.018 w
.51074 .6421 m
.48714 .68841 L
s
P
p
0 .4 1 r
.018 w
.51074 .6421 m
.56207 .65023 L
s
P
p
.2 0 1 r
.002 w
.7757 .35619 m
.80009 .51018 L
s
P
p
.2 0 1 r
.002 w
.7757 .35619 m
.84648 .49511 L
s
P
p
.2 0 1 r
.002 w
.7757 .35619 m
.88594 .46644 L
s
P
p
.2 0 1 r
.002 w
.78885 .27314 m
.92777 .20236 L
s
P
p
.2 0 1 r
.002 w
.78885 .27314 m
.8991 .16289 L
s
P
p
.2 0 1 r
.002 w
.78885 .27314 m
.85964 .13422 L
s
P
p
.2 0 1 r
.002 w
.7058 .28629 m
.59555 .17605 L
s
P
p
.2 0 1 r
.002 w
.7058 .28629 m
.56688 .21551 L
s
P
p
.2 0 1 r
.002 w
.7058 .28629 m
.55181 .2619 L
s
P
p
0 .4 1 r
.018 w
.75211 .30989 m
.7757 .35619 L
s
P
p
0 .4 1 r
.018 w
.75211 .30989 m
.78885 .27314 L
s
P
p
0 .4 1 r
.018 w
.75211 .30989 m
.7058 .28629 L
s
P
p
.2 0 1 r
.002 w
.41176 .49993 m
.43615 .34594 L
s
P
p
.2 0 1 r
.002 w
.41176 .49993 m
.38737 .34594 L
s
P
p
.2 0 1 r
.002 w
.41176 .49993 m
.34098 .36101 L
s
P
p
.2 0 1 r
.002 w
.37358 .57485 m
.21959 .59924 L
s
P
p
.2 0 1 r
.002 w
.37358 .57485 m
.23467 .64563 L
s
P
p
.2 0 1 r
.002 w
.37358 .57485 m
.26334 .6851 L
s
P
p
.2 0 1 r
.002 w
.45664 .58801 m
.52742 .72692 L
s
P
p
.2 0 1 r
.002 w
.45664 .58801 m
.56688 .69825 L
s
P
p
.2 0 1 r
.002 w
.45664 .58801 m
.59555 .65879 L
s
P
p
0 .4 1 r
.018 w
.41989 .55126 m
.41176 .49993 L
s
P
p
0 .4 1 r
.018 w
.41989 .55126 m
.37358 .57485 L
s
P
p
0 .4 1 r
.018 w
.41989 .55126 m
.45664 .58801 L
s
P
p
.2 0 1 r
.016 w
.60511 .45688 m
.63763 .25156 L
s
P
p
.2 0 1 r
.016 w
.60511 .45688 m
.51074 .6421 L
s
P
p
.2 0 1 r
.016 w
.60511 .45688 m
.75211 .30989 L
s
P
p
.2 0 1 r
.016 w
.60511 .45688 m
.41989 .55126 L
s
P
p
1 .6 0 r
.016 w
.5 .38051 m
.39489 .45688 L
s
P
p
1 .6 0 r
.016 w
.5 .38051 m
.45985 .50408 L
s
P
p
1 .6 0 r
.016 w
.5 .38051 m
.54015 .50408 L
s
P
p
1 .6 0 r
.016 w
.5 .38051 m
.60511 .45688 L
s
P
p
P
p
P
MathSubEnd
P
% End of sub-graphic
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{258, 108},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000420000K0P10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`000?l00`0001@000=<04`014`L0003C01<00A<7002C00304`0009<7P000d`0
C00N00M<7007C1`01D800`12000D00004P03C@0304e=00A=6@03C@0304e=00A=6@04C@0304d000A=
6@001Td004d0C@8000==00006009CAX02DdJ00I200@0@T924`0001403D`F00e<5P02C00604a<04`0
0T`00`1<C00F0005C000C0000d`01@1<001<01L02d`G00e<5P0=@Q80000@00i=5@0>CAL00Td00`1=
C@03C@0304e=01P000==04d01Td00`1=000F00I=00<0CDd014dE00m=500?@Q40000?009<00<0C4`0
0T`00lI<C003C0800T`B009<00<0C4`00T`00kA<C003C0800T`B0003C00000A<00?6C4`014`00`1<
000E00A<00?6C4`014`H00A<00?6C<H014`E009<00<0C4`00T`00lI<C004C00304a<01800T800`12
@P02@P03aT9200A200<0@T80400000l01Dd00lI=C@02aPM=4P05C@03]4e=00:d1ddB0003C@1=0080
00?6CDd00/H2C@800TdD0004C@0000A=00?6CDd00`000dd0000@0004C@1=C@8000?6CDd00Td01<I=
0002C@0304d001001Dd01LI=CDg600M=4P05@P05aT92CLH01d8@00003`08C003aTc600I<4P08C003
]4bd00I<4P05C006aTa<aTc61T`B009<00@0C4c614`01LI<C4`0009<4@08C005aTa<C<H01T`A00M<
00G6C4a<aP05C1801d801LI<C4;600E2400000l01Td00lI=C@08CA801Td00kA=C@08CA804DdB00I=
0/H9CA401Dd01LI=CDd000U=4@06C@03aTe=00Q=4P06@P03aT9=009=1T8@000030000d`0C007C0<A
00=<aT`01T`=0003C01<00M<0a400dbdC006C0h00T`01LH0C4c6009<0a400dc6C002C0040<I<C0d0
00A<04a<0`000lI<C0034@03C<K600<00T`00`1<000<0006C<I<04`00d`34@09C<I<04`0C<I<00h0
2D`34@03C<I<00E<00<0C0003007@P03aT`A008A00=<aT801D800`12000<00002@04C@0404e=00A=
00DACA5=4@08C@0404e=C@H014d0101=C@04C@054DdACA4024d0101=CDd600==00<0CDd00Td20007
CLHACA5=4@02C@8000E=aTe=0003C@X01Dd02`1=CA5=4DdAaTd0009=00?6CDd02P05C@04aTd0009=
00K64DdACA43C@8000E=aTe=0002C@H00dd0101=CLH5C@054DdACA4014d0101=C@04C@H00d801012
@/H5@P054DdACA4014801012@P04@PX0000800E<00?6C4`014`01a404D`AaQ401T`00lI<C002C0H0
14`00kA<C004C0074@0AC16d4@06C003]4a<009<2002C003aTa<00A<00LAC15<4@0A00I<00?6C4`0
2004C003aTa<00A<00LAC15<4D`A00I<00?6C4`00T`600=<0/H6C0074D`AC1404@07C004aTa<C0H0
14`00lI<C004C0074D`AC1404@0;C0H014800lI2C004@P074LHAC1404@06C0E22P0000T00Td300Q=
00<A014024d3009=1P02C@<024d00a404@08C@<00Td6009=0`000dg6C@05C@034@0A00Q=0`02C@X0
0Td01LI=CDd0009=00<A01400Td00`1=C@04C@X00Td300Q=00<A014024d40003C@0000@00Td300Q=
00<A014024d3009=1P02@P<014801de2CD8A01400Td00d9=C@03@P<00T8:00003P09C00304a<009<
00<0C4`00T`@00U<00<0C4`00T`00`1<C002C1401T`01@1<04`000I<3`000d`0C002C00904a<C01<
04`000E<00C6C01<3P03C08014`00`1<C002C0800d`@00A<00<0C4`00T`00`1<C002C00304a<009<
4004@P080492@T`0C482C09200=<@T803`0000d014d00lI=C@02C@0304e=00U=3P04C@03]4e=009=
00<0CDd02Dd>00A=00?6CDd00Td00`1=0004C@03aTe=009=3P04C@03aTe=009=00<0C@001Dd01<I=
CDd?009=00?6C@000dd00`1=0003C@0304e=009=3`04C@03aTe=009=00<0C@0014d00lI=C@02C@h0
14800lI2@P03@P09C@1=@Te2aT9=00923P0000`00T`00lI<C00<C004aTa<aP9<3002C003]4a<00a<
00BdC4bd0T`=0003C<I<00I<00<0C00014`01LI<C<I<00l00d`00lI<C00<C003aP0000`014`01LI<
C4`000E<00<0C4`01T`<009<00?6C4`034`01<I<C<H2C0`00T800lI2@P08@P05C49<@/H00T800lI2
@P0=00002P02C@0704e=CLI=aP07C@;61Td00`1=C@08009=00L0CDe=]4fd00M=0[@6C@0304e=00T0
0dd01@1=aTg600M=0/H4C@0404e=C@`000I=04g6CLH7C@;600I=aTe=04d;00==00<0CDd01Td00`1=
0004C@05aTe=C@000dd8009=00L0CDe=aTg600M=0/H6C@0304e=00P00T801`12@T;6CLH01d82aP03
CD9200=200<0@T802`0000`01d`00lI<aP06C003aP1<00A<3005C00504bdC;@01T`00k@0C004C0X0
00=<04`00d`200=<00?6C4`014`00lH0C004C00304`000T000E<001<0002C003aTc600I<00C6C01<
0P000d`000090003C01<009<00?60<H00T`00lI<C002C0;60T`01/I<C4`0C0/01D`01@1<aTc600I<
00?604`014`<00E200H0@/I<aT`3@P04C4;600E23@0000/00dd0101=0005C@;60dd00lH00005C@X0
1Dd200E=0[@3C@03]00000E=2P02C@0304d000801Dd2aP==00K60000C@02C@X000E=001=0007C@;6
0dd01LI=C@1=008000==00002@03C@0304d000Y=00C604d00dd;00E=0P05C@;60dd00lH00005C@X0
1D8200E20/H3@P03aP0000E2300000`000=<04`00P05C005aP1<C<H00d`00`1<0002C0`00d`200E<
00Fd04a<]003C00304`0009<3@000d`00002000;C036C<H0C03604`010000d`0000<0004C00000E<
00?6C4`00T`00`1<C0030003C00000`000A<04`00d`01<I<aP02C00804a<C01<04`=009<00<0C000
1D`01LH0C4c600=<00<0C0000T`<009200<0@P001D801LH0@T;600=20P03@Pd0000=0003C@0000M=
00<0CDd00dd0101=04d?0003C@0000M=00<0CDd00dd0101=04dC009=00T0C@1=04d0C@000TdG0003
C@1=009=00H0C@1=04dD0003C@1=00A=00D0C@1=0005C@0304d000l000A=04d01Dd00`1=C@03C@04
04d0CA0000A204801D800`12@P05@P8000=20000300000l000=<04`01D`00`1<0004C00304`00140
00=<04`01D`00`1<0004C00304`001<000=<04`00d`00`1<C002C00304`001D000=<04`00P000d`0
C0020003C01<01@000=<04`01D`0101<C003C00304`0014000=<04`00d`01@1<04`000A<00<0C000
4@000d80@P03@P03048000I200<0@P003`0001001dd00`1=C@04CAD01dd00`1=C@04CAD00Td0101=
04d30004C@1=009=5@001Dd0C@1=00<000E=04d0C@0E00M=00<0CDd01DdE00I=00<0CDd014dF00I2
00<0@T801D8A00004P001T`0C01<00=<00<0C0005`001T`0C01<00=<00<0C0005`04C0<014`H0004
C000C0<000A<001<60000d`0C002C00404a<009<60000d`0C002C00604a<C01<60000d80@P02@P06
0480@P124`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l00`000?l0
0`000?l00`000?l00`0001<00T`01@1<04`0009<QP03C5d0000C009=00D0C@1=0002CA/01TdM00M=
7007CA`01ddL00M=7007CAD0000A0003C00000=<00@0C4a<0P000d`0000F00M<00<0C0006@09C1X0
2D`I0003C01<00I<00<0C0006009C1X02D`D00004002C@800dd0101=CDd2009=5@0<CAL03DdF00e=
5P0=CAH03DdG00a=4P0000l01T`01@3604`000=<00<0C4`04`02C00304a<00U<5@0?C1@03d`D00m<
5007C00304a<00E<5@06C00304a<00E<4@0001401Dd00lI=C@05CA@01dd00lI=C@05C@0304d00140
0Td00`1=C@02C@03aTe=00A=00<0CDd04P02C@0304e=009=00?6CDd014d00`1=C@0>0003C@000080
1dd00lI=aP05C@@000==00003`03C@050<H0C@000ddH00A=00?6CDd00Td00`1=000B00004@03C003
aTc600;61D`D00M<00?6C<H01d`B00E<00?6C4`00/H7C1801D`00lI<C002aPM<3@02C0<01T`01LI<
04c600I<0`02C0h014`01LI<C4c600I<4P000d`0C00@C0l0000A00I=00<0CLH00ddE00Y=0/H5CA80
24d00lI=aP06CA801dd4aPI=3002C@0304d000U=00<0CDd00/H5C@0304d0009=3005C@;62TdA00Q=
00?6CDd024d?0000300014`0C004C009aT`04@1<04`0009<00<0C4`03`08C003aTa<00Q<4@06C003
aTa<00Q<4P06C003aT`000;61T`>009<0`02C08000?6C4`00d`00lH00002C0<00T`?00E<0/H8C180
34`00lI<C004C0l0000;009=00<0C@000P0014d0C@034@9=00<0C@000P02C@0304d000L00Td00`1=
0008C@<A00==aTd01Td2009=2@000dd0C@07C@<A00==aTd01Td=0003C@1=00E=0/H34@;61dd=0004
C@00C@@00Td34@9=100014d004d>00E=00?6CDd00a48C@/00Td200U=0a49C@800Td:00002`0014`0
C4`20009C01<C1404@0A009<00@0C0000T`00`1<000900A<00?6C4`00d`01A5<4D`A00Y<2004C004
04a<00A<00DAC15<4@08C00404a<C0H014`0101<C004C0054LHAaQ4024`0101<C4`:0003aP000080
00]<aP0AC15<4@36C0040003aP0000P00d`20005C<I<C0000T`01A5<4D`A009<00<0C4`00T`200=<
2003C003aT`000=<00K64D`AC142C00504`0C<H00d`<00003003C@<00Td01a404@0ACA400Td30003
C@1=00T014d00lI=C@04C@074DdACA764@06C@03aTe=009=1P04C@03aTe=00A=00LACA5=4LHA00I=
00?6CDd00Td600A=00?6CDd014d01a5=4LHACA401lH4C@/01Td01a5=CA5=01401Td;00A=00?6CDd0
14d01a5=4DdACA401Td00lI=C@02C@H014d00lI=C@04C@074DdACA5=4@06C@03aTe=009=2P0000d0
0T`200A<00@04@0A0T`00`1<C002009<2P02C0802D`00a404@08C0<00T`6009<0`08C0034@0A00Q<
0`02C0H00T`300A<00O6C4c64@0A00;600=<a/H00d`3009<1`03C00AaP1<C01<04`04D`A04`0C000
0T`00`36C002C0L00T`40003aTa<00A<00<A01401d`4009<1P02C0800d`00`1<C003C0034@0A00E<
00@0C4a<0P02C0X0000>0003aTe=00800Td00`1=0002C@0704d004d0aP0A00==00<0CDd00Td00`1=
C@06CA4014d00`1=C@02C@0304e=009=00<0CDd00Td@00A=00P0CDe=aP36C@;600<0CLH00Td;00E=
01<0C@1=04d0CA404Dd0C@1=04d000E=2`02C@03aTe=00i=4004C@0304e=009=00<0CDd00Td00`1=
C@02C@l0000>009<1@001D`0001<00@00T`00lH0000=00A<00?6C4`03T`>00A<00?6C4`00T`00`1<
C004C003aTa<009<3P04C003aTa<009<00X0aP36C<I<aTc60T`:00E<00?604`00P02C00504`0C000
0T`20004C036aPA<30000lI<aP0>C14014`00`1<C007C00304a<009<3`0000`000A=aP000Td30005
C@0004d00`001Tg60036C@`00Td00lI=C@0<C@03aTg600==3002C@03aTe=00a=00C6CDg60Td<009=
00?6CDd014d02LI=CDg6CLI=aP02C@03aTe=00T000==04d014d2009=00L0C@1=04d0009=0P05C@03
04d000P00Td01<H0CLH;C@04aTd0aP9=3@04C@03aTe=00m=3@0000X00T`00`1<C005C00304`00080
14`00`1<C002C00304a<00P00d`0101<C<H2C003aTc600A<0/H00d`0C006C0P00T`01`1<C4c6C<H0
1d`2aP03C<I<00=<00<0C4`02002C00404a<C0?61d`4aPA<00<0C4`02005C0;60T`20005C01<04`0
0P02C0;61D`8009<00H0C4a<aT`2aPI<0/H2C005aTa<C0000T`800I<00?6C4`00d`00`1<0004C005
aTa<C0000d`;00002@02C@0304d000<000==a/H02Td40004C@1=C@P000==04d02Td01LI=CDg600E=
00<0C@002P05C@0504g6CLH01Td00lH0C@04C@`01Dd00`1=aP03aP==00C6CLH01Dd;0008C@0004d0
aTd20005C@1=04d00P0014g604d30003C@0000T01Dd00`1=aP03C@;60dd00lH0C@04C@/000==04d0
3Dd00lI=C@04C@0304d000/000090003C01<00H000=<04`014`01<I<04`50004C000C0T000A<04a<
0P04C003aTa<00A<0P02C00304`000X01D`200E<0/H3C003aP0000E<2P05C0801D`2aP=<00?60000
1D`;00A<0/H02`36C01<04`0C<H000;614`;00E<0P000lH0C002C00604a<C0360P05C0/000A<04a<
0P0;C0800T`00`1<000<00002P000dd000060003CLI=00A=00?6C@001P000dd0000:0004C@1=009=
00T0C@36CLI=aP000Td0101=04d=00==0P05C@05aP1=CLH00dd00`1=0002C@`00Td00`1=0005C@05
aP1=CLH00dd00`1=0002C@`02Dd2aP060<I=aTg61Td<009=00<0C@000Td02@360<H0C@360002C@03
04d0009=3@0014d0C@03C@04aTg600I=00@0C@1=3P0001<000?6C00010000dc6000D0003C01<00I<
00<0C0001D`00`1<000>0003C00000=<00D0C4a<0003C00604`0C01<400014`0C005C00304a<00=<
00@0C01<3`08C005aTc6C<H00T`00`1<C003C0l000A<04`01D`00`1<C003C00404`0C10000=<04`0
1T`00`1<C005C00304`000h0000C0003C@0000D000==000050000dd0C@03C@0304d000I=00<0C@00
4@000dd0C@05C@0304e=00A=00<0C@004@000dd0C@03C@0504d0C@0014d00`1=000?0003C@1=00==
00<0CDd01Dd00`1=C@02C@0304d000l000==04d00dd01@1=04d000A=00<0C@004@000dd0C@03C@05
04d0C@0014d00`1=000?00004P02C0L00T`F00M<00<0C4`014`E0003C01<00A<00<0C4`014`F00I<
00<0C4`014`D0003C01<00E<00<0C4`014`00`1<000C00I<00<0C4`014`F00I<00<0C4`01D`A0000
4@03C@L00TdH0003C@1=009=00H0CDe=04dG00I=00<0CDd014dG0003C@1=009=00H0CDe=04dJ00M=
6P000dd0C@02C@0604e=C@1=60000dd0C@02C@0604e=C@1=4`00010000A<04a<1`03C8800d`0101<
C4aK00004`000dd000050003C@000>@0003o00<0003o00<0003o00<0003o00<0003o00<0003o00<0
003o00<0003o00<0003T009<1`02C1<0003R0004C@1=C@L00Td00`1=000@0000=P03C00304a<009<
7P03C1h01d`L00M<7007C1P000A<04a<1`02C00304`00100000e00A=00<0CDd00Td00`1=000F0003
C@0000800dd30003C@0001P01ddK00U=6P09CA<000==00000P02C@T00Td50003C@0000X0000c00m<
3P000d`00004009<0P05C00404a<C0D000=<00003`0;C1L03D`F00e<3`000d`0C004009<2@02C0D0
0T`;00005P034AX03dd>009=100>C@D00Td?00e=5@0?CA@03dd=00==00<0CDd00`000lH0C@05009=
00K60000C@04C@X0000E00054@0A01404P02C0D01d`00lI<C005C0D000=<000020000d`0C00;C003
04a<00A<00<0C0003P02C00304a<009<00?6C4`014`00`1<C00B009<00<0C4`00T`00lI<C004C003
04a<01800T`00`1<C002C003aTa<00A<00<0C4`03P04C0<000?6C4`01T`00`1<000200A<300001<0
0Q400`0A4@02008A4003C@0304e=00I=00?6CLH00/H8C@0404e=C@H014d2aPE=00?6CLH02Td00lI=
C@02C@`02Dd00lI=C@05CA801Dd01LI=CDg600M=4P05C@05aTe=CLH01dd?00A=0P000lI=aP09C@03
04e=00==3000018000LA00004@0A00<000<A00003`04C005aP1<C<H00T`00lI<aP06C003aTa<009<
3@09C003aTc600M<4@07C003aTa<00;61D`B00M<00C6C4c61T`B00M<00?6C4`00/H5C0l024`00`1<
C007C003aTc6009<3@00014000<A00000P000a404@0400034@0000`014d00lI=C@05C@03aTd0009=
00?6CDd02Dd:0004CLI=00A=00?6CDd01Td0101=CDd@00Q=00<ACDd01TdB00I=00?6C@0024dB00I=
00?6CDd024dA009=00?6CDd03Td?00003`024@@000@A000A1@024A401T`00lI<4@034@M<3P03C004
04a<00=<11400lI<0002C00404a<C0T00T`01@1<C03600I<0a400dc6C005C00304`0009<2@000d`0
C007C0<A00=<aT`01D`00`1<000<00U<0a400dc6C005C00304`000`000A<aT`01D`300E<00@0C<I<
3P0000h000<A000010001A40000A00H000<A00003@06C@05aQ4ACA400Td00a5=C@05C@X00dd00`1=
C@05C@8A00E=4De=4@07C@0404e=C@P00dd00`36C@04C@054DdACA401dd00`1=C@0800A=00@0CDd0
14d01A5=4DdA00A=00@0CDd014d600==00@0CDg61Dd01A5=4DdA00A=00@0CDd014d6009=00D0CDe=
0006C@<A1Td01@1=CDd0009=2P0000`00Q4700054@0001401`024@`02T`34@Y<2@0=C0034@0A00Q<
00?6C4`00T`600A<00?6C4`014`01a5<4D`AC1402d`600A<00?6C4`014`01a5<4D`AC1402d`600A<
00?6C4`014`01a5<4D`AC1402d`800A<00@0C4`00T`01A404@0A009<00C6C<H00T`00`1<000;0000
2`000a40000600034@00008000<A00001`000a40000600I=00?6CDd00dd01A404@0A00==00D0CDe=
aP04C@H00Td00`1=0004C@0804e=4Dd0aQ42C@0404e=aP9=0P02C@H00Td300Q=00<A014024d3009=
1P02C@<024d00a404@08C@<00Td6009=0`08C@034@0A00Q=0`02C@H02Dd03`1=4Dd04@1=4Dg6CLI=
0005C@X0000:00034@0000L000<A00000`000a40000700034@0000D00d`00`1<C003C00304a<00U<
0/H2C00404a<C0`000=<aP000T`00`1<C003C00404a<009<4005C00304a<009<00<0C4`00T`00`1<
C002C10014`00`1<C002C00304a<009<00<0C4`00T`@00A<00<0C4`00T`00`1<C002C00304a<009<
2`07C0;614`00a5<4@07C003aTa<00=<2P0000T000<A00001`000a40000400034@0000P000<A0000
1005C@03aTg600a=00?6CDd01Dd<009=00?6CDd02Td01<I=aTd?00A=00?6CDd00dd00`1=C@08C@h0
14d00lI=C@02C@0304d000A=00?6CDd00Td>00A=00?6CDd00Td00`1=0004C@03aTe=009=3@02C@0;
04e=CLI=aTdACA401Dd00`360002C@d0000C00034@0000@000<A00004003C0800T`00lI<C008C004
aTc6C0800d`:00=<00?6C4`04D`<009<00?6C4`034`01<I<C<H2C0`00T`01<I<C<H;C004aTa<aP9<
3002C004aTa<aP]<00C6C4c60T`>0004C<I<009<00C6C4`014`01LH00<I<00l0000C00034@0000D0
00<A000040001Dd004g600==00?6CDd024d00lI=00020003C@0000P01Dd00`36C@04C@0304e=009=
00?600001Dd900==00H0CDg6CLH8C@03aTe=00==00@0CDe=2002C@0504e=CLH02Dd2aP03CLI=00==
00<0CDd02002C@0504e=CLH02Dd2aP03CLI=00==00<0CDd03@04C@05aTg6C@0014d01<I=CDd@0000
4P000a40000600034@00018000=<04`024`00lI<aP07C0`014`200E<0/H00dc6C003C0800d`;0003
C01<00=<00@0C<I<0/H5C003aP1<00=<00<0C0002P05C00504c6C<H01T`00lH0C004C0`01D`01@1<
aTc600I<00?604`014`>00I<0P000lI<C00200I<3`00018000<A00001P000a40000A0005C@1=C@00
0Td00lH0C@03C@03aP1=009=00D0CDd0C@0<009=0`03C@800dd200==0`02C@`000A=04e=0P02C@04
aTe=aPE=0P02C@0304d000X01Dd200E=0/H3C@03aP0000E=2P05C@801Dd2aP==00?600001Dd>00E=
00?6CDd014d00lI=C@03C@l0000B00034@0000L000<A00004@02C00304a<009<00<0C4`00T`00lH0
C006C18014`01@1<aT`000A<4P0014`0C002C00504a<aP000T`02<H0C4`0C01<3@02C00304`000E<
00G604a<aP03C00304`0009<3002C00304`000E<00G604a<aP03C00304`0009<3009C005aTa<C<H0
2D`=00004@000a40000800034@0001401Td20003C@1=009=00<0C@001DdA00==0`02C@@00ddB0003
C@1=00I=00<0CDd01Dd00`1=000?0006C@1=04d00dd02P1=CDd0C@1=04d@0006C@1=04d00dd02P1=
CDd0C@1=04d?009=00<0C@000Td00`1=C@06C@800Td00`1=000<0000<@03C00904`004`0C01<0080
00E<04`0C00A0004C01<C0<00T`4009<00<0C0004@02C00304a<00=<00<0C4`00d`00`1<C00B0003
C01<00E<00<0C4`014`00`1<000A0003C01<00E<00<0C4`014`00`1<000?0005C00004`00`05C0<0
00E<0000C00>0000=0000dd00007C@0304d001D000==04d00`03C@<000==04d05@000dd0C@03C@03
04e=009=00<0C@005@06C@0304e=00A=5P06C@0304e=00A=6@07CAD0000g00M<7P03C1`000=<04`0
0T`01P1<C4`0C1L01T`00`1<C004C1H01T`00`1<C004C1P000E<04a<0002C00304`001<0000j0003
C@000:T000M=04d0C@1=01D0003X0003C01<01L0003o00<0003o00<0003o00<0003o00<0003o00<0
0000\
\>"],
  ImageRangeCache->{{{0, 257}, {107, 0}} -> {-0.216591, -0.0737002, 0.028923, 
  0.028923}, {{7.4375, 39.3125}, {104.438, 72.5625}} -> {-0.270008, -0.10942, 
  0.0329415, 0.0329415}, {{42.5, 74.3125}, {104.438, 72.5625}} -> {-1.42777,
   -0.110617, 0.0330062, 0.0330062}, {{77.5, 109.375}, {104.438, 72.5625}} ->
   {-2.57797, -0.109418, 0.0329415, 0.0329415}, {{112.562, 144.375}, {104.438,
   72.5625}} -> {-3.74027, -0.110614, 0.0330062, 0.0330062}, {{147.562, 
  179.438}, {104.438, 72.5625}} -> {-4.88594, -0.109419, 0.0329415, 
  0.0329415}, {{182.625, 214.438}, {104.438, 72.5625}} -> {-6.05277,
   -0.110617, 0.0330062, 0.0330062}, {{217.625, 249.5}, {104.438, 72.5625}} ->
   {-7.1939, -0.10942, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {69.375, 
  37.5625}} -> {-0.270008, -1.2634, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  69.375, 37.5625}} -> {-1.42777, -1.26686, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {69.375, 37.5625}} -> {-2.57797, -1.2634, 0.0329415, 0.0329415},
   {{112.562, 144.375}, {69.375, 37.5625}} -> {-3.74027, -1.26687, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {69.375, 37.5625}} -> {-4.88594, -1.2634, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {69.375, 37.5625}} -> {-6.05277,
   -1.26687, 0.0330062, 0.0330062}, {{217.625, 249.5}, {69.375, 37.5625}} ->
   {-7.1939, -1.2634, 0.0329415, 0.0329415}, {{7.4375, 39.3125}, {34.375, 
  2.5}} -> {-0.270008, -2.41738, 0.0329415, 0.0329415}, {{42.5, 74.3125}, {
  34.375, 2.5}} -> {-1.42777, -2.42311, 0.0330062, 0.0330062}, {{77.5, 
  109.375}, {34.375, 2.5}} -> {-2.57797, -2.41738, 0.0329415, 0.0329415}, {{
  112.562, 144.375}, {34.375, 2.5}} -> {-3.74027, -2.42312, 0.0330062, 
  0.0330062}, {{147.562, 179.438}, {34.375, 2.5}} -> {-4.88594, -2.41738, 
  0.0329415, 0.0329415}, {{182.625, 214.438}, {34.375, 2.5}} -> {-6.05277,
   -2.42312, 0.0330062, 0.0330062}, {{217.625, 249.5}, {34.375, 2.5}} ->
   {-7.1939, -2.41738, 0.0329415, 0.0329415}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .88864 
MathPictureStart
%% Graphics3D
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 -0.0318709 0.952381 [
[ 0 0 0 0 ]
[ 1 .88864 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
0 0 m
1 0 L
1 .88864 L
0 .88864 L
closepath
clip
newpath
p
P
p
.2 0 1 r
.002 w
.54336 .58801 m
.40445 .65879 L
s
P
p
.2 0 1 r
.002 w
.54336 .58801 m
.43312 .69825 L
s
P
p
.2 0 1 r
.002 w
.54336 .58801 m
.47258 .72692 L
s
P
p
.2 0 1 r
.002 w
.62642 .57485 m
.73666 .6851 L
s
P
p
.2 0 1 r
.002 w
.62642 .57485 m
.76533 .64563 L
s
P
p
.2 0 1 r
.002 w
.62642 .57485 m
.78041 .59924 L
s
P
p
.2 0 1 r
.002 w
.58824 .49993 m
.65902 .36101 L
s
P
p
.2 0 1 r
.002 w
.58824 .49993 m
.61263 .34594 L
s
P
p
.2 0 1 r
.002 w
.58824 .49993 m
.56385 .34594 L
s
P
p
0 .4 1 r
.018 w
.58011 .55126 m
.54336 .58801 L
s
P
p
0 .4 1 r
.018 w
.58011 .55126 m
.62642 .57485 L
s
P
p
0 .4 1 r
.018 w
.58011 .55126 m
.58824 .49993 L
s
P
p
.2 0 1 r
.002 w
.2942 .28629 m
.44819 .2619 L
s
P
p
.2 0 1 r
.002 w
.2942 .28629 m
.43312 .21551 L
s
P
p
.2 0 1 r
.002 w
.2942 .28629 m
.40445 .17605 L
s
P
p
.2 0 1 r
.002 w
.21115 .27314 m
.14036 .13422 L
s
P
p
.2 0 1 r
.002 w
.21115 .27314 m
.1009 .16289 L
s
P
p
.2 0 1 r
.002 w
.21115 .27314 m
.07223 .20236 L
s
P
p
.2 0 1 r
.002 w
.2243 .35619 m
.11406 .46644 L
s
P
p
.2 0 1 r
.002 w
.2243 .35619 m
.15352 .49511 L
s
P
p
.2 0 1 r
.002 w
.2243 .35619 m
.19991 .51018 L
s
P
p
0 .4 1 r
.018 w
.24789 .30989 m
.2942 .28629 L
s
P
p
0 .4 1 r
.018 w
.24789 .30989 m
.21115 .27314 L
s
P
p
0 .4 1 r
.018 w
.24789 .30989 m
.2243 .35619 L
s
P
p
.2 0 1 r
.002 w
.43793 .65023 m
.28394 .62584 L
s
P
p
.2 0 1 r
.002 w
.43793 .65023 m
.28394 .67462 L
s
P
p
.2 0 1 r
.002 w
.43793 .65023 m
.29902 .72102 L
s
P
p
.2 0 1 r
.002 w
.51286 .68841 m
.53725 .8424 L
s
P
p
.2 0 1 r
.002 w
.51286 .68841 m
.58364 .82733 L
s
P
p
.2 0 1 r
.002 w
.51286 .68841 m
.6231 .79866 L
s
P
p
.2 0 1 r
.002 w
.52601 .60536 m
.66493 .53457 L
s
P
p
.2 0 1 r
.002 w
.52601 .60536 m
.63626 .49511 L
s
P
p
.2 0 1 r
.002 w
.52601 .60536 m
.59679 .46644 L
s
P
p
0 .4 1 r
.018 w
.48926 .6421 m
.43793 .65023 L
s
P
p
0 .4 1 r
.018 w
.48926 .6421 m
.51286 .68841 L
s
P
p
0 .4 1 r
.018 w
.48926 .6421 m
.52601 .60536 L
s
P
p
.2 0 1 r
.002 w
.4137 .25969 m
.55262 .33047 L
s
P
p
.2 0 1 r
.002 w
.4137 .25969 m
.56769 .28408 L
s
P
p
.2 0 1 r
.002 w
.4137 .25969 m
.56769 .2353 L
s
P
p
.2 0 1 r
.002 w
.35424 .20023 m
.37863 .04624 L
s
P
p
.2 0 1 r
.002 w
.35424 .20023 m
.32985 .04624 L
s
P
p
.2 0 1 r
.002 w
.35424 .20023 m
.28346 .06131 L
s
P
p
.2 0 1 r
.002 w
.31606 .27515 m
.16207 .29954 L
s
P
p
.2 0 1 r
.002 w
.31606 .27515 m
.17715 .34594 L
s
P
p
.2 0 1 r
.002 w
.31606 .27515 m
.20582 .3854 L
s
P
p
0 .4 1 r
.018 w
.36237 .25156 m
.4137 .25969 L
s
P
p
0 .4 1 r
.018 w
.36237 .25156 m
.35424 .20023 L
s
P
p
0 .4 1 r
.018 w
.36237 .25156 m
.31606 .27515 L
s
P
p
.2 0 1 r
.016 w
.39489 .45688 m
.58011 .55126 L
s
P
p
.2 0 1 r
.016 w
.39489 .45688 m
.24789 .30989 L
s
P
p
.2 0 1 r
.016 w
.39489 .45688 m
.48926 .6421 L
s
P
p
.2 0 1 r
.016 w
.39489 .45688 m
.36237 .25156 L
s
P
p
.2 0 1 r
.002 w
.65704 .52289 m
.58626 .66181 L
s
P
p
.2 0 1 r
.002 w
.65704 .52289 m
.63265 .67688 L
s
P
p
.2 0 1 r
.002 w
.65704 .52289 m
.68143 .67688 L
s
P
p
.2 0 1 r
.002 w
.7165 .46343 m
.87049 .48782 L
s
P
p
.2 0 1 r
.002 w
.7165 .46343 m
.87049 .43904 L
s
P
p
.2 0 1 r
.002 w
.7165 .46343 m
.85542 .39265 L
s
P
p
.2 0 1 r
.002 w
.64158 .42525 m
.61719 .27126 L
s
P
p
.2 0 1 r
.002 w
.64158 .42525 m
.5708 .28634 L
s
P
p
.2 0 1 r
.002 w
.64158 .42525 m
.53133 .31501 L
s
P
p
0 .4 1 r
.018 w
.66517 .47156 m
.65704 .52289 L
s
P
p
0 .4 1 r
.018 w
.66517 .47156 m
.7165 .46343 L
s
P
p
0 .4 1 r
.018 w
.66517 .47156 m
.64158 .42525 L
s
P
p
.2 0 1 r
.002 w
.27812 .42525 m
.38837 .31501 L
s
P
p
.2 0 1 r
.002 w
.27812 .42525 m
.34891 .28634 L
s
P
p
.2 0 1 r
.002 w
.27812 .42525 m
.30251 .27126 L
s
P
p
.2 0 1 r
.002 w
.2032 .46343 m
.06428 .39265 L
s
P
p
.2 0 1 r
.002 w
.2032 .46343 m
.04921 .43904 L
s
P
p
.2 0 1 r
.002 w
.2032 .46343 m
.04921 .48782 L
s
P
p
.2 0 1 r
.002 w
.26266 .52289 m
.23827 .67688 L
s
P
p
.2 0 1 r
.002 w
.26266 .52289 m
.28705 .67688 L
s
P
p
.2 0 1 r
.002 w
.26266 .52289 m
.33344 .66181 L
s
P
p
0 .4 1 r
.018 w
.25453 .47156 m
.27812 .42525 L
s
P
p
0 .4 1 r
.018 w
.25453 .47156 m
.2032 .46343 L
s
P
p
0 .4 1 r
.018 w
.25453 .47156 m
.26266 .52289 L
s
P
p
.2 0 1 r
.002 w
.60833 .6352 m
.46941 .70599 L
s
P
p
.2 0 1 r
.002 w
.60833 .6352 m
.49808 .74545 L
s
P
p
.2 0 1 r
.002 w
.60833 .6352 m
.53754 .77412 L
s
P
p
.2 0 1 r
.002 w
.69138 .62205 m
.80162 .73229 L
s
P
p
.2 0 1 r
.002 w
.69138 .62205 m
.8303 .69283 L
s
P
p
.2 0 1 r
.002 w
.69138 .62205 m
.84537 .64644 L
s
P
p
.2 0 1 r
.002 w
.6532 .54712 m
.72399 .40821 L
s
P
p
.2 0 1 r
.002 w
.6532 .54712 m
.67759 .39313 L
s
P
p
.2 0 1 r
.002 w
.6532 .54712 m
.62881 .39313 L
s
P
p
0 .4 1 r
.018 w
.64507 .59845 m
.60833 .6352 L
s
P
p
0 .4 1 r
.018 w
.64507 .59845 m
.69138 .62205 L
s
P
p
0 .4 1 r
.018 w
.64507 .59845 m
.6532 .54712 L
s
P
p
.2 0 1 r
.002 w
.35916 .33349 m
.51315 .3091 L
s
P
p
.2 0 1 r
.002 w
.35916 .33349 m
.49808 .26271 L
s
P
p
.2 0 1 r
.002 w
.35916 .33349 m
.46941 .22325 L
s
P
p
.2 0 1 r
.002 w
.27611 .32034 m
.20533 .18142 L
s
P
p
.2 0 1 r
.002 w
.27611 .32034 m
.16586 .21009 L
s
P
p
.2 0 1 r
.002 w
.27611 .32034 m
.13719 .24956 L
s
P
p
.2 0 1 r
.002 w
.28926 .40339 m
.17902 .51364 L
s
P
p
.2 0 1 r
.002 w
.28926 .40339 m
.21848 .54231 L
s
P
p
.2 0 1 r
.002 w
.28926 .40339 m
.26487 .55738 L
s
P
p
0 .4 1 r
.018 w
.31286 .35709 m
.35916 .33349 L
s
P
p
0 .4 1 r
.018 w
.31286 .35709 m
.27611 .32034 L
s
P
p
0 .4 1 r
.018 w
.31286 .35709 m
.28926 .40339 L
s
P
p
.2 0 1 r
.016 w
.45985 .50408 m
.66517 .47156 L
s
P
p
.2 0 1 r
.016 w
.45985 .50408 m
.25453 .47156 L
s
P
p
.2 0 1 r
.016 w
.45985 .50408 m
.64507 .59845 L
s
P
p
.2 0 1 r
.016 w
.45985 .50408 m
.31286 .35709 L
s
P
p
.2 0 1 r
.002 w
.71074 .40339 m
.73513 .55738 L
s
P
p
.2 0 1 r
.002 w
.71074 .40339 m
.78152 .54231 L
s
P
p
.2 0 1 r
.002 w
.71074 .40339 m
.82098 .51364 L
s
P
p
.2 0 1 r
.002 w
.72389 .32034 m
.86281 .24956 L
s
P
p
.2 0 1 r
.002 w
.72389 .32034 m
.83414 .21009 L
s
P
p
.2 0 1 r
.002 w
.72389 .32034 m
.79467 .18142 L
s
P
p
.2 0 1 r
.002 w
.64084 .33349 m
.53059 .22325 L
s
P
p
.2 0 1 r
.002 w
.64084 .33349 m
.50192 .26271 L
s
P
p
.2 0 1 r
.002 w
.64084 .33349 m
.48685 .3091 L
s
P
p
0 .4 1 r
.018 w
.68714 .35709 m
.71074 .40339 L
s
P
p
0 .4 1 r
.018 w
.68714 .35709 m
.72389 .32034 L
s
P
p
0 .4 1 r
.018 w
.68714 .35709 m
.64084 .33349 L
s
P
p
.2 0 1 r
.002 w
.3468 .54712 m
.37119 .39313 L
s
P
p
.2 0 1 r
.002 w
.3468 .54712 m
.32241 .39313 L
s
P
p
.2 0 1 r
.002 w
.3468 .54712 m
.27601 .40821 L
s
P
p
.2 0 1 r
.002 w
.30862 .62205 m
.15463 .64644 L
s
P
p
.2 0 1 r
.002 w
.30862 .62205 m
.1697 .69283 L
s
P
p
.2 0 1 r
.002 w
.30862 .62205 m
.19838 .73229 L
s
P
p
.2 0 1 r
.002 w
.39167 .6352 m
.46246 .77412 L
s
P
p
.2 0 1 r
.002 w
.39167 .6352 m
.50192 .74545 L
s
P
p
.2 0 1 r
.002 w
.39167 .6352 m
.53059 .70599 L
s
P
p
0 .4 1 r
.018 w
.35493 .59845 m
.3468 .54712 L
s
P
p
0 .4 1 r
.018 w
.35493 .59845 m
.30862 .62205 L
s
P
p
0 .4 1 r
.018 w
.35493 .59845 m
.39167 .6352 L
s
P
p
.2 0 1 r
.002 w
.73734 .52289 m
.66656 .66181 L
s
P
p
.2 0 1 r
.002 w
.73734 .52289 m
.71295 .67688 L
s
P
p
.2 0 1 r
.002 w
.73734 .52289 m
.76173 .67688 L
s
P
p
.2 0 1 r
.002 w
.7968 .46343 m
.95079 .48782 L
s
P
p
.2 0 1 r
.002 w
.7968 .46343 m
.95079 .43904 L
s
P
p
.2 0 1 r
.002 w
.7968 .46343 m
.93572 .39265 L
s
P
p
.2 0 1 r
.002 w
.72188 .42525 m
.69749 .27126 L
s
P
p
.2 0 1 r
.002 w
.72188 .42525 m
.65109 .28634 L
s
P
p
.2 0 1 r
.002 w
.72188 .42525 m
.61163 .31501 L
s
P
p
0 .4 1 r
.018 w
.74547 .47156 m
.73734 .52289 L
s
P
p
0 .4 1 r
.018 w
.74547 .47156 m
.7968 .46343 L
s
P
p
0 .4 1 r
.018 w
.74547 .47156 m
.72188 .42525 L
s
P
p
.2 0 1 r
.002 w
.35842 .42525 m
.46867 .31501 L
s
P
p
.2 0 1 r
.002 w
.35842 .42525 m
.4292 .28634 L
s
P
p
.2 0 1 r
.002 w
.35842 .42525 m
.38281 .27126 L
s
P
p
.2 0 1 r
.002 w
.2835 .46343 m
.14458 .39265 L
s
P
p
.2 0 1 r
.002 w
.2835 .46343 m
.12951 .43904 L
s
P
p
.2 0 1 r
.002 w
.2835 .46343 m
.12951 .48782 L
s
P
p
.2 0 1 r
.002 w
.34296 .52289 m
.31857 .67688 L
s
P
p
.2 0 1 r
.002 w
.34296 .52289 m
.36735 .67688 L
s
P
p
.2 0 1 r
.002 w
.34296 .52289 m
.41374 .66181 L
s
P
p
0 .4 1 r
.018 w
.33483 .47156 m
.35842 .42525 L
s
P
p
0 .4 1 r
.018 w
.33483 .47156 m
.2835 .46343 L
s
P
p
0 .4 1 r
.018 w
.33483 .47156 m
.34296 .52289 L
s
P
p
.2 0 1 r
.016 w
.54015 .50408 m
.68714 .35709 L
s
P
p
.2 0 1 r
.016 w
.54015 .50408 m
.35493 .59845 L
s
P
p
.2 0 1 r
.016 w
.54015 .50408 m
.74547 .47156 L
s
P
p
.2 0 1 r
.016 w
.54015 .50408 m
.33483 .47156 L
s
P
p
.2 0 1 r
.002 w
.68394 .27515 m
.79418 .3854 L
s
P
p
.2 0 1 r
.002 w
.68394 .27515 m
.82285 .34594 L
s
P
p
.2 0 1 r
.002 w
.68394 .27515 m
.83793 .29954 L
s
P
p
.2 0 1 r
.002 w
.64576 .20023 m
.71654 .06131 L
s
P
p
.2 0 1 r
.002 w
.64576 .20023 m
.67015 .04624 L
s
P
p
.2 0 1 r
.002 w
.64576 .20023 m
.62137 .04624 L
s
P
p
.2 0 1 r
.002 w
.5863 .25969 m
.43231 .2353 L
s
P
p
.2 0 1 r
.002 w
.5863 .25969 m
.43231 .28408 L
s
P
p
.2 0 1 r
.002 w
.5863 .25969 m
.44738 .33047 L
s
P
p
0 .4 1 r
.018 w
.63763 .25156 m
.68394 .27515 L
s
P
p
0 .4 1 r
.018 w
.63763 .25156 m
.64576 .20023 L
s
P
p
0 .4 1 r
.018 w
.63763 .25156 m
.5863 .25969 L
s
P
p
.2 0 1 r
.002 w
.47399 .60536 m
.40321 .46644 L
s
P
p
.2 0 1 r
.002 w
.47399 .60536 m
.36374 .49511 L
s
P
p
.2 0 1 r
.002 w
.47399 .60536 m
.33507 .53457 L
s
P
p
.2 0 1 r
.002 w
.48714 .68841 m
.3769 .79866 L
s
P
p
.2 0 1 r
.002 w
.48714 .68841 m
.41636 .82733 L
s
P
p
.2 0 1 r
.002 w
.48714 .68841 m
.46275 .8424 L
s
P
p
.2 0 1 r
.002 w
.56207 .65023 m
.70098 .72102 L
s
P
p
.2 0 1 r
.002 w
.56207 .65023 m
.71606 .67462 L
s
P
p
.2 0 1 r
.002 w
.56207 .65023 m
.71606 .62584 L
s
P
p
0 .4 1 r
.018 w
.51074 .6421 m
.47399 .60536 L
s
P
p
0 .4 1 r
.018 w
.51074 .6421 m
.48714 .68841 L
s
P
p
0 .4 1 r
.018 w
.51074 .6421 m
.56207 .65023 L
s
P
p
.2 0 1 r
.002 w
.7757 .35619 m
.80009 .51018 L
s
P
p
.2 0 1 r
.002 w
.7757 .35619 m
.84648 .49511 L
s
P
p
.2 0 1 r
.002 w
.7757 .35619 m
.88594 .46644 L
s
P
p
.2 0 1 r
.002 w
.78885 .27314 m
.92777 .20236 L
s
P
p
.2 0 1 r
.002 w
.78885 .27314 m
.8991 .16289 L
s
P
p
.2 0 1 r
.002 w
.78885 .27314 m
.85964 .13422 L
s
P
p
.2 0 1 r
.002 w
.7058 .28629 m
.59555 .17605 L
s
P
p
.2 0 1 r
.002 w
.7058 .28629 m
.56688 .21551 L
s
P
p
.2 0 1 r
.002 w
.7058 .28629 m
.55181 .2619 L
s
P
p
0 .4 1 r
.018 w
.75211 .30989 m
.7757 .35619 L
s
P
p
0 .4 1 r
.018 w
.75211 .30989 m
.78885 .27314 L
s
P
p
0 .4 1 r
.018 w
.75211 .30989 m
.7058 .28629 L
s
P
p
.2 0 1 r
.002 w
.41176 .49993 m
.43615 .34594 L
s
P
p
.2 0 1 r
.002 w
.41176 .49993 m
.38737 .34594 L
s
P
p
.2 0 1 r
.002 w
.41176 .49993 m
.34098 .36101 L
s
P
p
.2 0 1 r
.002 w
.37358 .57485 m
.21959 .59924 L
s
P
p
.2 0 1 r
.002 w
.37358 .57485 m
.23467 .64563 L
s
P
p
.2 0 1 r
.002 w
.37358 .57485 m
.26334 .6851 L
s
P
p
.2 0 1 r
.002 w
.45664 .58801 m
.52742 .72692 L
s
P
p
.2 0 1 r
.002 w
.45664 .58801 m
.56688 .69825 L
s
P
p
.2 0 1 r
.002 w
.45664 .58801 m
.59555 .65879 L
s
P
p
0 .4 1 r
.018 w
.41989 .55126 m
.41176 .49993 L
s
P
p
0 .4 1 r
.018 w
.41989 .55126 m
.37358 .57485 L
s
P
p
0 .4 1 r
.018 w
.41989 .55126 m
.45664 .58801 L
s
P
p
.2 0 1 r
.016 w
.60511 .45688 m
.63763 .25156 L
s
P
p
.2 0 1 r
.016 w
.60511 .45688 m
.51074 .6421 L
s
P
p
.2 0 1 r
.016 w
.60511 .45688 m
.75211 .30989 L
s
P
p
.2 0 1 r
.016 w
.60511 .45688 m
.41989 .55126 L
s
P
p
1 .6 0 r
.016 w
.5 .38051 m
.39489 .45688 L
s
P
p
1 .6 0 r
.016 w
.5 .38051 m
.45985 .50408 L
s
P
p
1 .6 0 r
.016 w
.5 .38051 m
.54015 .50408 L
s
P
p
1 .6 0 r
.016 w
.5 .38051 m
.60511 .45688 L
s
P
p
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{178, 158},
  ImageMargins->{{34, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002b0000WPP10`4000010?ooooooc?ooZ_ooI_oo
<ooo0?o<ooo<c?o<VC/k>gYjN[Vi^OShn03ooeGooj[ooonI<onI0?mVoomVc?mVVOmVI_mV<omV0?lc
oclo?ginO[fm_Oclo5D00:X00?l00?l0VOl0I_l0<ol00<coolcoc<coVLcoIP<30d92@X61PL30`000
EED0EJX0EOl0ELbIolbIc<bIVLbII/bI<lbI0<aVolaVc0L71dI6AXF5QLC4a000ZUD0ZZX0Z_l0Z/`c
<l`c0<`0ol`0c<`0VL`0I/`0<l`000/;2dY:BXV9RLS8b000oeD0ojX0ool0oiW<VIW<IYW<<iW<09VI
oiVIc9VIVIVIIPl?3di>CXf=SLc<c01E05EE0:YE0?mE09TcoiTcc9TcVITcIYTc<iTc09T0oiT0c1<C
4e9BDY6ATM3@d01EEEEEEJYEEOmEEFKo<fKo06K<ofK<c6K<VFK<IVK<<fK<01LG5eIFEYFEUMCDe01E
ZUEEZZYEZ_mEZVIVVFIVIVIV<fIV06HcofHcc6HcVFHcIQ/K6eYJFYVIVMSHf01EoeEEojYEoomEoc?o
oc?oc3?oVC?oIS?o<c?o03?<oc?<c1lO7eiNGYfMWMcLg02Z05FZ0:ZZ0?nZ03>I<c>I03=Voc=Vc3=V
VC=VIS=V<c=V02<S8f9RHZ6QXN3Ph02ZEEFZEJZZEOnZEC<0VC<0IS<0<c<0003oo`3oc03oV@3oIRLW
9fIVIZFUYNCTi02ZZUFZZZZZZ_nZZP2Io`2Ic02IV@2IIP2I<`2I001Vo`1Vc2/[:fYZJZVYZNSXj02Z
oeFZojZZoonZo`0c<`0c0000o`00c000V@00IP00<nh002l_;fi^KZf][Nc/k03o05Go0:[o0?oo0140
003^003M002k002Z0028001g001E03<c<g9bL[6a/O3`l03oEEGoEJ[oEOooE@00M`00E@00A0008P00
4Nk^k]gMgK^k^cLg=gIfM[Fe]OCdm03oZUGoZZ[oZP000;80002b0000/P000;80002b0000/P000;80
002b0000/P0003X000==00001P000dd0000W0003C@0000H000==0000>@0003X000=<00001P000d`0
000W0003C00000H000=<0000>@00038000==00001@000dd000060003C@0002L000==00001P000dd0
00050003C@000340000b0003C00000D000=<00001P000d`0000W0003C00000H000=<00001@000d`0
000a0000<`000dd000050003C@0000@000==0000:@000dd000040003C@0000D000==0000<P0003<0
00=<00001@000d`000040003C00002T000=<000010000d`000050003C0000380000d0003C@0000@0
00==000010000dd0000Y0003C@0000@000==000010000dd0000c0000=0000d`000040003C00000@0
00=<0000:@000d`000040003C00000@000=<0000<`0003D000==00000`000dd000040003C@0002T0
00==000010000dd000030003C@0003@0000e0003C00000<000=<00000`000d`0000[0003C00000<0
00=<00000`000d`0000d0000=P000dd000020003C@0000<000==0000:`000dd000030003C@000080
00==0000=@0003H000=<00000`000d`000020003C00002/000=<00000P000d`000030003C00003D0
000g0003C@00008000==00000P000dd0000[0003C@00008000==00000P000dd0000f0000=`000d`0
00020003C000008000=<0000:`000d`000020003C000008000=<0000=P0003P000E=0000C@030003
C@0002d000E=0000C@030003C@0003L0000H0003C00001d000E<0000C0030003C00002d000E<0000
C0030003C00001d000=<00005`0001P000==00007@001Dd0001=00<000==0000;@001Dd0001=00<0
00==00007@000dd0000G00006@000d`0000M0004C000C0<000=<0000;@001D`0001<008000=<0000
7@000d`0000H00006@000dd0000M0005C@0004d00P000dd0000]0004C@00C@<000==00007@000dd0
000H00006P000d`0000M0004C000C08000=<0000;@0014`004`20003C00001d000=<00006@000140
00==00001P000dd0000M0006C@00C@1=<@000dd0C@020003C@0001d000==00001P000dd0000@0000
4P000d`000060003C00001d000E<04`0C00a0005C01<04`07`000d`000060003C0000140000C0003
C@0000D000==00007@001Dd0C@1=034000E=04d0C@0O0003C@0000D000==00004P0001@000=<0000
1@000d`0000M009<00<0C0001P000d`0000O0003C00000D000A<04a<7`000d`000050003C00001<0
000E0003C@0000@000==00001@000dd0000E009=00<0C@001@000dd0000Q0003C@0000@000A=04e=
5`000dd000050003C@0000@000==0000500001H000=<000010000d`000040003C00001H00T`60003
C00002<000=<00001002C1P000=<000010000d`000040003C00001D0000G0003C@0000<000==0000
1@000dd0000E00?610000dd0000U0003C@0000800lHG0003C@0000D000==00000`000dd0000F0000
3002C0X000=<00000`000d`000040003C00001D00lH30003C00002L000A<00000lHG0003C00000@0
00=<00000`000d`00008009<3@0000h00Td90003C@0000<000==000010000dd0000D00?60P000dd0
000Y0003C@0000?65P000dd000040003C@0000<000==00001`02C@l0000@009<20001T`004`0C0H0
00=<00005004aP03C00002/000=<a/H00/HF0003C00000@000=<04`00P000d`00006009<4@000180
0Td70006C@00C@1=1P000dd0000C00C62P02CAL00Td:0004CLK6aQD000==000010000dd0C@020003
C@0000D00TdC00005002C0H000=<00000T`60003C00001@00lH8009<1`02C0T00T`7009<20000lI<
aP0F0003C00000@00T`20003C00000@00T`E00005P02C@D000==00000Td60003C@0001<00lH6009=
20000dd0000;0003C@0000H00Td600;600==00004`000dd00004009=0P000dd00003009=5`0001P0
0T`40004C000C0H000=<00004P0014c6a/H4009<1@05C0l01D`5009<1003aP03C000018000=<0000
100014`004`4009<6@0001X000==00000P0014d004d60003C@00010000==0<H00lH00`1=C@0:00Q=
0`08C@X00Td00`36aP02aP0304d0014000==0000100014d004d40003C@0001T0000K009<0`0014`0
C4`50003C00000l000=<00002LH70003C00000802d`40003C00000H00lH2C0?60P000d`0000?0003
C00000<00T`00`1<0002009<700001P00Td3009=0P0014d0CDd50003C@0000d000==0<H00/H2C@[6
00<0CDd01Dd;00M=00<0a/H01lH3C@?600<0C@003P000dd00003009=00@0C@000Td3009=6@0001X0
0T`3009<00D0C4`0C0040003C00000`000=<a/H00lH2C0[60T`G009<2LH2C003aTa<00?600=<0000
30000d`000020005C01<C0000T`3009<6`0001`00Td300A=00<0C@000`000dd0000:00O60Td400K6
1dd500==1@07C@O60P02C@?60Td2aP03C@0000X000==00000P000dd0C@03C@<00TdM00007P02C0<0
00E<a/K6C0030003C00000L000=<0<H01/H00`1<C0020003C01<00I<00<0C4`00`06C00304a<00A<
0`02C00304a<00E<00<0C0000T`200?60T`01<I<04`90005C00004`00lH014`00002C1l0000P009=
0P04aP05C@0004d02002C@G60P07C@@000==00000`0014d0000;C@<000==00000`000dd0000200M=
0P03aPE=1`001Dd0001=00C60P02CB40000R009<1LH01D`004`000U<0lH4C00604a<C01<10000d`0
000400E<2@05C0H000=<00000P04C08024`4aPI<0P000dc6aP03aP9<8`0002@00Td00lI=C@05C@80
0lH4C@H000==00000Td00`1=00020004C@0000I=00<0CDd02@02C@0304e=00A=0`0014d00003C@<0
00==000010000dg6aP04aP8014d5aP03C@0002<0000P00Q<0lH00d`0C003aP9<00?6C4`01`000d`0
0003C0<000=<00000P0014`0C4`5009<1@02C0D00T`00`1<00030004C000009<0`000d`0000500W6
00<0C<H01<H7C200000L00A=1`000lI=C@02aP03CLI=009=0lH00dd000050004C@0000==0P000dd0
000200==2@02C@0304e=00T00dd40003C@00009=10000dd000050003CLK600_62003CAd0000X00;6
0T`00lI<C003aP0304a<00L000A<00000d`00`1<000200=<3003C0`00d`30004C01<C0@000=<0000
1@02C0030<K600S6:@0002T000?6CDd014d20003C@1=00H000==00000P04C@800Td00`1=000:00M=
2`0014d0CDd200==1@000dd000040003C@1=008000==a/H00Td2aRX0000Y0006aTa<C01<0lH20003
C00000@000=<00000P03C00304a<00<000=<00001007C0<01d`60004C000009<00<0C4`01@000d`0
00040004C000C0;614`2aRX0000X009=00G6CDe=0004aP0304d000@000==00000`05C@<024d2009=
2@02C@8024d300A=1P000dd000030006C@36aTg60dd3aP03C@0002L0000V009<1<H3C0G600=<0000
0`000d`00004aPQ<1`02C0d00T`700Q<1<H20003C00000<000=<a/H00/H3C0030<K600;60T`W0000
9002C@801<H0101=CDd5aP@000==00001LH2C@@000==00001@02C@l00Td70004C@0000==1LH20003
C@00008000C6CLK60dd200C60P02CBD0000R009<0`04aP8014`5aP<000=<a/H01LH2C0@000=<0000
1@000d`0000?0003C00000D000A<00000d`7aP04C00000;600=<aT`00T`0101<0004aP<00T`S0000
8002C@D01<H0101=0003C@G600<0a/H01LH0101=CDd30003C@0000D000==00004@000dd000050003
C@0000A=00<0a/H01<H00dd0aP02aPA=0`000dd0aP03aPD00TdQ00007`000d`0000400C600<0C000
0`03C0_600<0C0000T`0101<04`60003C00001<000=<000010000d`0C003C00304`000G600=<a/H0
0/H3C0D000=<0<H00lH60003C00001h0000V00C600==00001003C@S60P000dd00002C@0304e=00H0
0TdE009=1P05C@8000==00001<H00dg6aP03C@L000==a/H00/HW00009P03aP03C00000H00d`00lI<
C002aP800T`300E<1@000d`0C00E0003C01<00D01D`3009<0P001<I<C<H3C0T000A<a/K69`0002H0
0dd:009=00C6CDe=0`000dd0000200E=100014d004dE0004C@00C@@00dd00`1=00030003C@0000M=
2P03CBL0000U00=<2P000d`0C002aP=<00@0C01<0P000d`0C003C0<000A<001<5`0014`004`300=<
0P001D`004`000M<0P000d`0000800=<9P0002@00dd;0003C@3600?60dd20005C@00C@0014d20005
C@0004d05`001Dd0001=00800dd20005C@00C@001Td2aP0304d000X00ddU00008`0014`0C4`;0003
C03600?614`20004C01<009<00@0C01<10000d`0000700@A2P000d`000020003C01<009<0P0014`0
C006C005aTc604`02`02C00304`002<0000R0005C@1=04d02`000dg6aP02aPI=00D0C@1=0002C@03
04e=00D000==00001P064@T000==00000`04C@8000==04d01Td00`36C@02aP03C@0000T000E=04d0
C@0S00002`02C0`00T`60006C000C01<2`000dc6aP02aPM<00<0C4`00d`00`1<00050003C00000@0
2Q470003C00000@03D`01`1<a/I<aT`02`000d`0C0020003C00000@00T`<009<300000d00Td<009=
0`0014d004d20003C@0000T01<H00dd0000=C@D000==0000100<4@L000==00000`0=C@8000E=aTg6
C@0;0004C@00C@8000A=00000Td<009=3P0000l00T`<00=<0`0014`004`;00C60`09C00404a<C0D0
00=<00000P044@80114200@A1@000d`0000300=<00<0C4`01D`00`1<00020004C<I<C0/000A<001<
0`03C0`00T`@00004@02C@/00dd00`1=00020003C@0000L00Td3aP@000==04d02Dd00`1=00030004
C@0000@A0`044@<011440003C@0000800dd00`1=C@05C@8000==00000P02C@03aTe=00T000I=0000
C@03C@/00TdB00004`02C0P000A<00000T`20003C00000P014`60003C01<00E<00D0C4`0C0040003
C00A00<A10064@@011420003C00000800d`00`1<C004C08000=<00001004C0X000=<00000T`30003
C00000H00T`D00005@02C@D000==00000P000dd0C@02C@T000==aTd00Td60004C@00C@?614d00`1=
00030003CA4A008A1@024@800Q4500@A00<0C@000`09C@<000==000010001Dg6a/I=00T00dd00`1=
00030003C@0000<00TdF00005`03C00304`000@000A<00000d`60003C036009<1`0014`00003aPA<
00<0C0000P0014`A4A47008A0P024@L00a400`1<000200Q<00G60000C00700?600<0C0001@03C0<0
00=<00000`000d`0C002C1P0000J009=1@001Dd0001=00800Td30004C@36aP9=1`000dd00004aPA=
00@0C@00114700<A0P034@L0114300M=0lH20003C@0000D01<H00`1=0002009=0P001Dd0001=00D0
0TdK00002005C0X014`00`1<C0020003C000008000=<00000P03C08000C6C<I<1`000d`00004aPI<
00<04A400Q48008A10024@P0114200M<0lH20003C00000D01<H200=<10000d`000020003C000009<
00<0C4`00T`;00A<2@0000d01dd40003C@0000M=0`000dd0000300==00C6CLK60Td60003C@3600?6
1Td44@03C@0000L00Q44008A2P044@E=00<0CLH00lH00`1=0005009=1<H3C@D000A=00001dd20003
C@0000<01dd=00005007C0@02T`00`1<0002009<0/H00d`0C0050003C03600?600=<04`00T`44@03
04`000L00a4400<A2@000d`A4@024@=<0P000dc6aP02aP0304`000@000=<04`01<H30003C01<00U<
1@07C1@0000F0003C@00008024d5aP0304e=00I=1LH500C600E=0000C@034@9=00<0C@001`024@H0
0Q4900==0a400dd000020005CLK6aTd01@001LI=a/I=00C614d02036a/I=aTd01dd30003C@0001D0
000E0003C00000H000=<00000T`5aP03C<K600?60d`>aP03C00000800Q44C0T00Q46008A2@04C08A
00=<00000P001Dc6a/I<00G600E<a/K6C00<aP04C<I<C08000=<00001P000d`0000D000050000dd0
000500E=0P04aP03CLK600E=00?60<H03<H00`1=000300M=1`034@H00a4700M=1@001Dd0a/I=00G6
00I=a/K6C@0;aP04CLH000E=1`000dd0000C00005P06C00304`000D01T`2aPI<0P06aPI<1@08C0D0
0Q48008A1@05C00404a<C0D01D`4aP03C<K600801D`7aP9<1P000d`0C005C1L0000@00I=1`000dd0
C@06C@D000?6CDd02Dd20003aTe=01==0`024@P00Q4300E=00<0CDd03Dd2aP0304e=00U=0/H500M=
00<0C@001P06CA40000;00E<2P05C0D000=<00001@0014c6aP0:C0?600<0C4`04D`34@P00a4CC003
04a<00a<00@0a/K61`000d`0000300E<2P05C0`0000800==3003C@8000==00001002C@H000I=a/K6
04d500A=0lH6C@0304e=00]=0Q4:008A3Dd00`1=C@0;C@H000==0<H00/H00dd00004009=1P000dd0
0003C@`00dd900006`000d`00004009<1`000dc6aP02aP03C00000D000=<0<H00lH9C0?61d`24@A<
0P04C08A1d`00`1<C00<C0;600<0C0001P000dc6aP02aP03C00000D00T`60003C00001X0000Q0003
C@1=00H000==0<H00lH00dd000050003C@3600?600==00001Td3aPI=0a4:C@<A3Td01`1=001=aTd0
0/H00`1=00060003CLK600;600<0C@001@000dd0C@0R0000800014`004`60003C00000?600=<0000
1P000d`0aP02aP05C00004`01003aPI<0Q4<C08A24`2aP@000Y<0000C<I<aP1<200014c6a/H20003
C00000@000A<001<8@0001l000E=0000C@050004C@0000?600==00001P000dd0aP02aP03C@000080
00A=00001<H00dd00002C@8A0dd00`1=C@02C@0404e=C@8A0Td300==0/H30003C@00008000I=aTg6
04d80004CLK6aP<000==00000`001Dd0001=0200000X0003C00000800/H00d`000080005C<K6aT`0
1@000d`00004aP03C00000@034`7009<0lH20003C00000<000E<aTc6C00:00?610000d`0000W0000
:0000dd0000200;600==00002@03aP03C@0000@000==00000lH2C@D034d600==0/H20003C@0000@0
00A=aTe=2`03aP@000==00009`0002L000=<00000`02aP03C00000T00lH00d`000050003C03600;6
0T`3011<1002C0?600<0C0001P0014c6C4`;00?61@000d`0000V00009`000dd00004009=2`03C@T0
00A=a/K65dd0101=CDd3aP03C@0000L00dd;009=1P000dd0000V00009P000d`00005009<3003C0T0
1<H:C0@02d`3aP03C00000L00lH<009<1`000d`0000U0000;@04C@X000==aTd00dd700;62Td800Y=
00?6CLH01`02C@?600==00002004CBh0000]00A<2P0014c6C4`2009<0`03aPU<3009C0C60`02C080
0lH00d`0000800A<;P0002d00dd00`1=00080005CLI=aTd00`000dg6aP03aP9=0lH2CA001dd5aP9=
0`001Dg6a/I=00T000==04d00Td^0000;@000d`0C0020003C00000H000M<aTc604`000g600=<0000
3P08C0;60T`3aP0304`000?600=<00001P001T`004`0C2h0000]0003C@1=008000==00001P000dg6
C@02aP03CLK600G60dd5aP03C@0000d00Td00lI=aP05C@K600==a/H00/H00dd000060006C@00C@1=
;P0002d000=<04`00`000d`000050003C<K600=<1LH5C0030<K600?63P04C0;600<0C4`014`3aP9<
1<H00d`000050007C00004`0C00^0000;@000dd0C@030003C@0000802Dd3aP==1002C@G63@03C@;6
0Td300E=00?6CDd00lH6C@<000M=0000C@1=02h0000/0004C00000Q<0P000d`00002C003aTa<00=<
20000dc6aP02aP`00d`00lI<C00700I<0lH20004C00000M<0`000d`0000[0000:P07C@<000==0000
0`03C@03aTe=00==3003aP9=2@05C@/01Dd3aP9=1@0014d00008CBX0000V00A<0P001D`0001<00@0
00A<00000T`2aPA<0P000d`0000:00=<00?6C4`01@000dc6C002C0d000=<04`00d`4aP05C00004`0
10001D`0001<00<00d`W0000;0001Dd0001=00@000I=04e=aTd2aP==0/H00`1=000<0003CLI=00;6
0Td00`1=C@02aP==3@0014d0a/H2C@K600==04d010001Dd0001=02d0000/0005C00004`01002C0?6
00=<aT`00/H01Tc6a/H0C0`00T`01<I<a/H3C0;60d`=0003C03600_60T`40005C00004`0;@0002`0
00E=0000C@030003CLK600?60Td30003CLK600;600==00002`0014g6aTd2aP030<I=00A=3@000dg6
aP03aP<01LH00dg6C@030005C@0004d0;@0002`000I<0000C003C0G600=<00000P000dc6aP03aP03
C00000X00T`2aP03C<K600;60d`=0003C<K600?600=<00000P0014c6aT`2aP=<00<0C0000P000d`0
000[0000:`000dd00007C@?600<0C@0010000dd0aP03aP03C@0000X00dd2aP04CLK6aPA=3005aP03
04d000@000A=04g624d20003C@0002X0000X00Q<00<0C4`00P08C08000=<00001<H00d`00007009<
00@0C4a<0/H00dc6C002C0800T`900G60P000d`00008C0800T`00`1<C006C2T0000S00E=0`03C@80
0Td20006C@00C@1=0`06C@C600==00001002C@040<K6aP9=0lH3C@G60Td60004CLK6aPM=0`000dd0
C@020003C@00009=0P03C@<01DdT00007P05C0L00T`2009<00@0C01<0P0014`004`60004C00000?6
14`00`36aP06aP=<0/H3C0O60T`00`1<C005C0<000=<0000100014`004`20004C01<009<0P02C0L0
1D`O00006`03C@/000==04d00Td3009=0P0014d00002C@D000==00000`06C@W60Td2aP==2LH6C@D0
00==00000`02C@<000==00000Td300==00<0C@002P03CA`0000Z009<1@0014`004`4009<1@000d`0
000200Q<1/H0101<aT`5aP03C00000K61d`40003C00000<00T`40004C000C0D00T`[0000:002C@03
04d000<00Td00`1=00040003C@1=00<01Td200==0`02C@@000E=0036C@03aP8000==00000P02C@<0
0dd200I=0`000dd0C@050004C@1=C@@000A=04e=:@0002H00T`20003C000008000A<001<1@000d`0
C004C08000=<00000P02C08000=<00000P02C00304`0008000?6C<H00/H30004C01<C0@000=<0000
0T`40003C00000E<00<0C000100014`004`40003C000009<9`0002@00Td40005C@0004d00P02C@80
1Dd70003C@00009=0P0014d004d5009=0`02aP03CLK600<00Td50004C@00C@800Td20003C@0000D0
1Dd2009=0P001Dd0001=00@00TdU00008`000d`000040004C000C08000=<04`00T`30003C00000H0
0d`40005C00004`00`000d`00002C0040<K6C0;600<0C4`00P001D`0001<00<000=<00000P03C0P0
00A<00000d`01@1<001<008000=<000010000d`0000R00008@02C@T000A=001=4002C@L000M=0000
C@1=00D01<H3C@D000==04d00`000dd00005009=400014d004d9009=8P0001l00T`:0004C000C100
00=<00001`000d`000020003C00000@01<H00dc6aP060003C000008000=<00001`000d`0000>0004
C000C0X00T`P00007P000dd000090003C@0001000Td;0006C@00C@1=1@03aP0404e=aPD000==04d0
0P000dd00009009=4P000dd000090003C@0001d0000Y0003C00000l00T`=0003C01<00<000A<0000
0d`300=<0`001d`0001<04`03@02C14000=<0000:00002P000==00003P02CA0000==00000`0014d0
C@02C@<00Td0101=04d50003C@0000h00Td@0003C@0002L0000W0003C00000d00T`B0003C00000@0
00A<04a<1@02C00304`000D000=<00004002C0l000=<00009P0002H000==00003002CAD000==0000
0P000dd0C@02C@D00dd00`1=00030003C@0001<00Td>0003C@0002D0000U0003C00000`000=<0000
5@001D`0001<00800d`500=<0P001D`0001<01L000=<000030000d`0000T000090000dd0000V0003
C@1=00<000==04d01@000dd0C@030003C@1=02P000==00008`0002<000=<00009`02C0<000=<0000
0T`3009<0P0014`00002C2T000=<00008P0004d00Td30003C@1=008000==04d00P000dd0C@03009=
CP0004`000=<04`00P0014`004`30005C00004`00P001T`004`0C4d0001;0007C@0004d0C@020003
C@0000D000I=001=04d30003C@0004X0001:0003C00000800T`30003C00000D000A<00000T`40003
C00004T000190003C@0000<00Td30003C@0000D000A=00000Td50003C@0004P000180003C00000@0
0T`20003C00000L000=<00000T`60003C00004L000170003C@0000@000I=001=04d90003C@1=0080
00==000010000dd000160000AP000d`000050003C000008000=<00001`000d`000020003C00000D0
00=<0000A@0004D000==00001@000dd000030003C@0000L000==00000`000dd000050003C@0004@0
00140003C00000H000=<00000`000d`000070003C00000<000=<00001P000d`000130000@`000dd0
00060003C@0000@000==00001`000dd000040003C@0000H000==0000@P00048000=<00001`000d`0
00030003C00000T000=<00000`000d`000070003C0000440001;0003C@0000@000==00002@000dd0
00040003C@0004X0001;0003C00000@000=<00002@000d`000040003C00004X0001:0003C@0000D0
00==00002@000dd000050003C@0004T0001:0003C00000D000=<00002@000d`000050003C00004T0
00190003C@0000D000==00002`000dd000050003C@0004P0001A0003C00000/000=<0000D0000540
00==00002`000dd0001@0000/P000;80002b0000/P000;80002b0000/P000;800000\
\>"],
  ImageRangeCache->{{{0, 177}, {157, 0}} -> {-0.0259726, 0.0334598, 
  0.00594319, 0.00594319}}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Implementation \[Ellipsis]"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontColor->RGBColor[1, 0, 0]],

Cell[CellGroupData[{

Cell["Generating Biomorphs", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Biomorph function", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ClearAll[biomorph]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(biomorph[params_?VectorQ, opts___] := 
      Module[{startPos, startDir, iterations}, 
        startPos = \(StartPosition /. {opts}\) /. Options[biomorph]; 
        startDir = \(StartDirection /. {opts}\) /. Options[biomorph]; 
        iterations = params\[LeftDoubleBracket]1\[RightDoubleBracket]; 
        branches = params\[LeftDoubleBracket]2\[RightDoubleBracket]; 
        globalGraphList = Table[Null, {3125}]; globalIndex = 1; 
        biomorphSubgraph[Drop[params, 1], startPos, startDir, iterations]; 
        Graphics3D[Take[globalGraphList, globalIndex - 1], 
          ViewPoint \[Rule] {0, \(-2.4\), 0}, Boxed \[Rule] False]]\)], 
  "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(biomorph[bios_?MatrixQ, opts___] := 
      Module[{}, \((biomorph[#1, opts]&)\)/@bios]\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(biomorph[bios_?ListQ, opts___] := 
      Module[{}, Show[GraphicsArray[\((biomorph[#1, opts]&)\)/@bios]]]\)], 
  "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(Options[biomorph] = {StartPosition \[Rule] {0, 0, 0}, 
        StartDirection \[Rule] 
          Transpose[{{0, 0, 1}, {1, 0, 0}, {0, \(-1\), 0}}]}; \)\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(randomBiomorphParams[] := 
      Flatten[Join[{Random[Integer, {1, 4}]}, 
          Table[randomSubBranchParameters[5, 10, 10, 10, 10], {4}]]]\)], 
  "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Utility functions", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(yawScale[x_Integer] := Range[x] - Mean[Range[x]]\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Mean[l_List] := N[Plus@@l\/Length[l]]\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\(yawMatrix[a_]
         := {{Cos[a], Sin[a], 0}, {\(-Sin[a]\), Cos[a], 0}, {0, 0, 1}}; \)\), 
  
    \(\(pitchMatrix[a_]
         := {{Cos[a], 0, \(-Sin[a]\)}, {0, 1, 0}, {Sin[a], 0, Cos[a]}}; \)\), 
  
    \(\(rollMatrix[a_]
         := {{1, 0, 0}, {0, Cos[a], \(-Sin[a]\)}, {0, Sin[a], Cos[a]}}; 
    \)\)}], "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Recursion", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(ClearAll[biomorphSubgraph]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \(biomorphSubgraph[_List, _List, _List, 0] := Module[{}, graphList]\)], 
  "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(biomorphSubgraph[params_List, pos_List, dir_List, level_Integer] := 
      Module[{branches, angle, bLength, branchDirs, branchTips, graphs}, 
        branches = params\[LeftDoubleBracket]1\[RightDoubleBracket]; 
        angle = 18\ params\[LeftDoubleBracket]2\[RightDoubleBracket]\ Degree; 
        bLength = params\[LeftDoubleBracket]3\[RightDoubleBracket]; 
        bThick = 0.002\ params\[LeftDoubleBracket]4\[RightDoubleBracket]; 
        bColor = 0.1\ params\[LeftDoubleBracket]5\[RightDoubleBracket]; 
        branchDirs = \((N[dir.yawMatrix[#1\ angle]]&)\)/@yawScale[branches]; 
        branchTips = \((pos + bLength\ First[Transpose[#1]]&)\)/@branchDirs; 
        graphs = {Thickness[bThick], Hue[bColor], 
            \((Line[{pos, #1}]&)\)/@branchTips}; 
        globalGraphList
            \[LeftDoubleBracket]\(globalIndex++\)\[RightDoubleBracket] = 
          graphs; MapThread[
          biomorphSubgraph[Drop[params, 5], #1, #2, level - 1]&, {branchTips, 
            branchDirs}]]\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell["\<\
General::spell1: 
   Possible spelling error: new symbol name \"bLength\"
     is similar to existing symbol \"Length\".\
\>", "Message",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[BoxData[
    \(randomSubBranchParameters[branches_, angle_, len_, thick_, col_] := {
        Random[Integer, {1, branches}], Random[Integer, {1, angle}], 
        Random[Integer, {1, len}], Random[Integer, {1, thick}], 
        Random[Integer, {1, col}]}\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(randomSubBranchParameters[5, 10, 10, 10, 10]\)], "Input",
  AspectRatioFixed->True],

Cell[BoxData[
    \({1, 4, 6, 2, 7}\)], "Output",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Mutation Operators", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(PointMutation[params_List, index_Integer] := 
      Module[{modTable}, 
        modTable = Flatten[{4, Table[{5, 10, 10, 10, 10}, {4}]}]; 
        MapThread[
          Modulo[#1, #2] + 1&, {
            ReplacePart[params, 
              params\[LeftDoubleBracket]index\[RightDoubleBracket] + 
                randomSelect[{\(-1\), 1}], index], modTable}]]\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell["Utility functions", "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(randomSelect[l_] := 
      l\[LeftDoubleBracket]Random[Integer, {1, Length[l]}]
          \[RightDoubleBracket]\)], "Input",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(Modulo[x_, m_] := 
      Module[{}, If[x == 0, m, If[Mod[x, m] == 0, m - 1, Mod[x, m] - 1]]]\)], 
  "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Interactive Evolution", "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(evolveBiomorphs[startBio_] := 
      Module[{selectedBio, biomorphsMut, gen = 1}, selectedBio = startBio; 
        While[True, Show[biomorph[selectedBio]]; 
          biomorphsMut = Table[PointMutation[selectedBio, i], {i, 1, 21}]; 
          Print["\<Gen \>", gen]; Print[biomorphsMut]; 
          Show[GraphicsArray[Partition[biomorph[biomorphsMut], 7]]]; 
          index = Input["\<Selected index: \>"]; If[index == 0, Break[]]; 
          selectedBio = 
            biomorphsMut\[LeftDoubleBracket]index\[RightDoubleBracket]; 
          Print["\<Gen. \>", \(gen++\), "\<, selected bio: \>"]; 
          Print[selectedBio]; ]]\)], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["References \[Ellipsis]"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Download the ",
  ButtonBox["latest version",
    ButtonData:>{
      URL[ 
      "http://www.cpsc.ucalgary.ca/~jacob/Evolvica/EA-TableOfContents.html#\
Biomorphs"], None},
    ButtonStyle->"Hyperlink"],
  " of this notebook from"
}], "Text"],

Cell["\<\
http://www.cpsc.ucalgary.ca/~jacob/Evolvica/EA-TableOfContents.html\
\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{618, 437},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Biomorphs"}]]}, {Cell[ 
        TextData[ {"Biomorphs"}]], Inherited, Inherited}},
PrintingOptions->{"FirstPageHeader"->False,
"FacingPages"->True},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> "CourseStyles.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?mooh<<H`Ui0fL5:0?l0080004/0B`000002n88o001
0000I00000400`<300000BL?00400@86oaX000000000050<01T1T00000080000
00000000003ooP5CQS3ooP000EL00000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "breeding experiment"->{
    Cell[631996, 38427, 138, 4, 25, "Text",
      CellTags->"breeding experiment"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"breeding experiment", 3356755, 321147}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 74, 2, 105, "Title"],
Cell[1808, 55, 108, 2, 61, "Subsubtitle"],

Cell[CellGroupData[{
Cell[1941, 61, 79, 2, 60, "Section"],
Cell[2023, 65, 875, 18, 179, "Text"],
Cell[2901, 85, 1635, 31, 180, "Text"],
Cell[4539, 118, 153, 3, 47, "NumberedFigure"],
Cell[4695, 123, 686, 10, 198, "Text"],
Cell[5384, 135, 17, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[5426, 139, 12095, 189, 96, 11897, 183, "GraphicsData", 
"PICT", "Graphics"],
Cell[17524, 330, 19332, 299, 96, 19157, 294, "GraphicsData", 
"PICT", "Graphics"],
Cell[36859, 631, 27856, 431, 97, 27681, 426, "GraphicsData", 
"PICT", "Graphics"]
}, Open  ]],
Cell[64730, 1065, 59, 0, 47, "NumberedFigure"],
Cell[64792, 1067, 523, 10, 122, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[65352, 1082, 79, 2, 44, "Section"],

Cell[CellGroupData[{
Cell[65456, 1088, 86, 2, 40, "Subsection"],

Cell[CellGroupData[{
Cell[65567, 1094, 62, 0, 32, "Subsubsection"],
Cell[65632, 1096, 92, 2, 45, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65761, 1103, 113, 2, 32, "Subsubsection"],

Cell[CellGroupData[{
Cell[65899, 1109, 162, 4, 49, "Input"],
Cell[66064, 1115, 8553, 228, 158, 1188, 132, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[74632, 1346, 80, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[74737, 1352, 162, 4, 49, "Input"],
Cell[74902, 1358, 11316, 363, 151, 2052, 244, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[86233, 1724, 80, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[86338, 1730, 162, 4, 49, "Input"],
Cell[86503, 1736, 8790, 275, 140, 1560, 181, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[95308, 2014, 80, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[95413, 2020, 162, 4, 49, "Input"],
Cell[95578, 2026, 7680, 217, 145, 1202, 132, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[103273, 2246, 80, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[103378, 2252, 162, 4, 49, "Input"],
Cell[103543, 2258, 9638, 279, 147, 1528, 174, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[113196, 2540, 81, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[113302, 2546, 162, 4, 49, "Input"],
Cell[113467, 2552, 9462, 265, 152, 1408, 160, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[122944, 2820, 81, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[123050, 2826, 162, 4, 49, "Input"],
Cell[123215, 2832, 8297, 225, 152, 1202, 132, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[131527, 3060, 91, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[131643, 3066, 162, 4, 49, "Input"],
Cell[131808, 3072, 8367, 226, 155, 1188, 132, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[140190, 3301, 80, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[140295, 3307, 162, 4, 49, "Input"],
Cell[140460, 3313, 6928, 157, 169, 771, 76, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[147403, 3473, 80, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[147508, 3479, 162, 4, 49, "Input"],
Cell[147673, 3485, 7886, 175, 233, 830, 83, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[155574, 3663, 80, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[155679, 3669, 162, 4, 49, "Input"],
Cell[155844, 3675, 6864, 169, 173, 879, 90, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[162723, 3847, 80, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[162828, 3853, 162, 4, 49, "Input"],
Cell[162993, 3859, 8595, 228, 163, 1197, 132, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[171603, 4090, 81, 2, 25, "Text"],

Cell[CellGroupData[{
Cell[171709, 4096, 162, 4, 49, "Input"],
Cell[171874, 4102, 8620, 229, 161, 1194, 132, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[180543, 4337, 85, 2, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[180653, 4343, 131, 3, 44, "Input"],
Cell[180787, 4348, 1239, 18, 239, "Output"],
Cell[182029, 4368, 101634, 8719, 266, 64792, 8259, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[283712, 13093, 85, 2, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[283822, 13099, 131, 3, 44, "Input"],
Cell[283956, 13104, 1241, 18, 239, "Output"],
Cell[285200, 13124, 51152, 3292, 266, 24714, 2960, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[336401, 16422, 85, 2, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[336511, 16428, 131, 3, 44, "Input"],
Cell[336645, 16433, 1232, 17, 239, "Output"],
Cell[337880, 16452, 43982, 2529, 266, 19226, 2218, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[381911, 18987, 85, 2, 24, "Subsubsection"],

Cell[CellGroupData[{
Cell[382021, 18993, 131, 3, 60, "Input"],
Cell[382155, 18998, 1258, 18, 254, "Output"],
Cell[383416, 19018, 126127, 12234, 266, 92087, 11808, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[509592, 31258, 85, 2, 29, "Subsubsection"],

Cell[CellGroupData[{
Cell[509702, 31264, 131, 3, 39, "Input"],
Cell[509836, 31269, 1245, 18, 207, "Output"],
Cell[511084, 31289, 62897, 4404, 266, 33146, 4031, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[574042, 35700, 86, 2, 34, "Subsection"],

Cell[CellGroupData[{
Cell[574153, 35706, 91, 2, 29, "Input"],
Cell[574247, 35710, 150, 4, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[574434, 35719, 82, 2, 29, "Input"],
Cell[574519, 35723, 7334, 181, 261, 910, 97, "GraphicsData", 
"PostScript", "Graphics"],
Cell[581856, 35906, 180, 5, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[582073, 35916, 120, 3, 29, "Input"],
Cell[582196, 35921, 1668, 23, 329, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[583901, 35949, 125, 3, 29, "Input"],
Cell[584029, 35954, 47629, 2455, 191, 19085, 2096, "GraphicsData", 
"PostScript", "Graphics"],
Cell[631661, 38411, 183, 5, 29, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[631905, 38423, 88, 2, 44, "Section"],
Cell[631996, 38427, 138, 4, 25, "Text",
  CellTags->"breeding experiment"],

Cell[CellGroupData[{
Cell[632159, 38435, 98, 2, 45, "Input"],
Cell[632260, 38439, 33255, 425, 19, "Print",
  CellOpen->False],

Cell[CellGroupData[{
Cell[665540, 38868, 4120, 148, 125, 976, 104, "GraphicsData", 
"PostScript", "Graphics"],
Cell[669663, 39018, 30438, 2453, 116, 21295, 2334, "GraphicsData", 
"PostScript", "Graphics"],
Cell[700104, 41473, 6518, 304, 133, 2049, 244, "GraphicsData", 
"PostScript", "Graphics"],
Cell[706625, 41779, 29207, 2273, 116, 19909, 2152, "GraphicsData", 
"PostScript", "Graphics"],
Cell[735835, 44054, 6564, 203, 208, 1200, 132, "GraphicsData", 
"PostScript", "Graphics"],
Cell[742402, 44259, 42451, 3145, 116, 26037, 2936, "GraphicsData", 
"PostScript", "Graphics"],
Cell[784856, 47406, 9695, 432, 200, 2848, 342, "GraphicsData", 
"PostScript", "Graphics"],
Cell[794554, 47840, 41162, 3015, 116, 25085, 2810, "GraphicsData", 
"PostScript", "Graphics"],
Cell[835719, 50857, 7099, 248, 200, 1540, 174, "GraphicsData", 
"PostScript", "Graphics"],
Cell[842821, 51107, 47842, 3774, 116, 30965, 3559, "GraphicsData", 
"PostScript", "Graphics"],
Cell[890666, 54883, 7720, 332, 185, 2152, 258, "GraphicsData", 
"PostScript", "Graphics"],
Cell[898389, 55217, 60047, 5387, 116, 42888, 5169, "GraphicsData", 
"PostScript", "Graphics"],
Cell[958439, 60606, 9156, 426, 188, 2790, 342, "GraphicsData", 
"PostScript", "Graphics"],
Cell[967598, 61034, 78710, 7572, 116, 59168, 7325, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1046311, 68608, 10582, 532, 165, 3541, 440, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1056896, 69142, 93482, 9462, 116, 73419, 9208, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1150381, 78606, 10508, 531, 156, 3531, 440, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1160892, 79139, 87438, 8855, 116, 68932, 8620, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1248333, 87996, 13232, 750, 159, 5015, 643, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1261568, 88748, 119570, 13104, 116, 100468, 12862, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1381141, 101854, 14351, 896, 162, 6163, 790, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1395495, 102752, 149748, 17024, 116, 130080, 16775, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1545246, 119778, 14013, 892, 170, 6136, 790, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1559262, 120672, 130502, 14579, 116, 111541, 14339, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1689767, 135253, 14168, 894, 192, 6162, 790, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1703938, 136149, 136945, 15400, 116, 117822, 15158, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1840886, 151551, 16680, 1154, 165, 8059, 1042, "GraphicsData", 
"PostScript", "Graphics"],
Cell[1857569, 152707, 166958, 19301, 116, 147679, 19057, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2024530, 172010, 19858, 1192, 165, 8139, 1042, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2044391, 173204, 168632, 19356, 116, 149425, 19113, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2213026, 192562, 21268, 1209, 163, 8167, 1042, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2234297, 193773, 169298, 19361, 116, 149699, 19113, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2403598, 213136, 24943, 1508, 160, 10327, 1322, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2428544, 214646, 227619, 26861, 116, 207203, 26603, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2656166, 241509, 30515, 2084, 157, 14596, 1882, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2686684, 243595, 307550, 37509, 116, 288776, 37271, "GraphicsData", 
"PostScript", "Graphics"],
Cell[2994237, 281106, 32285, 2105, 157, 14597, 1882, "GraphicsData", 
"PostScript", "Graphics"],
Cell[3026525, 283213, 293541, 35919, 116, 276587, 35703, "GraphicsData", 
"PostScript", "Graphics"],
Cell[3320069, 319134, 27704, 1719, 166, 11805, 1518, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[3347834, 320860, 135, 3, 44, "Section"],

Cell[CellGroupData[{
Cell[3347994, 320867, 90, 2, 40, "Subsection"],

Cell[CellGroupData[{
Cell[3348109, 320873, 90, 2, 32, "Subsubsection"],
Cell[3348202, 320877, 77, 2, 34, "Input"],
Cell[3348282, 320881, 728, 13, 169, "Input",
  InitializationCell->True],
Cell[3349013, 320896, 173, 4, 49, "Input",
  InitializationCell->True],
Cell[3349189, 320902, 195, 5, 49, "Input",
  InitializationCell->True],
Cell[3349387, 320909, 240, 5, 64, "Input",
  InitializationCell->True],
Cell[3349630, 320916, 232, 6, 64, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3349899, 320927, 90, 2, 24, "Subsubsection"],
Cell[3349992, 320931, 135, 3, 70, "Input",
  InitializationCell->True],
Cell[3350130, 320936, 124, 3, 70, "Input",
  InitializationCell->True],
Cell[3350257, 320941, 395, 11, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3350689, 320957, 82, 2, 24, "Subsubsection"],
Cell[3350774, 320961, 85, 2, 34, "Input"],
Cell[3350862, 320965, 155, 4, 49, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[3351042, 320973, 1084, 18, 214, "Input",
  InitializationCell->True],
Cell[3352129, 320993, 195, 6, 50, "Message"]
}, Open  ]],
Cell[3352339, 321002, 326, 6, 79, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[3352690, 321012, 103, 2, 34, "Input"],
Cell[3352796, 321016, 97, 3, 22, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3352954, 321026, 88, 2, 26, "Subsection"],
Cell[3353045, 321030, 443, 10, 109, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[3353513, 321044, 90, 2, 32, "Subsubsection"],
Cell[3353606, 321048, 198, 5, 70, "Input",
  InitializationCell->True],
Cell[3353807, 321055, 182, 5, 70, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3354038, 321066, 91, 2, 26, "Subsection"],
Cell[3354132, 321070, 689, 12, 169, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3354870, 321088, 99, 2, 44, "Section"],
Cell[3354972, 321092, 261, 9, 27, "Text"],
Cell[3355236, 321103, 93, 3, 46, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

